@@ -1,5 +1,4 @@
 #!/usr/bin/python
-from __future__ import print_function
 
 import getopt
 import os
@@ -49,9 +48,8 @@ def main(argv):
     if target == "":
         display_help()
 
-    if sys.version_info >= (3, 0):
-        search = search.encode("utf-8")
-        replace = replace.encode("utf-8")
+    search = search.encode("utf-8")
+    replace = replace.encode("utf-8")
     f = open(target, "rb").read()
     f = f.replace(search, replace)
     f = f.replace(search.lower(), replace)
