@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Beacon to fire event when we notice a AIX user is locked due to many failed login attempts.
 
@@ -6,10 +5,6 @@ Beacon to fire event when we notice a AIX user is locked due to many failed logi
 
 :depends: none
 """
-
-# Import Python libs
-from __future__ import absolute_import, unicode_literals
-
 import logging
 
 log = logging.getLogger(__name__)
@@ -21,13 +16,12 @@ def __virtual__():
     """
     Only load if kernel is AIX
     """
-    if __grains__["kernel"] == ("AIX"):
+    if __grains__["kernel"] == "AIX":
         return __virtualname__
 
     return (
         False,
-        "The aix_account beacon module failed to load: "
-        "only available on AIX systems.",
+        "The aix_account beacon module failed to load: only available on AIX systems.",
     )
 
 
@@ -37,14 +31,11 @@ def validate(config):
     """
     # Configuration for aix_account beacon should be a dictionary
     if not isinstance(config, dict):
-        return False, ("Configuration for aix_account beacon must be a dict.")
+        return False, "Configuration for aix_account beacon must be a dict."
     if "user" not in config:
         return (
             False,
-            (
-                "Configuration for aix_account beacon must "
-                "include a user or ALL for all users."
-            ),
+            "Configuration for aix_account beacon must include a user or ALL for all users.",
         )
     return True, "Valid beacon configuration"
 
