@@ -1,18 +1,12 @@
-# -*- coding: utf-8 -*-
 """
 Beacon to emit when a display is available to a linux machine
 
 .. versionadded:: 2016.3.0
 """
-
-# Import Python libs
-from __future__ import absolute_import, unicode_literals
-
 import logging
 
-# Salt libs
+import salt.utils.beacons
 import salt.utils.path
-from salt.ext.six.moves import map
 
 log = logging.getLogger(__name__)
 
@@ -36,18 +30,14 @@ def validate(config):
     """
     # Configuration for glxinfo beacon should be a dictionary
     if not isinstance(config, list):
-        return False, ("Configuration for glxinfo beacon must be a list.")
+        return False, "Configuration for glxinfo beacon must be a list."
 
-    _config = {}
-    list(map(_config.update, config))
+    config = salt.utils.beacons.list_to_dict(config)
 
-    if "user" not in _config:
+    if "user" not in config:
         return (
             False,
-            (
-                "Configuration for glxinfo beacon must "
-                "include a user as glxinfo is not available to root."
-            ),
+            "Configuration for glxinfo beacon must include a user as glxinfo is not available to root.",
         )
     return True, "Valid beacon configuration"
 
@@ -71,14 +61,13 @@ def beacon(config):
     log.trace("glxinfo beacon starting")
     ret = []
 
-    _config = {}
-    list(map(_config.update, config))
+    config = salt.utils.beacons.list_to_dict(config)
 
     retcode = __salt__["cmd.retcode"](
-        "DISPLAY=:0 glxinfo", runas=_config["user"], python_shell=True
+        "DISPLAY=:0 glxinfo", runas=config["user"], python_shell=True
     )
 
-    if "screen_event" in _config and _config["screen_event"]:
+    if "screen_event" in config and config["screen_event"]:
         last_value = last_state.get("screen_available", False)
         screen_available = retcode == 0
         if last_value != screen_available or "screen_available" not in last_state:
