@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Watch files and translate the changes into salt events
 
 :depends:   - pyinotify Python module >= 0.9.5
@@ -13,36 +12,31 @@ Watch files and translate the changes into salt events
 :note: The `inotify` beacon only works on OSes that have `inotify`
        kernel support.
 
-'''
-# Import Python libs
-from __future__ import absolute_import, unicode_literals
+"""
+
 import collections
 import fnmatch
 import logging
 import os
 import re
 
-# Import salt libs
-import salt.ext.six
-# pylint: disable=import-error
-from salt.ext.six.moves import map
-# pylint: enable=import-error
+import salt.utils.beacons
 
-# Import third party libs
 try:
     import pyinotify
+
     HAS_PYINOTIFY = True
     DEFAULT_MASK = pyinotify.IN_CREATE | pyinotify.IN_DELETE | pyinotify.IN_MODIFY
     MASKS = {}
     for var in dir(pyinotify):
-        if var.startswith('IN_'):
+        if var.startswith("IN_"):
             key = var[3:].lower()
             MASKS[key] = getattr(pyinotify, var)
 except ImportError:
     HAS_PYINOTIFY = False
     DEFAULT_MASK = None
 
-__virtualname__ = 'inotify'
+__virtualname__ = "inotify"
 
 log = logging.getLogger(__name__)
 
@@ -54,104 +48,131 @@ def __virtual__():
 
 
 def _get_mask(mask):
-    '''
+    """
     Return the int that represents the mask
-    '''
+    """
     return MASKS.get(mask, 0)
 
 
 def _enqueue(revent):
-    '''
+    """
     Enqueue the event
-    '''
-    __context__['inotify.queue'].append(revent)
+    """
+    __context__["inotify.queue"].append(revent)
 
 
 def _get_notifier(config):
-    '''
+    """
     Check the context for the notifier and construct it if not present
-    '''
-    if 'inotify.notifier' not in __context__:
-        __context__['inotify.queue'] = collections.deque()
+    """
+    beacon_name = config.get("_beacon_name", "inotify")
+    notifier = "{}.notifier".format(beacon_name)
+    if notifier not in __context__:
+        __context__["inotify.queue"] = collections.deque()
         wm = pyinotify.WatchManager()
-        __context__['inotify.notifier'] = pyinotify.Notifier(wm, _enqueue)
-        if ('coalesce' in config and
-                isinstance(config['coalesce'], bool) and
-                config['coalesce']):
-            __context__['inotify.notifier'].coalesce_events()
-    return __context__['inotify.notifier']
+        __context__[notifier] = pyinotify.Notifier(wm, _enqueue)
+        if (
+            "coalesce" in config
+            and isinstance(config["coalesce"], bool)
+            and config["coalesce"]
+        ):
+            __context__[notifier].coalesce_events()
+    return __context__[notifier]
 
 
 def validate(config):
-    '''
+    """
     Validate the beacon configuration
-    '''
+    """
 
     VALID_MASK = [
-        'access',
-        'attrib',
-        'close_nowrite',
-        'close_write',
-        'create',
-        'delete',
-        'delete_self',
-        'excl_unlink',
-        'ignored',
-        'modify',
-        'moved_from',
-        'moved_to',
-        'move_self',
-        'oneshot',
-        'onlydir',
-        'open',
-        'unmount'
+        "access",
+        "attrib",
+        "close_nowrite",
+        "close_write",
+        "create",
+        "delete",
+        "delete_self",
+        "excl_unlink",
+        "ignored",
+        "modify",
+        "moved_from",
+        "moved_to",
+        "move_self",
+        "oneshot",
+        "onlydir",
+        "open",
+        "unmount",
     ]
 
     # Configuration for inotify beacon should be a dict of dicts
     if not isinstance(config, list):
-        return False, 'Configuration for inotify beacon must be a list.'
+        return False, "Configuration for inotify beacon must be a list."
     else:
-        _config = {}
-        list(map(_config.update, config))
+        config = salt.utils.beacons.list_to_dict(config)
 
-        if 'files' not in _config:
-            return False, 'Configuration for inotify beacon must include files.'
+        if "files" not in config:
+            return False, "Configuration for inotify beacon must include files."
         else:
-            for path in _config.get('files'):
+            if not isinstance(config["files"], dict):
+                return (
+                    False,
+                    "Configuration for inotify beacon invalid, files must be a dict.",
+                )
 
-                if not isinstance(_config['files'][path], dict):
-                    return False, ('Configuration for inotify beacon must '
-                                   'be a list of dictionaries.')
+            for path in config.get("files"):
+
+                if not isinstance(config["files"][path], dict):
+                    return (
+                        False,
+                        "Configuration for inotify beacon must be a list of"
+                        " dictionaries.",
+                    )
                 else:
-                    if not any(j in ['mask',
-                                     'recurse',
-                                     'auto_add'] for j in _config['files'][path]):
-                        return False, ('Configuration for inotify beacon must '
-                                       'contain mask, recurse or auto_add items.')
+                    if not any(
+                        j in ["mask", "recurse", "auto_add"]
+                        for j in config["files"][path]
+                    ):
+                        return (
+                            False,
+                            "Configuration for inotify beacon must contain mask,"
+                            " recurse or auto_add items.",
+                        )
 
-                    if 'auto_add' in _config['files'][path]:
-                        if not isinstance(_config['files'][path]['auto_add'], bool):
-                            return False, ('Configuration for inotify beacon '
-                                           'auto_add must be boolean.')
+                    if "auto_add" in config["files"][path]:
+                        if not isinstance(config["files"][path]["auto_add"], bool):
+                            return (
+                                False,
+                                "Configuration for inotify beacon auto_add must be"
+                                " boolean.",
+                            )
 
-                    if 'recurse' in _config['files'][path]:
-                        if not isinstance(_config['files'][path]['recurse'], bool):
-                            return False, ('Configuration for inotify beacon '
-                                           'recurse must be boolean.')
+                    if "recurse" in config["files"][path]:
+                        if not isinstance(config["files"][path]["recurse"], bool):
+                            return (
+                                False,
+                                "Configuration for inotify beacon recurse must be"
+                                " boolean.",
+                            )
 
-                    if 'mask' in _config['files'][path]:
-                        if not isinstance(_config['files'][path]['mask'], list):
-                            return False, ('Configuration for inotify beacon '
-                                           'mask must be list.')
-                        for mask in _config['files'][path]['mask']:
+                    if "mask" in config["files"][path]:
+                        if not isinstance(config["files"][path]["mask"], list):
+                            return (
+                                False,
+                                "Configuration for inotify beacon mask must be list.",
+                            )
+                        for mask in config["files"][path]["mask"]:
                             if mask not in VALID_MASK:
-                                return False, ('Configuration for inotify beacon '
-                                               'invalid mask option {0}.'.format(mask))
-    return True, 'Valid beacon configuration'
+                                return (
+                                    False,
+                                    "Configuration for inotify beacon invalid mask"
+                                    " option {}.".format(mask),
+                                )
+    return True, "Valid beacon configuration"
 
 
 def beacon(config):
-    '''
+    """
     Watch the configured files
 
     Example Config
@@ -214,46 +235,48 @@ def beacon(config):
       This option is top-level (at the same level as the path) and therefore
       affects all paths that are being watched. This is due to this option
       being at the Notifier level in pyinotify.
-    '''
-    _config = {}
-    list(map(_config.update, config))
+    """
+
+    whitelist = ["_beacon_name"]
+    config = salt.utils.beacons.remove_hidden_options(config, whitelist)
+
+    config = salt.utils.beacons.list_to_dict(config)
 
     ret = []
-    notifier = _get_notifier(_config)
+    notifier = _get_notifier(config)
     wm = notifier._watch_manager
 
     # Read in existing events
     if notifier.check_events(1):
         notifier.read_events()
         notifier.process_events()
-        queue = __context__['inotify.queue']
+        queue = __context__["inotify.queue"]
         while queue:
             event = queue.popleft()
 
             _append = True
             # Find the matching path in config
             path = event.path
-            while path != '/':
-                if path in _config.get('files', {}):
+            while path != "/":
+                if path in config.get("files", {}):
                     break
                 path = os.path.dirname(path)
 
-            for path in _config.get('files', {}):
-                excludes = _config['files'][path].get('exclude', '')
+            excludes = config["files"].get(path, {}).get("exclude", "")
 
             if excludes and isinstance(excludes, list):
                 for exclude in excludes:
                     if isinstance(exclude, dict):
-                        if exclude.values()[0].get('regex', False):
+                        _exclude = next(iter(exclude))
+                        if exclude[_exclude].get("regex", False):
                             try:
-                                if re.search(list(exclude)[0], event.pathname):
+                                if re.search(_exclude, event.pathname):
                                     _append = False
-                            except Exception:
-                                log.warning('Failed to compile regex: %s',
-                                            list(exclude)[0])
+                            except Exception:  # pylint: disable=broad-except
+                                log.warning("Failed to compile regex: %s", _exclude)
                         else:
-                            exclude = list(exclude)[0]
-                    elif '*' in exclude:
+                            exclude = _exclude
+                    elif "*" in exclude:
                         if fnmatch.fnmatch(event.pathname, exclude):
                             _append = False
                     else:
@@ -261,12 +284,14 @@ def beacon(config):
                             _append = False
 
             if _append:
-                sub = {'tag': event.path,
-                       'path': event.pathname,
-                       'change': event.maskname}
+                sub = {
+                    "tag": event.path,
+                    "path": event.pathname,
+                    "change": event.maskname,
+                }
                 ret.append(sub)
             else:
-                log.info('Excluding %s from event for %s', event.pathname, path)
+                log.info("Excluding %s from event for %s", event.pathname, path)
 
     # Get paths currently being watched
     current = set()
@@ -275,21 +300,21 @@ def beacon(config):
 
     # Update existing watches and add new ones
     # TODO: make the config handle more options
-    for path in _config.get('files', ()):
+    for path in config.get("files", ()):
 
-        if isinstance(_config['files'][path], dict):
-            mask = _config['files'][path].get('mask', DEFAULT_MASK)
+        if isinstance(config["files"][path], dict):
+            mask = config["files"][path].get("mask", DEFAULT_MASK)
             if isinstance(mask, list):
                 r_mask = 0
                 for sub in mask:
                     r_mask |= _get_mask(sub)
-            elif isinstance(mask, salt.ext.six.binary_type):
+            elif isinstance(mask, bytes):
                 r_mask = _get_mask(mask)
             else:
                 r_mask = mask
             mask = r_mask
-            rec = _config['files'][path].get('recurse', False)
-            auto_add = _config['files'][path].get('auto_add', False)
+            rec = config["files"][path].get("recurse", False)
+            auto_add = config["files"][path].get("auto_add", False)
         else:
             mask = DEFAULT_MASK
             rec = False
@@ -306,13 +331,13 @@ def beacon(config):
                     if update:
                         wm.update_watch(wd, mask=mask, rec=rec, auto_add=auto_add)
         elif os.path.exists(path):
-            excludes = _config['files'][path].get('exclude', '')
+            excludes = config["files"][path].get("exclude", "")
             excl = None
             if isinstance(excludes, list):
                 excl = []
                 for exclude in excludes:
                     if isinstance(exclude, dict):
-                        excl.append(exclude.keys()[0])
+                        excl.append(list(exclude)[0])
                     else:
                         excl.append(exclude)
                 excl = pyinotify.ExcludeFilter(excl)
@@ -324,6 +349,9 @@ def beacon(config):
 
 
 def close(config):
-    if 'inotify.notifier' in __context__:
-        __context__['inotify.notifier'].stop()
-        del __context__['inotify.notifier']
+    config = salt.utils.beacons.list_to_dict(config)
+    beacon_name = config.get("_beacon_name", "inotify")
+    notifier = "{}.notifier".format(beacon_name)
+    if notifier in __context__:
+        __context__[notifier].stop()
+        del __context__[notifier]
