@@ -1,24 +1,21 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, print_function, unicode_literals
-
+import salt.defaults.exitcodes  # pylint: disable=W0611
 import salt.utils.parsers
 import salt.utils.profile
-from salt.utils.verify import check_user, verify_log
 from salt.exceptions import SaltClientError
-from salt.ext import six
-import salt.defaults.exitcodes  # pylint: disable=W0611
+from salt.utils.verify import check_user, verify_log
 
 
 class SaltRun(salt.utils.parsers.SaltRunOptionParser):
-    '''
+    """
     Used to execute Salt runners
-    '''
+    """
 
     def run(self):
-        '''
+        """
         Execute salt-run
-        '''
+        """
         import salt.runner
+
         self.parse_args()
 
         # Setup file logging!
@@ -34,7 +31,7 @@ class SaltRun(salt.utils.parsers.SaltRunOptionParser):
         # Run this here so SystemExit isn't raised anywhere else when
         # someone tries to use the runners via the python API
         try:
-            if check_user(self.config['user']):
+            if check_user(self.config["user"]):
                 pr = salt.utils.profile.activate_profile(profiling_enabled)
                 try:
                     ret = runner.run()
@@ -44,15 +41,14 @@ class SaltRun(salt.utils.parsers.SaltRunOptionParser):
                     # runners might still use it. For this reason, we
                     # also check ret['data']['retcode'] if
                     # ret['retcode'] is not available.
-                    if isinstance(ret, dict) and 'retcode' in ret:
-                        self.exit(ret['retcode'])
-                    elif isinstance(ret, dict) and 'retcode' in ret.get('data', {}):
-                        self.exit(ret['data']['retcode'])
+                    if isinstance(ret, dict) and "retcode" in ret:
+                        self.exit(ret["retcode"])
+                    elif isinstance(ret, dict) and "retcode" in ret.get("data", {}):
+                        self.exit(ret["data"]["retcode"])
                 finally:
                     salt.utils.profile.output_profile(
-                        pr,
-                        stats_path=self.options.profiling_path,
-                        stop=True)
+                        pr, stats_path=self.options.profiling_path, stop=True
+                    )
 
         except SaltClientError as exc:
-            raise SystemExit(six.text_type(exc))
+            raise SystemExit(str(exc))
