@@ -22,7 +22,7 @@ provided `kubeconfig` entry is preferred.
 
     salt '*' kubernetes.nodes kubeconfig=/etc/salt/k8s/kubeconfig context=minikube
 
-.. versionadded: 2017.7.0
+.. versionadded:: 2017.7.0
 .. versionchanged:: 2019.2.0
 
 .. warning::
@@ -43,7 +43,6 @@ provided `kubeconfig` entry is preferred.
 
 """
 
-
 import base64
 import errno
 import logging
@@ -51,16 +50,14 @@ import os.path
 import signal
 import sys
 import tempfile
+import time
 from contextlib import contextmanager
-from time import sleep
 
 import salt.utils.files
 import salt.utils.platform
 import salt.utils.templates
 import salt.utils.yaml
 from salt.exceptions import CommandExecutionError, TimeoutError
-from salt.ext.six import iteritems
-from salt.ext.six.moves import range  # pylint: disable=import-error
 
 try:
     import kubernetes  # pylint: disable=import-self
@@ -216,11 +213,13 @@ def _setup_conn(**kwargs):
                 return _setup_conn_old(**kwargs)
             except Exception:  # pylint: disable=broad-except
                 raise CommandExecutionError(
-                    "Old style kubernetes configuration is only supported up to python-kubernetes 2.0.0"
+                    "Old style kubernetes configuration is only supported up to"
+                    " python-kubernetes 2.0.0"
                 )
         else:
             raise CommandExecutionError(
-                "Invalid kubernetes configuration. Parameter 'kubeconfig' and 'context' are required."
+                "Invalid kubernetes configuration. Parameter 'kubeconfig' and 'context'"
+                " are required."
             )
     kubernetes.config.load_kube_config(config_file=kubeconfig, context=context)
 
@@ -271,6 +270,9 @@ def ping(**kwargs):
     Returns True if the connection can be established, False otherwise.
 
     CLI Example:
+
+    .. code-block:: bash
+
         salt '*' kubernetes.ping
     """
     status = True
@@ -286,7 +288,9 @@ def nodes(**kwargs):
     """
     Return the names of the nodes composing the kubernetes cluster
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.nodes
         salt '*' kubernetes.nodes kubeconfig=/etc/salt/k8s/kubeconfig context=minikube
@@ -314,7 +318,9 @@ def node(name, **kwargs):
     """
     Return the details of the node identified by the specified name
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.node name='minikube'
     """
@@ -342,7 +348,9 @@ def node_labels(name, **kwargs):
     """
     Return the labels of the node identified by the specified name
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.node_labels name="minikube"
     """
@@ -360,7 +368,9 @@ def node_add_label(node_name, label_name, label_value, **kwargs):
     the node identified by the name `node_name`.
     Creates the label if not present.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.node_add_label node_name="minikube" \
             label_name="foo" label_value="bar"
@@ -388,7 +398,9 @@ def node_remove_label(node_name, label_name, **kwargs):
     Removes the label identified by `label_name` from
     the node identified by the name `node_name`.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.node_remove_label node_name="minikube" \
             label_name="foo"
@@ -415,7 +427,9 @@ def namespaces(**kwargs):
     """
     Return the names of the available namespaces
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.namespaces
         salt '*' kubernetes.namespaces kubeconfig=/etc/salt/k8s/kubeconfig context=minikube
@@ -440,7 +454,9 @@ def deployments(namespace="default", **kwargs):
     """
     Return a list of kubernetes deployments defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.deployments
         salt '*' kubernetes.deployments namespace=default
@@ -468,7 +484,9 @@ def services(namespace="default", **kwargs):
     """
     Return a list of kubernetes services defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.services
         salt '*' kubernetes.services namespace=default
@@ -483,9 +501,7 @@ def services(namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->list_namespaced_service"
-            )
+            log.exception("Exception when calling CoreV1Api->list_namespaced_service")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -495,7 +511,9 @@ def pods(namespace="default", **kwargs):
     """
     Return a list of kubernetes pods defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.pods
         salt '*' kubernetes.pods namespace=default
@@ -510,7 +528,7 @@ def pods(namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->list_namespaced_pod")
+            log.exception("Exception when calling CoreV1Api->list_namespaced_pod")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -520,7 +538,9 @@ def secrets(namespace="default", **kwargs):
     """
     Return a list of kubernetes secrets defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.secrets
         salt '*' kubernetes.secrets namespace=default
@@ -537,7 +557,7 @@ def secrets(namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->list_namespaced_secret")
+            log.exception("Exception when calling CoreV1Api->list_namespaced_secret")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -547,7 +567,9 @@ def configmaps(namespace="default", **kwargs):
     """
     Return a list of kubernetes configmaps defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.configmaps
         salt '*' kubernetes.configmaps namespace=default
@@ -565,7 +587,7 @@ def configmaps(namespace="default", **kwargs):
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->list_namespaced_config_map"
+                "Exception when calling CoreV1Api->list_namespaced_config_map"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -576,7 +598,9 @@ def show_deployment(name, namespace="default", **kwargs):
     """
     Return the kubernetes deployment defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_deployment my-nginx default
         salt '*' kubernetes.show_deployment name=my-nginx namespace=default
@@ -604,7 +628,9 @@ def show_service(name, namespace="default", **kwargs):
     """
     Return the kubernetes service defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_service my-nginx default
         salt '*' kubernetes.show_service name=my-nginx namespace=default
@@ -619,9 +645,7 @@ def show_service(name, namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->read_namespaced_service"
-            )
+            log.exception("Exception when calling CoreV1Api->read_namespaced_service")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -631,7 +655,9 @@ def show_pod(name, namespace="default", **kwargs):
     """
     Return POD information for a given pod name defined in the namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_pod guestbook-708336848-fqr2x
         salt '*' kubernetes.show_pod guestbook-708336848-fqr2x namespace=default
@@ -646,7 +672,7 @@ def show_pod(name, namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->read_namespaced_pod")
+            log.exception("Exception when calling CoreV1Api->read_namespaced_pod")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -656,7 +682,9 @@ def show_namespace(name, **kwargs):
     """
     Return information for a given namespace defined by the specified name
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_namespace kube-system
     """
@@ -670,7 +698,7 @@ def show_namespace(name, **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->read_namespace")
+            log.exception("Exception when calling CoreV1Api->read_namespace")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -682,7 +710,9 @@ def show_secret(name, namespace="default", decode=False, **kwargs):
     The secrets can be decoded if specified by the user. Warning: this has
     security implications.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_secret confidential default
         salt '*' kubernetes.show_secret name=confidential namespace=default
@@ -703,7 +733,7 @@ def show_secret(name, namespace="default", decode=False, **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->read_namespaced_secret")
+            log.exception("Exception when calling CoreV1Api->read_namespaced_secret")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -713,7 +743,9 @@ def show_configmap(name, namespace="default", **kwargs):
     """
     Return the kubernetes configmap defined by name and namespace.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.show_configmap game-config default
         salt '*' kubernetes.show_configmap name=game-config namespace=default
@@ -729,7 +761,7 @@ def show_configmap(name, namespace="default", **kwargs):
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->read_namespaced_config_map"
+                "Exception when calling CoreV1Api->read_namespaced_config_map"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -740,7 +772,9 @@ def delete_deployment(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes deployment defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_deployment my-nginx
         salt '*' kubernetes.delete_deployment name=my-nginx namespace=default
@@ -758,7 +792,7 @@ def delete_deployment(name, namespace="default", **kwargs):
             try:
                 with _time_limit(POLLING_TIME_LIMIT):
                     while show_deployment(name, namespace) is not None:
-                        sleep(1)
+                        time.sleep(1)
                     else:  # pylint: disable=useless-else-on-loop
                         mutable_api_response["code"] = 200
             except TimeoutError:
@@ -771,7 +805,7 @@ def delete_deployment(name, namespace="default", **kwargs):
                     mutable_api_response["code"] = 200
                     break
                 else:
-                    sleep(1)
+                    time.sleep(1)
         if mutable_api_response["code"] != 200:
             log.warning(
                 "Reached polling time limit. Deployment is not yet "
@@ -796,7 +830,9 @@ def delete_service(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes service defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_service my-nginx default
         salt '*' kubernetes.delete_service name=my-nginx namespace=default
@@ -824,7 +860,9 @@ def delete_pod(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes pod defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_pod guestbook-708336848-5nl8c default
         salt '*' kubernetes.delete_pod name=guestbook-708336848-5nl8c namespace=default
@@ -843,7 +881,7 @@ def delete_pod(name, namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->delete_namespaced_pod")
+            log.exception("Exception when calling CoreV1Api->delete_namespaced_pod")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -853,7 +891,9 @@ def delete_namespace(name, **kwargs):
     """
     Deletes the kubernetes namespace defined by name
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_namespace salt
         salt '*' kubernetes.delete_namespace name=salt
@@ -869,7 +909,7 @@ def delete_namespace(name, **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->delete_namespace")
+            log.exception("Exception when calling CoreV1Api->delete_namespace")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -879,7 +919,9 @@ def delete_secret(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes secret defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_secret confidential default
         salt '*' kubernetes.delete_secret name=confidential namespace=default
@@ -908,7 +950,9 @@ def delete_configmap(name, namespace="default", **kwargs):
     """
     Deletes the kubernetes configmap defined by name and namespace
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' kubernetes.delete_configmap settings default
         salt '*' kubernetes.delete_configmap name=settings namespace=default
@@ -928,7 +972,7 @@ def delete_configmap(name, namespace="default", **kwargs):
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->delete_namespaced_config_map"
+                "Exception when calling CoreV1Api->delete_namespaced_config_map"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -1002,7 +1046,7 @@ def create_pod(name, namespace, metadata, spec, source, template, saltenv, **kwa
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->create_namespaced_pod")
+            log.exception("Exception when calling CoreV1Api->create_namespaced_pod")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1038,9 +1082,7 @@ def create_service(
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->create_namespaced_service"
-            )
+            log.exception("Exception when calling CoreV1Api->create_namespaced_service")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1058,7 +1100,9 @@ def create_secret(
     """
     Creates the kubernetes secret as defined by the user.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt 'minion1' kubernetes.create_secret \
             passwords default '{"db": "letmein"}'
@@ -1092,9 +1136,7 @@ def create_secret(
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->create_namespaced_secret"
-            )
+            log.exception("Exception when calling CoreV1Api->create_namespaced_secret")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1106,7 +1148,9 @@ def create_configmap(
     """
     Creates the kubernetes configmap as defined by the user.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt 'minion1' kubernetes.create_configmap \
             settings default '{"example.conf": "# example file"}'
@@ -1137,7 +1181,7 @@ def create_configmap(
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->create_namespaced_config_map"
+                "Exception when calling CoreV1Api->create_namespaced_config_map"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -1149,6 +1193,9 @@ def create_namespace(name, **kwargs):
     Creates a namespace with the specified name.
 
     CLI Example:
+
+    .. code-block:: bash
+
         salt '*' kubernetes.create_namespace salt
         salt '*' kubernetes.create_namespace name=salt
     """
@@ -1168,7 +1215,7 @@ def create_namespace(name, **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->create_namespace")
+            log.exception("Exception when calling CoreV1Api->create_namespace")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1259,7 +1306,7 @@ def replace_service(
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->replace_namespaced_service"
+                "Exception when calling CoreV1Api->replace_namespaced_service"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -1279,7 +1326,9 @@ def replace_secret(
     Replaces an existing secret with a new one defined by name and namespace,
     having the specificed data.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt 'minion1' kubernetes.replace_secret \
             name=passwords data='{"db": "letmein"}'
@@ -1313,9 +1362,7 @@ def replace_secret(
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->replace_namespaced_secret"
-            )
+            log.exception("Exception when calling CoreV1Api->replace_namespaced_secret")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1334,7 +1381,9 @@ def replace_configmap(
     Replaces an existing configmap with a new one defined by name and
     namespace with the specified data.
 
-    CLI Examples::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt 'minion1' kubernetes.replace_configmap \
             settings default '{"example.conf": "# example file"}'
@@ -1363,7 +1412,7 @@ def replace_configmap(
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->replace_namespaced_configmap"
+                "Exception when calling CoreV1Api->replace_namespaced_configmap"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -1393,7 +1442,7 @@ def __create_object_body(
             or src_obj["kind"] != kind
         ):
             raise CommandExecutionError(
-                "The source file should define only " "a {} object".format(kind)
+                "The source file should define only a {} object".format(kind)
             )
 
         if "metadata" in src_obj:
@@ -1438,8 +1487,7 @@ def __read_and_render_yaml_file(source, template, saltenv):
                 if not data["result"]:
                     # Failed to render the template
                     raise CommandExecutionError(
-                        "Failed to render file path with error: "
-                        "{}".format(data["data"])
+                        "Failed to render file path with error: {}".format(data["data"])
                     )
 
                 contents = data["data"].encode("utf-8")
@@ -1464,7 +1512,7 @@ def __dict_to_object_meta(name, namespace, metadata):
     if "kubernetes.io/change-cause" not in metadata["annotations"]:
         metadata["annotations"]["kubernetes.io/change-cause"] = " ".join(sys.argv)
 
-    for key, value in iteritems(metadata):
+    for key, value in metadata.items():
         if hasattr(meta_obj, key):
             setattr(meta_obj, key, value)
 
@@ -1483,7 +1531,7 @@ def __dict_to_deployment_spec(spec):
     Converts a dictionary into kubernetes AppsV1beta1DeploymentSpec instance.
     """
     spec_obj = AppsV1beta1DeploymentSpec(template=spec.get("template", ""))
-    for key, value in iteritems(spec):
+    for key, value in spec.items():
         if hasattr(spec_obj, key):
             setattr(spec_obj, key, value)
 
@@ -1495,7 +1543,7 @@ def __dict_to_pod_spec(spec):
     Converts a dictionary into kubernetes V1PodSpec instance.
     """
     spec_obj = kubernetes.client.V1PodSpec()
-    for key, value in iteritems(spec):
+    for key, value in spec.items():
         if hasattr(spec_obj, key):
             setattr(spec_obj, key, value)
 
@@ -1507,13 +1555,13 @@ def __dict_to_service_spec(spec):
     Converts a dictionary into kubernetes V1ServiceSpec instance.
     """
     spec_obj = kubernetes.client.V1ServiceSpec()
-    for key, value in iteritems(spec):  # pylint: disable=too-many-nested-blocks
+    for key, value in spec.items():  # pylint: disable=too-many-nested-blocks
         if key == "ports":
             spec_obj.ports = []
             for port in value:
                 kube_port = kubernetes.client.V1ServicePort()
                 if isinstance(port, dict):
-                    for port_key, port_value in iteritems(port):
+                    for port_key, port_value in port.items():
                         if hasattr(kube_port, port_key):
                             setattr(kube_port, port_key, port_value)
                 else:
@@ -1531,7 +1579,7 @@ def __enforce_only_strings_dict(dictionary):
     """
     ret = {}
 
-    for key, value in iteritems(dictionary):
+    for key, value in dictionary.items():
         ret[str(key)] = str(value)
 
     return ret
