@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Apache Libcloud Compute Management
 ==================================
 
@@ -26,72 +25,69 @@ Clouds include Amazon EC2, Azure, Google GCE, VMware, OpenStack Nova
               secret: mysecret
 
 :depends: apache-libcloud
-'''
+"""
 # keep lint from choking on _get_conn and _cache_id
-#pylint: disable=E0602
+# pylint: disable=E0602
 
-from __future__ import absolute_import, unicode_literals, print_function
 
-# Import Python libs
 import logging
 import os.path
 
-# Import salt libs
 import salt.utils.args
 import salt.utils.compat
 from salt.utils.versions import LooseVersion as _LooseVersion
-from salt.ext import six
 
 log = logging.getLogger(__name__)
 
-# Import third party libs
-REQUIRED_LIBCLOUD_VERSION = '2.0.0'
+REQUIRED_LIBCLOUD_VERSION = "2.0.0"
 try:
-    #pylint: disable=unused-import
+    # pylint: disable=unused-import
     import libcloud
     from libcloud.compute.providers import get_driver
     from libcloud.compute.base import Node
-    #pylint: enable=unused-import
-    if hasattr(libcloud, '__version__') and _LooseVersion(libcloud.__version__) < _LooseVersion(REQUIRED_LIBCLOUD_VERSION):
+
+    # pylint: enable=unused-import
+    if hasattr(libcloud, "__version__") and _LooseVersion(
+        libcloud.__version__
+    ) < _LooseVersion(REQUIRED_LIBCLOUD_VERSION):
         raise ImportError()
-    logging.getLogger('libcloud').setLevel(logging.CRITICAL)
+    logging.getLogger("libcloud").setLevel(logging.CRITICAL)
     HAS_LIBCLOUD = True
 except ImportError:
     HAS_LIBCLOUD = False
 
 
 def __virtual__():
-    '''
+    """
     Only load if libcloud libraries exist.
-    '''
+    """
     if not HAS_LIBCLOUD:
-        msg = ('A apache-libcloud library with version at least {0} was not '
-               'found').format(REQUIRED_LIBCLOUD_VERSION)
-        return (False, msg)
+        return (
+            False,
+            "A apache-libcloud library with version at least {} was not found".format(
+                REQUIRED_LIBCLOUD_VERSION
+            ),
+        )
     return True
 
 
-def __init__(opts):
-    salt.utils.compat.pack_dunder(__name__)
-
-
 def _get_driver(profile):
-    config = __salt__['config.option']('libcloud_compute')[profile]
-    cls = get_driver(config['driver'])
+    config = __salt__["config.option"]("libcloud_compute")[profile]
+    cls = get_driver(config["driver"])
     args = config.copy()
-    del args['driver']
-    args['key'] = config.get('key')
-    args['secret'] = config.get('secret', None)
-    if args['secret'] is None:
-        del args['secret']
-    args['secure'] = config.get('secure', True)
-    args['host'] = config.get('host', None)
-    args['port'] = config.get('port', None)
+    del args["driver"]
+    args["key"] = config.get("key")
+    args["secret"] = config.get("secret", None)
+    if args["secret"] is None:
+        del args["secret"]
+    args["secure"] = config.get("secure", True)
+    args["host"] = config.get("host", None)
+    args["port"] = config.get("port", None)
     return cls(**args)
 
 
 def list_nodes(profile, **libcloud_kwargs):
-    '''
+    """
     Return a list of nodes
 
     :param profile: The profile key
@@ -105,7 +101,7 @@ def list_nodes(profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.list_nodes profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     nodes = conn.list_nodes(**libcloud_kwargs)
@@ -116,7 +112,7 @@ def list_nodes(profile, **libcloud_kwargs):
 
 
 def list_sizes(profile, location_id=None, **libcloud_kwargs):
-    '''
+    """
     Return a list of node sizes
 
     :param profile: The profile key
@@ -134,12 +130,12 @@ def list_sizes(profile, location_id=None, **libcloud_kwargs):
 
         salt myminion libcloud_compute.list_sizes profile1
         salt myminion libcloud_compute.list_sizes profile1 us-east1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     if location_id is not None:
         locations = [loc for loc in conn.list_locations() if loc.id == location_id]
-        if len(locations) == 0:
+        if not locations:
             raise ValueError("Location not found")
         else:
             sizes = conn.list_sizes(location=locations[0], **libcloud_kwargs)
@@ -153,7 +149,7 @@ def list_sizes(profile, location_id=None, **libcloud_kwargs):
 
 
 def list_locations(profile, **libcloud_kwargs):
-    '''
+    """
     Return a list of locations for this cloud
 
     :param profile: The profile key
@@ -167,7 +163,7 @@ def list_locations(profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.list_locations profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     locations = conn.list_locations(**libcloud_kwargs)
@@ -179,7 +175,7 @@ def list_locations(profile, **libcloud_kwargs):
 
 
 def reboot_node(node_id, profile, **libcloud_kwargs):
-    '''
+    """
     Reboot a node in the cloud
 
     :param node_id: Unique ID of the node to reboot
@@ -196,14 +192,14 @@ def reboot_node(node_id, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.reboot_node as-2346 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     node = _get_by_id(conn.list_nodes(**libcloud_kwargs), node_id)
     return conn.reboot_node(node, **libcloud_kwargs)
 
 
 def destroy_node(node_id, profile, **libcloud_kwargs):
-    '''
+    """
     Destroy a node in the cloud
 
     :param node_id: Unique ID of the node to destroy
@@ -220,14 +216,14 @@ def destroy_node(node_id, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.destry_node as-2346 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     node = _get_by_id(conn.list_nodes(**libcloud_kwargs), node_id)
     return conn.destroy_node(node, **libcloud_kwargs)
 
 
 def list_volumes(profile, **libcloud_kwargs):
-    '''
+    """
     Return a list of storage volumes for this cloud
 
     :param profile: The profile key
@@ -241,7 +237,7 @@ def list_volumes(profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.list_volumes profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     volumes = conn.list_volumes(**libcloud_kwargs)
@@ -253,7 +249,7 @@ def list_volumes(profile, **libcloud_kwargs):
 
 
 def list_volume_snapshots(volume_id, profile, **libcloud_kwargs):
-    '''
+    """
     Return a list of storage volumes snapshots for this cloud
 
     :param volume_id: The volume identifier
@@ -270,7 +266,7 @@ def list_volume_snapshots(volume_id, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.list_volume_snapshots vol1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     volume = _get_by_id(conn.list_volumes(), volume_id)
@@ -283,7 +279,7 @@ def list_volume_snapshots(volume_id, profile, **libcloud_kwargs):
 
 
 def create_volume(size, name, profile, location_id=None, **libcloud_kwargs):
-    '''
+    """
     Create a storage volume
 
     :param size: Size of volume in gigabytes (required)
@@ -308,7 +304,7 @@ def create_volume(size, name, profile, location_id=None, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.create_volume 1000 vol1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     if location_id is not None:
@@ -322,7 +318,7 @@ def create_volume(size, name, profile, location_id=None, **libcloud_kwargs):
 
 
 def create_volume_snapshot(volume_id, profile, name=None, **libcloud_kwargs):
-    '''
+    """
     Create a storage volume snapshot
 
     :param volume_id:  Volume ID from which to create the new
@@ -343,7 +339,7 @@ def create_volume_snapshot(volume_id, profile, name=None, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.create_volume_snapshot vol1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     volume = _get_by_id(conn.list_volumes(), volume_id)
@@ -353,7 +349,7 @@ def create_volume_snapshot(volume_id, profile, name=None, **libcloud_kwargs):
 
 
 def attach_volume(node_id, volume_id, profile, device=None, **libcloud_kwargs):
-    '''
+    """
     Attaches volume to node.
 
     :param node_id:  Node ID to target
@@ -376,7 +372,7 @@ def attach_volume(node_id, volume_id, profile, device=None, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.detach_volume vol1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     volume = _get_by_id(conn.list_volumes(), volume_id)
@@ -385,7 +381,7 @@ def attach_volume(node_id, volume_id, profile, device=None, **libcloud_kwargs):
 
 
 def detach_volume(volume_id, profile, **libcloud_kwargs):
-    '''
+    """
     Detaches a volume from a node.
 
     :param volume_id:  Volume ID from which to detach
@@ -402,7 +398,7 @@ def detach_volume(volume_id, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.detach_volume vol1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     volume = _get_by_id(conn.list_volumes(), volume_id)
@@ -410,7 +406,7 @@ def detach_volume(volume_id, profile, **libcloud_kwargs):
 
 
 def destroy_volume(volume_id, profile, **libcloud_kwargs):
-    '''
+    """
     Destroy a volume.
 
     :param volume_id:  Volume ID from which to destroy
@@ -427,7 +423,7 @@ def destroy_volume(volume_id, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.destroy_volume vol1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     volume = _get_by_id(conn.list_volumes(), volume_id)
@@ -435,7 +431,7 @@ def destroy_volume(volume_id, profile, **libcloud_kwargs):
 
 
 def destroy_volume_snapshot(volume_id, snapshot_id, profile, **libcloud_kwargs):
-    '''
+    """
     Destroy a volume snapshot.
 
     :param volume_id:  Volume ID from which the snapshot belongs
@@ -455,7 +451,7 @@ def destroy_volume_snapshot(volume_id, snapshot_id, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.destroy_volume_snapshot snap1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     volume = _get_by_id(conn.list_volumes(), volume_id)
@@ -464,7 +460,7 @@ def destroy_volume_snapshot(volume_id, snapshot_id, profile, **libcloud_kwargs):
 
 
 def list_images(profile, location_id=None, **libcloud_kwargs):
-    '''
+    """
     Return a list of images for this cloud
 
     :param profile: The profile key
@@ -481,7 +477,7 @@ def list_images(profile, location_id=None, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.list_images profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     if location_id is not None:
@@ -497,7 +493,7 @@ def list_images(profile, location_id=None, **libcloud_kwargs):
 
 
 def create_image(node_id, name, profile, description=None, **libcloud_kwargs):
-    '''
+    """
     Create an image from a node
 
     :param node_id: Node to run the task on.
@@ -521,15 +517,17 @@ def create_image(node_id, name, profile, description=None, **libcloud_kwargs):
 
         salt myminion libcloud_compute.create_image server1 my_image profile1
         salt myminion libcloud_compute.create_image server1 my_image profile1 description='test image'
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     node = _get_by_id(conn.list_nodes(), node_id)
-    return _simple_image(conn.create_image(node, name, description=description, **libcloud_kwargs))
+    return _simple_image(
+        conn.create_image(node, name, description=description, **libcloud_kwargs)
+    )
 
 
 def delete_image(image_id, profile, **libcloud_kwargs):
-    '''
+    """
     Delete an image of a node
 
     :param image_id: Image to delete
@@ -546,7 +544,7 @@ def delete_image(image_id, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.delete_image image1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     image = _get_by_id(conn.list_images(), image_id)
@@ -554,7 +552,7 @@ def delete_image(image_id, profile, **libcloud_kwargs):
 
 
 def get_image(image_id, profile, **libcloud_kwargs):
-    '''
+    """
     Get an image of a node
 
     :param image_id: Image to fetch
@@ -571,15 +569,17 @@ def get_image(image_id, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.get_image image1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     image = conn.get_image(image_id, **libcloud_kwargs)
     return _simple_image(image)
 
 
-def copy_image(source_region, image_id, name, profile, description=None, **libcloud_kwargs):
-    '''
+def copy_image(
+    source_region, image_id, name, profile, description=None, **libcloud_kwargs
+):
+    """
     Copies an image from a source region to the current region.
 
     :param source_region: Region to copy the node from.
@@ -605,17 +605,18 @@ def copy_image(source_region, image_id, name, profile, description=None, **libcl
     .. code-block:: bash
 
         salt myminion libcloud_compute.copy_image us-east1 image1 'new image' profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     image = conn.get_image(image_id, **libcloud_kwargs)
-    new_image = conn.copy_image(source_region, image, name,
-                                description=description, **libcloud_kwargs)
+    new_image = conn.copy_image(
+        source_region, image, name, description=description, **libcloud_kwargs
+    )
     return _simple_image(new_image)
 
 
 def list_key_pairs(profile, **libcloud_kwargs):
-    '''
+    """
     List all the available key pair objects.
 
     :param profile: The profile key
@@ -629,7 +630,7 @@ def list_key_pairs(profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.list_key_pairs profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     keys = conn.list_key_pairs(**libcloud_kwargs)
@@ -641,7 +642,7 @@ def list_key_pairs(profile, **libcloud_kwargs):
 
 
 def get_key_pair(name, profile, **libcloud_kwargs):
-    '''
+    """
     Get a single key pair by name
 
     :param name: Name of the key pair to retrieve.
@@ -658,14 +659,14 @@ def get_key_pair(name, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.get_key_pair pair1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     return _simple_key_pair(conn.get_key_pair(name, **libcloud_kwargs))
 
 
 def create_key_pair(name, profile, **libcloud_kwargs):
-    '''
+    """
     Create a single key pair by name
 
     :param name: Name of the key pair to create.
@@ -682,14 +683,14 @@ def create_key_pair(name, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.create_key_pair pair1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     return _simple_key_pair(conn.create_key_pair(name, **libcloud_kwargs))
 
 
 def import_key_pair(name, key, profile, key_type=None, **libcloud_kwargs):
-    '''
+    """
     Import a new public key from string or a file path
 
     :param name: Key pair name.
@@ -714,21 +715,21 @@ def import_key_pair(name, key, profile, key_type=None, **libcloud_kwargs):
 
         salt myminion libcloud_compute.import_key_pair pair1 key_value_data123 profile1
         salt myminion libcloud_compute.import_key_pair pair1 /path/to/key profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
-    if os.path.exists(key) or key_type == 'FILE':
-        return _simple_key_pair(conn.import_key_pair_from_file(name,
-                                                               key,
-                                                               **libcloud_kwargs))
+    if os.path.exists(key) or key_type == "FILE":
+        return _simple_key_pair(
+            conn.import_key_pair_from_file(name, key, **libcloud_kwargs)
+        )
     else:
-        return _simple_key_pair(conn.import_key_pair_from_string(name,
-                                                                 key,
-                                                                 **libcloud_kwargs))
+        return _simple_key_pair(
+            conn.import_key_pair_from_string(name, key, **libcloud_kwargs)
+        )
 
 
 def delete_key_pair(name, profile, **libcloud_kwargs):
-    '''
+    """
     Delete a key pair
 
     :param name: Key pair name.
@@ -745,7 +746,7 @@ def delete_key_pair(name, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.delete_key_pair pair1 profile1
-    '''
+    """
     conn = _get_driver(profile=profile)
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     key = conn.get_key_pair(name)
@@ -753,7 +754,7 @@ def delete_key_pair(name, profile, **libcloud_kwargs):
 
 
 def extra(method, profile, **libcloud_kwargs):
-    '''
+    """
     Call an extended method on the driver
 
     :param method: Driver's method name
@@ -770,7 +771,7 @@ def extra(method, profile, **libcloud_kwargs):
     .. code-block:: bash
 
         salt myminion libcloud_compute.extra ex_get_permissions google container_name=my_container object_name=me.jpg --out=yaml
-    '''
+    """
     libcloud_kwargs = salt.utils.args.clean_kwargs(**libcloud_kwargs)
     conn = _get_driver(profile=profile)
     connection_method = getattr(conn, method)
@@ -778,83 +779,79 @@ def extra(method, profile, **libcloud_kwargs):
 
 
 def _get_by_id(collection, id):
-    '''
+    """
     Get item from a list by the id field
-    '''
+    """
     matches = [item for item in collection if item.id == id]
-    if len(matches) == 0:
-        raise ValueError('Could not find a matching item')
+    if not matches:
+        raise ValueError("Could not find a matching item")
     elif len(matches) > 1:
-        raise ValueError('The id matched {0} items, not 1'.format(len(matches)))
+        raise ValueError("The id matched {} items, not 1".format(len(matches)))
     return matches[0]
 
 
 def _simple_volume(volume):
     return {
-        'id': volume.id,
-        'name': volume.name,
-        'size': volume.size,
-        'state': volume.state,
-        'extra': volume.extra
+        "id": volume.id,
+        "name": volume.name,
+        "size": volume.size,
+        "state": volume.state,
+        "extra": volume.extra,
     }
 
 
 def _simple_location(location):
-    return {
-        'id': location.id,
-        'name': location.name,
-        'country': location.country
-    }
+    return {"id": location.id, "name": location.name, "country": location.country}
 
 
 def _simple_size(size):
     return {
-        'id': size.id,
-        'name': size.name,
-        'ram': size.ram,
-        'disk': size.disk,
-        'bandwidth': size.bandwidth,
-        'price': size.price,
-        'extra': size.extra
+        "id": size.id,
+        "name": size.name,
+        "ram": size.ram,
+        "disk": size.disk,
+        "bandwidth": size.bandwidth,
+        "price": size.price,
+        "extra": size.extra,
     }
 
 
 def _simple_node(node):
     return {
-        'id': node.id,
-        'name': node.name,
-        'state': six.text_type(node.state),
-        'public_ips': node.public_ips,
-        'private_ips': node.private_ips,
-        'size': _simple_size(node.size) if node.size else {},
-        'extra': node.extra
+        "id": node.id,
+        "name": node.name,
+        "state": str(node.state),
+        "public_ips": node.public_ips,
+        "private_ips": node.private_ips,
+        "size": _simple_size(node.size) if node.size else {},
+        "extra": node.extra,
     }
 
 
 def _simple_volume_snapshot(snapshot):
     return {
-        'id': snapshot.id,
-        'name': snapshot.name if hasattr(snapshot, 'name') else snapshot.id,
-        'size': snapshot.size,
-        'extra': snapshot.extra,
-        'created': snapshot.created,
-        'state': snapshot.state
+        "id": snapshot.id,
+        "name": snapshot.name if hasattr(snapshot, "name") else snapshot.id,
+        "size": snapshot.size,
+        "extra": snapshot.extra,
+        "created": snapshot.created,
+        "state": snapshot.state,
     }
 
 
 def _simple_image(image):
     return {
-        'id': image.id,
-        'name': image.name,
-        'extra': image.extra,
+        "id": image.id,
+        "name": image.name,
+        "extra": image.extra,
     }
 
 
 def _simple_key_pair(key):
     return {
-        'name': key.name,
-        'fingerprint': key.fingerprint,
-        'public_key': key.public_key,
-        'private_key': key.private_key,
-        'extra': key.extra
+        "name": key.name,
+        "fingerprint": key.fingerprint,
+        "public_key": key.public_key,
+        "private_key": key.private_key,
+        "extra": key.extra,
     }
