@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Module to provide MongoDB functionality to Salt
 
 :configuration: This module uses PyMongo, and accepts configuration details as
@@ -12,23 +11,18 @@ Module to provide MongoDB functionality to Salt
 
     This data can also be passed into pillar. Options passed into opts will
     overwrite options passed into pillar.
-'''
-from __future__ import absolute_import
+"""
 
-# Import python libs
 import logging
-import json
 import re
 
-# Import salt libs
-from salt.utils.versions import LooseVersion as _LooseVersion
+import salt.utils.json
 from salt.exceptions import get_error_message as _get_error_message
+from salt.utils.versions import LooseVersion as _LooseVersion
 
-
-# Import third party libs
-import salt.ext.six as six
 try:
     import pymongo
+
     HAS_MONGODB = True
 except ImportError:
     HAS_MONGODB = False
@@ -37,28 +31,34 @@ log = logging.getLogger(__name__)
 
 
 def __virtual__():
-    '''
+    """
     Only load this module if pymongo is installed
-    '''
+    """
     if HAS_MONGODB:
-        return 'mongodb'
+        return "mongodb"
     else:
-        return (False, 'The mongodb execution module cannot be loaded: the pymongo library is not available.')
+        return (
+            False,
+            "The mongodb execution module cannot be loaded: the pymongo library is not"
+            " available.",
+        )
 
 
-def _connect(user=None, password=None, host=None, port=None, database='admin', authdb=None):
-    '''
+def _connect(
+    user=None, password=None, host=None, port=None, database="admin", authdb=None
+):
+    """
     Returns a tuple of (user, host, port) with config, pillar, or default
     values assigned to missing values.
-    '''
+    """
     if not user:
-        user = __salt__['config.option']('mongodb.user')
+        user = __salt__["config.option"]("mongodb.user")
     if not password:
-        password = __salt__['config.option']('mongodb.password')
+        password = __salt__["config.option"]("mongodb.password")
     if not host:
-        host = __salt__['config.option']('mongodb.host')
+        host = __salt__["config.option"]("mongodb.host")
     if not port:
-        port = __salt__['config.option']('mongodb.port')
+        port = __salt__["config.option"]("mongodb.port")
     if not authdb:
         authdb = database
 
@@ -68,7 +68,7 @@ def _connect(user=None, password=None, host=None, port=None, database='admin', a
         if user and password:
             mdb.authenticate(user, password, source=authdb)
     except pymongo.errors.PyMongoError:
-        log.error('Error connecting to database {0}'.format(database))
+        log.error("Error connecting to database %s", database)
         return False
 
     return conn
@@ -79,31 +79,31 @@ def _to_dict(objects):
     Potentially interprets a string as JSON for usage with mongo
     """
     try:
-        if isinstance(objects, six.string_types):
-            objects = json.loads(objects)
+        if isinstance(objects, str):
+            objects = salt.utils.json.loads(objects)
     except ValueError as err:
         log.error("Could not parse objects: %s", err)
-        raise err
+        raise
 
     return objects
 
 
 def db_list(user=None, password=None, host=None, port=None, authdb=None):
-    '''
-    List all Mongodb databases
+    """
+    List all MongoDB databases
 
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' mongodb.db_list <user> <password> <host> <port>
-    '''
+    """
     conn = _connect(user, password, host, port, authdb=authdb)
     if not conn:
-        return 'Failed to connect to mongo database'
+        return "Failed to connect to mongo database"
 
     try:
-        log.info('Listing databases')
+        log.info("Listing databases")
         return conn.database_names()
     except pymongo.errors.PyMongoError as err:
         log.error(err)
@@ -111,57 +111,55 @@ def db_list(user=None, password=None, host=None, port=None, authdb=None):
 
 
 def db_exists(name, user=None, password=None, host=None, port=None, authdb=None):
-    '''
-    Checks if a database exists in Mongodb
+    """
+    Checks if a database exists in MongoDB
 
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' mongodb.db_exists <name> <user> <password> <host> <port>
-    '''
+    """
     dbs = db_list(user, password, host, port, authdb=authdb)
 
-    if isinstance(dbs, six.string_types):
+    if isinstance(dbs, str):
         return False
 
     return name in dbs
 
 
 def db_remove(name, user=None, password=None, host=None, port=None, authdb=None):
-    '''
-    Remove a Mongodb database
+    """
+    Remove a MongoDB database
 
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' mongodb.db_remove <name> <user> <password> <host> <port>
-    '''
+    """
     conn = _connect(user, password, host, port, authdb=authdb)
     if not conn:
-        return 'Failed to connect to mongo database'
+        return "Failed to connect to mongo database"
 
     try:
-        log.info('Removing database {0}'.format(name))
+        log.info("Removing database %s", name)
         conn.drop_database(name)
     except pymongo.errors.PyMongoError as err:
-        log.error(
-            'Removing database {0} failed with error: {1}'.format(
-                name, str(err)
-            )
-        )
+        log.error("Removing database %s failed with error: %s", name, err)
         return str(err)
 
     return True
 
 
 def _version(mdb):
-    return mdb.command('buildInfo')['version']
+    return mdb.command("buildInfo")["version"]
 
 
-def version(user=None, password=None, host=None, port=None, database='admin', authdb=None):
-    '''
+def version(
+    user=None, password=None, host=None, port=None, database="admin", authdb=None
+):
+    """
     Get MongoDB instance version
 
     CLI Example:
@@ -169,10 +167,10 @@ def version(user=None, password=None, host=None, port=None, database='admin', au
     .. code-block:: bash
 
         salt '*' mongodb.version <user> <password> <host> <port> <database>
-    '''
+    """
     conn = _connect(user, password, host, port, authdb=authdb)
     if not conn:
-        err_msg = "Failed to connect to MongoDB database {0}:{1}".format(host, port)
+        err_msg = "Failed to connect to MongoDB database {}:{}".format(host, port)
         log.error(err_msg)
         return (False, err_msg)
 
@@ -180,17 +178,14 @@ def version(user=None, password=None, host=None, port=None, database='admin', au
         mdb = pymongo.database.Database(conn, database)
         return _version(mdb)
     except pymongo.errors.PyMongoError as err:
-        log.error(
-            'Listing users failed with error: {0}'.format(
-                str(err)
-            )
-        )
+        log.error("Listing users failed with error: %s", err)
         return str(err)
 
 
-def user_find(name, user=None, password=None, host=None, port=None,
-                database='admin', authdb=None):
-    '''
+def user_find(
+    name, user=None, password=None, host=None, port=None, database="admin", authdb=None
+):
+    """
     Get single user from MongoDB
 
     CLI Example:
@@ -198,10 +193,10 @@ def user_find(name, user=None, password=None, host=None, port=None,
     .. code-block:: bash
 
         salt '*' mongodb.user_find <name> <user> <password> <host> <port> <database> <authdb>
-    '''
+    """
     conn = _connect(user, password, host, port, authdb=authdb)
     if not conn:
-        err_msg = "Failed to connect to MongoDB database {0}:{1}".format(host, port)
+        err_msg = "Failed to connect to MongoDB database {}:{}".format(host, port)
         log.error(err_msg)
         return (False, err_msg)
 
@@ -209,147 +204,141 @@ def user_find(name, user=None, password=None, host=None, port=None,
     try:
         return mdb.command("usersInfo", name)["users"]
     except pymongo.errors.PyMongoError as err:
-        log.error(
-            'Listing users failed with error: {0}'.format(
-                str(err)
-            )
-        )
+        log.error("Listing users failed with error: %s", err)
         return (False, str(err))
 
 
-def user_list(user=None, password=None, host=None, port=None, database='admin', authdb=None):
-    '''
-    List users of a Mongodb database
+def user_list(
+    user=None, password=None, host=None, port=None, database="admin", authdb=None
+):
+    """
+    List users of a MongoDB database
 
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' mongodb.user_list <user> <password> <host> <port> <database>
-    '''
+    """
     conn = _connect(user, password, host, port, authdb=authdb)
     if not conn:
-        return 'Failed to connect to mongo database'
+        return "Failed to connect to mongo database"
 
     try:
-        log.info('Listing users')
+        log.info("Listing users")
         mdb = pymongo.database.Database(conn, database)
 
         output = []
         mongodb_version = _version(mdb)
 
-        if _LooseVersion(mongodb_version) >= _LooseVersion('2.6'):
-            for user in mdb.command('usersInfo')['users']:
-                output.append(
-                    {'user': user['user'],
-                     'roles': user['roles']}
-                )
+        if _LooseVersion(mongodb_version) >= _LooseVersion("2.6"):
+            for user in mdb.command("usersInfo")["users"]:
+                output.append({"user": user["user"], "roles": user["roles"]})
         else:
             for user in mdb.system.users.find():
                 output.append(
-                    {'user': user['user'],
-                     'readOnly': user.get('readOnly', 'None')}
+                    {"user": user["user"], "readOnly": user.get("readOnly", "None")}
                 )
         return output
 
     except pymongo.errors.PyMongoError as err:
-        log.error(
-            'Listing users failed with error: {0}'.format(
-                str(err)
-            )
-        )
+        log.error("Listing users failed with error: %s", err)
         return str(err)
 
 
-def user_exists(name, user=None, password=None, host=None, port=None,
-                database='admin', authdb=None):
-    '''
-    Checks if a user exists in Mongodb
+def user_exists(
+    name, user=None, password=None, host=None, port=None, database="admin", authdb=None
+):
+    """
+    Checks if a user exists in MongoDB
 
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' mongodb.user_exists <name> <user> <password> <host> <port> <database>
-    '''
+    """
     users = user_list(user, password, host, port, database, authdb)
 
-    if isinstance(users, six.string_types):
-        return 'Failed to connect to mongo database'
+    if isinstance(users, str):
+        return "Failed to connect to mongo database"
 
     for user in users:
-        if name == dict(user).get('user'):
+        if name == dict(user).get("user"):
             return True
 
     return False
 
 
-def user_create(name, passwd, user=None, password=None, host=None, port=None,
-                database='admin', authdb=None, roles=None):
-    '''
-    Create a Mongodb user
+def user_create(
+    name,
+    passwd,
+    user=None,
+    password=None,
+    host=None,
+    port=None,
+    database="admin",
+    authdb=None,
+    roles=None,
+):
+    """
+    Create a MongoDB user
 
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' mongodb.user_create <user_name> <user_password> <roles> <user> <password> <host> <port> <database>
-    '''
+    """
     conn = _connect(user, password, host, port, authdb=authdb)
     if not conn:
-        return 'Failed to connect to mongo database'
+        return "Failed to connect to mongo database"
 
     if not roles:
         roles = []
 
     try:
-        log.info('Creating user {0}'.format(name))
+        log.info("Creating user %s", name)
         mdb = pymongo.database.Database(conn, database)
         mdb.add_user(name, passwd, roles=roles)
     except pymongo.errors.PyMongoError as err:
-        log.error(
-            'Creating database {0} failed with error: {1}'.format(
-                name, str(err)
-            )
-        )
+        log.error("Creating database %s failed with error: %s", name, err)
         return str(err)
     return True
 
 
-def user_remove(name, user=None, password=None, host=None, port=None,
-                database='admin', authdb=None):
-    '''
-    Remove a Mongodb user
+def user_remove(
+    name, user=None, password=None, host=None, port=None, database="admin", authdb=None
+):
+    """
+    Remove a MongoDB user
 
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' mongodb.user_remove <name> <user> <password> <host> <port> <database>
-    '''
+    """
     conn = _connect(user, password, host, port)
     if not conn:
-        return 'Failed to connect to mongo database'
+        return "Failed to connect to mongo database"
 
     try:
-        log.info('Removing user {0}'.format(name))
+        log.info("Removing user %s", name)
         mdb = pymongo.database.Database(conn, database)
         mdb.remove_user(name)
     except pymongo.errors.PyMongoError as err:
-        log.error(
-            'Creating database {0} failed with error: {1}'.format(
-                name, str(err)
-            )
-        )
+        log.error("Creating database %s failed with error: %s", name, err)
         return str(err)
 
     return True
 
 
-def user_roles_exists(name, roles, database, user=None, password=None, host=None,
-                      port=None, authdb=None):
-    '''
-    Checks if a user of a Mongodb database has specified roles
+def user_roles_exists(
+    name, roles, database, user=None, password=None, host=None, port=None, authdb=None
+):
+    """
+    Checks if a user of a MongoDB database has specified roles
 
     CLI Examples:
 
@@ -360,34 +349,35 @@ def user_roles_exists(name, roles, database, user=None, password=None, host=None
     .. code-block:: bash
 
         salt '*' mongodb.user_roles_exists johndoe '[{"role": "readWrite", "db": "dbname" }, {"role": "read", "db": "otherdb"}]' dbname admin adminpwd localhost 27017
-    '''
+    """
     try:
         roles = _to_dict(roles)
-    except Exception:
-        return 'Roles provided in wrong format'
+    except Exception:  # pylint: disable=broad-except
+        return "Roles provided in wrong format"
 
     users = user_list(user, password, host, port, database, authdb)
 
-    if isinstance(users, six.string_types):
-        return 'Failed to connect to mongo database'
+    if isinstance(users, str):
+        return "Failed to connect to mongo database"
 
     for user in users:
-        if name == dict(user).get('user'):
+        if name == dict(user).get("user"):
             for role in roles:
                 # if the role was provided in the shortened form, we convert it to a long form
                 if not isinstance(role, dict):
-                    role = {'role': role, 'db': database}
-                if role not in dict(user).get('roles', []):
+                    role = {"role": role, "db": database}
+                if role not in dict(user).get("roles", []):
                     return False
             return True
 
     return False
 
 
-def user_grant_roles(name, roles, database, user=None, password=None, host=None,
-                     port=None, authdb=None):
-    '''
-    Grant one or many roles to a Mongodb user
+def user_grant_roles(
+    name, roles, database, user=None, password=None, host=None, port=None, authdb=None
+):
+    """
+    Grant one or many roles to a MongoDB user
 
     CLI Examples:
 
@@ -398,35 +388,34 @@ def user_grant_roles(name, roles, database, user=None, password=None, host=None,
     .. code-block:: bash
 
         salt '*' mongodb.user_grant_roles janedoe '[{"role": "readWrite", "db": "dbname" }, {"role": "read", "db": "otherdb"}]' dbname admin adminpwd localhost 27017
-    '''
+    """
     conn = _connect(user, password, host, port, authdb=authdb)
     if not conn:
-        return 'Failed to connect to mongo database'
+        return "Failed to connect to mongo database"
 
     try:
         roles = _to_dict(roles)
-    except Exception:
-        return 'Roles provided in wrong format'
+    except Exception:  # pylint: disable=broad-except
+        return "Roles provided in wrong format"
 
     try:
-        log.info('Granting roles {0} to user {1}'.format(roles, name))
+        log.info("Granting roles %s to user %s", roles, name)
         mdb = pymongo.database.Database(conn, database)
         mdb.command("grantRolesToUser", name, roles=roles)
     except pymongo.errors.PyMongoError as err:
         log.error(
-            'Granting roles {0} to user {1} failed with error: {2}'.format(
-                roles, name, str(err)
-            )
+            "Granting roles %s to user %s failed with error: %s", roles, name, err
         )
         return str(err)
 
     return True
 
 
-def user_revoke_roles(name, roles, database, user=None, password=None, host=None,
-                      port=None, authdb=None):
-    '''
-    Revoke one or many roles to a Mongodb user
+def user_revoke_roles(
+    name, roles, database, user=None, password=None, host=None, port=None, authdb=None
+):
+    """
+    Revoke one or many roles to a MongoDB user
 
     CLI Examples:
 
@@ -437,33 +426,39 @@ def user_revoke_roles(name, roles, database, user=None, password=None, host=None
     .. code-block:: bash
 
         salt '*' mongodb.user_revoke_roles janedoe '[{"role": "readWrite", "db": "dbname" }, {"role": "read", "db": "otherdb"}]' dbname admin adminpwd localhost 27017
-    '''
+    """
     conn = _connect(user, password, host, port, authdb=authdb)
     if not conn:
-        return 'Failed to connect to mongo database'
+        return "Failed to connect to mongo database"
 
     try:
         roles = _to_dict(roles)
-    except Exception:
-        return 'Roles provided in wrong format'
+    except Exception:  # pylint: disable=broad-except
+        return "Roles provided in wrong format"
 
     try:
-        log.info('Revoking roles {0} from user {1}'.format(roles, name))
+        log.info("Revoking roles %s from user %s", roles, name)
         mdb = pymongo.database.Database(conn, database)
         mdb.command("revokeRolesFromUser", name, roles=roles)
     except pymongo.errors.PyMongoError as err:
         log.error(
-            'Revoking roles {0} from user {1} failed with error: {2}'.format(
-                roles, name, str(err)
-            )
+            "Revoking roles %s from user %s failed with error: %s", roles, name, err
         )
         return str(err)
 
     return True
 
 
-def insert(objects, collection, user=None, password=None,
-           host=None, port=None, database='admin', authdb=None):
+def insert(
+    objects,
+    collection,
+    user=None,
+    password=None,
+    host=None,
+    port=None,
+    database="admin",
+    authdb=None,
+):
     """
     Insert an object or list of objects into a collection
 
@@ -480,7 +475,7 @@ def insert(objects, collection, user=None, password=None,
 
     try:
         objects = _to_dict(objects)
-    except Exception as err:
+    except Exception as err:  # pylint: disable=broad-except
         return err
 
     try:
@@ -494,8 +489,17 @@ def insert(objects, collection, user=None, password=None,
         return err
 
 
-def update_one(objects, collection, user=None, password=None, host=None, port=None, database='admin', authdb=None):
-    '''
+def update_one(
+    objects,
+    collection,
+    user=None,
+    password=None,
+    host=None,
+    port=None,
+    database="admin",
+    authdb=None,
+):
+    """
     Update an object into a collection
     http://api.mongodb.com/python/current/api/pymongo/collection.html#pymongo.collection.Collection.update_one
 
@@ -507,20 +511,22 @@ def update_one(objects, collection, user=None, password=None, host=None, port=No
 
         salt '*' mongodb.update_one '{"_id": "my_minion"} {"bar": "BAR"}' mycollection <user> <password> <host> <port> <database>
 
-    '''
+    """
     conn = _connect(user, password, host, port, database, authdb)
     if not conn:
         return "Failed to connect to mongo database"
 
     objects = str(objects)
-    objs = re.split(r'}\s+{', objects)
+    objs = re.split(r"}\s+{", objects)
 
-    if len(objs) is not 2:
-        return "Your request does not contain a valid " + \
-        "'{_\"id\": \"my_id\"} {\"my_doc\": \"my_val\"}'"
+    if len(objs) != 2:
+        return (
+            "Your request does not contain a valid "
+            + '\'{_"id": "my_id"} {"my_doc": "my_val"}\''
+        )
 
-    objs[0] = objs[0] + '}'
-    objs[1] = '{' + objs[1]
+    objs[0] = objs[0] + "}"
+    objs[1] = "{" + objs[1]
 
     document = []
 
@@ -528,42 +534,43 @@ def update_one(objects, collection, user=None, password=None, host=None, port=No
         try:
             obj = _to_dict(obj)
             document.append(obj)
-        except Exception as err:
+        except Exception as err:  # pylint: disable=broad-except
             return err
 
     _id_field = document[0]
     _update_doc = document[1]
 
     # need a string to perform the test, so using objs[0]
-    test_f = find(collection,
-                  objs[0],
-                  user,
-                  password,
-                  host,
-                  port,
-                  database,
-                  authdb)
+    test_f = find(collection, objs[0], user, password, host, port, database, authdb)
     if not isinstance(test_f, list):
-        return 'The find result is not well formatted. An error appears; cannot update.'
-    elif len(test_f) < 1:
-        return 'Did not find any result. You should try an insert before.'
+        return "The find result is not well formatted. An error appears; cannot update."
+    elif not test_f:
+        return "Did not find any result. You should try an insert before."
     elif len(test_f) > 1:
-        return 'Too many results. Please try to be more specific.'
+        return "Too many results. Please try to be more specific."
     else:
         try:
             log.info("Updating %r into %s.%s", _id_field, database, collection)
             mdb = pymongo.database.Database(conn, database)
             col = getattr(mdb, collection)
-            ids = col.update_one(_id_field, {'$set': _update_doc})
+            ids = col.update_one(_id_field, {"$set": _update_doc})
             nb_mod = ids.modified_count
-            return "{0} objects updated".format(nb_mod)
+            return "{} objects updated".format(nb_mod)
         except pymongo.errors.PyMongoError as err:
-            log.error('Updating object {0} failed with error {1}'.format(objects, err))
+            log.error("Updating object %s failed with error %s", objects, err)
             return err
 
 
-def find(collection, query=None, user=None, password=None,
-         host=None, port=None, database='admin', authdb=None):
+def find(
+    collection,
+    query=None,
+    user=None,
+    password=None,
+    host=None,
+    port=None,
+    database="admin",
+    authdb=None,
+):
     """
     Find an object or list of objects in a collection
 
@@ -576,11 +583,11 @@ def find(collection, query=None, user=None, password=None,
     """
     conn = _connect(user, password, host, port, database, authdb)
     if not conn:
-        return 'Failed to connect to mongo database'
+        return "Failed to connect to mongo database"
 
     try:
         query = _to_dict(query)
-    except Exception as err:
+    except Exception as err:  # pylint: disable=broad-except
         return err
 
     try:
@@ -594,8 +601,17 @@ def find(collection, query=None, user=None, password=None,
         return err
 
 
-def remove(collection, query=None, user=None, password=None,
-           host=None, port=None, database='admin', w=1, authdb=None):
+def remove(
+    collection,
+    query=None,
+    user=None,
+    password=None,
+    host=None,
+    port=None,
+    database="admin",
+    w=1,
+    authdb=None,
+):
     """
     Remove an object or list of objects into a collection
 
@@ -608,11 +624,11 @@ def remove(collection, query=None, user=None, password=None,
     """
     conn = _connect(user, password, host, port, database, authdb)
     if not conn:
-        return 'Failed to connect to mongo database'
+        return "Failed to connect to mongo database"
 
     try:
         query = _to_dict(query)
-    except Exception as err:
+    except Exception as err:  # pylint: disable=broad-except
         return _get_error_message(err)
 
     try:
@@ -620,7 +636,7 @@ def remove(collection, query=None, user=None, password=None,
         mdb = pymongo.database.Database(conn, database)
         col = getattr(mdb, collection)
         ret = col.remove(query, w=w)
-        return "{0} objects removed".format(ret['n'])
+        return "{} objects removed".format(ret["n"])
     except pymongo.errors.PyMongoError as err:
         log.error("Removing objects failed with error: %s", _get_error_message(err))
         return _get_error_message(err)
