@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Provides the service module for systemd
 
@@ -15,8 +14,6 @@ Provides the service module for systemd
     call it under the name 'service' and NOT 'systemd'. You can see that also
     in the examples below.
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import errno
 import fnmatch
@@ -26,7 +23,6 @@ import os
 import re
 import shlex
 
-# Import Salt libs
 import salt.utils.files
 import salt.utils.itertools
 import salt.utils.path
@@ -34,9 +30,6 @@ import salt.utils.stringutils
 import salt.utils.systemd
 from salt.exceptions import CommandExecutionError
 
-# Import 3rd-party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 __func_alias__ = {
@@ -70,7 +63,10 @@ def __virtual__():
     """
     Only work on systems that have been booted with systemd
     """
-    if __grains__.get("kernel") == "Linux" and salt.utils.systemd.booted(__context__):
+    is_linux = __grains__.get("kernel") == "Linux"
+    is_booted = salt.utils.systemd.booted(__context__)
+    is_offline = salt.utils.systemd.offline(__context__)
+    if is_linux and (is_booted or is_offline):
         return __virtualname__
     return (
         False,
@@ -94,8 +90,8 @@ def _canonical_unit_name(name):
     Build a canonical unit name treating unit names without one
     of the valid suffixes as a service.
     """
-    if not isinstance(name, six.string_types):
-        name = six.text_type(name)
+    if not isinstance(name, str):
+        name = str(name)
     if any(name.endswith(suffix) for suffix in VALID_UNIT_TYPES):
         return name
     return "%s.service" % name
@@ -105,6 +101,11 @@ def _check_available(name):
     """
     Returns boolean telling whether or not the named service is available
     """
+    if offline():
+        raise CommandExecutionError(
+            "Cannot run in offline mode. Failed to get information on unit '%s'" % name
+        )
+
     _status = _systemctl_status(name)
     sd_version = salt.utils.systemd.version(__context__)
     if sd_version is not None and sd_version >= 231:
@@ -137,7 +138,7 @@ def _check_for_unit_changes(name):
     Check for modified/updated unit files, and run a daemon-reload if any are
     found.
     """
-    contextkey = "systemd._check_for_unit_changes.{0}".format(name)
+    contextkey = "systemd._check_for_unit_changes.{}".format(name)
     if contextkey not in __context__:
         if _untracked_custom_unit_found(name) or _unit_file_changed(name):
             systemctl_reload()
@@ -199,9 +200,7 @@ def _default_runlevel():
 
     # The default runlevel can also be set via the kernel command-line.
     try:
-        valid_strings = set(
-            ("0", "1", "2", "3", "4", "5", "6", "s", "S", "-s", "single")
-        )
+        valid_strings = {"0", "1", "2", "3", "4", "5", "6", "s", "S", "-s", "single"}
         with salt.utils.files.fopen("/proc/cmdline") as fp_:
             for line in fp_:
                 line = salt.utils.stringutils.to_unicode(line)
@@ -291,7 +290,7 @@ def _get_service_exec():
                 break
         else:
             raise CommandExecutionError(
-                "Unable to find sysv service manager (tried {0})".format(
+                "Unable to find sysv service manager (tried {})".format(
                     ", ".join(executables)
                 )
             )
@@ -345,7 +344,7 @@ def _systemctl_cmd(action, name=None, systemd_scope=False, no_block=False, root=
         ret.append("--no-block")
     if root:
         ret.extend(["--root", root])
-    if isinstance(action, six.string_types):
+    if isinstance(action, str):
         action = shlex.split(action)
     ret.extend(action)
     if name is not None:
@@ -492,7 +491,7 @@ def get_enabled(root=None):
     )
     for line in salt.utils.itertools.split(out, "\n"):
         try:
-            fullname, unit_state = line.strip().split(None, 1)
+            fullname, unit_state = line.strip().split()[:2]
         except ValueError:
             continue
         else:
@@ -507,7 +506,7 @@ def get_enabled(root=None):
             ret.add(unit_name if unit_type == "service" else fullname)
 
     # Add in any sysvinit services that are enabled
-    ret.update(set([x for x in _get_sysv_services(root) if _sysv_enabled(x, root)]))
+    ret.update({x for x in _get_sysv_services(root) if _sysv_enabled(x, root)})
     return sorted(ret)
 
 
@@ -534,7 +533,7 @@ def get_disabled(root=None):
     )
     for line in salt.utils.itertools.split(out, "\n"):
         try:
-            fullname, unit_state = line.strip().split(None, 1)
+            fullname, unit_state = line.strip().split()[:2]
         except ValueError:
             continue
         else:
@@ -549,7 +548,7 @@ def get_disabled(root=None):
             ret.add(unit_name if unit_type == "service" else fullname)
 
     # Add in any sysvinit services that are disabled
-    ret.update(set([x for x in _get_sysv_services(root) if not _sysv_enabled(x, root)]))
+    ret.update({x for x in _get_sysv_services(root) if not _sysv_enabled(x, root)})
     return sorted(ret)
 
 
@@ -578,7 +577,7 @@ def get_static(root=None):
     )
     for line in salt.utils.itertools.split(out, "\n"):
         try:
-            fullname, unit_state = line.strip().split(None, 1)
+            fullname, unit_state = line.strip().split()[:2]
         except ValueError:
             continue
         else:
@@ -1349,6 +1348,8 @@ def show(name, root=None):
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt '*' service.show <service name>
     """
     ret = {}
@@ -1384,6 +1385,8 @@ def execs(root=None):
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt '*' service.execs
     """
     ret = {}
@@ -1405,7 +1408,7 @@ def firstboot(
     root=None,
 ):
     """
-    .. versionadded:: TBD
+    .. versionadded:: 3001
 
     Call systemd-firstboot to configure basic settings of the system
 
@@ -1432,6 +1435,8 @@ def firstboot(
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt '*' service.firstboot keymap=jp locale=en_US.UTF-8
 
     """
@@ -1455,3 +1460,21 @@ def firstboot(
         raise CommandExecutionError("systemd-firstboot error: {}".format(out["stderr"]))
 
     return True
+
+
+def offline():
+    """
+    .. versionadded:: 3004
+
+    Check if systemd is working in offline mode, where is not possible
+    to talk with PID 1.
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' service.offline
+
+    """
+
+    return salt.utils.systemd.offline(__context__)
