@@ -1,31 +1,46 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Install features/packages for Windows using DISM, which is useful for minions
 not running server versions of Windows. Some functions are only available on
 Windows 10.
 
-'''
-from __future__ import absolute_import, unicode_literals, print_function
+"""
 
-# Import Python libs
-import re
 import logging
+import os
+import re
 
-# Import Salt libs
 import salt.utils.platform
 import salt.utils.versions
 
-# Import 3rd party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 __virtualname__ = "dism"
 
+# We always want to use the version of dism that matches the architecture of the
+# host machine. On 32bit boxes that will always be System32. On 64bit boxes that
+# are running 64bit salt that will always be System32. On 64bit boxes that are
+# running 32bit salt the 64bit dism will be found in SysNative
+# Sysnative is a virtual folder, a special alias, that can be used to access the
+# 64-bit System32 folder from a 32-bit application
+try:
+    # This does not apply to Non-Windows platforms
+    if not salt.utils.platform.is_windows():
+        raise OSError
+
+    if os.path.exists(os.path.join(os.environ.get("SystemRoot"), "SysNative")):
+        bin_path = os.path.join(os.environ.get("SystemRoot"), "SysNative")
+    else:
+        bin_path = os.path.join(os.environ.get("SystemRoot"), "System32")
+    bin_dism = os.path.join(bin_path, "dism.exe")
+
+except OSError:
+    log.trace("win_dism: Non-Windows system")
+    bin_dism = "dism.exe"
+
 
 def __virtual__():
-    '''
+    """
     Only work on Windows
-    '''
+    """
     if not salt.utils.platform.is_windows():
         return False, "Only available on Windows systems"
 
@@ -33,24 +48,23 @@ def __virtual__():
 
 
 def _get_components(type_regex, plural_type, install_value, image=None):
-    cmd = ['DISM',
-           '/English',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Get-{0}'.format(plural_type)]
-    out = __salt__['cmd.run'](cmd)
-    pattern = r'{0} : (.*)\r\n.*State : {1}\r\n'\
-              .format(type_regex, install_value)
+    cmd = [
+        bin_dism,
+        "/English",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Get-{}".format(plural_type),
+    ]
+    out = __salt__["cmd.run"](cmd)
+    pattern = r"{} : (.*)\r\n.*State : {}\r\n".format(type_regex, install_value)
     capabilities = re.findall(pattern, out, re.MULTILINE)
     capabilities.sort()
     return capabilities
 
 
-def add_capability(capability,
-                   source=None,
-                   limit_access=False,
-                   image=None,
-                   restart=False):
-    '''
+def add_capability(
+    capability, source=None, limit_access=False, image=None, restart=False
+):
+    """
     Install a capability
 
     Args:
@@ -76,30 +90,33 @@ def add_capability(capability,
     .. code-block:: bash
 
         salt '*' dism.add_capability Tools.Graphics.DirectX~~~~0.0.1.0
-    '''
-    if salt.utils.versions.version_cmp(__grains__['osversion'], '10') == -1:
+    """
+    if salt.utils.versions.version_cmp(__grains__["osversion"], "10") == -1:
         raise NotImplementedError(
-            '`install_capability` is not available on this version of Windows: '
-            '{0}'.format(__grains__['osversion']))
+            "`install_capability` is not available on this version of Windows: "
+            "{}".format(__grains__["osversion"])
+        )
 
-    cmd = ['DISM',
-           '/Quiet',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Add-Capability',
-           '/CapabilityName:{0}'.format(capability)]
+    cmd = [
+        bin_dism,
+        "/Quiet",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Add-Capability",
+        "/CapabilityName:{}".format(capability),
+    ]
 
     if source:
-        cmd.append('/Source:{0}'.format(source))
+        cmd.append("/Source:{}".format(source))
     if limit_access:
-        cmd.append('/LimitAccess')
+        cmd.append("/LimitAccess")
     if not restart:
-        cmd.append('/NoRestart')
+        cmd.append("/NoRestart")
 
-    return __salt__['cmd.run_all'](cmd)
+    return __salt__["cmd.run_all"](cmd)
 
 
 def remove_capability(capability, image=None, restart=False):
-    '''
+    """
     Uninstall a capability
 
     Args:
@@ -121,26 +138,29 @@ def remove_capability(capability, image=None, restart=False):
     .. code-block:: bash
 
         salt '*' dism.remove_capability Tools.Graphics.DirectX~~~~0.0.1.0
-    '''
-    if salt.utils.versions.version_cmp(__grains__['osversion'], '10') == -1:
+    """
+    if salt.utils.versions.version_cmp(__grains__["osversion"], "10") == -1:
         raise NotImplementedError(
-            '`uninstall_capability` is not available on this version of '
-            'Windows: {0}'.format(__grains__['osversion']))
+            "`uninstall_capability` is not available on this version of "
+            "Windows: {}".format(__grains__["osversion"])
+        )
 
-    cmd = ['DISM',
-           '/Quiet',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Remove-Capability',
-           '/CapabilityName:{0}'.format(capability)]
+    cmd = [
+        bin_dism,
+        "/Quiet",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Remove-Capability",
+        "/CapabilityName:{}".format(capability),
+    ]
 
     if not restart:
-        cmd.append('/NoRestart')
+        cmd.append("/NoRestart")
 
-    return __salt__['cmd.run_all'](cmd)
+    return __salt__["cmd.run_all"](cmd)
 
 
 def get_capabilities(image=None):
-    '''
+    """
     List all capabilities on the system
 
     Args:
@@ -160,19 +180,22 @@ def get_capabilities(image=None):
     .. code-block:: bash
 
         salt '*' dism.get_capabilities
-    '''
-    if salt.utils.versions.version_cmp(__grains__['osversion'], '10') == -1:
+    """
+    if salt.utils.versions.version_cmp(__grains__["osversion"], "10") == -1:
         raise NotImplementedError(
-            '`installed_capabilities` is not available on this version of '
-            'Windows: {0}'.format(__grains__['osversion']))
+            "`installed_capabilities` is not available on this version of "
+            "Windows: {}".format(__grains__["osversion"])
+        )
 
-    cmd = ['DISM',
-           '/English',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Get-Capabilities']
-    out = __salt__['cmd.run'](cmd)
+    cmd = [
+        bin_dism,
+        "/English",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Get-Capabilities",
+    ]
+    out = __salt__["cmd.run"](cmd)
 
-    pattern = r'Capability Identity : (.*)\r\n'
+    pattern = r"Capability Identity : (.*)\r\n"
     capabilities = re.findall(pattern, out, re.MULTILINE)
     capabilities.sort()
 
@@ -180,7 +203,7 @@ def get_capabilities(image=None):
 
 
 def installed_capabilities(image=None):
-    '''
+    """
     List the capabilities installed on the system
 
     Args:
@@ -200,16 +223,17 @@ def installed_capabilities(image=None):
     .. code-block:: bash
 
         salt '*' dism.installed_capabilities
-    '''
-    if salt.utils.versions.version_cmp(__grains__['osversion'], '10') == -1:
+    """
+    if salt.utils.versions.version_cmp(__grains__["osversion"], "10") == -1:
         raise NotImplementedError(
-            '`installed_capabilities` is not available on this version of '
-            'Windows: {0}'.format(__grains__['osversion']))
+            "`installed_capabilities` is not available on this version of "
+            "Windows: {}".format(__grains__["osversion"])
+        )
     return _get_components("Capability Identity", "Capabilities", "Installed")
 
 
 def available_capabilities(image=None):
-    '''
+    """
     List the capabilities available on the system
 
     Args:
@@ -229,22 +253,25 @@ def available_capabilities(image=None):
     .. code-block:: bash
 
         salt '*' dism.installed_capabilities
-    '''
-    if salt.utils.versions.version_cmp(__grains__['osversion'], '10') == -1:
+    """
+    if salt.utils.versions.version_cmp(__grains__["osversion"], "10") == -1:
         raise NotImplementedError(
-            '`installed_capabilities` is not available on this version of '
-            'Windows: {0}'.format(__grains__['osversion']))
+            "`installed_capabilities` is not available on this version of "
+            "Windows: {}".format(__grains__["osversion"])
+        )
     return _get_components("Capability Identity", "Capabilities", "Not Present")
 
 
-def add_feature(feature,
-                package=None,
-                source=None,
-                limit_access=False,
-                enable_parent=False,
-                image=None,
-                restart=False):
-    '''
+def add_feature(
+    feature,
+    package=None,
+    source=None,
+    limit_access=False,
+    enable_parent=False,
+    image=None,
+    restart=False,
+):
+    """
     Install a feature using DISM
 
     Args:
@@ -271,28 +298,30 @@ def add_feature(feature,
     .. code-block:: bash
 
         salt '*' dism.add_feature NetFx3
-    '''
-    cmd = ['DISM',
-           '/Quiet',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Enable-Feature',
-           '/FeatureName:{0}'.format(feature)]
+    """
+    cmd = [
+        bin_dism,
+        "/Quiet",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Enable-Feature",
+        "/FeatureName:{}".format(feature),
+    ]
     if package:
-        cmd.append('/PackageName:{0}'.format(package))
+        cmd.append("/PackageName:{}".format(package))
     if source:
-        cmd.append('/Source:{0}'.format(source))
+        cmd.append("/Source:{}".format(source))
     if limit_access:
-        cmd.append('/LimitAccess')
+        cmd.append("/LimitAccess")
     if enable_parent:
-        cmd.append('/All')
+        cmd.append("/All")
     if not restart:
-        cmd.append('/NoRestart')
+        cmd.append("/NoRestart")
 
-    return __salt__['cmd.run_all'](cmd)
+    return __salt__["cmd.run_all"](cmd)
 
 
 def remove_feature(feature, remove_payload=False, image=None, restart=False):
-    '''
+    """
     Disables the feature.
 
     Args:
@@ -312,23 +341,25 @@ def remove_feature(feature, remove_payload=False, image=None, restart=False):
     .. code-block:: bash
 
         salt '*' dism.remove_feature NetFx3
-    '''
-    cmd = ['DISM',
-           '/Quiet',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Disable-Feature',
-           '/FeatureName:{0}'.format(feature)]
+    """
+    cmd = [
+        bin_dism,
+        "/Quiet",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Disable-Feature",
+        "/FeatureName:{}".format(feature),
+    ]
 
     if remove_payload:
-        cmd.append('/Remove')
+        cmd.append("/Remove")
     if not restart:
-        cmd.append('/NoRestart')
+        cmd.append("/NoRestart")
 
-    return __salt__['cmd.run_all'](cmd)
+    return __salt__["cmd.run_all"](cmd)
 
 
 def get_features(package=None, image=None):
-    '''
+    """
     List features on the system or in a package
 
     Args:
@@ -358,21 +389,23 @@ def get_features(package=None, image=None):
 
             # Return all features in the calc package
             salt '*' dism.get_features Microsoft.Windows.Calc.Demo~6595b6144ccf1df~x86~en~1.0.0.0
-    '''
-    cmd = ['DISM',
-           '/English',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Get-Features']
+    """
+    cmd = [
+        bin_dism,
+        "/English",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Get-Features",
+    ]
 
     if package:
-        if '~' in package:
-            cmd.append('/PackageName:{0}'.format(package))
+        if "~" in package:
+            cmd.append("/PackageName:{}".format(package))
         else:
-            cmd.append('/PackagePath:{0}'.format(package))
+            cmd.append("/PackagePath:{}".format(package))
 
-    out = __salt__['cmd.run'](cmd)
+    out = __salt__["cmd.run"](cmd)
 
-    pattern = r'Feature Name : (.*)\r\n'
+    pattern = r"Feature Name : (.*)\r\n"
     features = re.findall(pattern, out, re.MULTILINE)
     features.sort()
 
@@ -380,7 +413,7 @@ def get_features(package=None, image=None):
 
 
 def installed_features(image=None):
-    '''
+    """
     List the features installed on the system
 
     Args:
@@ -396,12 +429,12 @@ def installed_features(image=None):
     .. code-block:: bash
 
         salt '*' dism.installed_features
-    '''
+    """
     return _get_components("Feature Name", "Features", "Enabled")
 
 
 def available_features(image=None):
-    '''
+    """
     List the features available on the system
 
     Args:
@@ -417,16 +450,14 @@ def available_features(image=None):
     .. code-block:: bash
 
         salt '*' dism.available_features
-    '''
+    """
     return _get_components("Feature Name", "Features", "Disabled")
 
 
-def add_package(package,
-                ignore_check=False,
-                prevent_pending=False,
-                image=None,
-                restart=False):
-    '''
+def add_package(
+    package, ignore_check=False, prevent_pending=False, image=None, restart=False
+):
+    """
     Install a package using DISM
 
     Args:
@@ -460,25 +491,27 @@ def add_package(package,
     .. code-block:: bash
 
         salt '*' dism.add_package C:\\Packages\\package.cab
-    '''
-    cmd = ['DISM',
-           '/Quiet',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Add-Package',
-           '/PackagePath:{0}'.format(package)]
+    """
+    cmd = [
+        bin_dism,
+        "/Quiet",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Add-Package",
+        "/PackagePath:{}".format(package),
+    ]
 
     if ignore_check:
-        cmd.append('/IgnoreCheck')
+        cmd.append("/IgnoreCheck")
     if prevent_pending:
-        cmd.append('/PreventPending')
+        cmd.append("/PreventPending")
     if not restart:
-        cmd.append('/NoRestart')
+        cmd.append("/NoRestart")
 
-    return __salt__['cmd.run_all'](cmd)
+    return __salt__["cmd.run_all"](cmd)
 
 
 def remove_package(package, image=None, restart=False):
-    '''
+    """
     Uninstall a package
 
     Args:
@@ -503,25 +536,27 @@ def remove_package(package, image=None, restart=False):
 
         # Remove the package.cab (does not remove C:\\packages\\package.cab)
         salt '*' dism.remove_package C:\\packages\\package.cab
-    '''
-    cmd = ['DISM',
-           '/Quiet',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Remove-Package']
+    """
+    cmd = [
+        bin_dism,
+        "/Quiet",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Remove-Package",
+    ]
 
     if not restart:
-        cmd.append('/NoRestart')
+        cmd.append("/NoRestart")
 
-    if '~' in package:
-        cmd.append('/PackageName:{0}'.format(package))
+    if "~" in package:
+        cmd.append("/PackageName:{}".format(package))
     else:
-        cmd.append('/PackagePath:{0}'.format(package))
+        cmd.append("/PackagePath:{}".format(package))
 
-    return __salt__['cmd.run_all'](cmd)
+    return __salt__["cmd.run_all"](cmd)
 
 
 def installed_packages(image=None):
-    '''
+    """
     List the packages installed on the system
 
     Args:
@@ -537,12 +572,12 @@ def installed_packages(image=None):
     .. code-block:: bash
 
         salt '*' dism.installed_packages
-    '''
+    """
     return _get_components("Package Identity", "Packages", "Installed")
 
 
 def package_info(package, image=None):
-    '''
+    """
     Display information about a package
 
     Args:
@@ -562,24 +597,26 @@ def package_info(package, image=None):
     .. code-block:: bash
 
         salt '*' dism. package_info C:\\packages\\package.cab
-    '''
-    cmd = ['DISM',
-           '/English',
-           '/Image:{0}'.format(image) if image else '/Online',
-           '/Get-PackageInfo']
+    """
+    cmd = [
+        bin_dism,
+        "/English",
+        "/Image:{}".format(image) if image else "/Online",
+        "/Get-PackageInfo",
+    ]
 
-    if '~' in package:
-        cmd.append('/PackageName:{0}'.format(package))
+    if "~" in package:
+        cmd.append("/PackageName:{}".format(package))
     else:
-        cmd.append('/PackagePath:{0}'.format(package))
+        cmd.append("/PackagePath:{}".format(package))
 
-    out = __salt__['cmd.run_all'](cmd)
+    out = __salt__["cmd.run_all"](cmd)
 
-    if out['retcode'] == 0:
+    if out["retcode"] == 0:
         ret = dict()
-        for line in six.text_type(out['stdout']).splitlines():
-            if ' : ' in line:
-                info = line.split(' : ')
+        for line in str(out["stdout"]).splitlines():
+            if " : " in line:
+                info = line.split(" : ")
                 if len(info) < 2:
                     continue
                 ret[info[0]] = info[1]
