@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage information about files on the minion, set/read user, group
 data, modify the ACL of files/directories
@@ -8,7 +7,6 @@ data, modify the ACL of files/directories
             - win32con
             - salt.utils.win_dacl
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 # pylint: disable=unused-import
 import contextlib  # do not remove, used in imported file.py functions
@@ -23,8 +21,6 @@ import itertools  # same as above, do not remove, it's used in __clean_tmp
 import logging
 import mmap  # do not remove, used in imported file.py functions
 import operator  # do not remove
-
-# Import python libs
 import os
 import os.path
 import re  # do not remove, used in imported file.py functions
@@ -33,20 +29,15 @@ import stat
 import string  # do not remove, used in imported file.py functions
 import sys  # do not remove, used in imported file.py functions
 import tempfile  # do not remove. Used in salt.modules.file.__clean_tmp
+import urllib.parse
 from collections.abc import Iterable, Mapping
 from functools import reduce  # do not remove
 
 import salt.utils.atomicfile  # do not remove, used in imported file.py functions
-
-# Import salt libs
-import salt.utils.path
 import salt.utils.platform
-import salt.utils.user
 from salt.exceptions import CommandExecutionError, SaltInvocationError
 
 # do not remove, used in imported file.py functions
-from salt.ext import six
-from salt.ext.six.moves.urllib.parse import urlparse as _urlparse
 from salt.modules.file import check_hash  # pylint: disable=W0611
 from salt.modules.file import (
     HASHES,
@@ -103,6 +94,7 @@ from salt.modules.file import (
 from salt.modules.file import normpath as normpath_
 from salt.modules.file import (
     pardir,
+    patch,
     path_exists_glob,
     prepend,
     psed,
@@ -145,15 +137,6 @@ except ImportError:
         pass
 
 
-HAS_WIN_DACL = False
-try:
-    if salt.utils.platform.is_windows():
-        import salt.utils.win_dacl
-
-        HAS_WIN_DACL = True
-except ImportError:
-    HAS_WIN_DACL = False
-
 log = logging.getLogger(__name__)
 
 # Define the module's virtual name
@@ -167,7 +150,7 @@ def __virtual__():
     if salt.utils.platform.is_windows():
         if HAS_WINDOWS_MODULES:
             # Load functions from file.py
-            global get_managed, manage_file
+            global get_managed, manage_file, patch
             global source_list, __clean_tmp, file_exists
             global check_managed, check_managed_changes, check_file_meta
             global append, _error, directory_exists, touch, contains
@@ -256,13 +239,11 @@ def __virtual__():
             list_backups_dir = _namespaced_function(list_backups_dir, globals())
             normpath_ = _namespaced_function(normpath_, globals())
             _assert_occurrence = _namespaced_function(_assert_occurrence, globals())
+            patch = _namespaced_function(patch, globals())
 
         else:
             return False, "Module win_file: Missing Win32 modules"
 
-    if not HAS_WIN_DACL:
-        return False, "Module win_file: Unable to load salt.utils.win_dacl"
-
     return __virtualname__
 
 
@@ -290,7 +271,7 @@ def _resolve_symlink(path, max_depth=64):
         )
 
     # make sure we don't get stuck in a symlink loop!
-    paths_seen = set((path,))
+    paths_seen = {path}
     cur_depth = 0
     while is_link(path):
         path = readlink(path)
@@ -328,7 +309,7 @@ def gid_to_group(gid):
 
         salt '*' file.gid_to_group S-1-5-21-626487655-2533044672-482107328-1010
     """
-    func_name = "{0}.gid_to_group".format(__virtualname__)
+    func_name = "{}.gid_to_group".format(__virtualname__)
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -363,7 +344,7 @@ def group_to_gid(group):
 
         salt '*' file.group_to_gid administrators
     """
-    func_name = "{0}.group_to_gid".format(__virtualname__)
+    func_name = "{}.group_to_gid".format(__virtualname__)
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -374,7 +355,7 @@ def group_to_gid(group):
     if group is None:
         return ""
 
-    return salt.utils.win_dacl.get_sid_string(group)
+    return __utils__["dacl.get_sid_string"](group)
 
 
 def get_pgid(path, follow_symlinks=True):
@@ -405,7 +386,7 @@ def get_pgid(path, follow_symlinks=True):
         salt '*' file.get_pgid c:\\temp\\test.txt
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
     # Under Windows, if the path is a symlink, the user that owns the symlink is
     # returned, not the user that owns the file/directory the symlink is
@@ -415,8 +396,8 @@ def get_pgid(path, follow_symlinks=True):
     if follow_symlinks and sys.getwindowsversion().major >= 6:
         path = _resolve_symlink(path)
 
-    group_name = salt.utils.win_dacl.get_primary_group(path)
-    return salt.utils.win_dacl.get_sid_string(group_name)
+    group_name = __utils__["dacl.get_primary_group"](path)
+    return __utils__["dacl.get_sid_string"](group_name)
 
 
 def get_pgroup(path, follow_symlinks=True):
@@ -489,7 +470,7 @@ def get_gid(path, follow_symlinks=True):
 
         salt '*' file.get_gid c:\\temp\\test.txt
     """
-    func_name = "{0}.get_gid".format(__virtualname__)
+    func_name = "{}.get_gid".format(__virtualname__)
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -536,7 +517,7 @@ def get_group(path, follow_symlinks=True):
 
         salt '*' file.get_group c:\\temp\\test.txt
     """
-    func_name = "{0}.get_group".format(__virtualname__)
+    func_name = "{}.get_group".format(__virtualname__)
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -567,7 +548,7 @@ def uid_to_user(uid):
     if uid is None or uid == "":
         return ""
 
-    return salt.utils.win_dacl.get_name(uid)
+    return __utils__["dacl.get_name"](uid)
 
 
 def user_to_uid(user):
@@ -587,9 +568,9 @@ def user_to_uid(user):
         salt '*' file.user_to_uid myusername
     """
     if user is None:
-        user = salt.utils.user.get_user()
+        user = __utils__["user.get_user"]()
 
-    return salt.utils.win_dacl.get_sid_string(user)
+    return __utils__["dacl.get_sid_string"](user)
 
 
 def get_uid(path, follow_symlinks=True):
@@ -609,7 +590,6 @@ def get_uid(path, follow_symlinks=True):
     Returns:
         str: The uid of the owner
 
-
     CLI Example:
 
     .. code-block:: bash
@@ -618,7 +598,7 @@ def get_uid(path, follow_symlinks=True):
         salt '*' file.get_uid c:\\temp\\test.txt follow_symlinks=False
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
     # Under Windows, if the path is a symlink, the user that owns the symlink is
     # returned, not the user that owns the file/directory the symlink is
@@ -628,8 +608,8 @@ def get_uid(path, follow_symlinks=True):
     if follow_symlinks and sys.getwindowsversion().major >= 6:
         path = _resolve_symlink(path)
 
-    owner_sid = salt.utils.win_dacl.get_owner(path)
-    return salt.utils.win_dacl.get_sid_string(owner_sid)
+    owner_sid = __utils__["dacl.get_owner"](path)
+    return __utils__["dacl.get_sid_string"](owner_sid)
 
 
 def get_user(path, follow_symlinks=True):
@@ -649,7 +629,6 @@ def get_user(path, follow_symlinks=True):
     Returns:
         str: The name of the owner
 
-
     CLI Example:
 
     .. code-block:: bash
@@ -658,7 +637,7 @@ def get_user(path, follow_symlinks=True):
         salt '*' file.get_user c:\\temp\\test.txt follow_symlinks=False
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
     # Under Windows, if the path is a symlink, the user that owns the symlink is
     # returned, not the user that owns the file/directory the symlink is
@@ -668,7 +647,7 @@ def get_user(path, follow_symlinks=True):
     if follow_symlinks and sys.getwindowsversion().major >= 6:
         path = _resolve_symlink(path)
 
-    return salt.utils.win_dacl.get_owner(path)
+    return __utils__["dacl.get_owner"](path)
 
 
 def get_mode(path):
@@ -691,9 +670,9 @@ def get_mode(path):
         salt '*' file.get_mode /etc/passwd
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
-    func_name = "{0}.get_mode".format(__virtualname__)
+    func_name = "{}.get_mode".format(__virtualname__)
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -742,7 +721,7 @@ def lchown(path, user, group=None, pgroup=None):
         salt '*' file.lchown c:\\temp\\test.txt myusername "pgroup='None'"
     """
     if group:
-        func_name = "{0}.lchown".format(__virtualname__)
+        func_name = "{}.lchown".format(__virtualname__)
         if __opts__.get("fun", "") == func_name:
             log.info(
                 "The group parameter has no effect when using %s on "
@@ -791,7 +770,7 @@ def chown(path, user, group=None, pgroup=None, follow_symlinks=True):
     """
     # the group parameter is not used; only provided for API compatibility
     if group is not None:
-        func_name = "{0}.chown".format(__virtualname__)
+        func_name = "{}.chown".format(__virtualname__)
         if __opts__.get("fun", "") == func_name:
             log.info(
                 "The group parameter has no effect when using %s on "
@@ -804,11 +783,11 @@ def chown(path, user, group=None, pgroup=None, follow_symlinks=True):
         path = _resolve_symlink(path)
 
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
-    salt.utils.win_dacl.set_owner(path, user)
+    __utils__["dacl.set_owner"](path, user)
     if pgroup:
-        salt.utils.win_dacl.set_primary_group(path, pgroup)
+        __utils__["dacl.set_primary_group"](path, pgroup)
 
     return True
 
@@ -838,7 +817,7 @@ def chpgrp(path, group):
         salt '*' file.chpgrp c:\\temp\\test.txt Administrators
         salt '*' file.chpgrp c:\\temp\\test.txt "'None'"
     """
-    return salt.utils.win_dacl.set_primary_group(path, group)
+    return __utils__["dacl.set_primary_group"](path, group)
 
 
 def chgrp(path, group):
@@ -875,7 +854,7 @@ def chgrp(path, group):
 
         salt '*' file.chpgrp c:\\temp\\test.txt administrators
     """
-    func_name = "{0}.chgrp".format(__virtualname__)
+    func_name = "{}.chgrp".format(__virtualname__)
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; see "
@@ -921,7 +900,7 @@ def stats(path, hash_type="sha256", follow_symlinks=True):
     # This is to mirror the behavior of file.py. `check_file_meta` expects an
     # empty dictionary when the file does not exist
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
     if follow_symlinks and sys.getwindowsversion().major >= 6:
         path = _resolve_symlink(path)
@@ -942,7 +921,7 @@ def stats(path, hash_type="sha256", follow_symlinks=True):
     ret["mtime"] = pstat.st_mtime
     ret["ctime"] = pstat.st_ctime
     ret["size"] = pstat.st_size
-    ret["mode"] = salt.utils.files.normalize_mode(oct(stat.S_IMODE(pstat.st_mode)))
+    ret["mode"] = __utils__["files.normalize_mode"](oct(stat.S_IMODE(pstat.st_mode)))
     if hash_type:
         ret["sum"] = get_sum(path, hash_type)
     ret["type"] = "file"
@@ -982,7 +961,7 @@ def get_attributes(path):
         salt '*' file.get_attributes c:\\temp\\a.txt
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
     # set up dictionary for attribute values
     attributes = {}
@@ -1064,7 +1043,7 @@ def set_attributes(
         salt '*' file.set_attributes c:\\temp\\a.txt readonly=True hidden=True
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
     if normal:
         if archive or hidden or notIndexed or readonly or system or temporary:
@@ -1133,7 +1112,7 @@ def set_mode(path, mode):
 
         salt '*' file.set_mode /etc/passwd 0644
     """
-    func_name = "{0}.set_mode".format(__virtualname__)
+    func_name = "{}.set_mode".format(__virtualname__)
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -1169,11 +1148,11 @@ def remove(path, force=False):
     path = os.path.expanduser(path)
 
     if not os.path.isabs(path):
-        raise SaltInvocationError("File path must be absolute: {0}".format(path))
+        raise SaltInvocationError("File path must be absolute: {}".format(path))
 
     # Does the file/folder exists
     if not os.path.exists(path) and not is_link(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
     # Remove ReadOnly Attribute
     if force:
@@ -1190,17 +1169,17 @@ def remove(path, force=False):
             os.rmdir(path)
         else:
             for name in os.listdir(path):
-                item = "{0}\\{1}".format(path, name)
+                item = "{}\\{}".format(path, name)
                 # If its a normal directory, recurse to remove it's contents
                 remove(item, force)
 
             # rmdir will work now because the directory is empty
             os.rmdir(path)
-    except (OSError, IOError) as exc:
+    except OSError as exc:
         if force:
             # Reset attributes to the original if delete fails.
             win32api.SetFileAttributes(path, file_attributes)
-        raise CommandExecutionError("Could not remove '{0}': {1}".format(path, exc))
+        raise CommandExecutionError("Could not remove '{}': {}".format(path, exc))
 
     return True
 
@@ -1258,9 +1237,7 @@ def symlink(src, link):
         return True
     except win32file.error as exc:
         raise CommandExecutionError(
-            "Could not create '{0}' - [{1}] {2}".format(
-                link, exc.winerror, exc.strerror
-            )
+            "Could not create '{}' - [{}] {}".format(link, exc.winerror, exc.strerror)
         )
 
 
@@ -1292,7 +1269,7 @@ def is_link(path):
         )
 
     try:
-        return salt.utils.path.islink(path)
+        return __utils__["path.islink"](path)
     except Exception as exc:  # pylint: disable=broad-except
         raise CommandExecutionError(exc)
 
@@ -1325,10 +1302,10 @@ def readlink(path):
         )
 
     try:
-        return salt.utils.path.readlink(path)
+        return __utils__["path.readlink"](path)
     except OSError as exc:
         if exc.errno == errno.EINVAL:
-            raise CommandExecutionError("{0} is not a symbolic link".format(path))
+            raise CommandExecutionError("{} is not a symbolic link".format(path))
         raise CommandExecutionError(exc.__str__())
     except Exception as exc:  # pylint: disable=broad-except
         raise CommandExecutionError(exc)
@@ -1407,7 +1384,7 @@ def mkdir(
     # Make sure the drive is valid
     drive = os.path.splitdrive(path)[0]
     if not os.path.isdir(drive):
-        raise CommandExecutionError("Drive {0} is not mapped".format(drive))
+        raise CommandExecutionError("Drive {} is not mapped".format(drive))
 
     path = os.path.expanduser(path)
     path = os.path.expandvars(path)
@@ -1420,18 +1397,19 @@ def mkdir(
 
             # Set owner
             if owner:
-                salt.utils.win_dacl.set_owner(obj_name=path, principal=owner)
+                __utils__["dacl.set_owner"](obj_name=path, principal=owner)
 
             # Set permissions
-            set_perms(
-                path=path,
+            __utils__["dacl.set_perms"](
+                obj_name=path,
+                obj_type="file",
                 grant_perms=grant_perms,
                 deny_perms=deny_perms,
                 inheritance=inheritance,
                 reset=reset,
             )
 
-        except WindowsError as exc:
+        except OSError as exc:
             raise CommandExecutionError(exc)
 
     return True
@@ -1523,12 +1501,12 @@ def makedirs_(
 
     if os.path.isdir(dirname):
         # There's nothing for us to do
-        msg = "Directory '{0}' already exists".format(dirname)
+        msg = "Directory '{}' already exists".format(dirname)
         log.debug(msg)
         return msg
 
     if os.path.exists(dirname):
-        msg = "The path '{0}' already exists and is not a directory".format(dirname)
+        msg = "The path '{}' already exists and is not a directory".format(dirname)
         log.debug(msg)
         return msg
 
@@ -1543,7 +1521,7 @@ def makedirs_(
 
         if current_dirname == dirname:
             raise SaltInvocationError(
-                "Recursive creation for path '{0}' would result in an "
+                "Recursive creation for path '{}' would result in an "
                 "infinite loop. Please use an absolute path.".format(dirname)
             )
 
@@ -1737,7 +1715,7 @@ def check_perms(
         salt '*' file.check_perms C:\\Temp\\ {} Administrators "{'jsnuffy': {'perms': ['read_attributes', 'read_ea'], 'applies_to': 'files_only'}}"
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {0}".format(path))
+        raise CommandExecutionError("Path not found: {}".format(path))
 
     path = os.path.expanduser(path)
 
