@@ -75,12 +75,12 @@ A REST API for Salt
     debug : ``False``
         Starts the web server in development mode. It will reload itself when
         the underlying code is changed and will output more debugging info.
-    log.access_file
+    log_access_file
         Path to a file to write HTTP access logs.
 
         .. versionadded:: 2016.11.0
 
-    log.error_file
+    log_error_file
         Path to a file to write HTTP error logs.
 
         .. versionadded:: 2016.11.0
@@ -616,8 +616,7 @@ try:
 except AttributeError:
     cpstats = None
     logger.warn(
-        "Import of cherrypy.cpstats failed. "
-        "Possible upstream bug: "
+        "Import of cherrypy.cpstats failed. Possible upstream bug: "
         "https://github.com/cherrypy/cherrypy/issues/1444"
     )
 except ImportError:
@@ -691,7 +690,7 @@ def salt_api_acl_tool(username, request):
     in order to provide whitelisting for the API similar to the
     master, but over the API.
 
-    ..code-block:: yaml
+    .. code-block:: yaml
 
         rest_cherrypy:
             api_acl:
@@ -709,9 +708,9 @@ def salt_api_acl_tool(username, request):
     :param request: Cherrypy request to check against the API.
     :type request: cherrypy.request
     """
-    failure_str = "[api_acl] Authentication failed for " "user {0} from IP {1}"
-    success_str = "[api_acl] Authentication successful for user {0} from IP {1}"
-    pass_str = "[api_acl] Authentication not checked for " "user {0} from IP {1}"
+    failure_str = "[api_acl] Authentication failed for " "user %s from IP %s"
+    success_str = "[api_acl] Authentication successful for user %s from IP %s"
+    pass_str = "[api_acl] Authentication not checked for " "user %s from IP %s"
 
     acl = None
     # Salt Configuration
@@ -729,23 +728,23 @@ def salt_api_acl_tool(username, request):
         if users:
             if username in users:
                 if ip in users[username] or "*" in users[username]:
-                    logger.info(success_str.format(username, ip))
+                    logger.info(success_str, username, ip)
                     return True
                 else:
-                    logger.info(failure_str.format(username, ip))
+                    logger.info(failure_str, username, ip)
                     return False
             elif username not in users and "*" in users:
                 if ip in users["*"] or "*" in users["*"]:
-                    logger.info(success_str.format(username, ip))
+                    logger.info(success_str, username, ip)
                     return True
                 else:
-                    logger.info(failure_str.format(username, ip))
+                    logger.info(failure_str, username, ip)
                     return False
             else:
-                logger.info(failure_str.format(username, ip))
+                logger.info(failure_str, username, ip)
                 return False
     else:
-        logger.info(pass_str.format(username, ip))
+        logger.info(pass_str, username, ip)
         return True
 
 
@@ -762,11 +761,11 @@ def salt_ip_verify_tool():
         if cherrypy_conf:
             auth_ip_list = cherrypy_conf.get("authorized_ips", None)
             if auth_ip_list:
-                logger.debug("Found IP list: {}".format(auth_ip_list))
+                logger.debug("Found IP list: %s", auth_ip_list)
                 rem_ip = cherrypy.request.headers.get("Remote-Addr", None)
-                logger.debug("Request from IP: {}".format(rem_ip))
+                logger.debug("Request from IP: %s", rem_ip)
                 if rem_ip not in auth_ip_list:
-                    logger.error("Blocked IP: {}".format(rem_ip))
+                    logger.error("Blocked IP: %s", rem_ip)
                     raise cherrypy.HTTPError(403, "Bad IP")
 
 
@@ -894,7 +893,7 @@ def hypermedia_handler(*args, **kwargs):
 
         ret = {
             "status": cherrypy.response.status,
-            "return": "{}".format(traceback.format_exc(exc))
+            "return": "{}".format(traceback.format_exc())
             if cherrypy.config["debug"]
             else "An unexpected error occurred",
         }
@@ -968,7 +967,15 @@ def urlencoded_processor(entity):
     except (UnicodeDecodeError, AttributeError):
         pass
     cherrypy.serving.request.raw_body = urlencoded
-    cherrypy.serving.request.unserialized_data = dict(parse_qsl(urlencoded))
+    unserialized_data = {}
+    for key, val in parse_qsl(urlencoded):
+        unserialized_data.setdefault(key, []).append(val)
+    for key, val in unserialized_data.items():
+        if len(val) == 1:
+            unserialized_data[key] = val[0]
+        if len(val) == 0:
+            unserialized_data[key] = ""
+    cherrypy.serving.request.unserialized_data = unserialized_data
 
 
 @process_request_body
@@ -1898,10 +1905,9 @@ class Login(LowDataAdapter):
                 logger.debug("Eauth permission list not found.")
         except Exception:  # pylint: disable=broad-except
             logger.debug(
-                "Configuration for external_auth malformed for "
-                "eauth '{}', and user '{}'.".format(
-                    token.get("eauth"), token.get("name")
-                ),
+                "Configuration for external_auth malformed for eauth %r, and user %r.",
+                token.get("eauth"),
+                token.get("name"),
                 exc_info=True,
             )
             perms = None
@@ -2354,25 +2360,21 @@ class Events:
             """
             An iterator to yield Salt events
             """
-            event = salt.utils.event.get_event(
+            with salt.utils.event.get_event(
                 "master",
                 sock_dir=self.opts["sock_dir"],
                 transport=self.opts["transport"],
                 opts=self.opts,
                 listen=True,
-            )
-            stream = event.iter_events(full=True, auto_reconnect=True)
+            ) as event:
+                stream = event.iter_events(full=True, auto_reconnect=True)
 
-            yield "retry: 400\n"  # future lint: disable=blacklisted-function
+                yield "retry: 400\n"
 
-            while True:
-                data = next(stream)
-                yield "tag: {}\n".format(
-                    data.get("tag", "")
-                )  # future lint: disable=blacklisted-function
-                yield "data: {}\n\n".format(
-                    salt.utils.json.dumps(data)
-                )  # future lint: disable=blacklisted-function
+                while True:
+                    data = next(stream)
+                    yield "tag: {}\n".format(data.get("tag", ""))
+                    yield "data: {}\n\n".format(salt.utils.json.dumps(data))
 
         return listen()
 
@@ -2534,38 +2536,36 @@ class WebsocketEndpoint:
             # blocks until send is called on the parent end of this pipe.
             pipe.recv()
 
-            event = salt.utils.event.get_event(
+            with salt.utils.event.get_event(
                 "master",
                 sock_dir=self.opts["sock_dir"],
                 transport=self.opts["transport"],
                 opts=self.opts,
                 listen=True,
-            )
-            stream = event.iter_events(full=True, auto_reconnect=True)
-            SaltInfo = event_processor.SaltInfo(handler)
+            ) as event:
+                stream = event.iter_events(full=True, auto_reconnect=True)
+                SaltInfo = event_processor.SaltInfo(handler)
 
-            def signal_handler(signal, frame):
-                os._exit(0)
+                def signal_handler(signal, frame):
+                    os._exit(0)
 
-            signal.signal(signal.SIGTERM, signal_handler)
+                signal.signal(signal.SIGTERM, signal_handler)
 
-            while True:
-                data = next(stream)
-                if data:
-                    try:  # work around try to decode catch unicode errors
-                        if "format_events" in kwargs:
-                            SaltInfo.process(data, salt_token, self.opts)
-                        else:
-                            handler.send(
-                                "data: {}\n\n".format(
-                                    salt.utils.json.dumps(data)
-                                ),  # future lint: disable=blacklisted-function
-                                False,
+                while True:
+                    data = next(stream)
+                    if data:
+                        try:  # work around try to decode catch unicode errors
+                            if "format_events" in kwargs:
+                                SaltInfo.process(data, salt_token, self.opts)
+                            else:
+                                handler.send(
+                                    "data: {}\n\n".format(salt.utils.json.dumps(data)),
+                                    False,
+                                )
+                        except UnicodeDecodeError:
+                            logger.error(
+                                "Error: Salt event has non UTF-8 data:\n%s", data
                             )
-                    except UnicodeDecodeError:
-                        logger.error(
-                            "Error: Salt event has non UTF-8 data:\n{}".format(data)
-                        )
 
         parent_pipe, child_pipe = Pipe()
         handler.pipe = parent_pipe
@@ -2792,7 +2792,7 @@ class App:
         This is useful in combination with a browser-based app using the HTML5
         history API.
 
-        .. http::get:: /app
+        .. http:get:: /app
 
             :reqheader X-Auth-Token: |req_token|
 
