@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Use LDAP data as a Pillar source
 
@@ -121,17 +120,10 @@ Result
         ]
     }
 """
-
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import os
 
-# Import third party libs
 import jinja2
-
-# Import salt libs
 import salt.utils.data
 from salt.exceptions import SaltInvocationError
 
@@ -336,11 +328,13 @@ def ext_pillar(
     except Exception as err:  # pylint: disable=broad-except
         import salt.log
 
-        msg = "pillar_ldap: error parsing configuration file: {0} - {1}"
+        msg = "pillar_ldap: error parsing configuration file: {} - {}".format(
+            config_file, err
+        )
         if salt.log.is_console_configured():
-            log.warning(msg.format(config_file, err))
+            log.warning(msg)
         else:
-            print(msg.format(config_file, err))
+            print(msg)
         return {}
     else:
         if not isinstance(opts, dict):
