@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Simple and flexible YAML ext_pillar which can read pillar from within pillar.
 
@@ -41,7 +40,7 @@ Installing the PillarStack ``ext_pillar`` is as simple as dropping the
 ``stack.py`` file in the ``<extension_modules>/pillar`` directory (no external
 python module required), given that ``extension_modules`` is set in your
 salt-master configuration, see:
-http://docs.saltstack.com/en/latest/ref/configuration/master.html#extension-modules
+https://docs.saltproject.io/en/latest/ref/configuration/master.html#extension-modules
 
 Configuration in Salt
 ---------------------
@@ -373,10 +372,6 @@ You can also select a custom merging strategy using a ``__`` object in a list:
 |       - root   |       - mat             |                         |
 +----------------+-------------------------+-------------------------+
 """
-
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import functools
 import glob
 import logging
@@ -388,9 +383,6 @@ import salt.utils.jinja
 import salt.utils.yaml
 from jinja2 import Environment, FileSystemLoader
 
-# Import Salt libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 strategies = ("overwrite", "merge-first", "merge-last", "remove")
 
@@ -403,12 +395,13 @@ def ext_pillar(minion_id, pillar, *args, **kwargs):
         "grains": functools.partial(salt.utils.data.traverse_dict_and_list, __grains__),
         "opts": functools.partial(salt.utils.data.traverse_dict_and_list, __opts__),
     }
-    for matcher, matchs in six.iteritems(kwargs):
+    for matcher, matchs in kwargs.items():
         t, matcher = matcher.split(":", 1)
         if t not in traverse:
             raise Exception(
-                'Unknown traverse option "{0}", '
-                "should be one of {1}".format(t, traverse.keys())
+                'Unknown traverse option "{}", should be one of {}'.format(
+                    t, traverse.keys()
+                )
             )
         cfgs = matchs.get(traverse[t](matcher, None), [])
         if not isinstance(cfgs, list):
@@ -452,8 +445,7 @@ def _process_stack_cfg(cfg, stack, minion_id, pillar):
         paths = glob.glob(os.path.join(basedir, item))
         if not paths:
             log.info(
-                'Ignoring pillar stack template "%s": can\'t find from root '
-                'dir "%s"',
+                'Ignoring pillar stack template "%s": can\'t find from root dir "%s"',
                 item,
                 basedir,
             )
@@ -480,7 +472,7 @@ def _cleanup(obj):
     if obj:
         if isinstance(obj, dict):
             obj.pop("__", None)
-            for k, v in six.iteritems(obj):
+            for k, v in obj.items():
                 obj[k] = _cleanup(v)
         elif isinstance(obj, list) and isinstance(obj[0], dict) and "__" in obj[0]:
             del obj[0]
@@ -491,12 +483,12 @@ def _merge_dict(stack, obj):
     strategy = obj.pop("__", "merge-last")
     if strategy not in strategies:
         raise Exception(
-            'Unknown strategy "{0}", should be one of {1}'.format(strategy, strategies)
+            'Unknown strategy "{}", should be one of {}'.format(strategy, strategies)
         )
     if strategy == "overwrite":
         return _cleanup(obj)
     else:
-        for k, v in six.iteritems(obj):
+        for k, v in obj.items():
             if strategy == "remove":
                 stack.pop(k, None)
                 continue
@@ -530,7 +522,7 @@ def _merge_list(stack, obj):
         del obj[0]
     if strategy not in strategies:
         raise Exception(
-            'Unknown strategy "{0}", should be one of {1}'.format(strategy, strategies)
+            'Unknown strategy "{}", should be one of {}'.format(strategy, strategies)
         )
     if strategy == "overwrite":
         return obj
