@@ -7,19 +7,17 @@
     It's just a wrapper around the python toml module.
 """
 
-# Import Salt libs
 from salt.serializers import DeserializationError, SerializationError
 
-# Import toml
 try:
     import toml
 
-    available = True
+    HAS_TOML = True
 except ImportError:
-    available = False
+    HAS_TOML = False
 
 
-__all__ = ["deserialize", "serialize", "available"]
+__all__ = ["deserialize", "serialize", "HAS_TOML"]
 
 
 def deserialize(stream_or_string, **options):
