@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of PostgreSQL users (roles)
 ======================================
@@ -10,20 +9,13 @@ The postgres_users module is used to create and manage Postgres users.
     frank:
       postgres_user.present
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import Python libs
 import datetime
 import logging
 
-from salt.ext import six
-
 # Salt imports
 from salt.modules import postgres
 
-# Import salt libs
-
-
 log = logging.getLogger(__name__)
 
 
@@ -63,7 +55,7 @@ def present(
     """
     Ensure that the named user is present with the specified privileges
     Please note that the user/group notion in postgresql is just abstract, we
-    have roles, where users can be seens as roles with the LOGIN privilege
+    have roles, where users can be seen as roles with the LOGIN privilege
     and groups the others.
 
     name
@@ -76,7 +68,19 @@ def present(
         Is the user allowed to create other users?
 
     encrypted
-        Should the password be encrypted in the system catalog?
+        How the password should be stored.
+
+        If encrypted is ``None``, ``True``, or ``md5``, it will use
+        PostgreSQL's MD5 algorithm.
+
+        If encrypted is ``False``, it will be stored in plaintext.
+
+        If encrypted is ``scram-sha-256``, it will use the algorithm described
+        in RFC 7677.
+
+        .. versionchanged:: 3003
+
+            Prior versions only supported ``True`` and ``False``
 
     login
         Should the group have login perm
@@ -91,14 +95,15 @@ def present(
         Should the new user be allowed to initiate streaming replication
 
     password
-        The system user's password. It can be either a plain string or a
-        md5 postgresql hashed password::
+        The user's password.
+        It can be either a plain string or a pre-hashed password::
 
             'md5{MD5OF({password}{role}}'
+            'SCRAM-SHA-256${iterations}:{salt}${stored_key}:{server_key}'
 
-        If encrypted is None or True, the password will be automatically
-        encrypted to the previous
-        format if it is not already done.
+        If encrypted is not ``False``, then the password will be converted
+        to the appropriate format above, if not already. As a consequence,
+        passwords that start with "md5" or "SCRAM-SHA-256" cannot be used.
 
     default_password
         The password used only when creating the user, unless password is set.
@@ -144,20 +149,9 @@ def present(
         "name": name,
         "changes": {},
         "result": True,
-        "comment": "User {0} is already present".format(name),
+        "comment": "User {} is already present".format(name),
     }
 
-    # default to encrypted passwords
-    if encrypted is not False:
-        encrypted = postgres._DEFAULT_PASSWORDS_ENCRYPTION
-    # maybe encrypt if it's not already and necessary
-    password = postgres._maybe_encrypt_password(name, password, encrypted=encrypted)
-
-    if default_password is not None:
-        default_password = postgres._maybe_encrypt_password(
-            name, default_password, encrypted=encrypted
-        )
-
     db_args = {
         "maintenance_db": maintenance_db,
         "runas": user,
@@ -167,6 +161,10 @@ def present(
         "password": db_password,
     }
 
+    # default to encrypted passwords
+    if encrypted is None:
+        encrypted = postgres._DEFAULT_PASSWORDS_ENCRYPTION
+
     # check if user exists
     mode = "create"
     user_attr = __salt__["postgres.role_get"](
@@ -175,7 +173,25 @@ def present(
     if user_attr is not None:
         mode = "update"
 
-    cret = None
+    if mode == "create" and password is None:
+        password = default_password
+
+    if password is not None:
+        if (
+            mode == "update"
+            and not refresh_password
+            and postgres._verify_password(
+                name, password, user_attr["password"], encrypted
+            )
+        ):
+            # if password already matches then don't touch it
+            password = None
+        else:
+            # encrypt password if necessary
+            password = postgres._maybe_encrypt_password(
+                name, password, encrypted=encrypted
+            )
+
     update = {}
     if mode == "update":
         user_groups = user_attr.get("groups", [])
@@ -191,13 +207,11 @@ def present(
             update["replication"] = replication
         if superuser is not None and user_attr["superuser"] != superuser:
             update["superuser"] = superuser
-        if password is not None and (
-            refresh_password or user_attr["password"] != password
-        ):
+        if password is not None:
             update["password"] = True
         if valid_until is not None:
             valid_until_dt = __salt__["postgres.psql_query"](
-                "SELECT '{0}'::timestamp(0) as dt;".format(
+                "SELECT '{}'::timestamp(0) as dt;".format(
                     valid_until.replace("'", "''")
                 ),
                 **db_args
@@ -212,24 +226,21 @@ def present(
                 update["valid_until"] = valid_until
         if groups is not None:
             lgroups = groups
-            if isinstance(groups, (six.string_types, six.text_type)):
+            if isinstance(groups, str):
                 lgroups = lgroups.split(",")
             if isinstance(lgroups, list):
                 missing_groups = [a for a in lgroups if a not in user_groups]
                 if missing_groups:
                     update["groups"] = missing_groups
 
-    if mode == "create" and password is None:
-        password = default_password
-
     if mode == "create" or (mode == "update" and update):
         if __opts__["test"]:
             if update:
                 ret["changes"][name] = update
             ret["result"] = None
-            ret["comment"] = "User {0} is set to be {1}d".format(name, mode)
+            ret["comment"] = "User {} is set to be {}d".format(name, mode)
             return ret
-        cret = __salt__["postgres.user_{0}".format(mode)](
+        cret = __salt__["postgres.user_{}".format(mode)](
             username=name,
             createdb=createdb,
             createroles=createroles,
@@ -247,13 +258,13 @@ def present(
         cret = None
 
     if cret:
-        ret["comment"] = "The user {0} has been {1}d".format(name, mode)
+        ret["comment"] = "The user {} has been {}d".format(name, mode)
         if update:
             ret["changes"][name] = update
         else:
             ret["changes"][name] = "Present"
     elif cret is not None:
-        ret["comment"] = "Failed to create user {0}".format(name)
+        ret["comment"] = "Failed to {} user {}".format(mode, name)
         ret["result"] = False
     else:
         ret["result"] = True
@@ -307,19 +318,17 @@ def absent(
     if __salt__["postgres.user_exists"](name, **db_args):
         if __opts__["test"]:
             ret["result"] = None
-            ret["comment"] = "User {0} is set to be removed".format(name)
+            ret["comment"] = "User {} is set to be removed".format(name)
             return ret
         if __salt__["postgres.user_remove"](name, **db_args):
-            ret["comment"] = "User {0} has been removed".format(name)
+            ret["comment"] = "User {} has been removed".format(name)
             ret["changes"][name] = "Absent"
             return ret
         else:
             ret["result"] = False
-            ret["comment"] = "User {0} failed to be removed".format(name)
+            ret["comment"] = "User {} failed to be removed".format(name)
             return ret
     else:
-        ret["comment"] = "User {0} is not present, so it cannot " "be removed".format(
-            name
-        )
+        ret["comment"] = "User {} is not present, so it cannot be removed".format(name)
 
     return ret
