@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Cobbler Tops
 ============
 
@@ -18,44 +17,40 @@ the Cobbler tops and Cobbler pillar modules.
 
 Module Documentation
 ====================
-'''
-from __future__ import absolute_import
+"""
 
-# Import python libs
 import logging
-import salt.ext.six.moves.xmlrpc_client  # pylint: disable=E0611
-
+import xmlrpc.client
 
 # Set up logging
 log = logging.getLogger(__name__)
 
 
-__opts__ = {'cobbler.url': 'http://localhost/cobbler_api',
-            'cobbler.user': None,
-            'cobbler.password': None
-           }
+__opts__ = {
+    "cobbler.url": "http://localhost/cobbler_api",
+    "cobbler.user": None,
+    "cobbler.password": None,
+}
 
 
 def top(**kwargs):
-    '''
+    """
     Look up top data in Cobbler for a minion.
-    '''
-    url = __opts__['cobbler.url']
-    user = __opts__['cobbler.user']
-    password = __opts__['cobbler.password']
+    """
+    url = __opts__["cobbler.url"]
+    user = __opts__["cobbler.user"]
+    password = __opts__["cobbler.password"]
 
-    minion_id = kwargs['opts']['id']
+    minion_id = kwargs["opts"]["id"]
 
     log.info("Querying cobbler for information for %r", minion_id)
     try:
-        server = salt.ext.six.moves.xmlrpc_client.Server(url, allow_none=True)
+        server = xmlrpc.client.Server(url, allow_none=True)
         if user:
             server.login(user, password)
         data = server.get_blended_data(None, minion_id)
-    except Exception:
-        log.exception(
-            'Could not connect to cobbler.'
-        )
+    except Exception:  # pylint: disable=broad-except
+        log.exception("Could not connect to cobbler.")
         return {}
 
-    return {data['status']: data['mgmt_classes']}
+    return {data["status"]: data["mgmt_classes"]}
