@@ -1,9 +1,6 @@
 """
 Zeromq transport classes
 """
-
-
-import copy
 import errno
 import hashlib
 import logging
@@ -11,7 +8,7 @@ import os
 import signal
 import sys
 import threading
-import weakref
+import uuid
 from random import randint
 
 import salt.auth
@@ -38,14 +35,7 @@ import zmq.eventloop.ioloop
 import zmq.eventloop.zmqstream
 from salt._compat import ipaddress
 from salt.exceptions import SaltException, SaltReqTimeoutError
-from salt.ext import six
-from salt.utils.zeromq import (
-    LIBZMQ_VERSION_INFO,
-    ZMQ_VERSION_INFO,
-    ZMQDefaultLoop,
-    install_zmq,
-    zmq,
-)
+from salt.utils.zeromq import LIBZMQ_VERSION_INFO, ZMQ_VERSION_INFO, zmq
 
 try:
     import zmq.utils.monitor
@@ -64,7 +54,8 @@ except ImportError:
     try:
         from Cryptodome.Cipher import PKCS1_OAEP
     except ImportError:
-        from Crypto.Cipher import PKCS1_OAEP
+        from Crypto.Cipher import PKCS1_OAEP  # nosec
+
 
 log = logging.getLogger(__name__)
 
@@ -77,22 +68,24 @@ def _get_master_uri(master_ip, master_port, source_ip=None, source_port=None):
     rc = zmq_connect(socket, "tcp://192.168.1.17:5555;192.168.1.1:5555"); assert (rc == 0);
     Source: http://api.zeromq.org/4-1:zmq-tcp
     """
+
     from salt.utils.zeromq import ip_bracket
 
     master_uri = "tcp://{master_ip}:{master_port}".format(
         master_ip=ip_bracket(master_ip), master_port=master_port
     )
-
     if source_ip or source_port:
         if LIBZMQ_VERSION_INFO >= (4, 1, 6) and ZMQ_VERSION_INFO >= (16, 0, 1):
             # The source:port syntax for ZeroMQ has been added in libzmq 4.1.6
             # which is included in the pyzmq wheels starting with 16.0.1.
             if source_ip and source_port:
-                master_uri = "tcp://{source_ip}:{source_port};{master_ip}:{master_port}".format(
-                    source_ip=ip_bracket(source_ip),
-                    source_port=source_port,
-                    master_ip=ip_bracket(master_ip),
-                    master_port=master_port,
+                master_uri = (
+                    "tcp://{source_ip}:{source_port};{master_ip}:{master_port}".format(
+                        source_ip=ip_bracket(source_ip),
+                        source_port=source_port,
+                        master_ip=ip_bracket(master_ip),
+                        master_port=master_port,
+                    )
                 )
             elif source_ip and not source_port:
                 master_uri = "tcp://{source_ip}:0;{master_ip}:{master_port}".format(
@@ -106,11 +99,13 @@ def _get_master_uri(master_ip, master_port, source_ip=None, source_port=None):
                     if ipaddress.ip_address(master_ip).version == 4
                     else ip_bracket("::")
                 )
-                master_uri = "tcp://{ip_any}:{source_port};{master_ip}:{master_port}".format(
-                    ip_any=ip_any,
-                    source_port=source_port,
-                    master_ip=ip_bracket(master_ip),
-                    master_port=master_port,
+                master_uri = (
+                    "tcp://{ip_any}:{source_port};{master_ip}:{master_port}".format(
+                        ip_any=ip_any,
+                        source_port=source_port,
+                        master_ip=ip_bracket(master_ip),
+                        master_port=master_port,
+                    )
                 )
         else:
             log.warning(
@@ -118,7 +113,8 @@ def _get_master_uri(master_ip, master_port, source_ip=None, source_port=None):
             )
             log.warning("Consider upgrading to pyzmq >= 16.0.1 and libzmq >= 4.1.6")
             log.warning(
-                "Specific source IP / port for connecting to master returner port: configuraion ignored"
+                "Specific source IP / port for connecting to master returner port:"
+                " configuraion ignored"
             )
 
     return master_uri
@@ -131,9 +127,6 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
     ZMQ Channels default to 'crypt=aes'
     """
 
-    # This class is only a singleton per minion/master pair
-    # mapping of io_loop -> {key -> channel}
-    instance_map = weakref.WeakKeyDictionary()
     async_methods = [
         "crypted_transfer_decode_dictentry",
         "_crypted_transfer",
@@ -145,103 +138,7 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
         "close",
     ]
 
-    def __new__(cls, opts, **kwargs):
-        """
-        Only create one instance of channel per __key()
-        """
-
-        # do we have any mapping for this io_loop
-        io_loop = kwargs.get("io_loop")
-        if io_loop is None:
-            install_zmq()
-            io_loop = ZMQDefaultLoop.current()
-        if io_loop not in cls.instance_map:
-            cls.instance_map[io_loop] = weakref.WeakValueDictionary()
-        loop_instance_map = cls.instance_map[io_loop]
-
-        key = cls.__key(opts, **kwargs)
-        obj = loop_instance_map.get(key)
-        if obj is None:
-            log.debug("Initializing new AsyncZeroMQReqChannel for %s", key)
-            # we need to make a local variable for this, as we are going to store
-            # it in a WeakValueDictionary-- which will remove the item if no one
-            # references it-- this forces a reference while we return to the caller
-            obj = object.__new__(cls)
-            obj.__singleton_init__(opts, **kwargs)
-            obj._instance_key = key
-            loop_instance_map[key] = obj
-            obj._refcount = 1
-            obj._refcount_lock = threading.RLock()
-            log.trace(
-                "Inserted key into loop_instance_map id %s for key %s and process %s",
-                id(loop_instance_map),
-                key,
-                os.getpid(),
-            )
-        else:
-            with obj._refcount_lock:
-                obj._refcount += 1
-            log.debug("Re-using AsyncZeroMQReqChannel for %s", key)
-        return obj
-
-    def __deepcopy__(self, memo):
-        cls = self.__class__
-        # pylint: disable=too-many-function-args
-        result = cls.__new__(cls, copy.deepcopy(self.opts, memo))
-        # pylint: enable=too-many-function-args
-        memo[id(self)] = result
-        for key in self.__dict__:
-            if key in ("_io_loop", "_refcount", "_refcount_lock"):
-                continue
-                # The _io_loop has a thread Lock which will fail to be deep
-                # copied. Skip it because it will just be recreated on the
-                # new copy.
-            if key == "message_client":
-                # Recreate the message client because it will fail to be deep
-                # copied. The reason is the same as the io_loop skip above.
-                setattr(
-                    result,
-                    key,
-                    AsyncReqMessageClientPool(
-                        result.opts,
-                        args=(result.opts, self.master_uri,),
-                        kwargs={"io_loop": self._io_loop},
-                    ),
-                )
-
-                continue
-            setattr(result, key, copy.deepcopy(self.__dict__[key], memo))
-        return result
-
-    @classmethod
-    def force_close_all_instances(cls):
-        """
-        Will force close all instances
-
-        ZMQ can hang on quit if left to deconstruct on its own.
-        This because is deconstructs out of order.
-
-        :return: None
-        """
-        for weak_dict in list(cls.instance_map.values()):
-            for instance in list(weak_dict.values()):
-                instance.close()
-
-    @classmethod
-    def __key(cls, opts, **kwargs):
-        return (
-            opts["pki_dir"],  # where the keys are stored
-            opts["id"],  # minion ID
-            kwargs.get("master_uri", opts.get("master_uri")),  # master ID
-            kwargs.get("crypt", "aes"),  # TODO: use the same channel for crypt
-        )
-
-    # has to remain empty for singletons, since __init__ will *always* be called
     def __init__(self, opts, **kwargs):
-        pass
-
-    # an init for the singleton instance to call
-    def __singleton_init__(self, opts, **kwargs):
         self.opts = dict(opts)
         self.ttype = "zeromq"
 
@@ -253,8 +150,7 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
 
         self._io_loop = kwargs.get("io_loop")
         if self._io_loop is None:
-            install_zmq()
-            self._io_loop = ZMQDefaultLoop.current()
+            self._io_loop = salt.ext.tornado.ioloop.IOLoop.current()
 
         if self.crypt != "clear":
             # we don't need to worry about auth as a kwarg, since its a singleton
@@ -265,7 +161,10 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
         )
         self.message_client = AsyncReqMessageClientPool(
             self.opts,
-            args=(self.opts, self.master_uri,),
+            args=(
+                self.opts,
+                self.master_uri,
+            ),
             kwargs={"io_loop": self._io_loop},
         )
         self._closing = False
@@ -277,39 +176,13 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
         """
         if self._closing:
             return
-
-        if self._refcount > 1:
-            # Decrease refcount
-            with self._refcount_lock:
-                self._refcount -= 1
-            log.debug(
-                "This is not the last %s instance. Not closing yet.",
-                self.__class__.__name__,
-            )
-            return
-
         log.debug("Closing %s instance", self.__class__.__name__)
         self._closing = True
         if hasattr(self, "message_client"):
             self.message_client.close()
 
-        # Remove the entry from the instance map so that a closed entry may not
-        # be reused.
-        # This forces this operation even if the reference count of the entry
-        # has not yet gone to zero.
-        if self._io_loop in self.__class__.instance_map:
-            loop_instance_map = self.__class__.instance_map[self._io_loop]
-            if self._instance_key in loop_instance_map:
-                del loop_instance_map[self._instance_key]
-            if not loop_instance_map:
-                del self.__class__.instance_map[self._io_loop]
-
     # pylint: disable=W1701
     def __del__(self):
-        with self._refcount_lock:
-            # Make sure we actually close no matter if something
-            # went wrong with our ref counting
-            self._refcount = 1
         try:
             self.close()
         except OSError as exc:
@@ -340,22 +213,27 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
         return {
             "enc": self.crypt,
             "load": load,
+            "version": 2,
         }
 
     @salt.ext.tornado.gen.coroutine
     def crypted_transfer_decode_dictentry(
         self, load, dictkey=None, tries=3, timeout=60
     ):
+        nonce = uuid.uuid4().hex
+        load["nonce"] = nonce
         if not self.auth.authenticated:
             # Return control back to the caller, continue when authentication succeeds
             yield self.auth.authenticate()
-        # Return control to the caller. When send() completes, resume by populating ret with the Future.result
+
+        # Return control to the caller. When send() completes, resume by
+        # populating ret with the Future.result
         ret = yield self.message_client.send(
             self._package_load(self.auth.crypticle.dumps(load)),
             timeout=timeout,
             tries=tries,
         )
-        key = self.auth.get_keys()
+
         if "key" not in ret:
             # Reauth in the case our key is deleted on the master side.
             yield self.auth.authenticate()
@@ -364,15 +242,36 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
                 timeout=timeout,
                 tries=tries,
             )
+
+        key = self.auth.get_keys()
         if HAS_M2:
             aes = key.private_decrypt(ret["key"], RSA.pkcs1_oaep_padding)
         else:
             cipher = PKCS1_OAEP.new(key)
             aes = cipher.decrypt(ret["key"])
+
+        # Decrypt using the public key.
         pcrypt = salt.crypt.Crypticle(self.opts, aes)
-        data = pcrypt.loads(ret[dictkey])
-        data = salt.transport.frame.decode_embedded_strs(data)
-        raise salt.ext.tornado.gen.Return(data)
+        signed_msg = pcrypt.loads(ret[dictkey])
+
+        # Validate the master's signature.
+        master_pubkey_path = os.path.join(self.opts["pki_dir"], "minion_master.pub")
+        if not salt.crypt.verify_signature(
+            master_pubkey_path, signed_msg["data"], signed_msg["sig"]
+        ):
+            raise salt.crypt.AuthenticationError(
+                "Pillar payload signature failed to validate."
+            )
+
+        # Make sure the signed key matches the key we used to decrypt the data.
+        data = salt.payload.loads(signed_msg["data"])
+        if data["key"] != ret["key"]:
+            raise salt.crypt.AuthenticationError("Key verification failed.")
+
+        # Validate the nonce.
+        if data["nonce"] != nonce:
+            raise salt.crypt.AuthenticationError("Pillar nonce verification failed.")
+        raise salt.ext.tornado.gen.Return(data["pillar"])
 
     @salt.ext.tornado.gen.coroutine
     def _crypted_transfer(self, load, tries=3, timeout=60, raw=False):
@@ -389,6 +288,9 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
         :param int tries: The number of times to make before failure
         :param int timeout: The number of seconds on a response before failing
         """
+        nonce = uuid.uuid4().hex
+        if load and isinstance(load, dict):
+            load["nonce"] = nonce
 
         @salt.ext.tornado.gen.coroutine
         def _do_transfer():
@@ -403,8 +305,8 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
             # communication, we do not subscribe to return events, we just
             # upload the results to the master
             if data:
-                data = self.auth.crypticle.loads(data, raw)
-            if six.PY3 and not raw:
+                data = self.auth.crypticle.loads(data, raw, nonce)
+            if not raw:
                 data = salt.transport.frame.decode_embedded_strs(data)
             raise salt.ext.tornado.gen.Return(data)
 
@@ -430,7 +332,9 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
         :param int timeout: The number of seconds on a response before failing
         """
         ret = yield self.message_client.send(
-            self._package_load(load), timeout=timeout, tries=tries,
+            self._package_load(load),
+            timeout=timeout,
+            tries=tries,
         )
 
         raise salt.ext.tornado.gen.Return(ret)
@@ -469,16 +373,15 @@ class AsyncZeroMQPubChannel(
         self.opts = opts
         self.ttype = "zeromq"
         self.io_loop = kwargs.get("io_loop")
+        self._closing = False
 
         if self.io_loop is None:
-            install_zmq()
-            self.io_loop = ZMQDefaultLoop.current()
+            self.io_loop = salt.ext.tornado.ioloop.IOLoop.current()
 
         self.hexid = hashlib.sha1(
             salt.utils.stringutils.to_bytes(self.opts["id"])
         ).hexdigest()
         self.auth = salt.crypt.AsyncAuth(self.opts, io_loop=self.io_loop)
-        self.serial = salt.payload.Serial(self.opts)
         self.context = zmq.Context()
         self._socket = self.context.socket(zmq.SUB)
 
@@ -548,16 +451,16 @@ class AsyncZeroMQPubChannel(
             self._monitor.start_io_loop(self.io_loop)
 
     def close(self):
+        if self._closing is True:
+            return
+
+        self._closing = True
+
         if hasattr(self, "_monitor") and self._monitor is not None:
             self._monitor.stop()
             self._monitor = None
         if hasattr(self, "_stream"):
-            if ZMQ_VERSION_INFO < (14, 3, 0):
-                # stream.close() doesn't work properly on pyzmq < 14.3.0
-                self._stream.io_loop.remove_handler(self._stream.socket)
-                self._stream.socket.close(0)
-            else:
-                self._stream.close(0)
+            self._stream.close(0)
         elif hasattr(self, "_socket"):
             self._socket.close(0)
         if hasattr(self, "context") and self.context.closed is False:
@@ -568,6 +471,11 @@ class AsyncZeroMQPubChannel(
         self.close()
 
     # pylint: enable=W1701
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.close()
 
     # TODO: this is the time to see if we are connected, maybe use the req channel to guess?
     @salt.ext.tornado.gen.coroutine
@@ -610,7 +518,7 @@ class AsyncZeroMQPubChannel(
         messages_len = len(messages)
         # if it was one message, then its old style
         if messages_len == 1:
-            payload = self.serial.loads(messages[0])
+            payload = salt.payload.loads(messages[0])
         # 2 includes a header which says who should do it
         elif messages_len == 2:
             message_target = salt.utils.stringutils.to_str(messages[0])
@@ -623,13 +531,12 @@ class AsyncZeroMQPubChannel(
             ):
                 log.debug("Publish received for not this minion: %s", message_target)
                 raise salt.ext.tornado.gen.Return(None)
-            payload = self.serial.loads(messages[1])
+            payload = salt.payload.loads(messages[1])
         else:
             raise Exception(
-                (
-                    "Invalid number of messages ({}) in zeromq pub"
-                    "message from master"
-                ).format(len(messages_len))
+                "Invalid number of messages ({}) in zeromq pubmessage from master".format(
+                    len(messages_len)
+                )
             )
         # Yield control back to the caller. When the payload has been decoded, assign
         # the decoded payload to 'ret' and resume operation
@@ -671,6 +578,8 @@ class ZeroMQReqServerChannel(
     def __init__(self, opts):
         salt.transport.server.ReqServerChannel.__init__(self, opts)
         self._closing = False
+        self._monitor = None
+        self._w_monitor = None
 
     def zmq_device(self):
         """
@@ -729,7 +638,6 @@ class ZeroMQReqServerChannel(
             return
         log.info("MWorkerQueue under PID %s is closing", os.getpid())
         self._closing = True
-        # pylint: disable=E0203
         if getattr(self, "_monitor", None) is not None:
             self._monitor.stop()
             self._monitor = None
@@ -746,7 +654,6 @@ class ZeroMQReqServerChannel(
             self._socket.close()
         if hasattr(self, "context") and self.context.closed is False:
             self.context.term()
-        # pylint: enable=E0203
 
     def pre_fork(self, process_manager):
         """
@@ -820,7 +727,7 @@ class ZeroMQReqServerChannel(
         :param dict payload: A payload to process
         """
         try:
-            payload = self.serial.loads(payload[0])
+            payload = salt.payload.loads(payload[0])
             payload = self._decode_payload(payload)
         except Exception as exc:  # pylint: disable=broad-except
             exc_type = type(exc).__name__
@@ -833,7 +740,7 @@ class ZeroMQReqServerChannel(
                 )
             else:
                 log.error("Bad load from minion: %s: %s", exc_type, exc)
-            stream.send(self.serial.dumps("bad load"))
+            stream.send(salt.payload.dumps("bad load"))
             raise salt.ext.tornado.gen.Return()
 
         # TODO helper functions to normalize payload?
@@ -843,28 +750,40 @@ class ZeroMQReqServerChannel(
                 payload,
                 payload.get("load"),
             )
-            stream.send(self.serial.dumps("payload and load must be a dict"))
+            stream.send(salt.payload.dumps("payload and load must be a dict"))
             raise salt.ext.tornado.gen.Return()
 
         try:
             id_ = payload["load"].get("id", "")
             if "\0" in id_:
                 log.error("Payload contains an id with a null byte: %s", payload)
-                stream.send(self.serial.dumps("bad load: id contains a null byte"))
+                stream.send(salt.payload.dumps("bad load: id contains a null byte"))
                 raise salt.ext.tornado.gen.Return()
         except TypeError:
             log.error("Payload contains non-string id: %s", payload)
             stream.send(
-                self.serial.dumps("bad load: id {} is not a string".format(id_))
+                salt.payload.dumps("bad load: id {} is not a string".format(id_))
             )
             raise salt.ext.tornado.gen.Return()
 
+        version = 0
+        if "version" in payload:
+            version = payload["version"]
+
+        sign_messages = False
+        if version > 1:
+            sign_messages = True
+
         # intercept the "_auth" commands, since the main daemon shouldn't know
         # anything about our key auth
         if payload["enc"] == "clear" and payload.get("load", {}).get("cmd") == "_auth":
-            stream.send(self.serial.dumps(self._auth(payload["load"])))
+            stream.send(salt.payload.dumps(self._auth(payload["load"], sign_messages)))
             raise salt.ext.tornado.gen.Return()
 
+        nonce = None
+        if version > 1:
+            nonce = payload["load"].pop("nonce", None)
+
         # TODO: test
         try:
             # Take the payload_handler function that was registered when we created the channel
@@ -878,13 +797,19 @@ class ZeroMQReqServerChannel(
 
         req_fun = req_opts.get("fun", "send")
         if req_fun == "send_clear":
-            stream.send(self.serial.dumps(ret))
+            stream.send(salt.payload.dumps(ret))
         elif req_fun == "send":
-            stream.send(self.serial.dumps(self.crypticle.dumps(ret)))
+            stream.send(salt.payload.dumps(self.crypticle.dumps(ret, nonce)))
         elif req_fun == "send_private":
             stream.send(
-                self.serial.dumps(
-                    self._encrypt_private(ret, req_opts["key"], req_opts["tgt"],)
+                salt.payload.dumps(
+                    self._encrypt_private(
+                        ret,
+                        req_opts["key"],
+                        req_opts["tgt"],
+                        nonce,
+                        sign_messages,
+                    )
                 )
             )
         else:
@@ -942,7 +867,6 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
 
     def __init__(self, opts):
         self.opts = opts
-        self.serial = salt.payload.Serial(self.opts)  # TODO: in init?
         self.ckminions = salt.utils.minions.CkMinions(self.opts)
 
     def connect(self):
@@ -1015,6 +939,8 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
                 try:
                     log.debug("Publish daemon getting data from puller %s", pull_uri)
                     package = pull_sock.recv()
+                    package = salt.payload.loads(package)
+                    package = self.pack_publish(package)
                     log.debug("Publish daemon received payload. size=%d", len(package))
 
                     unpacked_package = salt.payload.unpackage(package)
@@ -1107,8 +1033,8 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
         """
         if self.pub_sock:
             self.pub_close()
-        ctx = zmq.Context.instance()
-        self._sock_data.sock = ctx.socket(zmq.PUSH)
+        self._sock_data._ctx = zmq.Context()
+        self._sock_data.sock = self._sock_data._ctx.socket(zmq.PUSH)
         self.pub_sock.setsockopt(zmq.LINGER, -1)
         if self.opts.get("ipc_mode", "") == "tcp":
             pull_uri = "tcp://127.0.0.1:{}".format(
@@ -1130,15 +1056,12 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
         if hasattr(self._sock_data, "sock"):
             self._sock_data.sock.close()
             delattr(self._sock_data, "sock")
+            if hasattr(self._sock_data, "_ctx"):
+                self._sock_data._ctx.destroy()
 
-    def publish(self, load):
-        """
-        Publish "load" to minions. This send the load to the publisher daemon
-        process with does the actual sending to minions.
-
-        :param dict load: A load to be sent across the wire to minions
-        """
+    def pack_publish(self, load):
         payload = {"enc": "aes"}
+        load["serial"] = salt.master.SMaster.get_serial()
         crypticle = salt.crypt.Crypticle(
             self.opts, salt.master.SMaster.secrets["aes"]["secret"].value
         )
@@ -1147,7 +1070,7 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
             master_pem_path = os.path.join(self.opts["pki_dir"], "master.pem")
             log.debug("Signing data packet")
             payload["sig"] = salt.crypt.sign_message(master_pem_path, payload["load"])
-        int_payload = {"payload": self.serial.dumps(payload)}
+        int_payload = {"payload": salt.payload.dumps(payload)}
 
         # add some targeting stuff for lists only (for now)
         if load["tgt_type"] == "list":
@@ -1163,15 +1086,24 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
             log.debug("Publish Side Match: %s", match_ids)
             # Send list of miions thru so zmq can target them
             int_payload["topic_lst"] = match_ids
-        payload = self.serial.dumps(int_payload)
+        payload = salt.payload.dumps(int_payload)
         log.debug(
             "Sending payload to publish daemon. jid=%s size=%d",
             load.get("jid", None),
             len(payload),
         )
+        return payload
+
+    def publish(self, load):
+        """
+        Publish "load" to minions. This send the load to the publisher daemon
+        process with does the actual sending to minions.
+
+        :param dict load: A load to be sent across the wire to minions
+        """
         if not self.pub_sock:
             self.pub_connect()
-        self.pub_sock.send(payload)
+        self.pub_sock.send(salt.payload.dumps(load))
         log.debug("Sent payload to publish daemon.")
 
 
@@ -1181,8 +1113,8 @@ class AsyncReqMessageClientPool(salt.transport.MessageClientPool):
     """
 
     def __init__(self, opts, args=None, kwargs=None):
-        super().__init__(AsyncReqMessageClient, opts, args=args, kwargs=kwargs)
         self._closing = False
+        super().__init__(AsyncReqMessageClient, opts, args=args, kwargs=kwargs)
 
     def close(self):
         if self._closing:
@@ -1197,11 +1129,11 @@ class AsyncReqMessageClientPool(salt.transport.MessageClientPool):
         message_clients = sorted(self.message_clients, key=lambda x: len(x.send_queue))
         return message_clients[0].send(*args, **kwargs)
 
-    # pylint: disable=W1701
-    def __del__(self):
-        self.close()
+    def __enter__(self):
+        return self
 
-    # pylint: enable=W1701
+    def __exit__(self, *args):
+        self.close()
 
 
 # TODO: unit tests!
@@ -1232,7 +1164,6 @@ class AsyncReqMessageClient:
         else:
             self.io_loop = io_loop
 
-        self.serial = salt.payload.Serial(self.opts)
         self.context = zmq.Context()
 
         # wire up sockets
@@ -1318,7 +1249,7 @@ class AsyncReqMessageClient:
             # send
             def mark_future(msg):
                 if not future.done():
-                    data = self.serial.loads(msg[0])
+                    data = salt.payload.loads(msg[0])
                     future.set_result(data)
 
             self.stream.on_recv(mark_future)
@@ -1363,7 +1294,10 @@ class AsyncReqMessageClient:
                     future.tries,
                 )
                 self.send(
-                    message, timeout=future.timeout, tries=future.tries, future=future,
+                    message,
+                    timeout=future.timeout,
+                    tries=future.tries,
+                    future=future,
                 )
 
             else:
@@ -1381,7 +1315,7 @@ class AsyncReqMessageClient:
             future.attempts = 0
             future.timeout = timeout
             # if a future wasn't passed in, we need to serialize the message
-            message = self.serial.dumps(message)
+            message = salt.payload.dumps(message)
         if callback is not None:
 
             def handle_future(future):
