@@ -3,6 +3,7 @@
 Define some generic socket functions for network modules
 """
 
+
 import fnmatch
 import itertools
 import logging
@@ -46,18 +47,25 @@ except (ImportError, OSError, AttributeError, TypeError):
     pass
 
 
-_INTERFACES = {}
+class Interfaces:
+    __slots__ = ("interfaces",)
+
+    def __init__(self, interfaces=None):
+        if interfaces is None:
+            interfaces = {}
+        self.interfaces = interfaces
+
+    def __call__(self, *args, **kwargs):
+        if not self.interfaces:
+            self.interfaces = interfaces()
+        return self.interfaces
+
+    def clear(self):
+        self.interfaces = {}
 
 
-def _get_interfaces():
-    """
-    Provide a dict of the connected interfaces and their ip addresses
-    """
-
-    global _INTERFACES
-    if not _INTERFACES:
-        _INTERFACES = interfaces()
-    return _INTERFACES
+_get_interfaces = Interfaces()
+_clear_interfaces = _get_interfaces.clear
 
 
 def sanitize_host(host):
@@ -793,7 +801,8 @@ def _interfaces_ifconfig(out):
         pip = re.compile(r".*?(?:inet addr:|inet [^\d]*)(.*?)\s")
         pip6 = re.compile(".*?(?:inet6 addr: (.*?)/|inet6 )([0-9a-fA-F:]+)")
         pmask6 = re.compile(
-            r".*?(?:inet6 addr: [0-9a-fA-F:]+/(\d+)|prefixlen (\d+))(?: Scope:([a-zA-Z]+)| scopeid (0x[0-9a-fA-F]))?"
+            r".*?(?:inet6 addr: [0-9a-fA-F:]+/(\d+)|prefixlen (\d+))(?:"
+            r" Scope:([a-zA-Z]+)| scopeid (0x[0-9a-fA-F]))?"
         )
     pmask = re.compile(r".*?(?:Mask:|netmask )(?:((?:0x)?[0-9a-fA-F]{8})|([\d\.]+))")
     pupdown = re.compile("UP")
@@ -896,15 +905,13 @@ def linux_interfaces():
     ifconfig_path = None if ip_path else salt.utils.path.which("ifconfig")
     if ip_path:
         cmd1 = subprocess.Popen(
-            "{} link show".format(ip_path),
-            shell=True,
+            [ip_path, "link", "show"],
             close_fds=True,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
         ).communicate()[0]
         cmd2 = subprocess.Popen(
-            "{} addr show".format(ip_path),
-            shell=True,
+            [ip_path, "addr", "show"],
             close_fds=True,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
@@ -916,8 +923,7 @@ def linux_interfaces():
         )
     elif ifconfig_path:
         cmd = subprocess.Popen(
-            "{} -a".format(ifconfig_path),
-            shell=True,
+            [ifconfig_path, "-a"],
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
         ).communicate()[0]
@@ -985,6 +991,91 @@ def _netbsd_interfaces_ifconfig(out):
     return ret
 
 
+def _junos_interfaces_ifconfig(out):
+    """
+    Uses ifconfig to return a dictionary of interfaces with various information
+    about each (up/down state, ip address, netmask, and hwaddr)
+    """
+    ret = dict()
+
+    piface = re.compile(r"^([^\s:]+)")
+    pmac = re.compile("curr media .*? ([0-9a-f:]+)")
+
+    pip = re.compile(
+        r".*?inet\s*(primary)*\s+mtu"
+        r" (\d+)\s+local=[^\d]*(.*?)\s{0,40}dest=[^\d]*(.*?)\/([\d]*)\s{0,40}bcast=((?:[0-9]{1,3}\.){3}[0-9]{1,3})"
+    )
+    pip6 = re.compile(
+        r".*?inet6 mtu [^\d]+\s{0,40}local=([0-9a-f:]+)%([a-zA-Z0-9]*)/([\d]*)\s"
+    )
+
+    pupdown = re.compile("UP")
+    pbcast = re.compile(r".*?broadcast ([\d\.]+)")
+
+    groups = re.compile("\r?\n(?=\\S)").split(out)
+    for group in groups:
+        data = dict()
+        iface = ""
+        updown = False
+        primary = False
+        for line in group.splitlines():
+            miface = piface.match(line)
+            mmac = pmac.match(line)
+            mip = pip.match(line)
+            mip6 = pip6.match(line)
+            mupdown = pupdown.search(line)
+            if miface:
+                iface = miface.group(1)
+            if mmac:
+                data["hwaddr"] = mmac.group(1)
+            if mip:
+                if "primary" in data:
+                    primary = True
+                if "inet" not in data:
+                    data["inet"] = list()
+                if mip.group(2):
+                    data["mtu"] = int(mip.group(2))
+                addr_obj = dict()
+                addr_obj["address"] = mip.group(3)
+                mmask = mip.group(5)
+                if mip.group(5):
+                    addr_obj["netmask"] = cidr_to_ipv4_netmask(mip.group(5))
+                mbcast = pbcast.match(line)
+                if mbcast:
+                    addr_obj["broadcast"] = mbcast.group(1)
+                data["inet"].append(addr_obj)
+            if mupdown:
+                updown = True
+            if mip6:
+                if "inet6" not in data:
+                    data["inet6"] = list()
+                addr_obj = dict()
+                addr_obj["address"] = mip6.group(1)
+                mmask6 = mip6.group(3)
+                addr_obj["scope"] = mip6.group(2)
+                addr_obj["prefixlen"] = mip6.group(3)
+                data["inet6"].append(addr_obj)
+        data["up"] = updown
+        ret[iface] = data
+        del data
+    return ret
+
+
+def junos_interfaces():
+    """
+    Obtain interface information for Junos; ifconfig
+    output diverged from other BSD variants (Netmask is now part of the
+    address)
+    """
+    ifconfig_path = salt.utils.path.which("ifconfig")
+    cmd = subprocess.Popen(
+        [ifconfig_path, "-a"],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
+    ).communicate()[0]
+    return _junos_interfaces_ifconfig(salt.utils.stringutils.to_str(cmd))
+
+
 def netbsd_interfaces():
     """
     Obtain interface information for NetBSD >= 8 where the ifconfig
@@ -997,8 +1088,7 @@ def netbsd_interfaces():
 
     ifconfig_path = salt.utils.path.which("ifconfig")
     cmd = subprocess.Popen(
-        "{} -a".format(ifconfig_path),
-        shell=True,
+        [ifconfig_path, "-a"],
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
     ).communicate()[0]
@@ -1072,6 +1162,8 @@ def interfaces():
     """
     if salt.utils.platform.is_windows():
         return win_interfaces()
+    elif salt.utils.platform.is_junos():
+        return junos_interfaces()
     elif salt.utils.platform.is_netbsd():
         return netbsd_interfaces()
     else:
@@ -1127,7 +1219,7 @@ def _get_iface_info(iface):
     if iface in iface_info.keys():
         return iface_info, False
     else:
-        error_msg = 'Interface "{}" not in available interfaces: "{}"' "".format(
+        error_msg = 'Interface "{}" not in available interfaces: "{}"'.format(
             iface, '", "'.join(iface_info.keys())
         )
         log.error(error_msg)
@@ -1140,8 +1232,12 @@ def _hw_addr_aix(iface):
     MAC address not available in through interfaces
     """
     cmd = subprocess.Popen(
-        "entstat -d {} | grep 'Hardware Address'".format(iface),
-        shell=True,
+        ["grep", "Hardware Address"],
+        stdin=subprocess.Popen(
+            ["entstat", "-d", iface],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+        ).stdout,
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
     ).communicate()[0]
@@ -2069,15 +2165,18 @@ def dns_check(addr, port, safe=False, ipv6=None):
         addrinfo = socket.getaddrinfo(addr, port, family, socket.SOCK_STREAM)
         ip_addrs = _test_addrs(addrinfo, port)
     except TypeError:
-        err = (
-            "Attempt to resolve address '{}' failed. Invalid or unresolveable address"
-        ).format(addr)
-        raise SaltSystemExit(code=42, msg=err)
+        raise SaltSystemExit(
+            code=42,
+            msg=(
+                "Attempt to resolve address '{}' failed. Invalid or unresolveable"
+                " address".format(addr)
+            ),
+        )
     except OSError:
         pass
 
     if not ip_addrs:
-        err = ("DNS lookup or connection check of '{}' failed.").format(addr)
+        err = "DNS lookup or connection check of '{}' failed.".format(addr)
         if safe:
             if salt.log.is_console_configured():
                 # If logging is not configured it also means that either
@@ -2154,16 +2253,11 @@ def parse_host_port(host_port):
             try:
                 port = int(port)
             except ValueError as _e_:
-                log.error(
-                    'host_port "{}" port value "{}" is not an integer.'.format(
-                        host_port, port
-                    )
-                )
-                raise ValueError(
-                    'host_port "{}" port value "{}" is not an integer.'.format(
-                        host_port, port
-                    )
+                errmsg = 'host_port "{}" port value "{}" is not an integer.'.format(
+                    host_port, port
                 )
+                log.error(errmsg)
+                raise ValueError(errmsg)
         else:
             host = _s_
     try:
