@@ -24,8 +24,8 @@ import salt.utils.stringutils
 import salt.utils.yamlencoding
 from salt import __path__ as saltpath
 from salt.exceptions import CommandExecutionError, SaltInvocationError, SaltRenderError
-from salt.ext import six
 from salt.features import features
+from salt.loader.context import NamedLoaderContext
 from salt.utils.decorators.jinja import JinjaFilter, JinjaGlobal, JinjaTest
 from salt.utils.odict import OrderedDict
 from salt.utils.versions import LooseVersion
@@ -272,7 +272,7 @@ def wrap_tmpl_func(render_str):
 
         except SaltRenderError as exc:
             log.exception("Rendering exception occurred")
-            # return dict(result=False, data=six.text_type(exc))
+            # return dict(result=False, data=str(exc))
             raise
         except Exception:  # pylint: disable=broad-except
             return dict(result=False, data=traceback.format_exc())
@@ -427,14 +427,16 @@ def render_jinja_tmpl(tmplstr, context, tmplpath=None):
     if opts.get("jinja_trim_blocks", False):
         log.debug("Jinja2 trim_blocks is enabled")
         log.warning(
-            "jinja_trim_blocks is deprecated and will be removed in a future release, please use jinja_env and/or jinja_sls_env instead"
+            "jinja_trim_blocks is deprecated and will be removed in a future release,"
+            " please use jinja_env and/or jinja_sls_env instead"
         )
         opt_jinja_env["trim_blocks"] = True
         opt_jinja_sls_env["trim_blocks"] = True
     if opts.get("jinja_lstrip_blocks", False):
         log.debug("Jinja2 lstrip_blocks is enabled")
         log.warning(
-            "jinja_lstrip_blocks is deprecated and will be removed in a future release, please use jinja_env and/or jinja_sls_env instead"
+            "jinja_lstrip_blocks is deprecated and will be removed in a future release,"
+            " please use jinja_env and/or jinja_sls_env instead"
         )
         opt_jinja_env["lstrip_blocks"] = True
         opt_jinja_sls_env["lstrip_blocks"] = True
@@ -460,13 +462,9 @@ def render_jinja_tmpl(tmplstr, context, tmplpath=None):
             undefined=jinja2.StrictUndefined, **env_args
         )
 
-    tojson_filter = jinja_env.filters.get("tojson")
     indent_filter = jinja_env.filters.get("indent")
     jinja_env.tests.update(JinjaTest.salt_jinja_tests)
     jinja_env.filters.update(JinjaFilter.salt_jinja_filters)
-    if tojson_filter is not None:
-        # Use the existing tojson filter, if present (jinja2 >= 2.9)
-        jinja_env.filters["tojson"] = tojson_filter
     if salt.utils.jinja.JINJA_VERSION >= LooseVersion("2.11"):
         # Use the existing indent filter on Jinja versions where it's not broken
         jinja_env.filters["indent"] = indent_filter
@@ -481,7 +479,10 @@ def render_jinja_tmpl(tmplstr, context, tmplpath=None):
     decoded_context = {}
     for key, value in context.items():
         if not isinstance(value, str):
-            decoded_context[key] = value
+            if isinstance(value, NamedLoaderContext):
+                decoded_context[key] = value.value()
+            else:
+                decoded_context[key] = value
             continue
 
         try:
@@ -495,9 +496,9 @@ def render_jinja_tmpl(tmplstr, context, tmplpath=None):
             )
             decoded_context[key] = salt.utils.data.decode(value)
 
+    jinja_env.globals.update(decoded_context)
     try:
         template = jinja_env.from_string(tmplstr)
-        template.globals.update(decoded_context)
         output = template.render(**decoded_context)
     except jinja2.exceptions.UndefinedError as exc:
         trace = traceback.extract_tb(sys.exc_info()[2])
@@ -635,12 +636,9 @@ def render_cheetah_tmpl(tmplstr, context, tmplpath=None):
     data = tclass(namespaces=[context])
 
     # Figure out which method to call based on the type of tmplstr
-    if six.PY3 and isinstance(tmplstr, str):
+    if isinstance(tmplstr, str):
         # This should call .__unicode__()
         res = str(data)
-    elif six.PY2 and isinstance(tmplstr, str):
-        # Expicitly call .__unicode__()
-        res = data.__unicode__()
     elif isinstance(tmplstr, bytes):
         # This should call .__str()
         res = str(data)
