@@ -1,12 +1,8 @@
-# -*- coding: utf-8 -*-
 '''
     :codeauthor: {{full_name}} <{{email}}>
 '''
 
-# Import Python Libs
-from __future__ import absolute_import, unicode_literals, print_function
 
-# Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.unit import TestCase
 from tests.support.mock import patch
