@@ -19,7 +19,6 @@ import shutil
 import ssl
 import stat
 import sys
-import textwrap
 from functools import partial, wraps
 from unittest import TestCase  # pylint: disable=blacklisted-module
 
@@ -27,15 +26,14 @@ import _pytest.logging
 import _pytest.skipping
 import psutil
 import pytest
+import salt._logging.impl
 import salt.config
 import salt.loader
 import salt.log.mixins
-import salt.log.setup
 import salt.utils.files
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.win_functions
-import saltfactories.utils.compat
 from salt.serializers import yaml
 from salt.utils.immutabletypes import freeze
 from tests.support.helpers import (
@@ -123,7 +121,7 @@ def pytest_tempdir_basename():
     """
     Return the temporary directory basename for the salt test suite.
     """
-    return "salt-tests-tmpdir"
+    return "stsuite"
 
 
 # <---- PyTest Tempdir Plugin Hooks ----------------------------------------------------------------------------------
@@ -139,11 +137,13 @@ def pytest_addoption(parser):
         "--from-filenames",
         default=None,
         help=(
-            "Pass a comma-separated list of file paths, and any test module which corresponds to the "
-            "specified file(s) will run. For example, if 'setup.py' was passed, then the corresponding "
-            "test files defined in 'tests/filename_map.yml' would run. Absolute paths are assumed to be "
-            "files containing relative paths, one per line. Providing the paths in a file can help get "
-            "around shell character limits when the list of files is long."
+            "Pass a comma-separated list of file paths, and any test module which"
+            " corresponds to the specified file(s) will run. For example, if 'setup.py'"
+            " was passed, then the corresponding test files defined in"
+            " 'tests/filename_map.yml' would run. Absolute paths are assumed to be"
+            " files containing relative paths, one per line. Providing the paths in a"
+            " file can help get around shell character limits when the list of files is"
+            " long."
         ),
     )
     # Add deprecated CLI flag until we completely switch to PyTest
@@ -155,7 +155,8 @@ def pytest_addoption(parser):
         default="zeromq",
         choices=("zeromq", "tcp"),
         help=(
-            "Select which transport to run the integration tests with, zeromq or tcp. Default: %(default)s"
+            "Select which transport to run the integration tests with, zeromq or tcp."
+            " Default: %(default)s"
         ),
     )
     test_selection_group.addoption(
@@ -164,9 +165,11 @@ def pytest_addoption(parser):
         dest="ssh",
         action="store_true",
         default=False,
-        help="Run salt-ssh tests. These tests will spin up a temporary "
-        "SSH server on your machine. In certain environments, this "
-        "may be insecure! Default: False",
+        help=(
+            "Run salt-ssh tests. These tests will spin up a temporary "
+            "SSH server on your machine. In certain environments, this "
+            "may be insecure! Default: False"
+        ),
     )
     test_selection_group.addoption(
         "--proxy",
@@ -174,10 +177,13 @@ def pytest_addoption(parser):
         dest="proxy",
         action="store_true",
         default=False,
-        help="Run proxy tests",
+        help="Run proxy tests (DEPRECATED)",
     )
     test_selection_group.addoption(
-        "--run-slow", action="store_true", default=False, help="Run slow tests.",
+        "--run-slow",
+        action="store_true",
+        default=False,
+        help="Run slow tests.",
     )
 
     output_options_group = parser.getgroup("Output Options")
@@ -231,11 +237,13 @@ def pytest_configure(config):
     # Expose the markers we use to pytest CLI
     config.addinivalue_line(
         "markers",
-        "requires_salt_modules(*required_module_names): Skip if at least one module is not available.",
+        "requires_salt_modules(*required_module_names): Skip if at least one module is"
+        " not available.",
     )
     config.addinivalue_line(
         "markers",
-        "requires_salt_states(*required_state_names): Skip if at least one state module is not available.",
+        "requires_salt_states(*required_state_names): Skip if at least one state module"
+        " is not available.",
     )
     config.addinivalue_line(
         "markers", "windows_whitelisted: Mark test as whitelisted to run under Windows"
@@ -245,11 +253,9 @@ def pytest_configure(config):
     )
     config.addinivalue_line(
         "markers",
-        "slow_test: Mark test as being slow. These tests are skipped by default unless `--run-slow` is passed",
+        "slow_test: Mark test as being slow. These tests are skipped by default unless"
+        " `--run-slow` is passed",
     )
-    # Make sure the test suite "knows" this is a pytest test run
-    RUNTIME_VARS.PYTEST_SESSION = True
-
     # "Flag" the slowTest decorator if we're skipping slow tests or not
     os.environ["SLOW_TESTS"] = str(config.getoption("--run-slow"))
 
@@ -288,8 +294,8 @@ def set_max_open_files_limits(min_soft=3072, min_hard=4096):
     # Increase limits
     if set_limits:
         log.debug(
-            " * Max open files settings is too low (soft: %s, hard: %s) for running the tests. "
-            "Trying to raise the limits to soft: %s, hard: %s",
+            " * Max open files settings is too low (soft: %s, hard: %s) for running the"
+            " tests. Trying to raise the limits to soft: %s, hard: %s",
             prev_soft,
             prev_hard,
             soft,
@@ -303,8 +309,8 @@ def set_max_open_files_limits(min_soft=3072, min_hard=4096):
                 resource.setrlimit(resource.RLIMIT_NOFILE, (soft, hard))
         except Exception as err:  # pylint: disable=broad-except
             log.error(
-                "Failed to raise the max open files settings -> %s. Please issue the following command "
-                "on your console: 'ulimit -u %s'",
+                "Failed to raise the max open files settings -> %s. Please issue the"
+                " following command on your console: 'ulimit -u %s'",
                 err,
                 soft,
             )
@@ -324,8 +330,8 @@ def pytest_itemcollected(item):
         # Test is under tests/pytests
         if item.cls and issubclass(item.cls, TestCase):
             pytest.fail(
-                "The tests under {0!r} MUST NOT use unittest's TestCase class or a subclass of it. "
-                "Please move {1!r} outside of {0!r}".format(
+                "The tests under {0!r} MUST NOT use unittest's TestCase class or a"
+                " subclass of it. Please move {1!r} outside of {0!r}".format(
                     str(PYTESTS_DIR.relative_to(CODE_DIR)), item.nodeid
                 )
             )
@@ -333,7 +339,8 @@ def pytest_itemcollected(item):
         # Test is not under tests/pytests
         if not item.cls or (item.cls and not issubclass(item.cls, TestCase)):
             pytest.fail(
-                "The test {!r} appears to be written for pytest but it's not under {!r}. Please move it there.".format(
+                "The test {!r} appears to be written for pytest but it's not under"
+                " {!r}. Please move it there.".format(
                     item.nodeid, str(PYTESTS_DIR.relative_to(CODE_DIR)), pytrace=False
                 )
             )
@@ -386,8 +393,9 @@ def pytest_collection_modifyitems(config, items):
                                             and not request.session.shouldstop
                                         ):
                                             log.debug(
-                                                "The next test item is still under the fixture package path. "
-                                                "Not terminating %s",
+                                                "The next test item is still under the"
+                                                " fixture package path. Not"
+                                                " terminating %s",
                                                 self,
                                             )
                                             return
@@ -469,9 +477,7 @@ def pytest_runtest_setup(item):
         item._skipped_by_mark = True
         pytest.skip(PRE_PYTEST_SKIP_REASON)
 
-    if saltfactories.utils.compat.has_unittest_attr(
-        item, "__slow_test__"
-    ) or item.get_closest_marker("slow_test"):
+    if item.get_closest_marker("slow_test"):
         if item.config.getoption("--run-slow") is False:
             item._skipped_by_mark = True
             pytest.skip("Slow tests are disabled!")
@@ -482,6 +488,7 @@ def pytest_runtest_setup(item):
             item._skipped_by_mark = True
             pytest.skip("SSH tests are disabled, pass '--ssh-tests' to enable them.")
         item.fixturenames.append("sshd_server")
+        item.fixturenames.append("salt_ssh_roster_file")
 
     requires_salt_modules_marker = item.get_closest_marker("requires_salt_modules")
     if requires_salt_modules_marker is not None:
@@ -596,7 +603,8 @@ def groups_collection_modifyitems(config, items):
 
     terminal_reporter = config.pluginmanager.get_plugin("terminalreporter")
     terminal_reporter.write(
-        "Running test group #{} ({} tests)\n".format(group_id, len(items)), yellow=True,
+        "Running test group #{} ({} tests)\n".format(group_id, len(items)),
+        yellow=True,
     )
 
 
@@ -699,6 +707,17 @@ def base_env_pillar_tree_root_dir(pillar_tree_root_dir):
     return dirname
 
 
+@pytest.fixture(scope="session")
+def ext_pillar_file_tree_root_dir(pillar_tree_root_dir):
+    """
+    Fixture which returns the salt pillar file tree directory path.
+    Creates the directory if it does not yet exist.
+    """
+    dirname = pillar_tree_root_dir / "file-tree"
+    dirname.mkdir(exist_ok=True)
+    return dirname
+
+
 @pytest.fixture(scope="session")
 def prod_env_pillar_tree_root_dir(pillar_tree_root_dir):
     """
@@ -738,7 +757,7 @@ def salt_syndic_master_factory(
     config_defaults["syndic_master"] = "localhost"
     config_defaults["transport"] = request.config.getoption("--transport")
 
-    config_overrides = {}
+    config_overrides = {"log_level_logfile": "quiet"}
     ext_pillar = []
     if salt.utils.platform.is_windows():
         ext_pillar.append(
@@ -794,11 +813,11 @@ def salt_syndic_master_factory(
         }
     )
 
-    factory = salt_factories.get_salt_master_daemon(
+    factory = salt_factories.salt_master_daemon(
         "syndic_master",
         order_masters=True,
-        config_defaults=config_defaults,
-        config_overrides=config_overrides,
+        defaults=config_defaults,
+        overrides=config_overrides,
         extra_cli_arguments_after_first_start_failure=["--log-level=debug"],
     )
     return factory
@@ -814,9 +833,11 @@ def salt_syndic_factory(salt_factories, salt_syndic_master_factory):
         opts["aliases.file"] = os.path.join(RUNTIME_VARS.TMP, "aliases")
         opts["transport"] = salt_syndic_master_factory.config["transport"]
         config_defaults["syndic"] = opts
-    factory = salt_syndic_master_factory.get_salt_syndic_daemon(
+    config_overrides = {"log_level_logfile": "quiet"}
+    factory = salt_syndic_master_factory.salt_syndic_daemon(
         "syndic",
-        config_defaults=config_defaults,
+        defaults=config_defaults,
+        overrides=config_overrides,
         extra_cli_arguments_after_first_start_failure=["--log-level=debug"],
     )
     return factory
@@ -830,6 +851,7 @@ def salt_master_factory(
     base_env_pillar_tree_root_dir,
     prod_env_state_tree_root_dir,
     prod_env_pillar_tree_root_dir,
+    ext_pillar_file_tree_root_dir,
 ):
     root_dir = salt_factories.get_root_dir_for_daemon("master")
     conf_dir = root_dir / "conf"
@@ -846,11 +868,8 @@ def salt_master_factory(
     config_defaults["known_hosts_file"] = tests_known_hosts_file
     config_defaults["syndic_master"] = "localhost"
     config_defaults["transport"] = salt_syndic_master_factory.config["transport"]
-    config_defaults["reactor"] = [
-        {"salt/test/reactor": [os.path.join(RUNTIME_VARS.FILES, "reactor-test.sls")]}
-    ]
 
-    config_overrides = {}
+    config_overrides = {"log_level_logfile": "quiet"}
     ext_pillar = []
     if salt.utils.platform.is_windows():
         ext_pillar.append(
@@ -863,7 +882,7 @@ def salt_master_factory(
     ext_pillar.append(
         {
             "file_tree": {
-                "root_dir": os.path.join(RUNTIME_VARS.PILLAR_DIR, "base", "file_tree"),
+                "root_dir": str(ext_pillar_file_tree_root_dir),
                 "follow_dir_links": False,
                 "keep_newline": True,
             }
@@ -927,10 +946,10 @@ def salt_master_factory(
         else:
             shutil.copyfile(source, dest)
 
-    factory = salt_syndic_master_factory.get_salt_master_daemon(
+    factory = salt_syndic_master_factory.salt_master_daemon(
         "master",
-        config_defaults=config_defaults,
-        config_overrides=config_overrides,
+        defaults=config_defaults,
+        overrides=config_overrides,
         extra_cli_arguments_after_first_start_failure=["--log-level=debug"],
     )
     return factory
@@ -945,6 +964,7 @@ def salt_minion_factory(salt_master_factory):
     config_defaults["transport"] = salt_master_factory.config["transport"]
 
     config_overrides = {
+        "log_level_logfile": "quiet",
         "file_roots": salt_master_factory.config["file_roots"].copy(),
         "pillar_roots": salt_master_factory.config["pillar_roots"].copy(),
     }
@@ -952,13 +972,13 @@ def salt_minion_factory(salt_master_factory):
     virtualenv_binary = get_virtualenv_binary_path()
     if virtualenv_binary:
         config_overrides["venv_bin"] = virtualenv_binary
-    factory = salt_master_factory.get_salt_minion_daemon(
+    factory = salt_master_factory.salt_minion_daemon(
         "minion",
-        config_defaults=config_defaults,
-        config_overrides=config_overrides,
+        defaults=config_defaults,
+        overrides=config_overrides,
         extra_cli_arguments_after_first_start_failure=["--log-level=debug"],
     )
-    factory.register_after_terminate_callback(
+    factory.after_terminate(
         pytest.helpers.remove_stale_minion_key, salt_master_factory, factory.id
     )
     return factory
@@ -975,6 +995,7 @@ def salt_sub_minion_factory(salt_master_factory):
     config_defaults["transport"] = salt_master_factory.config["transport"]
 
     config_overrides = {
+        "log_level_logfile": "quiet",
         "file_roots": salt_master_factory.config["file_roots"].copy(),
         "pillar_roots": salt_master_factory.config["pillar_roots"].copy(),
     }
@@ -982,40 +1003,13 @@ def salt_sub_minion_factory(salt_master_factory):
     virtualenv_binary = get_virtualenv_binary_path()
     if virtualenv_binary:
         config_overrides["venv_bin"] = virtualenv_binary
-    factory = salt_master_factory.get_salt_minion_daemon(
+    factory = salt_master_factory.salt_minion_daemon(
         "sub_minion",
-        config_defaults=config_defaults,
-        config_overrides=config_overrides,
+        defaults=config_defaults,
+        overrides=config_overrides,
         extra_cli_arguments_after_first_start_failure=["--log-level=debug"],
     )
-    factory.register_after_terminate_callback(
-        pytest.helpers.remove_stale_minion_key, salt_master_factory, factory.id
-    )
-    return factory
-
-
-@pytest.fixture(scope="session")
-def salt_proxy_factory(salt_factories, salt_master_factory):
-    proxy_minion_id = "proxytest"
-    root_dir = salt_factories.get_root_dir_for_daemon(proxy_minion_id)
-    conf_dir = root_dir / "conf"
-    conf_dir.mkdir(parents=True, exist_ok=True)
-    RUNTIME_VARS.TMP_PROXY_CONF_DIR = str(conf_dir)
-
-    with salt.utils.files.fopen(os.path.join(RUNTIME_VARS.CONF_DIR, "proxy")) as rfh:
-        config_defaults = yaml.deserialize(rfh.read())
-
-    config_defaults["root_dir"] = str(root_dir)
-    config_defaults["hosts.file"] = os.path.join(RUNTIME_VARS.TMP, "hosts")
-    config_defaults["aliases.file"] = os.path.join(RUNTIME_VARS.TMP, "aliases")
-    config_defaults["transport"] = salt_master_factory.config["transport"]
-
-    factory = salt_master_factory.get_salt_proxy_minion_daemon(
-        proxy_minion_id,
-        config_defaults=config_defaults,
-        extra_cli_arguments_after_first_start_failure=["--log-level=debug"],
-    )
-    factory.register_after_terminate_callback(
+    factory.after_terminate(
         pytest.helpers.remove_stale_minion_key, salt_master_factory, factory.id
     )
     return factory
@@ -1023,32 +1017,27 @@ def salt_proxy_factory(salt_factories, salt_master_factory):
 
 @pytest.fixture(scope="session")
 def salt_cli(salt_master_factory):
-    return salt_master_factory.get_salt_cli()
+    return salt_master_factory.salt_cli()
 
 
 @pytest.fixture(scope="session")
 def salt_cp_cli(salt_master_factory):
-    return salt_master_factory.get_salt_cp_cli()
+    return salt_master_factory.salt_cp_cli()
 
 
 @pytest.fixture(scope="session")
 def salt_key_cli(salt_master_factory):
-    return salt_master_factory.get_salt_key_cli()
+    return salt_master_factory.salt_key_cli()
 
 
 @pytest.fixture(scope="session")
 def salt_run_cli(salt_master_factory):
-    return salt_master_factory.get_salt_run_cli()
-
-
-@pytest.fixture(scope="session")
-def salt_ssh_cli(salt_master_factory):
-    return salt_master_factory.get_salt_ssh_cli()
+    return salt_master_factory.salt_run_cli()
 
 
 @pytest.fixture(scope="session")
 def salt_call_cli(salt_minion_factory):
-    return salt_minion_factory.get_salt_call_cli()
+    return salt_minion_factory.salt_call_cli()
 
 
 @pytest.fixture(scope="session", autouse=True)
@@ -1132,36 +1121,31 @@ def sshd_server(salt_factories, sshd_config_dir, salt_master):
         "UsePAM": "yes",
     }
     factory = salt_factories.get_sshd_daemon(
-        sshd_config_dict=sshd_config_dict, config_dir=sshd_config_dir,
+        sshd_config_dict=sshd_config_dict,
+        config_dir=sshd_config_dir,
     )
-    # We also need a salt-ssh roster config file
-    roster_path = pathlib.Path(salt_master.config_dir) / "roster"
-    roster_contents = textwrap.dedent(
-        """\
-        localhost:
-          host: 127.0.0.1
-          port: {}
-          user: {}
-          mine_functions:
-            test.arg: ['itworked']
-        """.format(
-            factory.listen_port, RUNTIME_VARS.RUNNING_TESTS_USER
-        )
+    with factory.started():
+        yield factory
+
+
+@pytest.fixture(scope="module")
+def salt_ssh_roster_file(sshd_server, salt_master):
+    roster_contents = """
+    localhost:
+      host: 127.0.0.1
+      port: {}
+      user: {}
+      mine_functions:
+        test.arg: ['itworked']
+    """.format(
+        sshd_server.listen_port, RUNTIME_VARS.RUNNING_TESTS_USER
     )
     if salt.utils.platform.is_darwin():
         roster_contents += "  set_path: $PATH:/usr/local/bin/\n"
-    log.debug(
-        "Writing to configuration file %s. Configuration:\n%s",
-        roster_path,
-        roster_contents,
-    )
-    with salt.utils.files.fopen(str(roster_path), "w") as wfh:
-        wfh.write(roster_contents)
-
-    with factory.started():
-        yield factory
-    if roster_path.exists():
-        roster_path.unlink()
+    with pytest.helpers.temp_file(
+        "roster", roster_contents, salt_master.config_dir
+    ) as roster_file:
+        yield roster_file
 
 
 # <---- Salt Factories -----------------------------------------------------------------------------------------------
@@ -1170,6 +1154,9 @@ def sshd_server(salt_factories, sshd_config_dir, salt_master):
 # ----- From Filenames Test Selection ------------------------------------------------------------------------------->
 def _match_to_test_file(match):
     parts = match.split(".")
+    test_module_path = TESTS_DIR.joinpath(*parts)
+    if test_module_path.exists():
+        return test_module_path
     parts[-1] += ".py"
     return TESTS_DIR.joinpath(*parts).relative_to(CODE_DIR)
 
@@ -1180,30 +1167,53 @@ def from_filenames_collection_modifyitems(config, items):
         # Don't do anything
         return
 
-    test_categories_paths = (
-        (TESTS_DIR / "integration").relative_to(CODE_DIR),
-        (TESTS_DIR / "multimaster").relative_to(CODE_DIR),
-        (TESTS_DIR / "unit").relative_to(CODE_DIR),
-        (PYTESTS_DIR / "e2e").relative_to(CODE_DIR),
-        (PYTESTS_DIR / "functional").relative_to(CODE_DIR),
-        (PYTESTS_DIR / "integration").relative_to(CODE_DIR),
-        (PYTESTS_DIR / "unit").relative_to(CODE_DIR),
+    terminal_reporter = config.pluginmanager.getplugin("terminalreporter")
+    terminal_reporter.ensure_newline()
+    terminal_reporter.section(
+        "From Filenames(--from-filenames) Test Selection", sep=">"
     )
-
-    test_module_paths = set()
-    from_filenames_listing = set()
-    for path in [pathlib.Path(path.strip()) for path in from_filenames.split(",")]:
-        if path.is_absolute():
+    errors = []
+    test_module_selections = []
+    changed_files_selections = []
+    from_filenames_paths = set()
+    for path in [path.strip() for path in from_filenames.split(",")]:
+        # Make sure that, no matter what kind of path we're passed, Windows or Posix path,
+        # we resolve it to the platform slash separator
+        properly_slashed_path = pathlib.Path(
+            path.replace("\\", os.sep).replace("/", os.sep)
+        )
+        if not properly_slashed_path.exists():
+            errors.append("{}: Does not exist".format(properly_slashed_path))
+            continue
+        if properly_slashed_path.is_absolute():
             # In this case, this path is considered to be a file containing a line separated list
             # of files to consider
-            with salt.utils.files.fopen(str(path)) as rfh:
-                for line in rfh:
-                    line_path = pathlib.Path(line.strip())
-                    if not line_path.exists():
-                        continue
-                    from_filenames_listing.add(line_path)
+            contents = properly_slashed_path.read_text()
+            for sep in ("\r\n", "\\r\\n", "\\n"):
+                contents = contents.replace(sep, "\n")
+            for line in contents.split("\n"):
+                line_path = pathlib.Path(
+                    line.strip().replace("\\", os.sep).replace("/", os.sep)
+                )
+                if not line_path.exists():
+                    errors.append(
+                        "{}: Does not exist. Source {}".format(
+                            line_path, properly_slashed_path
+                        )
+                    )
+                    continue
+                changed_files_selections.append(
+                    "{}: Source {}".format(line_path, properly_slashed_path)
+                )
+                from_filenames_paths.add(line_path)
             continue
-        from_filenames_listing.add(path)
+        changed_files_selections.append(
+            "{}: Source --from-filenames".format(properly_slashed_path)
+        )
+        from_filenames_paths.add(properly_slashed_path)
+
+    # Let's start collecting test modules
+    test_module_paths = set()
 
     filename_map = yaml.deserialize((TESTS_DIR / "filename_map.yml").read_text())
     # Let's add the match all rule
@@ -1214,22 +1224,55 @@ def from_filenames_collection_modifyitems(config, items):
             break
 
     # Let's now go through the list of files gathered
-    for filename in from_filenames_listing:
-        if str(filename).startswith("tests/"):
+    for path in from_filenames_paths:
+        if path.as_posix().startswith("tests/"):
+            if path.name == "conftest.py":
+                # This is not a test module, but consider any test_*.py files in child directories
+                for match in path.parent.rglob("test_*.py"):
+                    test_module_selections.append(
+                        "{}: Source '{}/test_*.py' recursive glob match because '{}' was modified".format(
+                            match, path.parent, path
+                        )
+                    )
+                    test_module_paths.add(match)
+                continue
             # Tests in the listing don't require additional matching and will be added to the
             # list of tests to run
-            test_module_paths.add(filename)
+            test_module_selections.append("{}: Source --from-filenames".format(path))
+            test_module_paths.add(path)
             continue
-        if filename.name == "setup.py" or str(filename).startswith("salt/"):
+        if path.name == "setup.py" or path.as_posix().startswith("salt/"):
             if path.name == "__init__.py":
-                # No direct macthing
+                # No direct matching
                 continue
-            # Now let's try a direct match between the passed file and possible test modules
-            for test_categories_path in test_categories_paths:
-                test_module_path = test_categories_path / "test_{}".format(path.name)
-                if test_module_path.is_file():
-                    test_module_paths.add(test_module_path)
-                    continue
+
+            # Let's try a direct match between the passed file and possible test modules
+            glob_patterns = (
+                # salt/version.py ->
+                #    tests/unit/test_version.py
+                #    tests/pytests/unit/test_version.py
+                "**/test_{}".format(path.name),
+                # salt/modules/grains.py ->
+                #    tests/pytests/integration/modules/grains/tests_*.py
+                # salt/modules/saltutil.py ->
+                #    tests/pytests/integration/modules/saltutil/test_*.py
+                "**/{}/test_*.py".format(path.stem),
+                # salt/modules/config.py ->
+                #    tests/unit/modules/test_config.py
+                #    tests/integration/modules/test_config.py
+                #    tests/pytests/unit/modules/test_config.py
+                #    tests/pytests/integration/modules/test_config.py
+                "**/{}/test_{}".format(path.parent.name, path.name),
+            )
+            for pattern in glob_patterns:
+                for match in TESTS_DIR.rglob(pattern):
+                    relative_path = match.relative_to(CODE_DIR)
+                    test_module_selections.append(
+                        "{}: Source '{}' glob pattern match".format(
+                            relative_path, pattern
+                        )
+                    )
+                    test_module_paths.add(relative_path)
 
             # Do we have an entry in tests/filename_map.yml
             for rule, matches in filename_map.items():
@@ -1237,31 +1280,65 @@ def from_filenames_collection_modifyitems(config, items):
                     continue
                 elif "|" in rule:
                     # This is regex
-                    if re.match(rule, str(filename)):
+                    if re.match(rule, path.as_posix()):
                         for match in matches:
                             test_module_paths.add(_match_to_test_file(match))
+                            test_module_selections.append(
+                                "{}: Source '{}' regex match from 'tests/filename_map.yml'".format(
+                                    match, rule
+                                )
+                            )
                 elif "*" in rule or "\\" in rule:
                     # Glob matching
                     for filerule in CODE_DIR.glob(rule):
                         if not filerule.exists():
                             continue
                         filerule = filerule.relative_to(CODE_DIR)
-                        if filerule != filename:
+                        if filerule != path:
                             continue
                         for match in matches:
-                            test_module_paths.add(_match_to_test_file(match))
+                            match_path = _match_to_test_file(match)
+                            test_module_selections.append(
+                                "{}: Source '{}' file rule from 'tests/filename_map.yml'".format(
+                                    match_path, filerule
+                                )
+                            )
+                            test_module_paths.add(match_path)
                 else:
-                    if str(filename) != rule:
+                    if path.as_posix() != rule:
                         continue
                     # Direct file paths as rules
                     filerule = pathlib.Path(rule)
                     if not filerule.exists():
                         continue
                     for match in matches:
-                        test_module_paths.add(_match_to_test_file(match))
+                        match_path = _match_to_test_file(match)
+                        test_module_selections.append(
+                            "{}: Source '{}' direct file rule from 'tests/filename_map.yml'".format(
+                                match_path, filerule
+                            )
+                        )
+                        test_module_paths.add(match_path)
             continue
         else:
-            log.debug("Don't know what to do with path %s", filename)
+            errors.append("{}: Don't know what to do with this path".format(path))
+
+    if errors:
+        terminal_reporter.write("Errors:\n", bold=True)
+        for error in errors:
+            terminal_reporter.write(" * {}\n".format(error))
+    if changed_files_selections:
+        terminal_reporter.write("Changed files collected:\n", bold=True)
+        for selection in changed_files_selections:
+            terminal_reporter.write(" * {}\n".format(selection))
+    if test_module_selections:
+        terminal_reporter.write("Selected test modules:\n", bold=True)
+        for selection in test_module_selections:
+            terminal_reporter.write(" * {}\n".format(selection))
+    terminal_reporter.section(
+        "From Filenames(--from-filenames) Test Selection", sep="<"
+    )
+    terminal_reporter.ensure_newline()
 
     selected = []
     deselected = []
