@@ -27,7 +27,7 @@ def salt_minion(salt_minion_factory):
     """
     with salt_minion_factory.started():
         # Sync All
-        salt_call_cli = salt_minion_factory.get_salt_call_cli()
+        salt_call_cli = salt_minion_factory.salt_call_cli()
         ret = salt_call_cli.run("saltutil.sync_all", _timeout=120)
         assert ret.exitcode == 0, ret
         yield salt_minion_factory
@@ -40,7 +40,7 @@ def salt_sub_minion(salt_sub_minion_factory):
     """
     with salt_sub_minion_factory.started():
         # Sync All
-        salt_call_cli = salt_sub_minion_factory.get_salt_call_cli()
+        salt_call_cli = salt_sub_minion_factory.salt_call_cli()
         ret = salt_call_cli.run("saltutil.sync_all", _timeout=120)
         assert ret.exitcode == 0, ret
         yield salt_sub_minion_factory
