@@ -1,8 +1,5 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import os
+import random
 import sys
 import tempfile
 from contextlib import contextmanager
@@ -11,17 +8,9 @@ import pytest
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.user
-from salt.ext import six
 from tests.support.case import ModuleCase
-from tests.support.helpers import (
-    dedent,
-    destructiveTest,
-    skip_if_binaries_missing,
-    skip_if_not_root,
-    slowTest,
-)
+from tests.support.helpers import dedent
 from tests.support.runtests import RUNTIME_VARS
-from tests.support.unit import skipIf
 
 AVAILABLE_PYTHON_EXECUTABLE = salt.utils.path.which_bin(
     ["python", "python2", "python2.6", "python2.7"]
@@ -52,7 +41,7 @@ class CMDModuleTest(ModuleCase):
             finally:
                 self.run_function("user.delete", [name], remove=True)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_run(self):
         """
         cmd.run
@@ -65,7 +54,7 @@ class CMDModuleTest(ModuleCase):
         self.assertTrue(self.run_function("cmd.run", ["echo $SHELL"]))
         self.assertEqual(
             self.run_function(
-                "cmd.run", ["echo $SHELL", "shell={0}".format(shell)], python_shell=True
+                "cmd.run", ["echo $SHELL", "shell={}".format(shell)], python_shell=True
             ).rstrip(),
             shell,
         )
@@ -94,7 +83,7 @@ class CMDModuleTest(ModuleCase):
             "a:b",
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_stdout(self):
         """
         cmd.run_stdout
@@ -104,7 +93,7 @@ class CMDModuleTest(ModuleCase):
             "cheese" if not salt.utils.platform.is_windows() else '"cheese"',
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_stderr(self):
         """
         cmd.run_stderr
@@ -117,13 +106,13 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(
             self.run_function(
                 "cmd.run_stderr",
-                ['echo "cheese" 1>&2', "shell={0}".format(shell)],
+                ['echo "cheese" 1>&2', "shell={}".format(shell)],
                 python_shell=True,
             ).rstrip(),
             "cheese" if not salt.utils.platform.is_windows() else '"cheese"',
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_run_all(self):
         """
         cmd.run_all
@@ -135,7 +124,7 @@ class CMDModuleTest(ModuleCase):
 
         ret = self.run_function(
             "cmd.run_all",
-            ['echo "cheese" 1>&2', "shell={0}".format(shell)],
+            ['echo "cheese" 1>&2', "shell={}".format(shell)],
             python_shell=True,
         )
         self.assertTrue("pid" in ret)
@@ -144,14 +133,14 @@ class CMDModuleTest(ModuleCase):
         self.assertTrue("stderr" in ret)
         self.assertTrue(isinstance(ret.get("pid"), int))
         self.assertTrue(isinstance(ret.get("retcode"), int))
-        self.assertTrue(isinstance(ret.get("stdout"), six.string_types))
-        self.assertTrue(isinstance(ret.get("stderr"), six.string_types))
+        self.assertTrue(isinstance(ret.get("stdout"), str))
+        self.assertTrue(isinstance(ret.get("stderr"), str))
         self.assertEqual(
             ret.get("stderr").rstrip(),
             "cheese" if not salt.utils.platform.is_windows() else '"cheese"',
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_retcode(self):
         """
         cmd.retcode
@@ -163,7 +152,7 @@ class CMDModuleTest(ModuleCase):
             self.run_function("cmd.retcode", ["exit 1"], python_shell=True), 1
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_run_all_with_success_retcodes(self):
         """
         cmd.run with success_retcodes
@@ -175,7 +164,7 @@ class CMDModuleTest(ModuleCase):
         self.assertTrue("retcode" in ret)
         self.assertEqual(ret.get("retcode"), 0)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_retcode_with_success_retcodes(self):
         """
         cmd.run with success_retcodes
@@ -186,7 +175,32 @@ class CMDModuleTest(ModuleCase):
 
         self.assertEqual(ret, 0)
 
-    @slowTest
+    @pytest.mark.slow_test
+    def test_run_all_with_success_stderr(self):
+        """
+        cmd.run with success_retcodes
+        """
+        random_file = "{}{}{}".format(
+            RUNTIME_VARS.TMP_ROOT_DIR, os.path.sep, random.random()
+        )
+
+        if salt.utils.platform.is_windows():
+            func = "type"
+            expected_stderr = "cannot find the file specified"
+        else:
+            func = "cat"
+            expected_stderr = "No such file or directory"
+        ret = self.run_function(
+            "cmd.run_all",
+            ["{} {}".format(func, random_file)],
+            success_stderr=[expected_stderr],
+            python_shell=True,
+        )
+
+        self.assertTrue("retcode" in ret)
+        self.assertEqual(ret.get("retcode"), 0)
+
+    @pytest.mark.slow_test
     def test_blacklist_glob(self):
         """
         cmd_blacklist_glob
@@ -196,7 +210,7 @@ class CMDModuleTest(ModuleCase):
             'ERROR: The shell command "bad_command --foo" is not permitted',
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_script(self):
         """
         cmd.script
@@ -206,7 +220,17 @@ class CMDModuleTest(ModuleCase):
         ret = self.run_function("cmd.script", [script, args])
         self.assertEqual(ret["stdout"], args)
 
-    @slowTest
+    @pytest.mark.slow_test
+    def test_script_query_string(self):
+        """
+        cmd.script
+        """
+        args = "saltines crackers biscuits=yes"
+        script = "salt://script.py?saltenv=base"
+        ret = self.run_function("cmd.script", [script, args])
+        self.assertEqual(ret["stdout"], args)
+
+    @pytest.mark.slow_test
     def test_script_retcode(self):
         """
         cmd.script_retcode
@@ -215,7 +239,7 @@ class CMDModuleTest(ModuleCase):
         ret = self.run_function("cmd.script_retcode", [script])
         self.assertEqual(ret, 0)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_script_cwd(self):
         """
         cmd.script with cwd
@@ -226,12 +250,12 @@ class CMDModuleTest(ModuleCase):
         ret = self.run_function("cmd.script", [script, args], cwd=tmp_cwd)
         self.assertEqual(ret["stdout"], args)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_script_cwd_with_space(self):
         """
         cmd.script with cwd
         """
-        tmp_cwd = "{0}{1}test 2".format(
+        tmp_cwd = "{}{}test 2".format(
             tempfile.mkdtemp(dir=RUNTIME_VARS.TMP), os.path.sep
         )
         os.mkdir(tmp_cwd)
@@ -241,7 +265,7 @@ class CMDModuleTest(ModuleCase):
         ret = self.run_function("cmd.script", [script, args], cwd=tmp_cwd)
         self.assertEqual(ret["stdout"], args)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_tty(self):
         """
         cmd.tty
@@ -251,7 +275,8 @@ class CMDModuleTest(ModuleCase):
                 ret = self.run_function("cmd.tty", [tty, "apply salt liberally"])
                 self.assertTrue("Success" in ret)
 
-    @skip_if_binaries_missing(["which"])
+    @pytest.mark.skip_on_windows
+    @pytest.mark.skip_if_binaries_missing("which")
     def test_which(self):
         """
         cmd.which
@@ -262,7 +287,8 @@ class CMDModuleTest(ModuleCase):
         self.assertIsInstance(cmd_run, str)
         self.assertEqual(cmd_which.rstrip(), cmd_run.rstrip())
 
-    @skip_if_binaries_missing(["which"])
+    @pytest.mark.skip_on_windows
+    @pytest.mark.skip_if_binaries_missing("which")
     def test_which_bin(self):
         """
         cmd.which_bin
@@ -271,7 +297,7 @@ class CMDModuleTest(ModuleCase):
         ret = self.run_function("cmd.which_bin", [cmds])
         self.assertTrue(os.path.split(ret)[1] in cmds)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_has_exec(self):
         """
         cmd.has_exec
@@ -283,7 +309,7 @@ class CMDModuleTest(ModuleCase):
             self.run_function("cmd.has_exec", ["alllfsdfnwieulrrh9123857ygf"])
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_exec_code(self):
         """
         cmd.exec_code
@@ -301,7 +327,7 @@ class CMDModuleTest(ModuleCase):
             "cheese",
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_exec_code_with_single_arg(self):
         """
         cmd.exec_code
@@ -320,7 +346,7 @@ class CMDModuleTest(ModuleCase):
             arg,
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_exec_code_with_multiple_args(self):
         """
         cmd.exec_code
@@ -339,7 +365,7 @@ class CMDModuleTest(ModuleCase):
             arg,
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_quotes(self):
         """
         cmd.run with quoted command
@@ -351,8 +377,8 @@ class CMDModuleTest(ModuleCase):
         result = self.run_function("cmd.run_stdout", [cmd]).strip()
         self.assertEqual(result, expected_result)
 
-    @skip_if_not_root
-    @skipIf(salt.utils.platform.is_windows(), "skip windows, requires password")
+    @pytest.mark.skip_if_not_root
+    @pytest.mark.skip_on_windows(reason="Skip on Windows, requires password")
     def test_quotes_runas(self):
         """
         cmd.run with quoted command
@@ -366,10 +392,10 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(result["retcode"], 0, errmsg)
         self.assertEqual(result["stdout"], expected_result, errmsg)
 
-    @destructiveTest
-    @skip_if_not_root
-    @skipIf(salt.utils.platform.is_windows(), "skip windows, uses unix commands")
-    @slowTest
+    @pytest.mark.destructive_test
+    @pytest.mark.skip_if_not_root
+    @pytest.mark.skip_on_windows(reason="Skip on Windows, uses unix commands")
+    @pytest.mark.slow_test
     def test_avoid_injecting_shell_code_as_root(self):
         """
         cmd.run should execute the whole command as the "runas" user, not
@@ -388,10 +414,10 @@ class CMDModuleTest(ModuleCase):
         self.assertNotEqual(user_id, runas_root_id)
         self.assertEqual(root_id, runas_root_id)
 
-    @destructiveTest
-    @skip_if_not_root
-    @skipIf(salt.utils.platform.is_windows(), "skip windows, uses unix commands")
-    @slowTest
+    @pytest.mark.destructive_test
+    @pytest.mark.skip_if_not_root
+    @pytest.mark.skip_on_windows(reason="Skip on Windows, uses unix commands")
+    @pytest.mark.slow_test
     def test_cwd_runas(self):
         """
         cmd.run should be able to change working directory correctly, whether
@@ -412,10 +438,10 @@ class CMDModuleTest(ModuleCase):
             ).rstrip("\n")
         self.assertEqual(tmp_cwd, cwd_runas)
 
-    @destructiveTest
-    @skip_if_not_root
-    @skipIf(not salt.utils.platform.is_darwin(), "applicable to MacOS only")
-    @slowTest
+    @pytest.mark.destructive_test
+    @pytest.mark.skip_if_not_root
+    @pytest.mark.skip_unless_on_darwin(reason="Applicable to MacOS only")
+    @pytest.mark.slow_test
     def test_runas_env(self):
         """
         cmd.run should be able to change working directory correctly, whether
@@ -430,10 +456,10 @@ class CMDModuleTest(ModuleCase):
         # profile.
         self.assertNotEqual("/bin:/usr/bin", user_path)
 
-    @destructiveTest
-    @skip_if_not_root
-    @skipIf(not salt.utils.platform.is_darwin(), "applicable to MacOS only")
-    @slowTest
+    @pytest.mark.destructive_test
+    @pytest.mark.skip_if_not_root
+    @pytest.mark.skip_unless_on_darwin(reason="Applicable to MacOS only")
+    @pytest.mark.slow_test
     def test_runas_complex_command_bad_cwd(self):
         """
         cmd.run should not accidentally run parts of a complex command when
@@ -460,10 +486,10 @@ class CMDModuleTest(ModuleCase):
         self.assertNotIn("You have failed the test", cmd_result["stderr"])
         self.assertNotEqual(0, cmd_result["retcode"])
 
-    @skipIf(salt.utils.platform.is_windows(), "minion is windows")
-    @skip_if_not_root
-    @destructiveTest
-    @slowTest
+    @pytest.mark.skip_on_windows(reason="Minion is Windows")
+    @pytest.mark.skip_if_not_root
+    @pytest.mark.destructive_test
+    @pytest.mark.slow_test
     def test_runas(self):
         """
         Ensure that the env is the runas user's
@@ -472,9 +498,9 @@ class CMDModuleTest(ModuleCase):
             out = self.run_function(
                 "cmd.run", ["env"], runas=self.runas_usr
             ).splitlines()
-        self.assertIn("USER={0}".format(self.runas_usr), out)
+        self.assertIn("USER={}".format(self.runas_usr), out)
 
-    @skipIf(not salt.utils.path.which_bin("sleep"), "sleep cmd not installed")
+    @pytest.mark.skip_if_binaries_missing("sleep", reason="sleep cmd not installed")
     def test_timeout(self):
         """
         cmd.run trigger timeout
@@ -484,7 +510,7 @@ class CMDModuleTest(ModuleCase):
         )
         self.assertTrue("Timed out" in out)
 
-    @skipIf(not salt.utils.path.which_bin("sleep"), "sleep cmd not installed")
+    @pytest.mark.skip_if_binaries_missing("sleep", reason="sleep cmd not installed")
     def test_timeout_success(self):
         """
         cmd.run sufficient timeout to succeed
@@ -494,7 +520,7 @@ class CMDModuleTest(ModuleCase):
         )
         self.assertEqual(out, "hello")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_hide_output(self):
         """
         Test the hide_output argument
@@ -531,7 +557,7 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(out["stdout"], "")
         self.assertEqual(out["stderr"], "")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_cmd_run_whoami(self):
         """
         test return of whoami
@@ -545,8 +571,8 @@ class CMDModuleTest(ModuleCase):
         cmd = self.run_function("cmd.run", ["whoami"])
         self.assertEqual(user.lower(), cmd.lower())
 
-    @skipIf(not salt.utils.platform.is_windows(), "minion is not windows")
-    @slowTest
+    @pytest.mark.skip_unless_on_windows(reason="Minion is not Windows")
+    @pytest.mark.slow_test
     def test_windows_env_handling(self):
         """
         Ensure that nt.environ is used properly with cmd.run*
@@ -557,38 +583,34 @@ class CMDModuleTest(ModuleCase):
         self.assertIn("abc=123", out)
         self.assertIn("ABC=456", out)
 
-    @skipIf(not salt.utils.platform.is_windows(), "minion is not windows")
-    def test_windows_cmd_powershell_list(self):
-        """
-        Ensure that cmd.run_all supports running shell='cmd' with cmd passed
-        as a list
-        """
-        out = self.run_function(
-            "cmd.run_all", cmd=["echo", "salt"], python_shell=False, shell="powershell"
-        )
-        self.assertEqual(out["stdout"], "salt")
-
-    @skipIf(not salt.utils.platform.is_windows(), "minion is not windows")
-    def test_windows_cmd_powershell_string(self):
-        """
-        Ensure that cmd.run_all supports running shell='cmd' with cmd passed
-        as a string
-        """
-        out = self.run_function(
-            "cmd.run_all", cmd="echo salt", python_shell=False, shell="powershell"
-        )
-        self.assertEqual(out["stdout"], "salt")
-
-    @slowTest
-    @skipIf(not salt.utils.platform.is_windows(), "minion is not windows")
+    @pytest.mark.slow_test
+    @pytest.mark.skip_unless_on_windows(reason="Minion is not Windows")
     def test_windows_powershell_script_args(self):
         """
         Ensure that powershell processes inline script in args
         """
         val = "i like cheese"
-        args = '-SecureString (ConvertTo-SecureString -String "{0}" -AsPlainText -Force) -ErrorAction Stop'.format(
-            val
+        args = (
+            '-SecureString (ConvertTo-SecureString -String "{}" -AsPlainText -Force)'
+            " -ErrorAction Stop".format(val)
         )
         script = "salt://issue-56195/test.ps1"
         ret = self.run_function("cmd.script", [script], args=args, shell="powershell")
         self.assertEqual(ret["stdout"], val)
+
+    @pytest.mark.slow_test
+    @pytest.mark.skip_unless_on_windows(reason="Minion is not Windows")
+    @pytest.mark.skip_if_binaries_missing("pwsh")
+    def test_windows_powershell_script_args_pwsh(self):
+        """
+        Ensure that powershell processes inline script in args with powershell
+        core
+        """
+        val = "i like cheese"
+        args = (
+            '-SecureString (ConvertTo-SecureString -String "{}" -AsPlainText -Force)'
+            " -ErrorAction Stop".format(val)
+        )
+        script = "salt://issue-56195/test.ps1"
+        ret = self.run_function("cmd.script", [script], args=args, shell="pwsh")
+        self.assertEqual(ret["stdout"], val)
