@@ -1,10 +1,5 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import pytest
 from tests.support.case import ModuleCase
-from tests.support.helpers import slowTest
 
 
 @pytest.mark.windows_whitelisted
@@ -17,7 +12,7 @@ class DataModuleTest(ModuleCase):
         self.run_function("data.clear")
         self.addCleanup(self.run_function, "data.clear")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_load_dump(self):
         """
         data.load
@@ -26,7 +21,7 @@ class DataModuleTest(ModuleCase):
         self.assertTrue(self.run_function("data.dump", ['{"foo": "bar"}']))
         self.assertEqual(self.run_function("data.load"), {"foo": "bar"})
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_get_update(self):
         """
         data.get
@@ -40,7 +35,7 @@ class DataModuleTest(ModuleCase):
             self.run_function("data.get", [["spam", "unladen"]]), ["eggs", "swallow"]
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_cas_update(self):
         """
         data.update
