@@ -1,20 +1,17 @@
-# -*- coding: utf-8 -*-
 """
 Integration tests for the docker_container states
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import random
 import string
 import sys
 
+import pytest
 import salt.utils.path
-from salt.ext.six.moves import range  # pylint: disable=import-error,redefined-builtin
+from saltfactories.utils.tempfiles import temp_file
 from tests.support.case import ModuleCase
-from tests.support.helpers import destructiveTest, slowTest
 from tests.support.mixins import SaltReturnAssertsMixin
-
-# Import Salt Testing Libs
+from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import skipIf
 
 
@@ -25,8 +22,8 @@ def _random_name(prefix=""):
     return ret
 
 
-@destructiveTest
 @skipIf(not salt.utils.path.which("dockerd"), "Docker not installed")
+@pytest.mark.destructive_test
 class DockerCallTestCase(ModuleCase, SaltReturnAssertsMixin):
     """
     Test docker_container states
@@ -44,7 +41,7 @@ class DockerCallTestCase(ModuleCase, SaltReturnAssertsMixin):
         self.run_state(
             "docker_container.running",
             name=self.random_name,
-            image="python:{0}".format(self.image_tag),
+            image="python:{}".format(self.image_tag),
             entrypoint="tail -f /dev/null",
         )
 
@@ -55,13 +52,13 @@ class DockerCallTestCase(ModuleCase, SaltReturnAssertsMixin):
         self.run_state("docker_container.absent", name=self.random_name, force=True)
         self.run_state(
             "docker_image.absent",
-            images=["python:{0}".format(self.image_tag)],
+            images=["python:{}".format(self.image_tag)],
             force=True,
         )
         delattr(self, "random_name")
         delattr(self, "image_tag")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_docker_call(self):
         """
         check that docker.call works, and works with a container not running as root
@@ -69,18 +66,48 @@ class DockerCallTestCase(ModuleCase, SaltReturnAssertsMixin):
         ret = self.run_function("docker.call", [self.random_name, "test.ping"])
         assert ret is True
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_docker_sls(self):
         """
         check that docker.sls works, and works with a container not running as root
         """
-        ret = self.run_function("docker.apply", [self.random_name, "core"])
-        self.assertSaltTrueReturn(ret)
+        core_state = """
+        {}/testfile:
+          file:
+            - managed
+            - source: salt://testfile
+            - makedirs: true
+            """.format(
+            RUNTIME_VARS.TMP
+        )
 
-    @slowTest
+        with temp_file("core.sls", core_state, RUNTIME_VARS.TMP_BASEENV_STATE_TREE):
+            ret = self.run_function("docker.apply", [self.random_name, "core"])
+            self.assertSaltTrueReturn(ret)
+
+    @pytest.mark.slow_test
     def test_docker_highstate(self):
         """
         check that docker.highstate works, and works with a container not running as root
         """
-        ret = self.run_function("docker.apply", [self.random_name])
-        self.assertSaltTrueReturn(ret)
+        top_sls = """
+        base:
+          '*':
+            - core
+            """
+
+        core_state = """
+        {}/testfile:
+          file:
+            - managed
+            - source: salt://testfile
+            - makedirs: true
+            """.format(
+            RUNTIME_VARS.TMP
+        )
+
+        with temp_file(
+            "top.sls", top_sls, RUNTIME_VARS.TMP_BASEENV_STATE_TREE
+        ), temp_file("core.sls", core_state, RUNTIME_VARS.TMP_BASEENV_STATE_TREE):
+            ret = self.run_function("docker.apply", [self.random_name])
+            self.assertSaltTrueReturn(ret)
