@@ -1,17 +1,15 @@
-# -*- coding: utf-8 -*-
 """
 Integration tests for the mac_desktop execution module.
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-from salt.ext import six
+import pytest
 from tests.support.case import ModuleCase
-from tests.support.helpers import destructiveTest, runs_on, skip_if_not_root, slowTest
+from tests.support.helpers import runs_on
 
 
-@destructiveTest
-@skip_if_not_root
+@pytest.mark.destructive_test
 @runs_on(kernel="Darwin")
+@pytest.mark.skip_if_not_root
 class MacDesktopTestCase(ModuleCase):
     """
     Integration tests for the mac_desktop module.
@@ -24,18 +22,16 @@ class MacDesktopTestCase(ModuleCase):
         ret = self.run_function("desktop.get_output_volume")
         self.assertIsNotNone(ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_set_output_volume(self):
         """
         Tests the return of set_output_volume.
         """
         current_vol = self.run_function("desktop.get_output_volume")
         to_set = 10
-        if current_vol == six.text_type(to_set):
+        if current_vol == str(to_set):
             to_set += 2
-        new_vol = self.run_function(
-            "desktop.set_output_volume", [six.text_type(to_set)]
-        )
+        new_vol = self.run_function("desktop.set_output_volume", [str(to_set)])
         check_vol = self.run_function("desktop.get_output_volume")
         self.assertEqual(new_vol, check_vol)
 
@@ -54,7 +50,7 @@ class MacDesktopTestCase(ModuleCase):
         """
         self.assertTrue(self.run_function("desktop.lock"))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_say(self):
         """
         Tests the return of the say function.
