@@ -1,16 +1,9 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
 import pytest
 import salt.utils.path
-from salt.ext import six
-from salt.ext.six.moves import range
 from salt.modules import mysql as mysqlmod
 from tests.support.case import ModuleCase
-from tests.support.helpers import destructiveTest
 from tests.support.mixins import SaltReturnAssertsMixin
 from tests.support.unit import skipIf
 
@@ -40,12 +33,12 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
     user = "root"
     password = "poney"
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def setUp(self):
         """
         Test presence of MySQL server, enforce a root password
         """
-        super(MysqlModuleDbTest, self).setUp()
+        super().setUp()
         NO_MYSQL_SERVER = True
         # now ensure we know the mysql root password
         # one of theses two at least should work
@@ -79,14 +72,14 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
         """
         ret = self.run_function("mysql.db_create", name=db_name, **kwargs)
         self.assertEqual(
-            True, ret, "Problem while creating db for db name: '{0}'".format(db_name)
+            True, ret, "Problem while creating db for db name: '{}'".format(db_name)
         )
         # test db exists
         ret = self.run_function("mysql.db_exists", name=db_name, **kwargs)
         self.assertEqual(
             True,
             ret,
-            "Problem while testing db exists for db name: '{0}'".format(db_name),
+            "Problem while testing db exists for db name: '{}'".format(db_name),
         )
         # List db names to ensure db is created with the right utf8 string
         ret = self.run_function("mysql.db_list", **kwargs)
@@ -94,7 +87,7 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
             raise AssertionError(
                 (
                     "Unexpected query result while retrieving databases list"
-                    " '{0}' for '{1}' test"
+                    " '{}' for '{}' test"
                 ).format(ret, db_name)
             )
         self.assertIn(
@@ -102,7 +95,7 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
             ret,
             (
                 "Problem while testing presence of db name in db lists"
-                " for db name: '{0}' in list '{1}'"
+                " for db name: '{}' in list '{}'"
             ).format(db_name, ret),
         )
 
@@ -113,20 +106,19 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
             )
             if not isinstance(ret, dict) or "results" not in ret:
                 raise AssertionError(
-                    (
-                        "Unexpected result while testing connection"
-                        " on database : {0}"
-                    ).format(repr(db_name))
+                    "Unexpected result while testing connection on database : {}".format(
+                        repr(db_name)
+                    )
                 )
             self.assertEqual([["1"]], ret["results"])
 
         # Now remove database
         ret = self.run_function("mysql.db_remove", name=db_name, **kwargs)
         self.assertEqual(
-            True, ret, "Problem while removing db for db name: '{0}'".format(db_name)
+            True, ret, "Problem while removing db for db name: '{}'".format(db_name)
         )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_database_creation_level1(self):
         """
         Create database, test presence, then drop db. All theses with complex names.
@@ -225,7 +217,7 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
             connection_pass=self.password,
         )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_mysql_dbname_character_percent(self):
         """
         Play with the '%' character problems
@@ -281,7 +273,7 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
         )
         self.assertEqual(True, ret)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_database_creation_utf8(self):
         """
         Test support of utf8 in database names
@@ -337,7 +329,7 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
             saltenv={"LC_ALL": "en_US.utf8"},
         )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_database_maintenance(self):
         """
         Test maintenance operations on a created database
@@ -375,23 +367,24 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
             "B%table '`2": "InnoDB",
             "Ctable --`3": "MEMORY",
         }
-        for tablename, engine in sorted(six.iteritems(tablenames)):
+        for tablename, engine in sorted(tablenames.items()):
             # prepare queries
             create_query = (
                 "CREATE TABLE {tblname} ("
                 " id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,"
                 " data VARCHAR(100)) ENGINE={engine};".format(
-                    tblname=mysqlmod.quote_identifier(tablename), engine=engine,
+                    tblname=mysqlmod.quote_identifier(tablename),
+                    engine=engine,
                 )
             )
-            insert_query = "INSERT INTO {tblname} (data)" " VALUES ".format(
+            insert_query = "INSERT INTO {tblname} (data) VALUES ".format(
                 tblname=mysqlmod.quote_identifier(tablename)
             )
-            delete_query = "DELETE from  {tblname}" " order by rand() limit 50;".format(
+            delete_query = "DELETE from  {tblname} order by rand() limit 50;".format(
                 tblname=mysqlmod.quote_identifier(tablename)
             )
             for x in range(100):
-                insert_query += "('foo" + six.text_type(x) + "'),"
+                insert_query += "('foo" + str(x) + "'),"
             insert_query += "('bar');"
 
             # populate database
@@ -407,9 +400,10 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
                 raise AssertionError(
                     (
                         "Unexpected query result while populating test table"
-                        " '{0}' : '{1}'"
+                        " '{}' : '{}'"
                     ).format(
-                        tablename, ret,
+                        tablename,
+                        ret,
                     )
                 )
             self.assertEqual(ret["rows affected"], 0)
@@ -425,9 +419,10 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
                 raise AssertionError(
                     (
                         "Unexpected query result while populating test table"
-                        " '{0}' : '{1}'"
+                        " '{}' : '{}'"
                     ).format(
-                        tablename, ret,
+                        tablename,
+                        ret,
                     )
                 )
             self.assertEqual(ret["rows affected"], 101)
@@ -443,9 +438,10 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
                 raise AssertionError(
                     (
                         "Unexpected query result while removing rows on test table"
-                        " '{0}' : '{1}'"
+                        " '{}' : '{}'"
                     ).format(
-                        tablename, ret,
+                        tablename,
+                        ret,
                     )
                 )
             self.assertEqual(ret["rows affected"], 50)
@@ -517,15 +513,14 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
             connection_pass=self.password,
         )
         expected = []
-        for tablename, engine in sorted(six.iteritems(tablenames)):
+        for tablename, engine in sorted(tablenames.items()):
             if engine == "MEMORY":
                 expected.append(
                     [
                         {
                             "Table": dbname + "." + tablename,
                             "Msg_text": (
-                                "The storage engine for the table doesn't"
-                                " support check"
+                                "The storage engine for the table doesn't support check"
                             ),
                             "Msg_type": "note",
                             "Op": "check",
@@ -552,7 +547,7 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
             connection_pass=self.password,
         )
         expected = []
-        for tablename, engine in sorted(six.iteritems(tablenames)):
+        for tablename, engine in sorted(tablenames.items()):
             if engine == "MYISAM":
                 expected.append(
                     [
@@ -588,7 +583,7 @@ class MysqlModuleDbTest(ModuleCase, SaltReturnAssertsMixin):
         )
 
         expected = []
-        for tablename, engine in sorted(six.iteritems(tablenames)):
+        for tablename, engine in sorted(tablenames.items()):
             if engine == "MYISAM":
                 expected.append(
                     [
@@ -659,12 +654,12 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
     user = "root"
     password = "poney"
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def setUp(self):
         """
         Test presence of MySQL server, enforce a root password
         """
-        super(MysqlModuleUserTest, self).setUp()
+        super().setUp()
         NO_MYSQL_SERVER = True
         # now ensure we know the mysql root password
         # one of theses two at least should work
@@ -713,7 +708,7 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            ("Calling user_create on" " user '{0}' did not return True: {1}").format(
+            "Calling user_create on user '{}' did not return True: {}".format(
                 uname, repr(ret)
             ),
         )
@@ -726,7 +721,7 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
             ret,
             (
                 "Calling user_create a second time on"
-                " user '{0}' did not return False: {1}"
+                " user '{}' did not return False: {}"
             ).format(uname, repr(ret)),
         )
         # Alter password
@@ -745,9 +740,9 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
             self.assertEqual(
                 True,
                 ret,
-                (
-                    "Calling user_chpass on" " user '{0}' did not return True: {1}"
-                ).format(uname, repr(ret)),
+                "Calling user_chpass on user '{}' did not return True: {}".format(
+                    uname, repr(ret)
+                ),
             )
 
     def _chck_userinfo(self, user, host, check_user, check_hash):
@@ -765,7 +760,7 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         )
         if not isinstance(ret, dict):
             raise AssertionError(
-                "Unexpected result while retrieving user_info for " "'{0}'".format(user)
+                "Unexpected result while retrieving user_info for '{}'".format(user)
             )
         self.assertEqual(ret["Host"], host)
         self.assertEqual(ret["Password"], check_hash)
@@ -779,12 +774,12 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            (
-                "Assertion failed  while removing user" " '{0}' on host '{1}': {2}"
-            ).format(user, host, repr(ret)),
+            "Assertion failed  while removing user '{}' on host '{}': {}".format(
+                user, host, repr(ret)
+            ),
         )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_user_management(self):
         """
         Test various users creation settings
@@ -844,7 +839,7 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            ("Testing final user '{0}' on host '{1}'" " existence failed").format(
+            "Testing final user '{}' on host '{}' existence failed".format(
                 user1, "localhost"
             ),
         )
@@ -897,9 +892,7 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            ("Testing final user '{0}' on host '{1}'" " failed").format(
-                user2, "localhost"
-            ),
+            "Testing final user '{}' on host '{}' failed".format(user2, "localhost"),
         )
         ret = self.run_function(
             "mysql.user_exists",
@@ -914,9 +907,9 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            (
-                "Testing final user '{0}' on host '{1}'" " without password failed"
-            ).format(user2, "10.0.0.1"),
+            "Testing final user '{}' on host '{}' without password failed".format(
+                user2, "10.0.0.1"
+            ),
         )
         ret = self.run_function(
             "mysql.user_exists",
@@ -932,9 +925,9 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            (
-                "Testing final user '{0}' on host '{1}'" " without password failed"
-            ).format(user2, "10.0.0.2"),
+            "Testing final user '{}' on host '{}' without password failed".format(
+                user2, "10.0.0.2"
+            ),
         )
 
         # Empty password is not passwordless (or is it a bug?)
@@ -966,10 +959,9 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            (
-                "Testing final user '{0}' on host '{1}'"
-                " without empty password failed"
-            ).format(user3, "localhost"),
+            "Testing final user '{}' on host '{}' without empty password failed".format(
+                user3, "localhost"
+            ),
         )
         ret = self.run_function(
             "mysql.user_exists",
@@ -982,7 +974,7 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            ("Testing final user '{0}' on host '{1}'" " with password failed").format(
+            "Testing final user '{}' on host '{}' with password failed".format(
                 user3, "%"
             ),
         )
@@ -1014,7 +1006,7 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
             True,
             ret,
             (
-                "Testing final user '{0}' on host '{1}'"
+                "Testing final user '{}' on host '{}'"
                 " with password take from password and not password_hash"
                 " failed"
             ).format(user4_utf8, "%"),
@@ -1043,9 +1035,9 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            (
-                "Testing final user '{0}' on host '{1}'" " with utf8 password failed"
-            ).format(user5_utf8, "localhost"),
+            "Testing final user '{}' on host '{}' with utf8 password failed".format(
+                user5_utf8, "localhost"
+            ),
         )
         # for this one we give password in unicode and check it in utf-8
         self._userCreationLoop(
@@ -1072,9 +1064,9 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(
             True,
             ret,
-            (
-                "Testing final user '{0}' on host '{1}'" " with unicode password failed"
-            ).format(user6_utf8, "10.0.0.1"),
+            "Testing final user '{}' on host '{}' with unicode password failed".format(
+                user6_utf8, "10.0.0.1"
+            ),
         )
         # Final result should be:
         # mysql> select Host, User, Password from user where user like 'user%';
@@ -1153,9 +1145,9 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         )
         if not isinstance(ret, dict) or "results" not in ret:
             raise AssertionError(
-                (
-                    "Unexpected result while testing connection" " with user '{0}': {1}"
-                ).format(user1, repr(ret))
+                "Unexpected result while testing connection with user '{}': {}".format(
+                    user1, repr(ret)
+                )
             )
         self.assertEqual([["1"]], ret["results"])
 
@@ -1194,9 +1186,9 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         )
         if not isinstance(ret, dict) or "results" not in ret:
             raise AssertionError(
-                (
-                    "Unexpected result while testing connection" " with user '{0}': {1}"
-                ).format(user3, repr(ret))
+                "Unexpected result while testing connection with user '{}': {}".format(
+                    user3, repr(ret)
+                )
             )
         self.assertEqual([["1"]], ret["results"])
         # FIXME: Failing
@@ -1231,9 +1223,9 @@ class MysqlModuleUserTest(ModuleCase, SaltReturnAssertsMixin):
         )
         if not isinstance(ret, dict) or "results" not in ret:
             raise AssertionError(
-                (
-                    "Unexpected result while testing connection" " with user '{0}': {1}"
-                ).format(user5_utf8, repr(ret))
+                "Unexpected result while testing connection with user '{}': {}".format(
+                    user5_utf8, repr(ret)
+                )
             )
         self.assertEqual([["1"]], ret["results"])
 
@@ -1349,12 +1341,12 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
         "user4": {"name": "user \xe6\xa8\x99", "pwd": "\xe6\xa8\x99\xe6\xa8\x99"},
     }
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def setUp(self):
         """
         Test presence of MySQL server, enforce a root password, create users
         """
-        super(MysqlModuleUserGrantTest, self).setUp()
+        super().setUp()
         NO_MYSQL_SERVER = True
         # now ensure we know the mysql root password
         # one of theses two at least should work
@@ -1382,7 +1374,7 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
         else:
             self.skipTest("No MySQL Server running, or no root access on it.")
         # Create some users and a test db
-        for user, userdef in six.iteritems(self.users):
+        for user, userdef in self.users.items():
             self._userCreation(uname=userdef["name"], password=userdef["pwd"])
         self.run_function(
             "mysql.db_create",
@@ -1400,7 +1392,8 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
             "CREATE TABLE {tblname} ("
             " id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,"
             " data VARCHAR(100)) ENGINE={engine};".format(
-                tblname=mysqlmod.quote_identifier(self.table1), engine="MYISAM",
+                tblname=mysqlmod.quote_identifier(self.table1),
+                engine="MYISAM",
             )
         )
         log.info("Adding table '%s'", self.table1)
@@ -1415,7 +1408,8 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
             "CREATE TABLE {tblname} ("
             " id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,"
             " data VARCHAR(100)) ENGINE={engine};".format(
-                tblname=mysqlmod.quote_identifier(self.table2), engine="MYISAM",
+                tblname=mysqlmod.quote_identifier(self.table2),
+                engine="MYISAM",
             )
         )
         log.info("Adding table '%s'", self.table2)
@@ -1427,12 +1421,12 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
             connection_pass=self.password,
         )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def tearDown(self):
         """
         Removes created users and db
         """
-        for user, userdef in six.iteritems(self.users):
+        for user, userdef in self.users.items():
             self._userRemoval(uname=userdef["name"], password=userdef["pwd"])
         self.run_function(
             "mysql.db_remove",
@@ -1501,8 +1495,7 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
             True,
             ret,
             (
-                "Calling grant_add on"
-                " user '{0}' and grants '{1}' did not return True: {2}"
+                "Calling grant_add on user '{}' and grants '{}' did not return True: {}"
             ).format(user, grant, repr(ret)),
         )
         ret = self.run_function(
@@ -1519,11 +1512,11 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
             ret,
             (
                 "Calling grant_exists on"
-                " user '{0}' and grants '{1}' did not return True: {2}"
+                " user '{}' and grants '{}' did not return True: {}"
             ).format(user, grant, repr(ret)),
         )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def testGrants(self):
         """
         Test user grant methods
@@ -1616,14 +1609,10 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
             ret,
             [
                 "GRANT USAGE ON *.* TO 'foo'@'localhost'",
-                (
-                    "GRANT SELECT, INSERT, UPDATE, CREATE ON "
-                    "`tes.t'\"saltdb`.* TO 'foo'@'localhost' WITH GRANT OPTION"
-                ),
-                (
-                    "GRANT SELECT, INSERT ON `t_st ``(:=salt%b)`.`foo`"
-                    " TO 'foo'@'localhost' WITH GRANT OPTION"
-                ),
+                "GRANT SELECT, INSERT, UPDATE, CREATE ON "
+                "`tes.t'\"saltdb`.* TO 'foo'@'localhost' WITH GRANT OPTION",
+                "GRANT SELECT, INSERT ON `t_st ``(:=salt%b)`.`foo`"
+                " TO 'foo'@'localhost' WITH GRANT OPTION",
             ],
         )
 
@@ -1638,11 +1627,9 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
             ret,
             [
                 "GRANT USAGE ON *.* TO 'user \";--,?:&/\\'@'localhost'",
-                (
-                    "GRANT SELECT, UPDATE, DELETE, CREATE TEMPORARY TABLES ON `tes.t'"
-                    "\"saltdb`.* TO 'user \";--,?:&/\\'@'localhost'"
-                    " WITH GRANT OPTION"
-                ),
+                "GRANT SELECT, UPDATE, DELETE, CREATE TEMPORARY TABLES ON `tes.t'"
+                "\"saltdb`.* TO 'user \";--,?:&/\\'@'localhost'"
+                " WITH GRANT OPTION",
             ],
         )
 
@@ -1657,11 +1644,9 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
             ret,
             [
                 "GRANT USAGE ON *.* TO 'user( @ )=foobar'@'localhost'",
-                (
-                    "GRANT SELECT, ALTER, CREATE TEMPORARY TABLES, EXECUTE ON "
-                    "`tes.t'\"saltdb`.* TO 'user( @ )=foobar'@'localhost' "
-                    "WITH GRANT OPTION"
-                ),
+                "GRANT SELECT, ALTER, CREATE TEMPORARY TABLES, EXECUTE ON "
+                "`tes.t'\"saltdb`.* TO 'user( @ )=foobar'@'localhost' "
+                "WITH GRANT OPTION",
             ],
         )
 
@@ -1681,14 +1666,10 @@ class MysqlModuleUserGrantTest(ModuleCase, SaltReturnAssertsMixin):
                     r"GRANT CREATE ON `t\_st ``(:=salt\%b)`.* TO "
                     "'user \xe6\xa8\x99'@'localhost'"
                 ),
-                (
-                    "GRANT SELECT, INSERT ON `t_st ``(:=salt%b)`.`foo ``'%_bar` TO "
-                    "'user \xe6\xa8\x99'@'localhost'"
-                ),
-                (
-                    "GRANT SELECT, INSERT ON `t_st ``(:=salt%b)`.`foo` TO "
-                    "'user \xe6\xa8\x99'@'localhost'"
-                ),
+                "GRANT SELECT, INSERT ON `t_st ``(:=salt%b)`.`foo ``'%_bar` TO "
+                "'user \xe6\xa8\x99'@'localhost'",
+                "GRANT SELECT, INSERT ON `t_st ``(:=salt%b)`.`foo` TO "
+                "'user \xe6\xa8\x99'@'localhost'",
             ],
         )
 
@@ -1723,12 +1704,12 @@ class MysqlModuleFileQueryTest(ModuleCase, SaltReturnAssertsMixin):
     password = "poney"
     testdb = "test_file_query"
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def setUp(self):
         """
         Test presence of MySQL server, enforce a root password, create users
         """
-        super(MysqlModuleFileQueryTest, self).setUp()
+        super().setUp()
         NO_MYSQL_SERVER = True
         # now ensure we know the mysql root password
         # one of theses two at least should work
@@ -1764,7 +1745,7 @@ class MysqlModuleFileQueryTest(ModuleCase, SaltReturnAssertsMixin):
             connection_db="mysql",
         )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def tearDown(self):
         """
         Removes created users and db
@@ -1777,7 +1758,7 @@ class MysqlModuleFileQueryTest(ModuleCase, SaltReturnAssertsMixin):
             connection_db="mysql",
         )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_update_file_query(self):
         """
         Test query without any output
@@ -1795,7 +1776,7 @@ class MysqlModuleFileQueryTest(ModuleCase, SaltReturnAssertsMixin):
         ret.pop("query time")
         self.assertEqual(ret, {"rows affected": 2})
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_select_file_query(self):
         """
         Test query with table output
