@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 tests.integration.modules.pip
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
 
 import os
 import pprint
@@ -19,7 +17,7 @@ import salt.utils.path
 import salt.utils.platform
 from salt.modules.virtualenv_mod import KNOWN_BINARY_NAMES
 from tests.support.case import ModuleCase
-from tests.support.helpers import patched_environ, slowTest
+from tests.support.helpers import patched_environ
 from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import skipIf
 
@@ -30,7 +28,7 @@ from tests.support.unit import skipIf
 @pytest.mark.windows_whitelisted
 class PipModuleTest(ModuleCase):
     def setUp(self):
-        super(PipModuleTest, self).setUp()
+        super().setUp()
         self.venv_test_dir = tempfile.mkdtemp(dir=RUNTIME_VARS.TMP)
         # Remove the venv test directory
         self.addCleanup(shutil.rmtree, self.venv_test_dir, ignore_errors=True)
@@ -89,7 +87,14 @@ class PipModuleTest(ModuleCase):
         """
         return any(w in ret for w in ["URLError", "Download error"])
 
-    def pip_successful_install(self, target, expect=("irc3-plugins-test", "pep8",)):
+    def pip_successful_install(
+        self,
+        target,
+        expect=(
+            "irc3-plugins-test",
+            "pep8",
+        ),
+    ):
         """
         isolate regex for extracting `successful install` message from pip
         """
@@ -102,16 +107,14 @@ class PipModuleTest(ModuleCase):
         )
 
         success_for = (
-            re.findall(
-                r"({0})(?:-(?:[\d\.-]))?".format(expect_str), success.groups()[0]
-            )
+            re.findall(r"({})(?:-(?:[\d\.-]))?".format(expect_str), success.groups()[0])
             if success
             else []
         )
 
         return expect.issubset(set(success_for))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_issue_2087_missing_pip(self):
         # Let's create the testing virtualenv
         self._create_virtualenv(self.venv_dir)
@@ -138,12 +141,12 @@ class PipModuleTest(ModuleCase):
         for func in ("pip.freeze", "pip.list"):
             ret = self.run_function(func, bin_env=self.venv_dir)
             self.assertIn(
-                "Command required for '{0}' not found: "
+                "Command required for '{}' not found: "
                 "Could not find a `pip` binary".format(func),
                 ret,
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_requirements_as_list_of_chains__cwd_set__absolute_file_path(self):
         self._create_virtualenv(self.venv_dir)
 
@@ -173,9 +176,8 @@ class PipModuleTest(ModuleCase):
         )
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -184,12 +186,11 @@ class PipModuleTest(ModuleCase):
             self.assertTrue(found)
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_requirements_as_list_of_chains__cwd_not_set__absolute_file_path(self):
         self._create_virtualenv(self.venv_dir)
 
@@ -217,9 +218,8 @@ class PipModuleTest(ModuleCase):
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -228,12 +228,11 @@ class PipModuleTest(ModuleCase):
             self.assertTrue(found)
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_requirements_as_list__absolute_file_path(self):
         self._create_virtualenv(self.venv_dir)
 
@@ -253,9 +252,8 @@ class PipModuleTest(ModuleCase):
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -264,12 +262,11 @@ class PipModuleTest(ModuleCase):
             self.assertTrue(found)
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_requirements_as_list__non_absolute_file_path(self):
         self._create_virtualenv(self.venv_dir)
 
@@ -298,9 +295,8 @@ class PipModuleTest(ModuleCase):
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -309,12 +305,11 @@ class PipModuleTest(ModuleCase):
             self.assertTrue(found)
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_chained_requirements__absolute_file_path(self):
         self._create_virtualenv(self.venv_dir)
 
@@ -333,9 +328,8 @@ class PipModuleTest(ModuleCase):
         )
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -343,12 +337,11 @@ class PipModuleTest(ModuleCase):
             self.assertIn("installed pep8", ret["stdout"])
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_chained_requirements__non_absolute_file_path(self):
         self._create_virtualenv(self.venv_dir)
 
@@ -374,9 +367,8 @@ class PipModuleTest(ModuleCase):
         )
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -384,12 +376,11 @@ class PipModuleTest(ModuleCase):
             self.assertIn("installed pep8", ret["stdout"])
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_issue_4805_nested_requirements(self):
         self._create_virtualenv(self.venv_dir)
 
@@ -410,9 +401,8 @@ class PipModuleTest(ModuleCase):
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -422,12 +412,11 @@ class PipModuleTest(ModuleCase):
             self.assertIn("installed pep8", ret["stdout"])
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_pip_uninstall(self):
         # Let's create the testing virtualenv
         self._create_virtualenv(self.venv_dir)
@@ -435,9 +424,8 @@ class PipModuleTest(ModuleCase):
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -447,17 +435,15 @@ class PipModuleTest(ModuleCase):
             self.assertIn("installed pep8", ret["stdout"])
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
         ret = self.run_function("pip.uninstall", ["pep8"], bin_env=self.venv_dir)
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.uninstall' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.uninstall' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -465,12 +451,11 @@ class PipModuleTest(ModuleCase):
             self.assertIn("uninstalled pep8", ret["stdout"])
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_pip_install_upgrade(self):
         # Create the testing virtualenv
         self._create_virtualenv(self.venv_dir)
@@ -478,9 +463,8 @@ class PipModuleTest(ModuleCase):
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -490,9 +474,8 @@ class PipModuleTest(ModuleCase):
             self.assertIn("installed pep8", ret["stdout"])
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
         ret = self.run_function(
@@ -501,9 +484,8 @@ class PipModuleTest(ModuleCase):
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -513,18 +495,16 @@ class PipModuleTest(ModuleCase):
             self.assertIn("installed pep8", ret["stdout"])
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
         ret = self.run_function("pip.uninstall", ["pep8"], bin_env=self.venv_dir)
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.uninstall' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.uninstall' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -532,12 +512,11 @@ class PipModuleTest(ModuleCase):
             self.assertIn("uninstalled pep8", ret["stdout"])
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_pip_install_multiple_editables(self):
         editables = [
             "git+https://github.com/jek/blinker.git#egg=Blinker",
@@ -549,30 +528,31 @@ class PipModuleTest(ModuleCase):
         ret = self.run_function(
             "pip.install",
             [],
-            editable="{0}".format(",".join(editables)),
+            editable="{}".format(",".join(editables)),
             bin_env=self.venv_dir,
         )
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
             if self._check_download_error(ret["stdout"]):
                 self.skipTest("Test skipped due to pip download error")
             self.assertEqual(ret["retcode"], 0)
-            self.assertIn("Successfully installed Blinker SaltTesting", ret["stdout"])
+            match = re.search(
+                "Successfully installed Blinker(.*) SaltTesting(.*)", ret["stdout"]
+            )
+            assert match is not None
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_pip_install_multiple_editables_and_pkgs(self):
         editables = [
             "git+https://github.com/jek/blinker.git#egg=Blinker",
@@ -584,15 +564,14 @@ class PipModuleTest(ModuleCase):
         ret = self.run_function(
             "pip.install",
             ["pep8"],
-            editable="{0}".format(",".join(editables)),
+            editable="{}".format(",".join(editables)),
             bin_env=self.venv_dir,
         )
 
         if not isinstance(ret, dict):
             self.fail(
-                "The 'pip.install' command did not return the excepted dictionary. Output:\n{}".format(
-                    ret
-                )
+                "The 'pip.install' command did not return the excepted dictionary."
+                " Output:\n{}".format(ret)
             )
 
         try:
@@ -602,13 +581,12 @@ class PipModuleTest(ModuleCase):
             for package in ("Blinker", "SaltTesting", "pep8"):
                 self.assertRegex(
                     ret["stdout"],
-                    r"(?:.*)(Successfully installed)(?:.*)({0})(?:.*)".format(package),
+                    r"(?:.*)(Successfully installed)(?:.*)({})(?:.*)".format(package),
                 )
         except KeyError as exc:
             self.fail(
-                "The returned dictionary is missing an expected key. Error: '{}'. Dictionary: {}".format(
-                    exc, pprint.pformat(ret)
-                )
+                "The returned dictionary is missing an expected key. Error: '{}'."
+                " Dictionary: {}".format(exc, pprint.pformat(ret))
             )
 
     @skipIf(not os.path.isfile("pip3"), "test where pip3 is installed")
