@@ -6,15 +6,7 @@ import salt.utils.path
 import salt.utils.pkg
 import salt.utils.platform
 from tests.support.case import ModuleCase
-from tests.support.helpers import (
-    destructiveTest,
-    requires_network,
-    requires_salt_modules,
-    requires_salt_states,
-    requires_system_grains,
-    skip_if_not_root,
-    slowTest,
-)
+from tests.support.helpers import requires_system_grains
 from tests.support.mixins import SaltReturnAssertsMixin
 from tests.support.unit import skipIf
 
@@ -33,17 +25,20 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
         if salt.utils.platform.is_windows():
             cls.pkg = "putty"
         elif grains["os_family"] == "RedHat":
-            cls.pkg = "units"
+            if grains["os"] == "VMware Photon OS":
+                cls.pkg = "snoopy"
+            else:
+                cls.pkg = "units"
 
-    @skip_if_not_root
-    @requires_salt_modules("pkg.refresh_db")
+    @pytest.mark.skip_if_not_root
+    @pytest.mark.requires_salt_modules("pkg.refresh_db")
     def setUp(self):
         if "refresh" not in self.ctx:
             self.run_function("pkg.refresh_db")
             self.ctx["refresh"] = True
 
-    @requires_salt_modules("pkg.list_pkgs")
-    @slowTest
+    @pytest.mark.requires_salt_modules("pkg.list_pkgs")
+    @pytest.mark.slow_test
     def test_list(self):
         """
         verify that packages are installed
@@ -51,9 +46,9 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
         ret = self.run_function("pkg.list_pkgs")
         self.assertNotEqual(len(ret.keys()), 0)
 
-    @requires_salt_modules("pkg.version_cmp")
+    @pytest.mark.requires_salt_modules("pkg.version_cmp")
     @requires_system_grains
-    @slowTest
+    @pytest.mark.slow_test
     def test_version_cmp(self, grains):
         """
         test package version comparison on supported platforms
@@ -76,11 +71,11 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(self.run_function(func, eq), 0)
         self.assertEqual(self.run_function(func, gt), 1)
 
-    @destructiveTest
-    @requires_salt_modules("pkg.mod_repo", "pkg.del_repo", "pkg.get_repo")
-    @requires_network()
+    @pytest.mark.destructive_test
+    @pytest.mark.requires_salt_modules("pkg.mod_repo", "pkg.del_repo", "pkg.get_repo")
     @requires_system_grains
-    @slowTest
+    @pytest.mark.slow_test
+    @pytest.mark.requires_network
     def test_mod_del_repo(self, grains):
         """
         test modifying and deleting a software repository
@@ -98,8 +93,8 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
                 self.assertIsInstance(
                     ret,
                     dict,
-                    "The 'pkg.get_repo' command did not return the excepted dictionary. "
-                    "Output:\n{}".format(ret),
+                    "The 'pkg.get_repo' command did not return the excepted dictionary."
+                    " Output:\n{}".format(ret),
                 )
                 self.assertEqual(
                     ret["uri"],
@@ -113,10 +108,12 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
                 name = "SaltStack repo for RHEL/CentOS {}".format(
                     grains["osmajorrelease"]
                 )
-                baseurl = "http://repo.saltstack.com/yum/redhat/{}/x86_64/latest/".format(
-                    grains["osmajorrelease"]
+                baseurl = (
+                    "http://repo.saltproject.io/py3/redhat/{}/x86_64/latest/".format(
+                        grains["osmajorrelease"]
+                    )
                 )
-                gpgkey = "https://repo.saltstack.com/yum/rhel{}/SALTSTACK-GPG-KEY.pub".format(
+                gpgkey = "https://repo.saltproject.io/py3/redhat/{}/x86_64/latest/SALTSTACK-GPG-KEY.pub".format(
                     grains["osmajorrelease"]
                 )
                 gpgcheck = 1
@@ -142,7 +139,7 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
             if repo is not None:
                 self.run_function("pkg.del_repo", [repo])
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_mod_del_repo_multiline_values(self):
         """
         test modifying and deleting a software repository defined with multiline values
@@ -150,7 +147,7 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
         os_grain = self.run_function("grains.item", ["os"])["os"]
         repo = None
         try:
-            if os_grain in ["CentOS", "RedHat"]:
+            if os_grain in ["CentOS", "RedHat", "VMware Photon OS"]:
                 my_baseurl = (
                     "http://my.fake.repo/foo/bar/\n http://my.fake.repo.alt/foo/bar/"
                 )
@@ -194,7 +191,7 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
             if repo is not None:
                 self.run_function("pkg.del_repo", [repo])
 
-    @requires_salt_modules("pkg.owner")
+    @pytest.mark.requires_salt_modules("pkg.owner")
     def test_owner(self):
         """
         test finding the package owning a file
@@ -204,7 +201,7 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertNotEqual(len(ret), 0)
 
     # Similar to pkg.owner, but for FreeBSD's pkgng
-    @requires_salt_modules("pkg.which")
+    @pytest.mark.requires_salt_modules("pkg.which")
     def test_which(self):
         """
         test finding the package owning a file
@@ -213,10 +210,10 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
         ret = self.run_function(func, ["/usr/local/bin/salt-call"])
         self.assertNotEqual(len(ret), 0)
 
-    @destructiveTest
-    @requires_salt_modules("pkg.version", "pkg.install", "pkg.remove")
-    @requires_network()
-    @slowTest
+    @pytest.mark.destructive_test
+    @pytest.mark.requires_salt_modules("pkg.version", "pkg.install", "pkg.remove")
+    @pytest.mark.slow_test
+    @pytest.mark.requires_network
     def test_install_remove(self):
         """
         successfully install and uninstall a package
@@ -241,8 +238,12 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
             test_install()
             test_remove()
 
-    @destructiveTest
-    @requires_salt_modules(
+    @pytest.mark.destructive_test
+    @pytest.mark.skipif(
+        salt.utils.platform.is_photonos(),
+        reason="package hold/unhold unsupported on Photon OS",
+    )
+    @pytest.mark.requires_salt_modules(
         "pkg.hold",
         "pkg.unhold",
         "pkg.install",
@@ -250,10 +251,10 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
         "pkg.remove",
         "pkg.list_pkgs",
     )
-    @requires_salt_states("pkg.installed")
-    @requires_network()
     @requires_system_grains
-    @slowTest
+    @pytest.mark.slow_test
+    @pytest.mark.requires_network
+    @pytest.mark.requires_salt_states("pkg.installed")
     def test_hold_unhold(self, grains):
         """
         test holding and unholding a package
@@ -296,11 +297,11 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
                 ret = self.run_state("pkg.removed", name=versionlock_pkg)
                 self.assertSaltTrueReturn(ret)
 
-    @destructiveTest
-    @requires_salt_modules("pkg.refresh_db")
-    @requires_network()
+    @pytest.mark.destructive_test
+    @pytest.mark.requires_salt_modules("pkg.refresh_db")
     @requires_system_grains
-    @slowTest
+    @pytest.mark.slow_test
+    @pytest.mark.requires_network
     def test_refresh_db(self, grains):
         """
         test refreshing the package database
@@ -330,9 +331,9 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
 
         self.assertFalse(os.path.isfile(rtag))
 
-    @requires_salt_modules("pkg.info_installed")
+    @pytest.mark.requires_salt_modules("pkg.info_installed")
     @requires_system_grains
-    @slowTest
+    @pytest.mark.slow_test
     def test_pkg_info(self, grains):
         """
         Test returning useful information on Ubuntu systems.
@@ -360,9 +361,8 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
             self.assertIn(self.pkg, keys)
 
     @skipIf(True, "Temporary Skip - Causes centos 8 test to fail")
-    @destructiveTest
-    @requires_network()
-    @requires_salt_modules(
+    @pytest.mark.destructive_test
+    @pytest.mark.requires_salt_modules(
         "pkg.refresh_db",
         "pkg.upgrade",
         "pkg.install",
@@ -370,7 +370,8 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
         "pkg.list_upgrades",
     )
     @requires_system_grains
-    @slowTest
+    @pytest.mark.slow_test
+    @pytest.mark.requires_network
     def test_pkg_upgrade_has_pending_upgrades(self, grains):
         """
         Test running a system upgrade when there are packages that need upgrading
@@ -415,7 +416,7 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
             if not isinstance(ret, dict):
                 if ret.startswith("ERROR"):
                     self.skipTest(
-                        "Could not install older {} to complete " "test.".format(target)
+                        "Could not install older {} to complete test.".format(target)
                     )
 
             # Run a system upgrade, which should catch the fact that the
@@ -440,15 +441,16 @@ class PkgModuleTest(ModuleCase, SaltReturnAssertsMixin):
                 ret = self.run_function(func, args)
                 self.assertNotEqual(ret, {})
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     @skipIf(
         salt.utils.platform.is_darwin(),
-        "The jenkins user is equivalent to root on mac, causing the test to be unrunnable",
+        "The jenkins user is equivalent to root on mac, causing the test to be"
+        " unrunnable",
     )
-    @requires_salt_modules("pkg.remove", "pkg.latest_version")
-    @requires_salt_states("pkg.removed")
+    @pytest.mark.requires_salt_modules("pkg.remove", "pkg.latest_version")
     @requires_system_grains
-    @slowTest
+    @pytest.mark.slow_test
+    @pytest.mark.requires_salt_states("pkg.removed")
     def test_pkg_latest_version(self, grains):
         """
         Check that pkg.latest_version returns the latest version of the uninstalled package.
