@@ -1,15 +1,10 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import pytest
 from tests.support.case import ModuleCase
-from tests.support.helpers import requires_salt_modules, skip_if_not_root
 
 
-@skip_if_not_root
-@requires_salt_modules("rabbitmq")
+@pytest.mark.requires_salt_modules("rabbitmq")
 @pytest.mark.windows_whitelisted
+@pytest.mark.skip_if_not_root
 class RabbitModuleTest(ModuleCase):
     """
     Validates the rabbitmqctl functions.
