@@ -1,19 +1,13 @@
-# -*- coding: utf-8 -*-
 """
 Integration tests for timezone module
 
 Linux and Solaris are supported
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import salt libs
+import pytest
 import salt.utils.platform
-
-# Import Salt Testing libs
 from tests.support.case import ModuleCase
-from tests.support.helpers import destructiveTest
 from tests.support.unit import skipIf
 
 try:
@@ -32,7 +26,7 @@ class TimezoneLinuxModuleTest(ModuleCase):
         ret_grain = self.run_function("grains.item", ["kernel"])
         if "Linux" not in ret_grain["kernel"]:
             self.skipTest("For Linux only")
-        super(TimezoneLinuxModuleTest, self).setUp()
+        super().setUp()
 
     def test_get_hwclock(self):
         timescale = ["UTC", "localtime"]
@@ -48,7 +42,7 @@ class TimezoneSolarisModuleTest(ModuleCase):
         ret_grain = self.run_function("grains.item", ["os_family"])
         if "Solaris" not in ret_grain["os_family"]:
             self.skipTest("For Solaris only")
-        super(TimezoneSolarisModuleTest, self).setUp()
+        super().setUp()
 
     def test_get_hwclock(self):
         timescale = ["UTC", "localtime"]
@@ -71,7 +65,7 @@ class TimezoneWindowsModuleTest(ModuleCase):
         ret = self.run_function("timezone.get_hwclock")
         self.assertIn(ret, timescale)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_get_zone(self):
         """
         test timezone.set_zone, get_zone and zone_compare
