@@ -1,11 +1,6 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import
-
 import pytest
 import salt.utils.platform
 from tests.support.case import ModuleCase
-from tests.support.helpers import slowTest
 from tests.support.unit import skipIf
 
 
@@ -16,7 +11,7 @@ class AutoRunsModuleTest(ModuleCase):
     Test the autoruns module
     """
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_win_autoruns_list(self):
         """
         test win_autoruns.list module
