@@ -11,12 +11,7 @@ import salt.utils.platform
 import salt.utils.pycrypto
 from salt.exceptions import EauthAuthenticationError
 from tests.support.case import ModuleCase, SSHCase
-from tests.support.helpers import (
-    SKIP_IF_NOT_RUNNING_PYTEST,
-    SaveRequestsPostHandler,
-    Webserver,
-    slowTest,
-)
+from tests.support.helpers import SaveRequestsPostHandler, Webserver
 from tests.support.mixins import AdaptedConfigurationTestCaseMixin
 from tests.support.mock import patch
 from tests.support.runtests import RUNTIME_VARS
@@ -43,7 +38,7 @@ class NetapiClientTest(TestCase):
     def tearDown(self):
         del self.netapi
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_local(self):
         low = {"client": "local", "tgt": "*", "fun": "test.ping", "timeout": 300}
         low.update(self.eauth_creds)
@@ -56,7 +51,7 @@ class NetapiClientTest(TestCase):
         ret.pop("proxytest", None)
         self.assertEqual(ret, {"minion": True, "sub_minion": True})
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_local_batch(self):
         low = {"client": "local_batch", "tgt": "*", "fun": "test.ping", "timeout": 300}
         low.update(self.eauth_creds)
@@ -94,7 +89,7 @@ class NetapiClientTest(TestCase):
         with self.assertRaises(EauthAuthenticationError) as excinfo:
             ret = self.netapi.run(low)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_wheel(self):
         low = {"client": "wheel", "fun": "key.list_all"}
         low.update(self.eauth_creds)
@@ -120,7 +115,7 @@ class NetapiClientTest(TestCase):
             {"master.pem", "master.pub"}.issubset(set(ret["data"]["return"]["local"]))
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_wheel_async(self):
         # Give this test a little breathing room
         time.sleep(3)
@@ -163,7 +158,6 @@ class NetapiClientTest(TestCase):
             ret = self.netapi.run(low)
 
 
-@SKIP_IF_NOT_RUNNING_PYTEST
 @pytest.mark.requires_sshd_server
 class NetapiSSHClientTest(SSHCase):
     eauth_creds = {
@@ -197,7 +191,7 @@ class NetapiSSHClientTest(SSHCase):
         cls.post_webserver.stop()
         del cls.post_webserver
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh(self):
         low = {
             "client": "ssh",
@@ -219,14 +213,14 @@ class NetapiSSHClientTest(SSHCase):
         self.assertEqual(ret["localhost"]["id"], "localhost")
         self.assertEqual(ret["localhost"]["fun"], "test.ping")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh_unauthenticated(self):
         low = {"client": "ssh", "tgt": "localhost", "fun": "test.ping"}
 
         with self.assertRaises(EauthAuthenticationError) as excinfo:
             ret = self.netapi.run(low)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh_unauthenticated_raw_shell_curl(self):
 
         fun = "-o ProxyCommand curl {}".format(self.post_web_root)
@@ -239,7 +233,7 @@ class NetapiSSHClientTest(SSHCase):
         self.assertEqual(self.post_web_handler.received_requests, [])
         self.assertEqual(ret, None)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh_unauthenticated_raw_shell_touch(self):
 
         badfile = os.path.join(RUNTIME_VARS.TMP, "badfile.txt")
@@ -253,7 +247,7 @@ class NetapiSSHClientTest(SSHCase):
         self.assertEqual(ret, None)
         self.assertFalse(os.path.exists("badfile.txt"))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh_authenticated_raw_shell_disabled(self):
 
         badfile = os.path.join(RUNTIME_VARS.TMP, "badfile.txt")
@@ -284,7 +278,7 @@ class NetapiSSHClientTest(SSHCase):
         except OSError:
             pass
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_shell_inject_ssh_priv(self):
         """
         Verify CVE-2020-16846 for ssh_priv variable
@@ -295,25 +289,28 @@ class NetapiSSHClientTest(SSHCase):
         self.addCleanup(self.cleanup_file, "aaa")
         self.addCleanup(self.cleanup_file, "aaa.pub")
         self.addCleanup(self.cleanup_dir, "aaa|id>")
-        tgt = "www.zerodayinitiative.com"
-        low = {
-            "roster": "cache",
-            "client": "ssh",
-            "tgt": tgt,
-            "ssh_priv": "aaa|id>{} #".format(path),
-            "fun": "test.ping",
-            "eauth": "auto",
-            "username": "saltdev_auto",
-            "password": "saltdev",
-            "roster_file": self.roster_file,
-            "rosters": self.rosters,
-        }
-        ret = self.netapi.run(low)
+        tgts = ["repo.saltproject.io", "www.zerodayinitiative.com"]
+        for tgt in tgts:
+            low = {
+                "roster": "cache",
+                "client": "ssh",
+                "tgt": tgt,
+                "ssh_priv": "aaa|id>{} #".format(path),
+                "fun": "test.ping",
+                "eauth": "auto",
+                "username": "saltdev_auto",
+                "password": "saltdev",
+                "roster_file": self.roster_file,
+                "rosters": self.rosters,
+            }
+            ret = self.netapi.run(low)
+            if ret.get(tgt):
+                break
         self.assertFalse(ret[tgt]["stdout"])
         self.assertTrue(ret[tgt]["stderr"])
         self.assertFalse(os.path.exists(path))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_shell_inject_tgt(self):
         """
         Verify CVE-2020-16846 for tgt variable
@@ -338,7 +335,7 @@ class NetapiSSHClientTest(SSHCase):
         self.assertTrue(ret["127.0.0.1"]["stderr"])
         self.assertFalse(os.path.exists(path))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_shell_inject_ssh_options(self):
         """
         Verify CVE-2020-16846 for ssh_options
@@ -364,7 +361,7 @@ class NetapiSSHClientTest(SSHCase):
         self.assertTrue(ret["127.0.0.1"]["stderr"])
         self.assertFalse(os.path.exists(path))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_shell_inject_ssh_port(self):
         """
         Verify CVE-2020-16846 for ssh_port variable
@@ -391,7 +388,7 @@ class NetapiSSHClientTest(SSHCase):
         self.assertTrue(ret["127.0.0.1"]["stderr"])
         self.assertFalse(os.path.exists(path))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_shell_inject_remote_port_forwards(self):
         """
         Verify CVE-2020-16846 for remote_port_forwards variable
@@ -452,7 +449,8 @@ class NetapiSSHClientAuthTest(SSHCase):
             else:
                 hashed_password = salt.utils.pycrypto.gen_hash(password=self.USERA_PWD)
             add_pwd = self.mod_case.run_function(
-                "shadow.set_password", [self.USERA, hashed_password],
+                "shadow.set_password",
+                [self.USERA, hashed_password],
             )
             self.assertTrue(add_pwd)
         except AssertionError:
@@ -476,7 +474,7 @@ class NetapiSSHClientAuthTest(SSHCase):
         except OSError:
             pass
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_extra_mods(self):
         """
         validate input from extra_mods
@@ -512,7 +510,7 @@ class NetapiSSHClientAuthTest(SSHCase):
         cls.post_webserver.stop()
         del cls.post_webserver
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh_auth_bypass(self):
         """
         CVE-2020-25592 - Bogus eauth raises exception.
@@ -531,7 +529,7 @@ class NetapiSSHClientAuthTest(SSHCase):
         with self.assertRaises(salt.exceptions.EauthAuthenticationError):
             ret = self.netapi.run(low)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh_auth_valid(self):
         """
         CVE-2020-25592 - Valid eauth works as expected.
@@ -551,7 +549,7 @@ class NetapiSSHClientAuthTest(SSHCase):
         assert "localhost" in ret
         assert ret["localhost"]["return"] is True
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh_auth_invalid(self):
         """
         CVE-2020-25592 - Wrong password raises exception.
@@ -570,7 +568,7 @@ class NetapiSSHClientAuthTest(SSHCase):
         with self.assertRaises(salt.exceptions.EauthAuthenticationError):
             ret = self.netapi.run(low)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh_auth_invalid_acl(self):
         """
         CVE-2020-25592 - Eauth ACL enforced.
@@ -590,7 +588,7 @@ class NetapiSSHClientAuthTest(SSHCase):
         with self.assertRaises(salt.exceptions.EauthAuthenticationError):
             ret = self.netapi.run(low)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_ssh_auth_token(self):
         """
         CVE-2020-25592 - Eauth tokens work as expected.
@@ -626,6 +624,8 @@ class NetapiSSHClientAuthTest(SSHCase):
             "fun": "test.ping",
             "ssh_port": '22 -o ProxyCommand="touch {}"'.format(self.expfile),
             "ssh_priv": self.priv_file,
+            "roster_file": "roster",
+            "rosters": [self.rosters],
         }
         ret = self.netapi.run(low)
         assert not os.path.exists(self.expfile)
@@ -642,6 +642,8 @@ class NetapiSSHClientAuthTest(SSHCase):
             "ssh_port": 22,
             "ssh_priv": self.priv_file,
             "ssh_options": ['ProxyCommand="touch {}"'.format(self.expfile)],
+            "roster_file": "roster",
+            "rosters": [self.rosters],
         }
         ret = self.netapi.run(low)
         assert not os.path.exists(self.expfile)
