@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
 """
 Tests for the salt-run command
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import pytest
 from tests.support.case import ShellCase
-from tests.support.helpers import slowTest
 
 
 @pytest.mark.windows_whitelisted
@@ -16,7 +13,7 @@ class ManageTest(ShellCase):
     Test the manage runner
     """
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_up(self):
         """
         manage.up
@@ -27,7 +24,7 @@ class ManageTest(ShellCase):
         self.assertTrue(any("- minion" in out for out in ret["out"]))
         self.assertTrue(any("- sub_minion" in out for out in ret["out"]))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_down(self):
         """
         manage.down
