@@ -1,12 +1,7 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import
-
 import os
 
 import pytest
 from tests.support.case import ShellCase, SPMCase
-from tests.support.helpers import slowTest
 
 
 @pytest.mark.windows_whitelisted
@@ -15,7 +10,7 @@ class SPMTest(ShellCase, SPMCase):
     Test spm script
     """
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_spm_help(self):
         """
         test --help argument for spm
@@ -25,7 +20,7 @@ class SPMTest(ShellCase, SPMCase):
         for arg in expected_args:
             self.assertIn(arg, "".join(output))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_spm_bad_arg(self):
         """
         test correct output when bad argument passed
@@ -35,7 +30,7 @@ class SPMTest(ShellCase, SPMCase):
         for arg in expected_args:
             self.assertIn(arg, "".join(output))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_spm_assume_yes(self):
         """
         test spm install with -y arg
@@ -45,15 +40,15 @@ class SPMTest(ShellCase, SPMCase):
 
         spm_file = os.path.join(config["spm_build_dir"], "apache-201506-2.spm")
 
-        build = self.run_spm("build {0} -c {1}".format(self.formula_dir, self._tmp_spm))
+        build = self.run_spm("build {} -c {}".format(self.formula_dir, self._tmp_spm))
 
-        install = self.run_spm("install {0} -c {1} -y".format(spm_file, self._tmp_spm))
+        install = self.run_spm("install {} -c {} -y".format(spm_file, self._tmp_spm))
 
         self.assertTrue(
             os.path.exists(os.path.join(config["formula_path"], "apache", "apache.sls"))
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_spm_force(self):
         """
         test spm install with -f arg
@@ -63,17 +58,15 @@ class SPMTest(ShellCase, SPMCase):
 
         spm_file = os.path.join(config["spm_build_dir"], "apache-201506-2.spm")
 
-        build = self.run_spm("build {0} -c {1}".format(self.formula_dir, self._tmp_spm))
+        build = self.run_spm("build {} -c {}".format(self.formula_dir, self._tmp_spm))
 
-        install = self.run_spm("install {0} -c {1} -y".format(spm_file, self._tmp_spm))
+        install = self.run_spm("install {} -c {} -y".format(spm_file, self._tmp_spm))
 
         self.assertTrue(
             os.path.exists(os.path.join(config["formula_path"], "apache", "apache.sls"))
         )
 
         # check if it forces the install after its already been installed it
-        install = self.run_spm(
-            "install {0} -c {1} -y -f".format(spm_file, self._tmp_spm)
-        )
+        install = self.run_spm("install {} -c {} -y -f".format(spm_file, self._tmp_spm))
 
         self.assertEqual(["... installing apache"], install)
