@@ -1,19 +1,16 @@
-# -*- coding: utf-8 -*-
 """
 Tests for the spm remove utility
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import os
 import shutil
 
 import pytest
 from tests.support.case import SPMCase
-from tests.support.helpers import destructiveTest, slowTest
 
 
-@destructiveTest
 @pytest.mark.windows_whitelisted
+@pytest.mark.destructive_test
 class SPMRemoveTest(SPMCase):
     """
     Validate the spm remove command
@@ -23,7 +20,7 @@ class SPMRemoveTest(SPMCase):
         self.config = self._spm_config()
         self._spm_build_files(self.config)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_spm_remove(self):
         """
         test spm remove from an inital repo install
