@@ -8,10 +8,10 @@ import tempfile
 import textwrap
 import time
 
+import pytest
 import salt.utils.files
 import salt.utils.platform
 from tests.support.case import ModuleCase
-from tests.support.helpers import slowTest
 from tests.support.mixins import SaltReturnAssertsMixin
 from tests.support.runtests import RUNTIME_VARS
 
@@ -104,7 +104,7 @@ class CMDRunRedirectTest(ModuleCase, SaltReturnAssertsMixin):
                 pass
         super().tearDown()
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_run_unless(self):
         """
         test cmd.run unless
@@ -128,7 +128,8 @@ class CMDRunRedirectTest(ModuleCase, SaltReturnAssertsMixin):
         ret = self.run_function("state.sls", [self.state_name])
         self.assertTrue(ret[state_key]["result"])
 
-    @slowTest
+    @pytest.mark.slow_test
+    @pytest.mark.windows_whitelisted
     def test_run_unless_multiple_cmds(self):
         """
         test cmd.run using multiple unless options where the first cmd in the
@@ -147,7 +148,7 @@ class CMDRunRedirectTest(ModuleCase, SaltReturnAssertsMixin):
             'Command "echo "hello"" run',
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_run_creates_exists(self):
         """
         test cmd.run creates already there
@@ -172,7 +173,7 @@ class CMDRunRedirectTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertTrue(ret[state_key]["result"])
         self.assertEqual(len(ret[state_key]["changes"]), 0)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_run_creates_new(self):
         """
         test cmd.run creates not there
@@ -198,7 +199,7 @@ class CMDRunRedirectTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertTrue(ret[state_key]["result"])
         self.assertEqual(len(ret[state_key]["changes"]), 4)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_run_redirect(self):
         """
         test cmd.run with shell redirect
