@@ -1,7 +1,6 @@
 """
 Integration tests for the docker_network states
 """
-# Import Python Libs
 
 import errno
 import functools
@@ -10,17 +9,15 @@ import os
 import subprocess
 import tempfile
 
-# Import Salt Libs
+import pytest
 import salt.utils.files
 import salt.utils.network
 import salt.utils.path
 from salt.exceptions import CommandExecutionError
 from tests.support.case import ModuleCase
 from tests.support.docker import random_name, with_network
-from tests.support.helpers import destructiveTest, requires_system_grains, slowTest
+from tests.support.helpers import requires_system_grains
 from tests.support.mixins import SaltReturnAssertsMixin
-
-# Import Salt Testing Libs
 from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import skipIf
 
@@ -107,8 +104,8 @@ def container_name(func):
     return wrapper
 
 
-@slowTest
-@destructiveTest
+@pytest.mark.destructive_test
+@pytest.mark.slow_test
 @skipIf(salt.utils.platform.is_freebsd(), "No Docker on FreeBSD available")
 @skipIf(not salt.utils.path.which("dockerd"), "Docker not installed")
 class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
@@ -139,7 +136,7 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
         return ret
 
     @with_network(create=False)
-    @slowTest
+    @pytest.mark.slow_test
     def test_absent(self, net):
         self.assertSaltTrueReturn(
             self.run_state("docker_network.present", name=net.name)
@@ -153,7 +150,7 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
 
     @container_name
     @with_network(create=False)
-    @slowTest
+    @pytest.mark.slow_test
     def test_absent_with_disconnected_container(self, net, container_name):
         self.assertSaltTrueReturn(
             self.run_state(
@@ -170,7 +167,7 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(ret["comment"], "Removed network '{}'".format(net.name))
 
     @with_network(create=False)
-    @slowTest
+    @pytest.mark.slow_test
     def test_absent_when_not_present(self, net):
         ret = self.run_state("docker_network.absent", name=net.name)
         self.assertSaltTrueReturn(ret)
@@ -179,7 +176,7 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
         self.assertEqual(ret["comment"], "Network '{}' already absent".format(net.name))
 
     @with_network(create=False)
-    @slowTest
+    @pytest.mark.slow_test
     def test_present(self, net):
         ret = self.run_state("docker_network.present", name=net.name)
         self.assertSaltTrueReturn(ret)
@@ -195,7 +192,7 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
 
     @container_name
     @with_network(create=False)
-    @slowTest
+    @pytest.mark.slow_test
     def test_present_with_containers(self, net, container_name):
         ret = self.run_state(
             "docker_network.present", name=net.name, containers=[container_name]
@@ -250,7 +247,7 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
 
     @container_name
     @with_network(create=False)
-    @slowTest
+    @pytest.mark.slow_test
     def test_present_with_reconnect(self, net, container_name):
         """
         Test reconnecting with containers not passed to state
@@ -259,7 +256,7 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
 
     @container_name
     @with_network(create=False)
-    @slowTest
+    @pytest.mark.slow_test
     def test_present_with_no_reconnect(self, net, container_name):
         """
         Test reconnecting with containers not passed to state
@@ -267,16 +264,20 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
         self._test_present_reconnect(net, container_name, reconnect=False)
 
     @with_network()
-    @slowTest
+    @pytest.mark.slow_test
     def test_present_internal(self, net):
         self.assertSaltTrueReturn(
-            self.run_state("docker_network.present", name=net.name, internal=True,)
+            self.run_state(
+                "docker_network.present",
+                name=net.name,
+                internal=True,
+            )
         )
         net_info = self.run_function("docker.inspect_network", [net.name])
         self.assertIs(net_info["Internal"], True)
 
     @with_network()
-    @slowTest
+    @pytest.mark.slow_test
     def test_present_labels(self, net):
         # Test a mix of different ways of specifying labels
         self.assertSaltTrueReturn(
@@ -288,13 +289,14 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
         )
         net_info = self.run_function("docker.inspect_network", [net.name])
         self.assertEqual(
-            net_info["Labels"], {"foo": "", "bar": "baz", "hello": "world"},
+            net_info["Labels"],
+            {"foo": "", "bar": "baz", "hello": "world"},
         )
 
     @with_network(subnet="fe3f:2180:26:1::/123")
     @with_network(subnet="10.247.197.96/27")
     @skipIf(not IPV6_ENABLED, "IPv6 not enabled")
-    @slowTest
+    @pytest.mark.slow_test
     def test_present_enable_ipv6(self, net1, net2):
         self.assertSaltTrueReturn(
             self.run_state(
@@ -309,13 +311,17 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
 
     @requires_system_grains
     @with_network()
-    @slowTest
+    @pytest.mark.slow_test
     def test_present_attachable(self, net, grains):
         if grains["os_family"] == "RedHat" and grains.get("osmajorrelease", 0) <= 7:
             self.skipTest("Cannot reliably manage attachable on RHEL <= 7")
 
         self.assertSaltTrueReturn(
-            self.run_state("docker_network.present", name=net.name, attachable=True,)
+            self.run_state(
+                "docker_network.present",
+                name=net.name,
+                attachable=True,
+            )
         )
         net_info = self.run_function("docker.inspect_network", [net.name])
         self.assertIs(net_info["Attachable"], True)
@@ -324,7 +330,11 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
     @with_network()
     def test_present_scope(self, net):
         self.assertSaltTrueReturn(
-            self.run_state("docker_network.present", name=net.name, scope="global",)
+            self.run_state(
+                "docker_network.present",
+                name=net.name,
+                scope="global",
+            )
         )
         net_info = self.run_function("docker.inspect_network", [net.name])
         self.assertIs(net_info["Scope"], "global")
@@ -333,14 +343,18 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
     @with_network()
     def test_present_ingress(self, net):
         self.assertSaltTrueReturn(
-            self.run_state("docker_network.present", name=net.name, ingress=True,)
+            self.run_state(
+                "docker_network.present",
+                name=net.name,
+                ingress=True,
+            )
         )
         net_info = self.run_function("docker.inspect_network", [net.name])
         self.assertIs(net_info["Ingress"], True)
 
     @with_network(subnet="10.247.197.128/27")
     @with_network(subnet="10.247.197.96/27")
-    @slowTest
+    @pytest.mark.slow_test
     def test_present_with_custom_ipv4(self, net1, net2):
         # First run will test passing the IPAM arguments individually
         self.assertSaltTrueReturn(
@@ -384,7 +398,7 @@ class DockerNetworkTestCase(ModuleCase, SaltReturnAssertsMixin):
     @with_network(subnet="fe3f:2180:26:1::/123")
     @with_network(subnet="10.247.197.96/27")
     @skipIf(not IPV6_ENABLED, "IPv6 not enabled")
-    @slowTest
+    @pytest.mark.slow_test
     def test_present_with_custom_ipv6(self, ipv4_net, ipv6_net1, ipv6_net2):
         self.assertSaltTrueReturn(
             self.run_state(
