@@ -1,16 +1,9 @@
-# coding: utf-8
 """
 Integration tests for renderer functions
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 import pytest
-import salt.utils.platform
-from salt.ext import six
 from tests.support.case import ModuleCase
-from tests.support.helpers import flaky, slowTest
-from tests.support.unit import skipIf
 
 
 @pytest.mark.windows_whitelisted
@@ -19,7 +12,7 @@ class TestJinjaRenderer(ModuleCase):
     Validate that ordering works correctly
     """
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_dot_notation(self):
         """
         Test the Jinja dot-notation syntax for calling execution modules
@@ -28,11 +21,8 @@ class TestJinjaRenderer(ModuleCase):
         for state_ret in ret.values():
             self.assertTrue(state_ret["result"])
 
-    @flaky
-    @skipIf(
-        salt.utils.platform.is_darwin() and six.PY2, "This test hangs on OS X on Py2"
-    )
-    @slowTest
+    @pytest.mark.flaky(max_runs=4)
+    @pytest.mark.slow_test
     def test_salt_contains_function(self):
         """
         Test if we are able to check if a function exists inside the "salt"
