@@ -1,21 +1,14 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 import inspect
-import io
 import logging
 import os
 import socket
 import subprocess
-
-# Service manager imports
 import sys
 import textwrap
 import threading
 import time
 import traceback
 
-import salt.ext.six
 import salt.utils.files
 import salt.utils.win_runas
 import yaml
@@ -192,8 +185,6 @@ def service_class_factory(
 ):
     frm = inspect.stack()[1]
     mod = inspect.getmodule(frm[0])
-    if salt.ext.six.PY2:
-        cls_name = cls_name.encode()
     return type(
         cls_name,
         (_ServiceManager, object),
@@ -243,7 +234,7 @@ def target(service, *args, **kwargs):
         )
 
     service.log_info("win_runas returned %s" % ret)
-    with open(OUTPUT, 'w') as fp:
+    with salt.utils.files.fopen(OUTPUT, 'w') as fp:
         yaml.dump(ret, fp)
     service.log_info("target stop")
 
@@ -283,7 +274,7 @@ def wait_for_service(name, timeout=200):
 class RunAsTest(ModuleCase):
     @classmethod
     def setUpClass(cls):
-        super(RunAsTest, cls).setUpClass()
+        super().setUpClass()
         cls.hostname = socket.gethostname()
 
     @with_system_user(
@@ -366,8 +357,14 @@ class RunAsTest(ModuleCase):
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
         ret = subprocess.call(
-            "cmd.exe /C winrs /r:{} python {}".format(self.hostname, RUNAS_PATH),
-            shell=True,
+            [
+                "cmd.exe",
+                "/C",
+                "winrs",
+                "/r:{}".format(self.hostname),
+                "python",
+                RUNAS_PATH,
+            ]
         )
         self.assertEqual(ret, 1)
 
@@ -388,8 +385,14 @@ class RunAsTest(ModuleCase):
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
         ret = subprocess.call(
-            "cmd.exe /C winrs /r:{} python {}".format(self.hostname, RUNAS_PATH),
-            shell=True,
+            [
+                "cmd.exe",
+                "/C",
+                "winrs",
+                "/r:{}".format(self.hostname),
+                "python",
+                RUNAS_PATH,
+            ]
         )
         self.assertEqual(ret, 1)
 
@@ -415,8 +418,14 @@ class RunAsTest(ModuleCase):
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
         ret = subprocess.call(
-            "cmd.exe /C winrs /r:{} python {}".format(self.hostname, RUNAS_PATH),
-            shell=True,
+            [
+                "cmd.exe",
+                "/C",
+                "winrs",
+                "/r:{}".format(self.hostname),
+                "python",
+                RUNAS_PATH,
+            ]
         )
         self.assertEqual(ret, 0)
 
@@ -441,8 +450,14 @@ class RunAsTest(ModuleCase):
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
         ret = subprocess.call(
-            "cmd.exe /C winrs /r:{} python {}".format(self.hostname, RUNAS_PATH),
-            shell=True,
+            [
+                "cmd.exe",
+                "/C",
+                "winrs",
+                "/r:{}".format(self.hostname),
+                "python",
+                RUNAS_PATH,
+            ]
         )
         self.assertEqual(ret, 0)
 
@@ -457,8 +472,14 @@ class RunAsTest(ModuleCase):
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
         ret = subprocess.call(
-            "cmd.exe /C winrs /r:{} python {}".format(self.hostname, RUNAS_PATH),
-            shell=True,
+            [
+                "cmd.exe",
+                "/C",
+                "winrs",
+                "/r:{}".format(self.hostname),
+                "python",
+                RUNAS_PATH,
+            ]
         )
         self.assertEqual(ret, 0)
 
@@ -473,8 +494,14 @@ class RunAsTest(ModuleCase):
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
         ret = subprocess.call(
-            "cmd.exe /C winrs /r:{} python {}".format(self.hostname, RUNAS_PATH),
-            shell=True,
+            [
+                "cmd.exe",
+                "/C",
+                "winrs",
+                "/r:{}".format(self.hostname),
+                "python",
+                RUNAS_PATH,
+            ]
         )
         self.assertEqual(ret, 1)
 
@@ -489,8 +516,14 @@ class RunAsTest(ModuleCase):
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
         ret = subprocess.call(
-            "cmd.exe /C winrs /r:{} python {}".format(self.hostname, RUNAS_PATH),
-            shell=True,
+            [
+                "cmd.exe",
+                "/C",
+                "winrs",
+                "/r:{}".format(self.hostname),
+                "python",
+                RUNAS_PATH,
+            ]
         )
         self.assertEqual(ret, 1)
 
@@ -498,7 +531,6 @@ class RunAsTest(ModuleCase):
         "test-runas", on_existing="delete", delete=True, password=PASSWORD
     )
     def test_runas_powershell_remoting(self, username):
-        psrp_wrap = "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}"
         runaspy = textwrap.dedent(
             """
         import sys
@@ -512,15 +544,22 @@ class RunAsTest(ModuleCase):
         )
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
-        cmd = "python.exe {}".format(RUNAS_PATH)
-        ret = subprocess.call(psrp_wrap.format(self.hostname, cmd), shell=True)
+        ret = subprocess.call(
+            [
+                "powershell",
+                "Invoke-Command",
+                "-ComputerName",
+                self.hostname,
+                "-ScriptBlock",
+                "{{ python.exe {} }}".format(RUNAS_PATH),
+            ]
+        )
         self.assertEqual(ret, 1)
 
     @with_system_user(
         "test-runas", on_existing="delete", delete=True, password=PASSWORD
     )
     def test_runas_powershell_remoting_no_pass(self, username):
-        psrp_wrap = "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}"
         runaspy = textwrap.dedent(
             """
         import sys
@@ -533,8 +572,16 @@ class RunAsTest(ModuleCase):
         )
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
-        cmd = "python.exe {}".format(RUNAS_PATH)
-        ret = subprocess.call(psrp_wrap.format(self.hostname, cmd), shell=True)
+        ret = subprocess.call(
+            [
+                "powershell",
+                "Invoke-Command",
+                "-ComputerName",
+                self.hostname,
+                "-ScriptBlock",
+                "{{ python.exe {} }}".format(RUNAS_PATH),
+            ]
+        )
         self.assertEqual(ret, 1)
 
     @with_system_user(
@@ -545,7 +592,10 @@ class RunAsTest(ModuleCase):
         groups=["Administrators"],
     )
     def test_runas_powershell_remoting_admin(self, username):
-        psrp_wrap = "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}; exit $LASTEXITCODE"
+        psrp_wrap = (
+            "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}; exit"
+            " $LASTEXITCODE"
+        )
         runaspy = textwrap.dedent(
             """
         import sys
@@ -561,7 +611,7 @@ class RunAsTest(ModuleCase):
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
         cmd = "python.exe {}; exit $LASTEXITCODE".format(RUNAS_PATH)
-        ret = subprocess.call(psrp_wrap.format(self.hostname, cmd), shell=True)
+        ret = subprocess.call(psrp_wrap.format(self.hostname, cmd), shell=True)  # nosec
         self.assertEqual(ret, 0)
 
     @with_system_user(
@@ -572,7 +622,10 @@ class RunAsTest(ModuleCase):
         groups=["Administrators"],
     )
     def test_runas_powershell_remoting_admin_no_pass(self, username):
-        psrp_wrap = "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}; exit $LASTEXITCODE"
+        psrp_wrap = (
+            "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}; exit"
+            " $LASTEXITCODE"
+        )
         runaspy = textwrap.dedent(
             """
         import sys
@@ -586,7 +639,7 @@ class RunAsTest(ModuleCase):
         with salt.utils.files.fopen(RUNAS_PATH, "w") as fp:
             fp.write(runaspy)
         cmd = "python.exe {}; exit $LASTEXITCODE".format(RUNAS_PATH)
-        ret = subprocess.call(psrp_wrap.format(self.hostname, cmd), shell=True)
+        ret = subprocess.call(psrp_wrap.format(self.hostname, cmd), shell=True)  # nosec
         self.assertEqual(ret, 0)
 
     @with_system_user(
@@ -597,10 +650,9 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), username, PASSWORD)
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
-        cmd = "python.exe {}".format(RUNAS_PATH)
-        ret = subprocess.call(cmd, shell=True)
+        ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
@@ -616,10 +668,9 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), username, "")
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
-        cmd = "python.exe {}".format(RUNAS_PATH)
-        ret = subprocess.call(cmd, shell=True)
+        ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
@@ -639,10 +690,9 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), username, PASSWORD)
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
-        cmd = "python.exe {}".format(RUNAS_PATH)
-        ret = subprocess.call(cmd, shell=True)
+        ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
@@ -662,10 +712,9 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), username, "")
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
-        cmd = "python.exe {}".format(RUNAS_PATH)
-        ret = subprocess.call(cmd, shell=True)
+        ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
@@ -678,10 +727,9 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), "SYSTEM", "")
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
-        cmd = "python.exe {}".format(RUNAS_PATH)
-        ret = subprocess.call(cmd, shell=True)
+        ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
