@@ -10,7 +10,9 @@ import salt.utils.idem as idem
 import salt.utils.path
 import tests.support.sminion
 
-pytestmark = pytest.mark.skipif(not idem.HAS_POP[0], reason=idem.HAS_POP[1])
+pytestmark = [
+    pytest.mark.skipif(not idem.HAS_POP[0], reason=idem.HAS_POP[1]),
+]
 
 
 @contextmanager
