@@ -22,14 +22,12 @@ from tests.support.mock import MagicMock, Mock, MockTimedProc, mock_open, patch
 from tests.support.runtests import RUNTIME_VARS
 
 DEFAULT_SHELL = "foo/bar"
-MOCK_SHELL_FILE = "# List of acceptable shells\n" "\n" "/bin/bash\n"
+MOCK_SHELL_FILE = "# List of acceptable shells\n\n/bin/bash\n"
 
 
-@pytest.fixture(autouse=True)
-def setup_loader():
-    setup_loader_modules = {cmdmod: {}}
-    with pytest.helpers.loader_mock(setup_loader_modules) as loader_mock:
-        yield loader_mock
+@pytest.fixture
+def configure_loader_modules():
+    return {cmdmod: {}}
 
 
 @pytest.fixture(scope="module")
@@ -157,7 +155,7 @@ def test_run_with_tuple():
         with patch("salt.utils.platform.is_windows", MagicMock(return_value=False)):
             with patch("os.path.isfile", mock_true):
                 with patch("os.access", mock_true):
-                    cmdmod._run(("echo", "foo"), python_shell=True)
+                    cmdmod._run(("echo", "foo"), python_shell=True, cwd="/")
 
 
 def test_run_user_not_available():
@@ -193,7 +191,11 @@ def test_run_invalid_umask():
             with patch("os.path.isfile", MagicMock(return_value=True)):
                 with patch("os.access", MagicMock(return_value=True)):
                     pytest.raises(
-                        CommandExecutionError, cmdmod._run, "foo", "bar", umask="baz",
+                        CommandExecutionError,
+                        cmdmod._run,
+                        "foo",
+                        "bar",
+                        umask="baz",
                     )
 
 
@@ -645,6 +647,8 @@ def test_run_chroot_runas():
         shell="/bin/sh",
         stdin=None,
         success_retcodes=None,
+        success_stdout=None,
+        success_stderr=None,
         template=None,
         timeout=None,
         umask=None,
@@ -660,3 +664,31 @@ def test_cve_2021_25284(caplog):
         with caplog.at_level(logging.DEBUG, logger="salt.modules.cmdmod"):
             cmdmod.run("testcmd -p ImAPassword", output_loglevel="error")
         assert "ImAPassword" not in caplog.text
+
+
+def test__log_cmd_str():
+    "_log_cmd function handles strings"
+    assert cmdmod._log_cmd("foo bar") == "foo"
+
+
+def test__log_cmd_list():
+    "_log_cmd function handles lists"
+    assert cmdmod._log_cmd(["foo", "bar"]) == "foo"
+
+
+def test_log_cmd_tuple():
+    "_log_cmd function handles tuples"
+    assert cmdmod._log_cmd(("foo", "bar")) == "foo"
+
+
+def test_log_cmd_non_str_tuple_list():
+    "_log_cmd function casts objects to strings"
+
+    class cmd:
+        def __init__(self, cmd):
+            self.cmd = cmd
+
+        def __str__(self):
+            return self.cmd
+
+    assert cmdmod._log_cmd(cmd("foo bar")) == "foo"
