@@ -27,11 +27,10 @@ import pytest
 import salt.utils.files
 from saltfactories.utils.processes import terminate_process
 from tests.support.cli_scripts import ScriptPathMixin
-from tests.support.helpers import SKIP_IF_NOT_RUNNING_PYTEST, RedirectStdStreams
+from tests.support.helpers import RedirectStdStreams
 from tests.support.mixins import (  # pylint: disable=unused-import
     AdaptedConfigurationTestCaseMixin,
     SaltClientTestCaseMixin,
-    SaltMultimasterClientTestCaseMixin,
 )
 from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import TestCase
@@ -109,8 +108,8 @@ class ShellCase(TestCase, AdaptedConfigurationTestCaseMixin, ScriptPathMixin):
         if not roster_file:
             roster_file = os.path.join(RUNTIME_VARS.TMP_CONF_DIR, "roster")
         arg_str = (
-            "{wipe} {raw} -l {log_level} --ignore-host-keys --priv {client_key} --roster-file "
-            "{roster_file} {ssh_opts} localhost {arg_str} --out=json"
+            "{wipe} {raw} -l {log_level} --ignore-host-keys --priv {client_key}"
+            " --roster-file {roster_file} {ssh_opts} localhost {arg_str} --out=json"
         ).format(
             wipe=" -W" if wipe else "",
             raw=" -r" if raw else "",
@@ -150,7 +149,9 @@ class ShellCase(TestCase, AdaptedConfigurationTestCaseMixin, ScriptPathMixin):
             timeout = self.RUN_TIMEOUT
         asynchronous = kwargs.get("async", asynchronous)
         arg_str = "{async_flag} -t {timeout} {}".format(
-            arg_str, timeout=timeout, async_flag=" --async" if asynchronous else "",
+            arg_str,
+            timeout=timeout,
+            async_flag=" --async" if asynchronous else "",
         )
         ret = self.run_script(
             "salt-run",
@@ -365,24 +366,29 @@ class ShellCase(TestCase, AdaptedConfigurationTestCaseMixin, ScriptPathMixin):
             return False
         popen_kwargs = popen_kwargs or {}
 
+        python_path_env_var = os.environ.get("PYTHONPATH") or None
+        if python_path_env_var is None:
+            python_path_entries = [RUNTIME_VARS.CODE_DIR]
+        else:
+            python_path_entries = python_path_env_var.split(os.pathsep)
+            if RUNTIME_VARS.CODE_DIR in python_path_entries:
+                python_path_entries.remove(RUNTIME_VARS.CODE_DIR)
+            python_path_entries.insert(0, RUNTIME_VARS.CODE_DIR)
+        python_path_entries.extend(sys.path[0:])
+
+        if "env" not in popen_kwargs:
+            popen_kwargs["env"] = os.environ.copy()
+
+        popen_kwargs["env"]["PYTHONPATH"] = os.pathsep.join(python_path_entries)
+
+        if "cwd" not in popen_kwargs:
+            popen_kwargs["cwd"] = RUNTIME_VARS.TMP
+
         if salt.utils.platform.is_windows():
             cmd = "python "
-            if "cwd" not in popen_kwargs:
-                popen_kwargs["cwd"] = os.getcwd()
-            if "env" not in popen_kwargs:
-                popen_kwargs["env"] = os.environ.copy()
-                popen_kwargs["env"]["PYTHONPATH"] = RUNTIME_VARS.CODE_DIR
         else:
-            cmd = "PYTHONPATH="
-            python_path = os.environ.get("PYTHONPATH", None)
-            if python_path is not None:
-                cmd += "{}:".format(python_path)
+            cmd = "python{}.{} ".format(*sys.version_info)
 
-            if sys.version_info[0] < 3:
-                cmd += "{} ".format(":".join(sys.path[1:]))
-            else:
-                cmd += "{} ".format(":".join(sys.path[0:]))
-            cmd += "python{}.{} ".format(*sys.version_info)
         cmd += "{} --config-dir={} {} ".format(
             script_path, config_dir or RUNTIME_VARS.TMP_CONF_DIR, arg_str
         )
@@ -403,8 +409,19 @@ class ShellCase(TestCase, AdaptedConfigurationTestCaseMixin, ScriptPathMixin):
         if catch_stderr is True:
             popen_kwargs["stderr"] = subprocess.PIPE
 
-        if not sys.platform.lower().startswith("win"):
-            popen_kwargs["close_fds"] = True
+        if salt.utils.platform.is_windows():
+            # Windows does not support closing FDs
+            close_fds = False
+        elif salt.utils.platform.is_freebsd() and sys.version_info < (3, 9):
+            # Closing FDs in FreeBSD before Py3.9 can be slow
+            #   https://bugs.python.org/issue38061
+            close_fds = False
+        else:
+            close_fds = True
+
+        popen_kwargs["close_fds"] = close_fds
+
+        if not salt.utils.platform.is_windows():
 
             def detach_from_parent_group():
                 # detach from parent group (no more inherited signals!)
@@ -462,7 +479,6 @@ class ShellCase(TestCase, AdaptedConfigurationTestCaseMixin, ScriptPathMixin):
 
         if timeout is not None:
             stop_at = datetime.now() + timedelta(seconds=timeout)
-            term_sent = False
             while True:
                 process.poll()
                 time.sleep(0.1)
@@ -485,23 +501,7 @@ class ShellCase(TestCase, AdaptedConfigurationTestCaseMixin, ScriptPathMixin):
             out = tmp_file.read().decode("utf-8")
 
         if catch_stderr:
-            if sys.version_info < (2, 7):
-                # On python 2.6, the subprocess'es communicate() method uses
-                # select which, is limited by the OS to 1024 file descriptors
-                # We need more available descriptors to run the tests which
-                # need the stderr output.
-                # So instead of .communicate() we wait for the process to
-                # finish, but, as the python docs state "This will deadlock
-                # when using stdout=PIPE and/or stderr=PIPE and the child
-                # process generates enough output to a pipe such that it
-                # blocks waiting for the OS pipe buffer to accept more data.
-                # Use communicate() to avoid that." <- a catch, catch situation
-                #
-                # Use this work around were it's needed only, python 2.6
-                process.wait()
-                err = process.stderr.read()
-            else:
-                _, err = process.communicate()
+            _, err = process.communicate()
             # Force closing stderr/stdout to release file descriptors
             if process.stdout is not None:
                 process.stdout.close()
@@ -550,17 +550,6 @@ class ShellCase(TestCase, AdaptedConfigurationTestCaseMixin, ScriptPathMixin):
                 pass
 
 
-class MultiMasterTestShellCase(ShellCase):
-    """
-    '''
-    Execute a test for a shell command when running multi-master tests
-    """
-
-    @property
-    def config_dir(self):
-        return RUNTIME_VARS.TMP_MM_CONF_DIR
-
-
 class SPMTestUserInterface:
     """
     Test user interface to SPMClient
@@ -755,7 +744,8 @@ class ModuleCase(TestCase, SaltClientTestCaseMixin):
             kwargs["timeout"] = kwargs.pop("f_timeout")
         client = self.client if master_tgt is None else self.clients[master_tgt]
         log.debug(
-            "Running client.cmd(minion_tgt=%r, function=%r, arg=%r, timeout=%r, kwarg=%r)",
+            "Running client.cmd(minion_tgt=%r, function=%r, arg=%r, timeout=%r,"
+            " kwarg=%r)",
             minion_tgt,
             function,
             arg,
@@ -764,18 +754,13 @@ class ModuleCase(TestCase, SaltClientTestCaseMixin):
         )
         orig = client.cmd(minion_tgt, function, arg, timeout=timeout, kwarg=kwargs)
 
-        if RUNTIME_VARS.PYTEST_SESSION:
-            fail_or_skip_func = self.fail
-        else:
-            fail_or_skip_func = self.skipTest
-
         if minion_tgt not in orig:
-            fail_or_skip_func(
+            self.fail(
                 "WARNING(SHOULD NOT HAPPEN #1935): Failed to get a reply "
                 "from the minion '{}'. Command output: {}".format(minion_tgt, orig)
             )
         elif orig[minion_tgt] is None and function not in known_to_return_none:
-            fail_or_skip_func(
+            self.fail(
                 "WARNING(SHOULD NOT HAPPEN #1935): Failed to get '{}' from "
                 "the minion '{}'. Command output: {}".format(function, minion_tgt, orig)
             )
@@ -822,92 +807,7 @@ class ModuleCase(TestCase, SaltClientTestCaseMixin):
                         job_data, job_kill
                     )
                 )
-                ret.append(
-                    "[TEST SUITE ENFORCED]{}" "[/TEST SUITE ENFORCED]".format(msg)
-                )
-        return ret
-
-
-class MultimasterModuleCase(ModuleCase, SaltMultimasterClientTestCaseMixin):
-    """
-    Execute a module function
-    """
-
-    def run_function(
-        self,
-        function,
-        arg=(),
-        minion_tgt="mm-minion",
-        timeout=300,
-        master_tgt="mm-master",
-        **kwargs
-    ):
-        """
-        Run a single salt function and condition the return down to match the
-        behavior of the raw function call
-        """
-        known_to_return_none = (
-            "data.get",
-            "file.chown",
-            "file.chgrp",
-            "pkg.refresh_db",
-            "ssh.recv_known_host_entries",
-            "time.sleep",
-        )
-        if minion_tgt == "mm-sub-minion":
-            known_to_return_none += ("mine.update",)
-        if "f_arg" in kwargs:
-            kwargs["arg"] = kwargs.pop("f_arg")
-        if "f_timeout" in kwargs:
-            kwargs["timeout"] = kwargs.pop("f_timeout")
-        if master_tgt is None:
-            client = self.clients["mm-master"]
-        elif isinstance(master_tgt, int):
-            client = self.clients[list(self.clients)[master_tgt]]
-        else:
-            client = self.clients[master_tgt]
-        orig = client.cmd(minion_tgt, function, arg, timeout=timeout, kwarg=kwargs)
-
-        if RUNTIME_VARS.PYTEST_SESSION:
-            fail_or_skip_func = self.fail
-        else:
-            fail_or_skip_func = self.skipTest
-
-        if minion_tgt not in orig:
-            fail_or_skip_func(
-                "WARNING(SHOULD NOT HAPPEN #1935): Failed to get a reply "
-                "from the minion '{}'. Command output: {}".format(minion_tgt, orig)
-            )
-        elif orig[minion_tgt] is None and function not in known_to_return_none:
-            fail_or_skip_func(
-                "WARNING(SHOULD NOT HAPPEN #1935): Failed to get '{}' from "
-                "the minion '{}'. Command output: {}".format(function, minion_tgt, orig)
-            )
-
-        # Try to match stalled state functions
-        orig[minion_tgt] = self._check_state_return(orig[minion_tgt])
-
-        return orig[minion_tgt]
-
-    def run_function_all_masters(
-        self, function, arg=(), minion_tgt="mm-minion", timeout=300, **kwargs
-    ):
-        """
-        Run a single salt function from all the masters in multimaster environment
-        and condition the return down to match the behavior of the raw function call
-        """
-        ret = []
-        for master_id in self.clients:
-            ret.append(
-                self.run_function(
-                    function,
-                    arg=arg,
-                    minion_tgt=minion_tgt,
-                    timeout=timeout,
-                    master_tgt=master_id,
-                    **kwargs
-                )
-            )
+                ret.append("[TEST SUITE ENFORCED]{}[/TEST SUITE ENFORCED]".format(msg))
         return ret
 
 
@@ -924,20 +824,14 @@ class SyndicCase(TestCase, SaltClientTestCaseMixin):
         behavior of the raw function call
         """
         orig = self.client.cmd("minion", function, arg, timeout=timeout)
-        if RUNTIME_VARS.PYTEST_SESSION:
-            fail_or_skip_func = self.fail
-        else:
-            fail_or_skip_func = self.skipTest
         if "minion" not in orig:
-            fail_or_skip_func(
+            self.fail(
                 "WARNING(SHOULD NOT HAPPEN #1935): Failed to get a reply "
                 "from the minion. Command output: {}".format(orig)
             )
         return orig["minion"]
 
 
-@SKIP_IF_NOT_RUNNING_PYTEST
-@pytest.mark.usefixtures("salt_ssh_cli")
 @pytest.mark.requires_sshd_server
 class SSHCase(ShellCase):
     """
