@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2011-2012, Sylvain Hellegouarch
 # All rights reserved.
 
@@ -28,17 +27,12 @@
 # Modified from the original. See the Git history of this file for details.
 # https://bitbucket.org/Lawouach/cherrypy-recipes/src/50aff88dc4e24206518ec32e1c32af043f2729da/testing/unit/serverless/cptestcase.py
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import 3rd-party libs
 # pylint: disable=import-error
+import io
+
 import cherrypy  # pylint: disable=3rd-party-module-not-gated
 import salt.utils.stringutils
-from salt.ext import six
-from salt.ext.six import BytesIO
-
-# Import Salt Testing libs
 from tests.support.case import TestCase
 
 # pylint: enable=import-error
@@ -104,8 +98,8 @@ class BaseCherryPyTestCase(TestCase):
         # let's make sure we have the content-length set
         fd = None
         if body is not None:
-            h["content-length"] = "{0}".format(len(body))
-            fd = BytesIO(salt.utils.stringutils.to_bytes(body))
+            h["content-length"] = "{}".format(len(body))
+            fd = io.BytesIO(salt.utils.stringutils.to_bytes(body))
 
         if headers is not None:
             h.update(headers)
@@ -114,7 +108,7 @@ class BaseCherryPyTestCase(TestCase):
         app = cherrypy.tree.apps.get(app_path)
         if not app:
             # XXX: perhaps not the best exception to raise?
-            raise AssertionError("No application mounted at '{0}'".format(app_path))
+            raise AssertionError("No application mounted at '{}'".format(app_path))
 
         # Cleanup any previous returned response
         # between calls to this method
@@ -123,7 +117,7 @@ class BaseCherryPyTestCase(TestCase):
         # Let's fake the local and remote addresses
         request, response = app.get_serving(local, remote, scheme, proto)
         try:
-            h = [(k, v) for k, v in six.iteritems(h)]
+            h = [(k, v) for k, v in h.items()]
             response = request.run(method, path, qs, proto, h, fd)
         finally:
             if fd:
@@ -132,8 +126,7 @@ class BaseCherryPyTestCase(TestCase):
 
         if response.output_status.startswith(b"500"):
             response_body = response.collapse_body()
-            if six.PY3:
-                response_body = response_body.decode(__salt_system_encoding__)
+            response_body = response_body.decode(__salt_system_encoding__)
             print(response_body)
             raise AssertionError("Unexpected error")
 
