@@ -18,15 +18,11 @@ import salt.utils.yaml
 from salt.fileserver import gitfs
 from salt.pillar import git_pillar
 from salt.utils.immutabletypes import freeze
-from saltfactories.factories.base import DaemonFactory
-from saltfactories.factories.daemons.sshd import SshdDaemonFactory as _SshdDaemonFactory
+from saltfactories.bases import Daemon
+from saltfactories.daemons.sshd import Sshd as _Sshd
 from saltfactories.utils.ports import get_unused_localhost_port
 from tests.support.case import ModuleCase
-from tests.support.helpers import (
-    SKIP_IF_NOT_RUNNING_PYTEST,
-    patched_environ,
-    requires_system_grains,
-)
+from tests.support.helpers import patched_environ, requires_system_grains
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import patch
 from tests.support.runtests import RUNTIME_VARS
@@ -71,12 +67,15 @@ _OPTS = freeze(
 )
 
 
-class SshdDaemonFactory(_SshdDaemonFactory):
+@attr.s
+class Sshd(_Sshd):
     def apply_pre_start_states(self, salt_call_cli, testclass, username):
+        # pylint: disable=access-member-before-definition
         if self.listen_port in self.check_ports:
             self.check_ports.remove(self.listen_port)
         if self.listen_port in self.listen_ports:
             self.listen_ports.remove(self.listen_port)
+        # pylint: enable=access-member-before-definition
         self.listen_port = get_unused_localhost_port()
         self.check_ports.append(self.listen_port)
         self.listen_ports.append(self.listen_port)
@@ -136,14 +135,16 @@ class SshdDaemonFactory(_SshdDaemonFactory):
 
 
 @attr.s(kw_only=True, slots=True)
-class UwsgiDaemon(DaemonFactory):
+class UwsgiDaemon(Daemon):
 
     config_dir = attr.ib()
     listen_port = attr.ib(default=attr.Factory(get_unused_localhost_port))
 
     def __attrs_post_init__(self):
+        # pylint: disable=access-member-before-definition
         if self.check_ports is None:
             self.check_ports = []
+        # pylint: enable=access-member-before-definition
         self.check_ports.append(self.listen_port)
         super().__attrs_post_init__()
 
@@ -206,15 +207,17 @@ class UwsgiDaemon(DaemonFactory):
 
 
 @attr.s(kw_only=True, slots=True)
-class NginxDaemon(DaemonFactory):
+class NginxDaemon(Daemon):
 
     config_dir = attr.ib()
     uwsgi_port = attr.ib()
     listen_port = attr.ib(default=attr.Factory(get_unused_localhost_port))
 
     def __attrs_post_init__(self):
+        # pylint: disable=access-member-before-definition
         if self.check_ports is None:
             self.check_ports = []
+        # pylint: enable=access-member-before-definition
         self.check_ports.append(self.listen_port)
         super().__attrs_post_init__()
 
@@ -273,24 +276,24 @@ def ssh_pillar_tests_prep(request, salt_master, salt_minion):
     """
     Stand up an SSHD server to serve up git repos for tests.
     """
-    salt_call_cli = salt_minion.get_salt_call_cli()
+    salt_call_cli = salt_minion.salt_call_cli()
 
     sshd_bin = salt.utils.path.which("sshd")
     sshd_config_dir = tempfile.mkdtemp(dir=RUNTIME_VARS.TMP)
 
-    sshd_proc = SshdDaemonFactory(
-        cli_script_name=sshd_bin,
+    sshd_proc = Sshd(
+        script_name=sshd_bin,
         config_dir=sshd_config_dir,
         start_timeout=120,
         display_name=request.cls.__name__,
     )
-    sshd_proc.register_before_start_callback(
+    sshd_proc.before_start(
         sshd_proc.apply_pre_start_states,
         salt_call_cli=salt_call_cli,
         testclass=request.cls,
         username=salt_master.config["user"],
     )
-    sshd_proc.register_after_start_callback(
+    sshd_proc.after_start(
         sshd_proc.set_known_host,
         salt_call_cli=salt_call_cli,
         username=salt_master.config["user"],
@@ -326,7 +329,7 @@ def webserver_pillar_tests_prep(request, salt_master, salt_minion):
     Stand up an nginx + uWSGI + git-http-backend webserver to
     serve up git repos for tests.
     """
-    salt_call_cli = salt_minion.get_salt_call_cli()
+    salt_call_cli = salt_minion.salt_call_cli()
 
     root_dir = tempfile.mkdtemp(dir=RUNTIME_VARS.TMP)
     config_dir = os.path.join(root_dir, "config")
@@ -336,12 +339,12 @@ def webserver_pillar_tests_prep(request, salt_master, salt_minion):
     uwsgi_proc = nginx_proc = None
     try:
         uwsgi_proc = UwsgiDaemon(
-            cli_script_name=uwsgi_bin,
+            script_name=uwsgi_bin,
             config_dir=config_dir,
             start_timeout=120,
             display_name=request.cls.__name__,
         )
-        uwsgi_proc.register_before_start_callback(
+        uwsgi_proc.before_start(
             uwsgi_proc.apply_pre_start_states,
             salt_call_cli=salt_call_cli,
             testclass=request.cls,
@@ -349,13 +352,13 @@ def webserver_pillar_tests_prep(request, salt_master, salt_minion):
         )
         uwsgi_proc.start()
         nginx_proc = NginxDaemon(
-            cli_script_name="nginx",
+            script_name="nginx",
             config_dir=config_dir,
             start_timeout=120,
             uwsgi_port=uwsgi_proc.listen_port,
             display_name=request.cls.__name__,
         )
-        nginx_proc.register_before_start_callback(
+        nginx_proc.before_start(
             nginx_proc.apply_pre_start_states,
             salt_call_cli=salt_call_cli,
             testclass=request.cls,
@@ -379,10 +382,12 @@ def webserver_pillar_tests_prep_authenticated(request, webserver_pillar_tests_pr
         password=request.cls.password,
         port=request.cls.nginx_port,
     )
-    url_extra_repo = "http://{username}:{password}@127.0.0.1:{port}/extra_repo.git".format(
-        username=request.cls.username,
-        password=request.cls.password,
-        port=request.cls.nginx_port,
+    url_extra_repo = (
+        "http://{username}:{password}@127.0.0.1:{port}/extra_repo.git".format(
+            username=request.cls.username,
+            password=request.cls.password,
+            port=request.cls.nginx_port,
+        )
     )
     request.cls.ext_opts["url"] = url
     request.cls.ext_opts["url_extra_repo"] = url_extra_repo
@@ -390,7 +395,6 @@ def webserver_pillar_tests_prep_authenticated(request, webserver_pillar_tests_pr
     request.cls.ext_opts["password"] = request.cls.password
 
 
-@SKIP_IF_NOT_RUNNING_PYTEST
 class GitTestBase(ModuleCase):
     """
     Base class for all gitfs/git_pillar tests.
@@ -481,7 +485,11 @@ class GitPillarTestBase(GitTestBase, LoaderModuleMockMixin):
                 git_opts=self.git_opts,
             )
             self.run_function(
-                "git.push", [self.admin_repo], remote="origin", ref=branch, user=user,
+                "git.push",
+                [self.admin_repo],
+                remote="origin",
+                ref=branch,
+                user=user,
             )
 
         with salt.utils.files.fopen(
