@@ -15,9 +15,11 @@ import logging
 import multiprocessing
 import os
 import pprint
+import queue
 import subprocess
 import tempfile
 import time
+import xml.etree.ElementTree as etree
 
 import salt.config
 import salt.exceptions
@@ -29,10 +31,6 @@ import salt.utils.process
 import salt.utils.stringutils
 import salt.utils.yaml
 import salt.version
-from salt._compat import ElementTree as etree
-from salt.ext import six
-from salt.ext.six.moves import zip
-from salt.ext.six.moves.queue import Empty
 from salt.utils.immutabletypes import freeze
 from salt.utils.verify import verify_env
 from saltfactories.utils import random_string
@@ -40,11 +38,6 @@ from tests.support.paths import CODE_DIR
 from tests.support.pytest.loader import LoaderModuleMock
 from tests.support.runtests import RUNTIME_VARS
 
-try:
-    from salt.utils.odict import OrderedDict
-except ImportError:
-    from collections import OrderedDict
-
 log = logging.getLogger(__name__)
 
 
@@ -255,27 +248,6 @@ class AdaptedConfigurationTestCaseMixin:
         """
         return self.get_config("sub_minion")
 
-    @property
-    def mm_master_opts(self):
-        """
-        Return the options used for the multimaster master
-        """
-        return self.get_config("mm_master")
-
-    @property
-    def mm_sub_master_opts(self):
-        """
-        Return the options used for the multimaster sub-master
-        """
-        return self.get_config("mm_sub_master")
-
-    @property
-    def mm_minion_opts(self):
-        """
-        Return the options used for the minion
-        """
-        return self.get_config("mm_minion")
-
 
 class SaltClientTestCaseMixin(AdaptedConfigurationTestCaseMixin):
     """
@@ -320,52 +292,6 @@ class SaltClientTestCaseMixin(AdaptedConfigurationTestCaseMixin):
         return RUNTIME_VARS.RUNTIME_CONFIGS["runtime_client"]
 
 
-class SaltMultimasterClientTestCaseMixin(AdaptedConfigurationTestCaseMixin):
-    """
-    Mix-in class that provides a ``clients`` attribute which returns a list of Salt
-    :class:`LocalClient<salt:salt.client.LocalClient>`.
-
-    .. code-block:: python
-
-        class LocalClientTestCase(TestCase, SaltMultimasterClientTestCaseMixin):
-
-            def test_check_pub_data(self):
-                just_minions = {'minions': ['m1', 'm2']}
-                jid_no_minions = {'jid': '1234', 'minions': []}
-                valid_pub_data = {'minions': ['m1', 'm2'], 'jid': '1234'}
-
-                for client in self.clients:
-                    self.assertRaises(EauthAuthenticationError,
-                                      client._check_pub_data, None)
-                    self.assertDictEqual({},
-                        client._check_pub_data(just_minions),
-                        'Did not handle lack of jid correctly')
-
-                    self.assertDictEqual(
-                        {},
-                        client._check_pub_data({'jid': '0'}),
-                        'Passing JID of zero is not handled gracefully')
-    """
-
-    _salt_client_config_file_name_ = "master"
-
-    @property
-    def clients(self):
-        # Late import
-        import salt.client
-
-        if "runtime_clients" not in RUNTIME_VARS.RUNTIME_CONFIGS:
-            RUNTIME_VARS.RUNTIME_CONFIGS["runtime_clients"] = OrderedDict()
-
-        runtime_clients = RUNTIME_VARS.RUNTIME_CONFIGS["runtime_clients"]
-        for master_id in ("mm-master", "mm-sub-master"):
-            if master_id in runtime_clients:
-                continue
-            mopts = self.get_config(master_id.replace("-", "_"), from_scratch=True)
-            runtime_clients[master_id] = salt.client.get_local_client(mopts=mopts)
-        return runtime_clients
-
-
 class ShellCaseCommonTestsMixin(CheckShellBinaryNameAndVersionMixin):
 
     _call_binary_expected_version_ = salt.version.__version__
@@ -397,8 +323,9 @@ class ShellCaseCommonTestsMixin(CheckShellBinaryNameAndVersionMixin):
             out, err = process.communicate()
         if not out:
             self.skipTest(
-                "Failed to get the output of 'git describe'. "
-                "Error: '{}'".format(salt.utils.stringutils.to_str(err))
+                "Failed to get the output of 'git describe'. Error: '{}'".format(
+                    salt.utils.stringutils.to_str(err)
+                )
             )
 
         parsed_version = SaltStackVersion.parse(out)
@@ -463,10 +390,12 @@ class LoaderModuleMockMixin(metaclass=_FixLoaderModuleMockMixinMroOrder):
             loader_modules_configs = self.setup_loader_modules()
             if not isinstance(loader_modules_configs, dict):
                 raise RuntimeError(
-                    "{}.setup_loader_modules() must return a dictionary where the keys are the "
-                    "modules that require loader mocking setup and the values, the global module "
-                    "variables for each of the module being mocked. For example '__salt__', "
-                    "'__opts__', etc.".format(self.__class__.__name__)
+                    "{}.setup_loader_modules() must return a dictionary where the keys"
+                    " are the modules that require loader mocking setup and the values,"
+                    " the global module variables for each of the module being mocked."
+                    " For example '__salt__', '__opts__', etc.".format(
+                        self.__class__.__name__
+                    )
                 )
 
             mocker = LoaderModuleMock(loader_modules_configs)
@@ -486,9 +415,9 @@ class LoaderModuleMockMixin(metaclass=_FixLoaderModuleMockMixinMroOrder):
 
 class XMLEqualityMixin:
     def assertEqualXML(self, e1, e2):
-        if six.PY3 and isinstance(e1, bytes):
+        if isinstance(e1, bytes):
             e1 = e1.decode("utf-8")
-        if six.PY3 and isinstance(e2, bytes):
+        if isinstance(e2, bytes):
             e2 = e2.decode("utf-8")
         if isinstance(e1, str):
             e1 = etree.XML(e1)
@@ -568,7 +497,7 @@ class SaltReturnAssertsMixin:
             for saltret in self.__getWithinSaltReturn(ret, "result"):
                 self.assertTrue(saltret)
         except AssertionError:
-            log.info("Salt Full Return:\n{}".format(pprint.pformat(ret)))
+            log.info("Salt Full Return:\n%s", pprint.pformat(ret))
             try:
                 raise AssertionError(
                     "{result} is not True. Salt Comment:\n{comment}".format(
@@ -587,7 +516,7 @@ class SaltReturnAssertsMixin:
             for saltret in self.__getWithinSaltReturn(ret, "result"):
                 self.assertFalse(saltret)
         except AssertionError:
-            log.info("Salt Full Return:\n{}".format(pprint.pformat(ret)))
+            log.info("Salt Full Return:\n%s", pprint.pformat(ret))
             try:
                 raise AssertionError(
                     "{result} is not False. Salt Comment:\n{comment}".format(
@@ -604,7 +533,7 @@ class SaltReturnAssertsMixin:
             for saltret in self.__getWithinSaltReturn(ret, "result"):
                 self.assertIsNone(saltret)
         except AssertionError:
-            log.info("Salt Full Return:\n{}".format(pprint.pformat(ret)))
+            log.info("Salt Full Return:\n%s", pprint.pformat(ret))
             try:
                 raise AssertionError(
                     "{result} is not None. Salt Comment:\n{comment}".format(
@@ -670,23 +599,25 @@ def _fetch_events(q, opts):
             queue_item.task_done()
 
     atexit.register(_clean_queue)
-    event = salt.utils.event.get_event("minion", sock_dir=opts["sock_dir"], opts=opts)
+    with salt.utils.event.get_event(
+        "minion", sock_dir=opts["sock_dir"], opts=opts
+    ) as event:
 
-    # Wait for event bus to be connected
-    while not event.connect_pull(30):
-        time.sleep(1)
+        # Wait for event bus to be connected
+        while not event.connect_pull(30):
+            time.sleep(1)
 
-    # Notify parent process that the event bus is connected
-    q.put("CONNECTED")
+        # Notify parent process that the event bus is connected
+        q.put("CONNECTED")
 
-    while True:
-        try:
-            events = event.get_event(full=False)
-        except Exception as exc:  # pylint: disable=broad-except
-            # This is broad but we'll see all kinds of issues right now
-            # if we drop the proc out from under the socket while we're reading
-            log.exception("Exception caught while getting events %r", exc)
-        q.put(events)
+        while True:
+            try:
+                events = event.get_event(full=False)
+            except Exception as exc:  # pylint: disable=broad-except
+                # This is broad but we'll see all kinds of issues right now
+                # if we drop the proc out from under the socket while we're reading
+                log.exception("Exception caught while getting events %r", exc)
+            q.put(events)
 
 
 class SaltMinionEventAssertsMixin:
@@ -725,7 +656,7 @@ class SaltMinionEventAssertsMixin:
         while True:
             try:
                 event = self.q.get(False)
-            except Empty:
+            except queue.Empty:
                 time.sleep(sleep_time)
                 if time.time() - start >= timeout:
                     break
