@@ -184,11 +184,6 @@ RUNTIME_VARS = RuntimeVars(
     TMP_SUB_MINION_CONF_DIR=paths.TMP_SUB_MINION_CONF_DIR,
     TMP_SYNDIC_MASTER_CONF_DIR=paths.TMP_SYNDIC_MASTER_CONF_DIR,
     TMP_SYNDIC_MINION_CONF_DIR=paths.TMP_SYNDIC_MINION_CONF_DIR,
-    TMP_PROXY_CONF_DIR=paths.TMP_PROXY_CONF_DIR,
-    TMP_MM_CONF_DIR=paths.TMP_MM_CONF_DIR,
-    TMP_MM_MINION_CONF_DIR=paths.TMP_MM_MINION_CONF_DIR,
-    TMP_MM_SUB_CONF_DIR=paths.TMP_MM_SUB_CONF_DIR,
-    TMP_MM_SUB_MINION_CONF_DIR=paths.TMP_MM_SUB_CONF_DIR,
     TMP_SSH_CONF_DIR=paths.TMP_SSH_CONF_DIR,
     TMP_SCRIPT_DIR=paths.TMP_SCRIPT_DIR,
     TMP_STATE_TREE=paths.TMP_STATE_TREE,
@@ -210,6 +205,5 @@ RUNTIME_VARS = RuntimeVars(
     BASE_FILES=paths.BASE_FILES,
     PROD_FILES=paths.PROD_FILES,
     TESTS_DIR=paths.TESTS_DIR,
-    PYTEST_SESSION="PYTEST_SESSION" in os.environ,
 )
 # <---- Tests Runtime Variables --------------------------------------------------------------------------------------
