@@ -2,12 +2,12 @@
     :codeauthor: :email:`Daniel Wallace <dwallace@saltstack.com`
 """
 
-
 import os
 import re
 import shutil
 import tempfile
 
+import pytest
 import salt.client.ssh.client
 import salt.config
 import salt.roster
@@ -17,7 +17,6 @@ import salt.utils.thin
 import salt.utils.yaml
 from salt.client import ssh
 from tests.support.case import ShellCase
-from tests.support.helpers import slowTest
 from tests.support.mock import MagicMock, call, patch
 from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import TestCase, skipIf
@@ -25,7 +24,7 @@ from tests.support.unit import TestCase, skipIf
 
 @skipIf(not salt.utils.path.which("ssh"), "No ssh binary found in path")
 class SSHPasswordTests(ShellCase):
-    @slowTest
+    @pytest.mark.slow_test
     def test_password_failure(self):
         """
         Check password failures when trying to deploy keys
@@ -178,8 +177,7 @@ class SSHSingleTests(TestCase):
         }
 
     def test_single_opts(self):
-        """ Sanity check for ssh.Single options
-        """
+        """Sanity check for ssh.Single options"""
 
         single = ssh.Single(
             self.opts,
