@@ -1,18 +1,13 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import io
-import os
 import stat
 from functools import wraps
 
+import pytest
 import salt.config
 import salt.daemons.masterapi as masterapi
 import salt.utils.platform
-from tests.support.helpers import slowTest
+from tests.support.mixins import AdaptedConfigurationTestCaseMixin
 from tests.support.mock import MagicMock, patch
-from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import TestCase
 
 
@@ -273,10 +268,12 @@ class LocalFuncsTestCase(TestCase):
     def setUp(self):
         opts = salt.config.master_config(None)
         self.local_funcs = masterapi.LocalFuncs(opts, "test-key")
+        self.addCleanup(self.local_funcs.destroy)
+        self.addCleanup(delattr, self, "local_funcs")
 
     # runner tests
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_runner_token_not_authenticated(self):
         """
         Asserts that a TokenAuthenticationError is returned when the token can't authenticate.
@@ -290,7 +287,7 @@ class LocalFuncsTestCase(TestCase):
         ret = self.local_funcs.runner({"token": "asdfasdfasdfasdf"})
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_runner_token_authorization_error(self):
         """
         Asserts that a TokenAuthenticationError is returned when the token authenticates, but is
@@ -302,8 +299,9 @@ class LocalFuncsTestCase(TestCase):
         mock_ret = {
             "error": {
                 "name": "TokenAuthenticationError",
-                "message": 'Authentication failure of type "token" occurred '
-                "for user test.",
+                "message": (
+                    'Authentication failure of type "token" occurred for user test.'
+                ),
             }
         }
 
@@ -314,7 +312,7 @@ class LocalFuncsTestCase(TestCase):
 
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_runner_token_salt_invocation_error(self):
         """
         Asserts that a SaltInvocationError is returned when the token authenticates, but the
@@ -339,7 +337,7 @@ class LocalFuncsTestCase(TestCase):
 
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_runner_eauth_not_authenticated(self):
         """
         Asserts that an EauthAuthenticationError is returned when the user can't authenticate.
@@ -347,14 +345,15 @@ class LocalFuncsTestCase(TestCase):
         mock_ret = {
             "error": {
                 "name": "EauthAuthenticationError",
-                "message": 'Authentication failure of type "eauth" occurred for '
-                "user UNKNOWN.",
+                "message": (
+                    'Authentication failure of type "eauth" occurred for user UNKNOWN.'
+                ),
             }
         }
         ret = self.local_funcs.runner({"eauth": "foo"})
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_runner_eauth_authorization_error(self):
         """
         Asserts that an EauthAuthenticationError is returned when the user authenticates, but is
@@ -364,8 +363,9 @@ class LocalFuncsTestCase(TestCase):
         mock_ret = {
             "error": {
                 "name": "EauthAuthenticationError",
-                "message": 'Authentication failure of type "eauth" occurred for '
-                "user test.",
+                "message": (
+                    'Authentication failure of type "eauth" occurred for user test.'
+                ),
             }
         }
         with patch(
@@ -375,7 +375,7 @@ class LocalFuncsTestCase(TestCase):
 
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_runner_eauth_salt_invocation_error(self):
         """
         Asserts that an EauthAuthenticationError is returned when the user authenticates, but the
@@ -404,7 +404,7 @@ class LocalFuncsTestCase(TestCase):
 
     # wheel tests
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_wheel_token_not_authenticated(self):
         """
         Asserts that a TokenAuthenticationError is returned when the token can't authenticate.
@@ -418,7 +418,7 @@ class LocalFuncsTestCase(TestCase):
         ret = self.local_funcs.wheel({"token": "asdfasdfasdfasdf"})
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_wheel_token_authorization_error(self):
         """
         Asserts that a TokenAuthenticationError is returned when the token authenticates, but is
@@ -430,8 +430,9 @@ class LocalFuncsTestCase(TestCase):
         mock_ret = {
             "error": {
                 "name": "TokenAuthenticationError",
-                "message": 'Authentication failure of type "token" occurred '
-                "for user test.",
+                "message": (
+                    'Authentication failure of type "token" occurred for user test.'
+                ),
             }
         }
 
@@ -442,7 +443,7 @@ class LocalFuncsTestCase(TestCase):
 
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_wheel_token_salt_invocation_error(self):
         """
         Asserts that a SaltInvocationError is returned when the token authenticates, but the
@@ -467,7 +468,7 @@ class LocalFuncsTestCase(TestCase):
 
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_wheel_eauth_not_authenticated(self):
         """
         Asserts that an EauthAuthenticationError is returned when the user can't authenticate.
@@ -475,14 +476,15 @@ class LocalFuncsTestCase(TestCase):
         mock_ret = {
             "error": {
                 "name": "EauthAuthenticationError",
-                "message": 'Authentication failure of type "eauth" occurred for '
-                "user UNKNOWN.",
+                "message": (
+                    'Authentication failure of type "eauth" occurred for user UNKNOWN.'
+                ),
             }
         }
         ret = self.local_funcs.wheel({"eauth": "foo"})
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_wheel_eauth_authorization_error(self):
         """
         Asserts that an EauthAuthenticationError is returned when the user authenticates, but is
@@ -492,8 +494,9 @@ class LocalFuncsTestCase(TestCase):
         mock_ret = {
             "error": {
                 "name": "EauthAuthenticationError",
-                "message": 'Authentication failure of type "eauth" occurred for '
-                "user test.",
+                "message": (
+                    'Authentication failure of type "eauth" occurred for user test.'
+                ),
             }
         }
         with patch(
@@ -503,7 +506,7 @@ class LocalFuncsTestCase(TestCase):
 
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_wheel_eauth_salt_invocation_error(self):
         """
         Asserts that an EauthAuthenticationError is returned when the user authenticates, but the
@@ -530,7 +533,7 @@ class LocalFuncsTestCase(TestCase):
 
         self.assertDictEqual(mock_ret, ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_wheel_user_not_authenticated(self):
         """
         Asserts that an UserAuthenticationError is returned when the user can't authenticate.
@@ -538,8 +541,9 @@ class LocalFuncsTestCase(TestCase):
         mock_ret = {
             "error": {
                 "name": "UserAuthenticationError",
-                "message": 'Authentication failure of type "user" occurred for '
-                "user UNKNOWN.",
+                "message": (
+                    'Authentication failure of type "user" occurred for user UNKNOWN.'
+                ),
             }
         }
         ret = self.local_funcs.wheel({})
@@ -547,7 +551,7 @@ class LocalFuncsTestCase(TestCase):
 
     # publish tests
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_publish_user_is_blacklisted(self):
         """
         Asserts that an AuthorizationError is returned when the user has been blacklisted.
@@ -565,7 +569,7 @@ class LocalFuncsTestCase(TestCase):
                 mock_ret, self.local_funcs.publish({"user": "foo", "fun": "test.arg"})
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_publish_cmd_blacklisted(self):
         """
         Asserts that an AuthorizationError is returned when the command has been blacklisted.
@@ -585,7 +589,7 @@ class LocalFuncsTestCase(TestCase):
                 mock_ret, self.local_funcs.publish({"user": "foo", "fun": "test.arg"})
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_publish_token_not_authenticated(self):
         """
         Asserts that an AuthenticationError is returned when the token can't authenticate.
@@ -609,7 +613,7 @@ class LocalFuncsTestCase(TestCase):
         ):
             self.assertEqual(mock_ret, self.local_funcs.publish(load))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_publish_token_authorization_error(self):
         """
         Asserts that an AuthorizationError is returned when the token authenticates, but is not
@@ -642,7 +646,7 @@ class LocalFuncsTestCase(TestCase):
         ):
             self.assertEqual(mock_ret, self.local_funcs.publish(load))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_publish_eauth_not_authenticated(self):
         """
         Asserts that an AuthenticationError is returned when the user can't authenticate.
@@ -666,7 +670,7 @@ class LocalFuncsTestCase(TestCase):
         ):
             self.assertEqual(mock_ret, self.local_funcs.publish(load))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_publish_eauth_authorization_error(self):
         """
         Asserts that an AuthorizationError is returned when the user authenticates, but is not
@@ -696,7 +700,7 @@ class LocalFuncsTestCase(TestCase):
         ):
             self.assertEqual(mock_ret, self.local_funcs.publish(load))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_publish_user_not_authenticated(self):
         """
         Asserts that an AuthenticationError is returned when the user can't authenticate.
@@ -715,7 +719,7 @@ class LocalFuncsTestCase(TestCase):
         ):
             self.assertEqual(mock_ret, self.local_funcs.publish(load))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_publish_user_authenticated_missing_auth_list(self):
         """
         Asserts that an AuthenticationError is returned when the user has an effective user id and is
@@ -746,7 +750,7 @@ class LocalFuncsTestCase(TestCase):
         ):
             self.assertEqual(mock_ret, self.local_funcs.publish(load))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_publish_user_authorization_error(self):
         """
         Asserts that an AuthorizationError is returned when the user authenticates, but is not
@@ -781,7 +785,7 @@ class LocalFuncsTestCase(TestCase):
             self.assertEqual(mock_ret, self.local_funcs.publish(load))
 
 
-class FakeCache(object):
+class FakeCache:
     def __init__(self):
         self.data = {}
 
@@ -798,13 +802,14 @@ class RemoteFuncsTestCase(TestCase):
     """
 
     def setUp(self):
-        opts = salt.config.master_config(
-            os.path.join(RUNTIME_VARS.TMP_CONF_DIR, "master")
-        )
+        opts = AdaptedConfigurationTestCaseMixin.get_temp_config("master")
+        salt.cache.MemCache.data.clear()
         self.funcs = masterapi.RemoteFuncs(opts)
         self.funcs.cache = FakeCache()
+        self.addCleanup(self.funcs.destroy)
+        self.addCleanup(delattr, self, "funcs")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_mine_get(self, tgt_type_key="tgt_type"):
         """
         Asserts that ``mine_get`` gives the expected results.
@@ -831,7 +836,7 @@ class RemoteFuncsTestCase(TestCase):
             )
         self.assertDictEqual(ret, dict(webserver="2001:db8::1:3"))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_mine_get_pre_nitrogen_compat(self):
         """
         Asserts that pre-Nitrogen API key ``expr_form`` is still accepted.
@@ -840,7 +845,7 @@ class RemoteFuncsTestCase(TestCase):
         """
         self.test_mine_get(tgt_type_key="expr_form")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_mine_get_dict_str(self, tgt_type_key="tgt_type"):
         """
         Asserts that ``mine_get`` gives the expected results when request
@@ -876,7 +881,7 @@ class RemoteFuncsTestCase(TestCase):
             ),
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_mine_get_dict_list(self, tgt_type_key="tgt_type"):
         """
         Asserts that ``mine_get`` gives the expected results when request
@@ -912,7 +917,7 @@ class RemoteFuncsTestCase(TestCase):
             ),
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_mine_get_acl_allowed(self):
         """
         Asserts that ``mine_get`` gives the expected results when this is allowed
@@ -949,7 +954,7 @@ class RemoteFuncsTestCase(TestCase):
             )
         self.assertDictEqual(ret, {"ip_addr": {"webserver": "2001:db8::1:4"}})
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_mine_get_acl_rejected(self):
         """
         Asserts that ``mine_get`` gives the expected results when this is rejected
