@@ -1,14 +1,12 @@
-# -*- coding: utf-8 -*-
 """
     :codeauthor: :email:`Jayesh Kariya <jayeshk@saltstack.com>`
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import os
 
+import pytest
 import salt.modules.beacons as beacons
 from salt.utils.event import SaltEvent
-from tests.support.helpers import slowTest
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.runtests import RUNTIME_VARS
@@ -27,7 +25,7 @@ class BeaconsTestCase(TestCase, LoaderModuleMockMixin):
     def setup_loader_modules(self):
         return {beacons: {}}
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_delete(self):
         """
         Test deleting a beacon.
@@ -59,7 +57,7 @@ class BeaconsTestCase(TestCase, LoaderModuleMockMixin):
                         beacons.delete("ps"), {"comment": comm1, "result": True}
                     )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_add(self):
         """
         Test adding a beacon
@@ -112,12 +110,12 @@ class BeaconsTestCase(TestCase, LoaderModuleMockMixin):
                         {"comment": comm1, "result": True},
                     )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_save(self):
         """
         Test saving beacons.
         """
-        comm1 = "Beacons saved to {0}beacons.conf.".format(RUNTIME_VARS.TMP + os.sep)
+        comm1 = "Beacons saved to {}beacons.conf.".format(RUNTIME_VARS.TMP + os.sep)
         with patch.dict(
             beacons.__opts__,
             {
@@ -136,7 +134,7 @@ class BeaconsTestCase(TestCase, LoaderModuleMockMixin):
                         beacons.save(), {"comment": comm1, "result": True}
                     )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_disable(self):
         """
         Test disabling beacons
@@ -163,7 +161,7 @@ class BeaconsTestCase(TestCase, LoaderModuleMockMixin):
                         beacons.disable(), {"comment": comm1, "result": True}
                     )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_enable(self):
         """
         Test enabling beacons
@@ -190,7 +188,7 @@ class BeaconsTestCase(TestCase, LoaderModuleMockMixin):
                         beacons.enable(), {"comment": comm1, "result": True}
                     )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_add_beacon_module(self):
         """
         Test adding a beacon
@@ -240,7 +238,7 @@ class BeaconsTestCase(TestCase, LoaderModuleMockMixin):
                         {"comment": comm1, "result": True},
                     )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_enable_beacon_module(self):
         """
         Test enabling beacons
@@ -268,7 +266,7 @@ class BeaconsTestCase(TestCase, LoaderModuleMockMixin):
                         beacons.enable(), {"comment": comm1, "result": True}
                     )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_delete_beacon_module(self):
         """
         Test deleting a beacon.
