@@ -1,27 +1,17 @@
-# -*- coding: utf-8 -*-
-
-# import Python Libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import os.path
 from collections import namedtuple
 
 import pkg_resources  # pylint: disable=3rd-party-module-not-gated
 
-# Import Salt Libs
 import salt.config
 import salt.loader
 import salt.utils.versions
-from salt.ext import six
-
-# Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import TestCase, skipIf
 
-# import Python Third Party Libs
 # pylint: disable=import-error
 try:
     import salt.modules.boto_route53 as boto_route53
@@ -55,8 +45,7 @@ except ImportError:
 
 log = logging.getLogger(__name__)
 
-required_moto = "0.3.7"
-required_moto_py3 = "1.0.1"
+required_moto = "1.0.1"
 
 
 def _has_required_moto():
@@ -72,19 +61,13 @@ def _has_required_moto():
         )
         if moto_version < salt.utils.versions.LooseVersion(required_moto):
             return False
-        elif six.PY3 and moto_version < salt.utils.versions.LooseVersion(
-            required_moto_py3
-        ):
-            return False
-
     return True
 
 
 @skipIf(HAS_MOTO is False, "The moto module must be installed.")
 @skipIf(
     _has_required_moto() is False,
-    "The moto module must be >= to {0} for "
-    "PY2 or {1} for PY3.".format(required_moto, required_moto_py3),
+    "The moto module must be >= to {}".format(required_moto),
 )
 class BotoRoute53TestCase(TestCase, LoaderModuleMockMixin):
     """
@@ -154,7 +137,7 @@ class BotoRoute53TestCase(TestCase, LoaderModuleMockMixin):
         self.assertEqual(healthcheck, expected)
 
 
-class DummyConn(object):
+class DummyConn:
     """
     Simple object housing a mock to simulate Error conditions. Each keyword
     argument passed into this will be set as MagicMock with the keyword value
@@ -162,7 +145,7 @@ class DummyConn(object):
     """
 
     def __init__(self, **kwargs):
-        for key, val in six.iteritems(kwargs):
+        for key, val in kwargs.items():
             setattr(self, key, MagicMock(side_effect=val))
 
 
@@ -210,7 +193,10 @@ class BotoRoute53RetryTestCase(TestCase, LoaderModuleMockMixin):
         # Retryable error (max retries reached)
         conn = DummyConn(get_zone=[self._retryable_error, self._retryable_error])
         with patch.object(boto_route53, "_get_conn", MagicMock(return_value=conn)):
-            result = boto_route53.zone_exists("foo", error_retries=2,)
+            result = boto_route53.zone_exists(
+                "foo",
+                error_retries=2,
+            )
             assert conn.get_zone.call_count == 2
             assert result is False
 
@@ -242,7 +228,10 @@ class BotoRoute53RetryTestCase(TestCase, LoaderModuleMockMixin):
             create_health_check=[self._retryable_error, self._retryable_error]
         )
         with patch.object(boto_route53, "_get_conn", MagicMock(return_value=conn)):
-            result = boto_route53.create_healthcheck("foo", error_retries=2,)
+            result = boto_route53.create_healthcheck(
+                "foo",
+                error_retries=2,
+            )
             assert conn.create_health_check.call_count == 2
             assert result is False
 
@@ -267,7 +256,12 @@ class BotoRoute53RetryTestCase(TestCase, LoaderModuleMockMixin):
         # Retryable error (max retries reached)
         conn = DummyConn(get_zone=[self._retryable_error, self._retryable_error])
         with patch.object(boto_route53, "_get_conn", MagicMock(return_value=conn)):
-            result = boto_route53.get_record("foo", "bar", "baz", error_retries=2,)
+            result = boto_route53.get_record(
+                "foo",
+                "bar",
+                "baz",
+                error_retries=2,
+            )
             assert conn.get_zone.call_count == 2
             assert not result
 
@@ -304,7 +298,13 @@ class BotoRoute53RetryTestCase(TestCase, LoaderModuleMockMixin):
         zone.id = "foo"
         conn = DummyConn(get_zone=[zone])
         with patch.object(boto_route53, "_get_conn", MagicMock(return_value=conn)):
-            result = boto_route53.add_record("a", "b", "c", "d", error_retries=2,)
+            result = boto_route53.add_record(
+                "a",
+                "b",
+                "c",
+                "d",
+                error_retries=2,
+            )
             assert zone.add_record.call_count == 2
             assert not result
 
@@ -339,7 +339,13 @@ class BotoRoute53RetryTestCase(TestCase, LoaderModuleMockMixin):
         zone = DummyConn(find_records=[self._retryable_error, self._retryable_error])
         conn = DummyConn(get_zone=[zone])
         with patch.object(boto_route53, "_get_conn", MagicMock(return_value=conn)):
-            result = boto_route53.update_record("a", "b", "c", "d", error_retries=2,)
+            result = boto_route53.update_record(
+                "a",
+                "b",
+                "c",
+                "d",
+                error_retries=2,
+            )
             assert zone.find_records.call_count == 2
             assert not result
 
@@ -375,7 +381,13 @@ class BotoRoute53RetryTestCase(TestCase, LoaderModuleMockMixin):
         zone = DummyConn(find_records=[self._retryable_error, self._retryable_error])
         conn = DummyConn(get_zone=[zone])
         with patch.object(boto_route53, "_get_conn", MagicMock(return_value=conn)):
-            result = boto_route53.delete_record("a", "b", "c", "d", error_retries=2,)
+            result = boto_route53.delete_record(
+                "a",
+                "b",
+                "c",
+                "d",
+                error_retries=2,
+            )
             assert zone.find_records.call_count == 2
             assert not result
 
