@@ -1,32 +1,26 @@
-# -*- coding: utf-8 -*-
 """
     :codeauthor: Jayesh Kariya <jayeshk@saltstack.com>
     :codeauthor: Joe Julian <me@joejulian.name>
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import Salt Libs
 import salt.modules.glusterfs as glusterfs
 from salt.exceptions import SaltInvocationError
-
-# Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.unit import TestCase
 
 
-class GlusterResults(object):
-    """ This class holds the xml results from gluster cli transactions """
+class GlusterResults:
+    """This class holds the xml results from gluster cli transactions"""
 
-    class v34(object):
-        """ This is for version 3.4 results """
+    class v34:
+        """This is for version 3.4 results"""
 
-        class list_peers(object):
-            """ results from "peer status" """
+        class list_peers:
+            """results from "peer status" """
 
-        class peer_probe(object):
+        class peer_probe:
             fail_cant_connect = fail_bad_hostname = "\n".join(
                 [
                     '<?xml version="1.0" encoding="UTF-8" standalone="yes"?>',
@@ -73,7 +67,8 @@ class GlusterResults(object):
                         "  <opRet>0</opRet>",
                         "  <opErrno>2</opErrno>",
                         "  <opErrstr>(null)</opErrstr>",
-                        "  <output>success: host 10.0.0.2 port 24007 already in peer list</output>",
+                        "  <output>success: host 10.0.0.2 port 24007 already in peer"
+                        " list</output>",
                         "</cliOutput>",
                         "",
                     ]
@@ -85,7 +80,8 @@ class GlusterResults(object):
                         "  <opRet>0</opRet>",
                         "  <opErrno>2</opErrno>",
                         "  <opErrstr>(null)</opErrstr>",
-                        "  <output>success: host server2 port 24007 already in peer list</output>",
+                        "  <output>success: host server2 port 24007 already in peer"
+                        " list</output>",
                         "</cliOutput>",
                         "",
                     ]
@@ -99,7 +95,8 @@ class GlusterResults(object):
                         "  <opRet>0</opRet>",
                         "  <opErrno>2</opErrno>",
                         "  <opErrstr>(null)</opErrstr>",
-                        "  <output>success: host 10.0.0.1 port 24007 already in peer list</output>",
+                        "  <output>success: host 10.0.0.1 port 24007 already in peer"
+                        " list</output>",
                         "</cliOutput>",
                         "",
                     ]
@@ -111,27 +108,29 @@ class GlusterResults(object):
                         "  <opRet>0</opRet>",
                         "  <opErrno>2</opErrno>",
                         "  <opErrstr>(null)</opErrstr>",
-                        "  <output>success: host server1 port 24007 already in peer list</output>",
+                        "  <output>success: host server1 port 24007 already in peer"
+                        " list</output>",
                         "</cliOutput>",
                         "",
                     ]
                 ),
             }
             success_first_hostname_from_second_first_time = success_other
-            success_first_hostname_from_second_second_time = success_reverse_already_peer[
-                "hostname"
-            ]
+            success_first_hostname_from_second_second_time = (
+                success_reverse_already_peer["hostname"]
+            )
             success_first_ip_from_second_first_time = success_reverse_already_peer["ip"]
 
-    class v37(object):
-        class peer_probe(object):
+    class v37:
+        class peer_probe:
             fail_cant_connect = fail_bad_hostname = "\n".join(
                 [
                     '<?xml version="1.0" encoding="UTF-8" standalone="yes"?>',
                     "<cliOutput>",
                     "  <opRet>-1</opRet>",
                     "  <opErrno>107</opErrno>",
-                    "  <opErrstr>Probe returned with Transport endpoint is not connected</opErrstr>",
+                    "  <opErrstr>Probe returned with Transport endpoint is not"
+                    " connected</opErrstr>",
                     "</cliOutput>",
                     "",
                 ]
@@ -170,7 +169,8 @@ class GlusterResults(object):
                         "  <opRet>0</opRet>",
                         "  <opErrno>2</opErrno>",
                         "  <opErrstr/>",
-                        "  <output>Host 10.0.0.2 port 24007 already in peer list</output>",
+                        "  <output>Host 10.0.0.2 port 24007 already in peer"
+                        " list</output>",
                         "</cliOutput>",
                         "",
                     ]
@@ -182,7 +182,8 @@ class GlusterResults(object):
                         "  <opRet>0</opRet>",
                         "  <opErrno>2</opErrno>",
                         "  <opErrstr/>",
-                        "  <output>Host server2 port 24007 already in peer list</output>",
+                        "  <output>Host server2 port 24007 already in peer"
+                        " list</output>",
                         "</cliOutput>",
                         "",
                     ]
@@ -196,7 +197,8 @@ class GlusterResults(object):
                         "  <opRet>0</opRet>",
                         "  <opErrno>2</opErrno>",
                         "  <opErrstr/>",
-                        "  <output>Host 10.0.0.1 port 24007 already in peer list</output>",
+                        "  <output>Host 10.0.0.1 port 24007 already in peer"
+                        " list</output>",
                         "</cliOutput>",
                         "",
                     ]
@@ -208,21 +210,42 @@ class GlusterResults(object):
                         "  <opRet>0</opRet>",
                         "  <opErrno>2</opErrno>",
                         "  <opErrstr/>",
-                        "  <output>Host server1 port 24007 already in peer list</output>",
+                        "  <output>Host server1 port 24007 already in peer"
+                        " list</output>",
                         "</cliOutput>",
                         "",
                     ]
                 ),
             }
-            success_first_hostname_from_second_first_time = success_reverse_already_peer[
-                "hostname"
-            ]
+            success_first_hostname_from_second_first_time = (
+                success_reverse_already_peer["hostname"]
+            )
             success_first_ip_from_second_first_time = success_other
             success_first_ip_from_second_second_time = success_reverse_already_peer[
                 "ip"
             ]
 
 
+#  gluster --version output collected in the wild.
+version_output_362 = """
+glusterfs 3.6.2 built on Jan 22 2015 12:59:57
+Repository revision: git://git.gluster.com/glusterfs.git
+Copyright (c) 2006-2011 Gluster Inc. <http://www.gluster.com>
+GlusterFS comes with ABSOLUTELY NO WARRANTY.
+You may redistribute copies of GlusterFS under the terms of the GNU General Public License
+   """
+
+version_output_61 = """
+glusterfs 6.1
+Repository revision: git://git.gluster.org/glusterfs.git
+Copyright (c) 2006-2016 Red Hat, Inc. <https://www.gluster.org/>
+GlusterFS comes with ABSOLUTELY NO WARRANTY.
+It is licensed to you under your choice of the GNU Lesser
+General Public License, version 3 or any later version (LGPLv3
+or later), or the GNU General Public License, version 2 (GPLv2),
+in all cases as published by the Free Software Foundation.
+"""
+
 xml_peer_present = """
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <cliOutput>
@@ -488,6 +511,33 @@ class GlusterfsTestCase(TestCase, LoaderModuleMockMixin):
 
     # 'peer_status' function tests: 1
 
+    def test__get_version(self):
+        """
+        Test parsing of gluster --version.
+        """
+        mock_version = MagicMock(return_value="foo")
+        with patch.dict(glusterfs.__salt__, {"cmd.run": mock_version}):
+            self.assertEqual(glusterfs._get_version(), (3, 6), msg="default behaviour")
+
+        mock_version = MagicMock(return_value=version_output_362)
+        with patch.dict(glusterfs.__salt__, {"cmd.run": mock_version}):
+            self.assertEqual(glusterfs._get_version(), (3, 6, 2))
+
+        mock_version = MagicMock(return_value=version_output_61)
+        with patch.dict(glusterfs.__salt__, {"cmd.run": mock_version}):
+            self.assertEqual(glusterfs._get_version(), (6, 1))
+
+        more_versions = {
+            "6.0": (6, 0),
+            "4.1.10": (4, 1, 10),
+            "5.13": (5, 13),
+            "10.0": (10, 0),
+        }
+        for v in more_versions:
+            mock_version = MagicMock(return_value="glusterfs {}".format(v))
+            with patch.dict(glusterfs.__salt__, {"cmd.run": mock_version}):
+                self.assertEqual(glusterfs._get_version(), more_versions[v])
+
     def test_peer_status(self):
         """
         Test gluster peer status
