@@ -2,14 +2,10 @@
     :codeauthor: Rupesh Tare <rupesht@saltstack.com>
 """
 
-# Import Python libs
 
 import os.path
 
-# Import Salt Libs
 import salt.modules.linux_lvm as linux_lvm
-
-# Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.unit import TestCase
@@ -28,9 +24,11 @@ class LinuxLVMTestCase(TestCase, LoaderModuleMockMixin):
         Tests LVM version info from lvm version
         """
         mock = MagicMock(
-            return_value="  LVM version:     2.02.168(2) (2016-11-30)\n"
-            "  Library version: 1.03.01 (2016-11-30)\n"
-            "  Driver version:  4.35.0\n"
+            return_value=(
+                "  LVM version:     2.02.168(2) (2016-11-30)\n"
+                "  Library version: 1.03.01 (2016-11-30)\n"
+                "  Driver version:  4.35.0\n"
+            )
         )
         with patch.dict(linux_lvm.__salt__, {"cmd.run": mock}):
             self.assertEqual(linux_lvm.version(), "2.02.168(2) (2016-11-30)")
@@ -40,9 +38,11 @@ class LinuxLVMTestCase(TestCase, LoaderModuleMockMixin):
         Tests all version info from lvm version
         """
         mock = MagicMock(
-            return_value="  LVM version:     2.02.168(2) (2016-11-30)\n"
-            "  Library version: 1.03.01 (2016-11-30)\n"
-            "  Driver version:  4.35.0\n"
+            return_value=(
+                "  LVM version:     2.02.168(2) (2016-11-30)\n"
+                "  Library version: 1.03.01 (2016-11-30)\n"
+                "  Driver version:  4.35.0\n"
+            )
         )
         with patch.dict(linux_lvm.__salt__, {"cmd.run": mock}):
             self.assertDictEqual(
@@ -311,7 +311,9 @@ class LinuxLVMTestCase(TestCase, LoaderModuleMockMixin):
                 self.assertDictEqual(
                     linux_lvm.vgcreate("fakevg", "B"),
                     {
-                        "Output from vgcreate": 'Volume group "fakevg" successfully created'
+                        "Output from vgcreate": (
+                            'Volume group "fakevg" successfully created'
+                        )
                     },
                 )
 
@@ -329,7 +331,9 @@ class LinuxLVMTestCase(TestCase, LoaderModuleMockMixin):
                 self.assertDictEqual(
                     linux_lvm.vgextend("fakevg", "B"),
                     {
-                        "Output from vgextend": 'Volume group "fakevg" successfully extended'
+                        "Output from vgextend": (
+                            'Volume group "fakevg" successfully extended'
+                        )
                     },
                 )
 
@@ -379,6 +383,36 @@ class LinuxLVMTestCase(TestCase, LoaderModuleMockMixin):
                     {"Output from lvcreate": 'Logical volume "None" created.'},
                 )
 
+    def test_lvcreate_extra_arguments_no_parameter(self):
+        extra_args = {
+            "nosync": None,
+            "noudevsync": None,
+            "ignoremonitoring": None,
+            "thin": None,
+        }
+        mock = MagicMock(return_value={"retcode": 0, "stderr": ""})
+        with patch.dict(linux_lvm.__salt__, {"cmd.run_all": mock}):
+            with patch.object(linux_lvm, "lvdisplay", return_value={}):
+                self.assertDictEqual(
+                    linux_lvm.lvcreate(None, None, None, 1, **extra_args),
+                    {"Output from lvcreate": 'Logical volume "None" created.'},
+                )
+        expected_args = ["--{}".format(arg) for arg in extra_args]
+        processed_extra_args = mock.call_args.args[0][-(len(extra_args) + 1) : -1]
+        self.assertTrue(all([arg in expected_args for arg in processed_extra_args]))
+
+    def test_lvcreate_invalid_extra_parameter(self):
+        invalid_parameter = {"foo": "bar"}
+        mock = MagicMock(return_value={"retcode": 0, "stderr": ""})
+        with patch.dict(linux_lvm.__salt__, {"cmd.run_all": mock}):
+            with patch.object(linux_lvm, "lvdisplay", return_value={}):
+                self.assertDictEqual(
+                    linux_lvm.lvcreate(None, None, None, 1, **invalid_parameter),
+                    {"Output from lvcreate": 'Logical volume "None" created.'},
+                )
+        processed_command = mock.call_args.args[0]
+        self.assertFalse("--foo" in processed_command)
+
     def test_vgremove(self):
         """
         Tests to remove an LVM volume group
@@ -425,7 +459,9 @@ class LinuxLVMTestCase(TestCase, LoaderModuleMockMixin):
             self.assertDictEqual(
                 linux_lvm.lvresize(12, "/dev/fakevg/fakelv"),
                 {
-                    "Output from lvresize": 'Logical volume "/dev/fakevg/fakelv" successfully resized.'
+                    "Output from lvresize": (
+                        'Logical volume "/dev/fakevg/fakelv" successfully resized.'
+                    )
                 },
             )
 
@@ -442,6 +478,8 @@ class LinuxLVMTestCase(TestCase, LoaderModuleMockMixin):
             self.assertDictEqual(
                 linux_lvm.lvextend(12, "/dev/fakevg/fakelv"),
                 {
-                    "Output from lvextend": 'Logical volume "/dev/fakevg/fakelv" successfully extended.'
+                    "Output from lvextend": (
+                        'Logical volume "/dev/fakevg/fakelv" successfully extended.'
+                    )
                 },
             )
