@@ -1,17 +1,10 @@
-# -*- coding: utf-8 -*-
 """
     :codeauthor: Rupesh Tare <rupesht@saltstack.com>
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import Salt Libs
 import salt.modules.localemod as localemod
 from salt.exceptions import CommandExecutionError
-from salt.ext import six
-
-# Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, Mock, patch
 from tests.support.unit import TestCase, skipIf
@@ -159,9 +152,10 @@ class LocalemodTestCase(TestCase, LoaderModuleMockMixin):
                 localemod.log.error.call_args[0][0]
                 % localemod.log.error.call_args[0][1]
             )
-            assert msg == (
-                'Odd locale parameter "Fatal error right in front of screen" detected in dbus locale output.'
-                " This should not happen. You should probably investigate what caused this."
+            assert (
+                msg == 'Odd locale parameter "Fatal error right in front of screen"'
+                " detected in dbus locale output. This should not happen. You should"
+                " probably investigate what caused this."
             )
 
     @patch("salt.utils.path.which", MagicMock(return_value=None))
@@ -173,7 +167,7 @@ class LocalemodTestCase(TestCase, LoaderModuleMockMixin):
         """
         with pytest.raises(CommandExecutionError) as exc_info:
             localemod._localectl_status()
-        assert 'Unable to find "localectl"' in six.text_type(exc_info.value)
+        assert 'Unable to find "localectl"' in str(exc_info.value)
         assert not localemod.log.debug.called
 
     @patch("salt.utils.path.which", MagicMock(return_value="/usr/bin/localctl"))
@@ -184,7 +178,7 @@ class LocalemodTestCase(TestCase, LoaderModuleMockMixin):
     def test_localectl_status_parser_empty(self):
         with pytest.raises(CommandExecutionError) as exc_info:
             localemod._localectl_status()
-        assert 'Unable to parse result of "localectl"' in six.text_type(exc_info.value)
+        assert 'Unable to parse result of "localectl"' in str(exc_info.value)
 
     @patch("salt.utils.path.which", MagicMock(return_value="/usr/bin/localctl"))
     @patch(
@@ -194,7 +188,7 @@ class LocalemodTestCase(TestCase, LoaderModuleMockMixin):
     def test_localectl_status_parser_broken(self):
         with pytest.raises(CommandExecutionError) as exc_info:
             localemod._localectl_status()
-        assert 'Unable to parse result of "localectl"' in six.text_type(exc_info.value)
+        assert 'Unable to parse result of "localectl"' in str(exc_info.value)
 
     @patch("salt.utils.path.which", MagicMock(return_value="/usr/bin/localctl"))
     @patch(
@@ -207,8 +201,8 @@ class LocalemodTestCase(TestCase, LoaderModuleMockMixin):
         for key in ["main", "cow_say"]:
             assert isinstance(out[key], dict)
             for in_key in out[key]:
-                assert isinstance(out[key][in_key], six.text_type)
-        assert isinstance(out["reason"]["data"], six.text_type)
+                assert isinstance(out[key][in_key], str)
+        assert isinstance(out["reason"]["data"], str)
 
     @patch("salt.utils.path.which", MagicMock(return_value="/usr/bin/localctl"))
     @patch(
@@ -371,7 +365,7 @@ class LocalemodTestCase(TestCase, LoaderModuleMockMixin):
         """
         with pytest.raises(CommandExecutionError) as exc_info:
             localemod.get_locale()
-        assert '"DrunkDragon" is unsupported' in six.text_type(exc_info.value)
+        assert '"DrunkDragon" is unsupported' in str(exc_info.value)
 
     @patch("salt.utils.path.which", MagicMock(return_value="/usr/bin/localctl"))
     @patch(
@@ -504,7 +498,7 @@ class LocalemodTestCase(TestCase, LoaderModuleMockMixin):
         with pytest.raises(CommandExecutionError) as exc_info:
             localemod.set_locale(loc)
         assert not localemod._localectl_set.called
-        assert 'Cannot set locale: "update-locale" was not found.' in six.text_type(
+        assert 'Cannot set locale: "update-locale" was not found.' in str(
             exc_info.value
         )
 
@@ -608,7 +602,7 @@ class LocalemodTestCase(TestCase, LoaderModuleMockMixin):
         """
         with pytest.raises(CommandExecutionError) as exc_info:
             localemod.set_locale("de_DE.utf8")
-        assert "Unsupported platform" in six.text_type(exc_info.value)
+        assert "Unsupported platform" in str(exc_info.value)
 
     @patch(
         "salt.utils.locales.normalize_locale",
@@ -711,7 +705,7 @@ class LocalemodTestCase(TestCase, LoaderModuleMockMixin):
             localemod.gen_locale("de_DE.utf8")
         assert (
             'Command "locale-gen" or "localedef" was not found on this system.'
-            in six.text_type(exc_info.value)
+            in str(exc_info.value)
         )
 
     def test_gen_locale_debian(self):
