@@ -6,14 +6,9 @@
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 """
 
-# Import Python libs
 
 import salt.modules.parted_partition as parted
-
-# Import Salt libs
 from salt.exceptions import CommandExecutionError
-
-# Import Salt Testing libs
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.unit import TestCase
@@ -44,7 +39,8 @@ class PartedTestCase(TestCase, LoaderModuleMockMixin):
             ret = parted.__virtual__()
             err = (
                 False,
-                "The parted execution module failed to load Windows systems are not supported.",
+                "The parted execution module failed to load Windows systems are not"
+                " supported.",
             )
             self.assertEqual(err, ret)
 
@@ -58,7 +54,8 @@ class PartedTestCase(TestCase, LoaderModuleMockMixin):
             ret = parted.__virtual__()
             err = (
                 False,
-                "The parted execution module failed to load parted binary is not in the path.",
+                "The parted execution module failed to load parted binary is not in the"
+                " path.",
             )
             self.assertEqual(err, ret)
 
@@ -72,7 +69,8 @@ class PartedTestCase(TestCase, LoaderModuleMockMixin):
             ret = parted.__virtual__()
             err = (
                 False,
-                "The parted execution module failed to load lsblk binary is not in the path.",
+                "The parted execution module failed to load lsblk binary is not in the"
+                " path.",
             )
             self.assertEqual(err, ret)
 
@@ -86,7 +84,8 @@ class PartedTestCase(TestCase, LoaderModuleMockMixin):
             ret = parted.__virtual__()
             err = (
                 False,
-                "The parted execution module failed to load partprobe binary is not in the path.",
+                "The parted execution module failed to load partprobe binary is not in"
+                " the path.",
             )
             self.assertEqual(err, ret)
 
