@@ -24,7 +24,7 @@ test_list_schema_csv = (
     'pg_toast,postgres,""'
 )
 
-test_list_language_csv = "Name\n" "internal\n" "c\n" "sql\n" "plpgsql\n"
+test_list_language_csv = "Name\ninternal\nc\nsql\nplpgsql\n"
 
 test_privileges_list_table_csv = (
     "name\n"
@@ -32,7 +32,7 @@ test_privileges_list_table_csv = (
 )
 
 test_privileges_list_group_csv = (
-    "rolname,admin_option\n" "baruwa,f\n" "baruwatest2,t\n" "baruwatest,f\n"
+    "rolname,admin_option\nbaruwa,f\nbaruwatest2,t\nbaruwatest,f\n"
 )
 
 log = logging.getLogger(__name__)
@@ -228,8 +228,7 @@ class PostgresTestCase(TestCase, LoaderModuleMockMixin):
                     "--dbname",
                     "maint_db",
                     "-c",
-                    "CREATE DATABASE \"dbname\" WITH ENCODING = 'utf8' "
-                    "LC_COLLATE = ''",
+                    "CREATE DATABASE \"dbname\" WITH ENCODING = 'utf8' LC_COLLATE = ''",
                 ],
                 host="testhost",
                 password="foo",
@@ -295,7 +294,7 @@ class PostgresTestCase(TestCase, LoaderModuleMockMixin):
                         "Tablespace": "pg_default",
                         "Collate": "en_US",
                         "Owner": "postgres",
-                        "Access privileges": ("{=c/postgres,postgres=CTc/postgres}"),
+                        "Access privileges": "{=c/postgres,postgres=CTc/postgres}",
                     },
                     "template0": {
                         "Encoding": "LATIN1",
@@ -303,7 +302,7 @@ class PostgresTestCase(TestCase, LoaderModuleMockMixin):
                         "Tablespace": "pg_default",
                         "Collate": "en_US",
                         "Owner": "postgres",
-                        "Access privileges": ("{=c/postgres,postgres=CTc/postgres}"),
+                        "Access privileges": "{=c/postgres,postgres=CTc/postgres}",
                     },
                     "postgres": {
                         "Encoding": "LATIN1",
@@ -371,7 +370,8 @@ class PostgresTestCase(TestCase, LoaderModuleMockMixin):
                         "--dbname",
                         "maint_db",
                         "-c",
-                        "SELECT pid, pg_terminate_backend(pid) FROM pg_stat_activity WHERE datname = 'test_db' AND pid <> pg_backend_pid();",
+                        "SELECT pid, pg_terminate_backend(pid) FROM pg_stat_activity"
+                        " WHERE datname = 'test_db' AND pid <> pg_backend_pid();",
                     ],
                     host="testhost",
                     password="foo",
@@ -2053,6 +2053,7 @@ class PostgresTestCase(TestCase, LoaderModuleMockMixin):
                     password="test",
                     runas="postgres",
                     checksums=False,
+                    waldir=None,
                     user="postgres",
                 )
                 self.assertTrue(ret)
