@@ -1,26 +1,15 @@
-# -*- coding: utf-8 -*-
 """
     :codeauthor: Mike Place <mp@saltstack.com>
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import time
 from collections import namedtuple
 
 import salt.modules.ps as ps
-
-# Import Salt libs
 import salt.utils.data
 import salt.utils.psutil_compat as psutil
-
-# Import 3rd-party libs
-# pylint: disable=import-error,unused-import
-from salt.ext.six.moves import range  # pylint: disable=redefined-builtin
 from tests.support.mock import MagicMock, Mock, call, patch
-
-# Import Salt Testing libs
 from tests.support.unit import TestCase, skipIf
 
 HAS_PSUTIL_VERSION = False
@@ -72,7 +61,7 @@ def _get_proc_pid(proc):
     return proc.pid
 
 
-class DummyProcess(object):
+class DummyProcess:
     """
     Dummy class to emulate psutil.Process. This ensures that _any_ string
     values used for any of the options passed in are converted to str types on
