@@ -5,15 +5,14 @@ import copy
 import glob
 import os
 
+import pytest
 import salt.config
-import salt.ext.six as six
 import salt.loader
 import salt.modules.win_lgpo as win_lgpo
 import salt.states.win_lgpo
 import salt.utils.files
 import salt.utils.platform
 import salt.utils.stringutils
-from tests.support.helpers import destructiveTest, slowTest
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, Mock, patch
 from tests.support.unit import TestCase, skipIf
@@ -294,8 +293,9 @@ class WinLGPOGetPolicyADMXTestCase(TestCase, LoaderModuleMockMixin):
             hierarchical_return=False,
         )
         expected = {
-            "Windows Components\\Data Collection and Preview Builds\\"
-            "Allow Telemetry": "Not Configured"
+            "Windows Components\\Data Collection and Preview Builds\\Allow Telemetry": (
+                "Not Configured"
+            )
         }
         self.assertDictEqual(result, expected)
 
@@ -308,8 +308,9 @@ class WinLGPOGetPolicyADMXTestCase(TestCase, LoaderModuleMockMixin):
             hierarchical_return=False,
         )
         expected = {
-            "Windows Components\\Data Collection and Preview Builds\\"
-            "Allow Telemetry": "Not Configured"
+            "Windows Components\\Data Collection and Preview Builds\\Allow Telemetry": (
+                "Not Configured"
+            )
         }
         self.assertDictEqual(result, expected)
 
@@ -377,7 +378,7 @@ class WinLGPOGetPolicyADMXTestCase(TestCase, LoaderModuleMockMixin):
         }
         self.assertDictEqual(result, expected)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test__load_policy_definitions(self):
         """
         Test that unexpected files in the PolicyDefinitions directory won't
@@ -463,7 +464,9 @@ class WinLGPOGetPolicyFromPolicyInfoTestCase(TestCase, LoaderModuleMockMixin):
             hierarchical_return=False,
         )
         expected = {
-            "Network firewall: Public: Settings: Display a notification": "Not configured"
+            "Network firewall: Public: Settings: Display a notification": (
+                "Not configured"
+            )
         }
         self.assertDictEqual(result, expected)
 
@@ -476,7 +479,9 @@ class WinLGPOGetPolicyFromPolicyInfoTestCase(TestCase, LoaderModuleMockMixin):
             hierarchical_return=False,
         )
         expected = {
-            "Network firewall: Public: Settings: Display a notification": "Not configured"
+            "Network firewall: Public: Settings: Display a notification": (
+                "Not configured"
+            )
         }
         self.assertDictEqual(result, expected)
 
@@ -489,7 +494,9 @@ class WinLGPOGetPolicyFromPolicyInfoTestCase(TestCase, LoaderModuleMockMixin):
             hierarchical_return=False,
         )
         expected = {
-            "Network firewall: Public: Settings: Display a notification": "Not configured"
+            "Network firewall: Public: Settings: Display a notification": (
+                "Not configured"
+            )
         }
         self.assertDictEqual(result, expected)
 
@@ -517,8 +524,7 @@ class WinLGPOGetPolicyFromPolicyInfoTestCase(TestCase, LoaderModuleMockMixin):
                 "Windows Settings": {
                     "Security Settings": {
                         "Windows Firewall with Advanced Security": {
-                            "Windows Firewall with Advanced Security - Local "
-                            "Group Policy Object": {
+                            "Windows Firewall with Advanced Security - Local Group Policy Object": {
                                 "WfwPublicSettingsNotification": "Not configured"
                             }
                         }
@@ -541,10 +547,10 @@ class WinLGPOGetPolicyFromPolicyInfoTestCase(TestCase, LoaderModuleMockMixin):
                 "Windows Settings": {
                     "Security Settings": {
                         "Windows Firewall with Advanced Security": {
-                            "Windows Firewall with Advanced Security - Local "
-                            "Group Policy Object": {
-                                "Network firewall: Public: Settings: Display a "
-                                "notification": "Not configured"
+                            "Windows Firewall with Advanced Security - Local Group Policy Object": {
+                                "Network firewall: Public: Settings: Display a notification": (
+                                    "Not configured"
+                                )
                             }
                         }
                     }
@@ -638,7 +644,7 @@ class WinLGPOPolicyInfoMechanismsTestCase(TestCase, LoaderModuleMockMixin):
         expected = "Not configured"
         self.assertEqual(result, expected)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_adv_audit_mechanism(self):
         """
         Test getting the policy value using the AdvAudit mechanism
@@ -692,8 +698,8 @@ class WinLGPOPolicyInfoMechanismsTestCase(TestCase, LoaderModuleMockMixin):
         self.assertEqual(result, expected)
 
 
-@destructiveTest
 @skipIf(not salt.utils.platform.is_windows(), "System is not Windows")
+@pytest.mark.destructive_test
 class WinLGPOGetPointAndPrintNCTestCase(TestCase, LoaderModuleMockMixin):
     """
     Test variations of the Point and Print Restrictions policy when Not
@@ -800,8 +806,8 @@ class WinLGPOGetPointAndPrintNCTestCase(TestCase, LoaderModuleMockMixin):
         self.assertDictEqual(result, expected)
 
 
-@destructiveTest
 @skipIf(not salt.utils.platform.is_windows(), "System is not Windows")
+@pytest.mark.destructive_test
 class WinLGPOGetPointAndPrintENTestCase(TestCase, LoaderModuleMockMixin):
     """
     Test variations of the Point and Print Restrictions policy when Enabled (EN)
@@ -833,12 +839,16 @@ class WinLGPOGetPointAndPrintENTestCase(TestCase, LoaderModuleMockMixin):
             computer_policy = {
                 "Point and Print Restrictions": {
                     "Users can only point and print to these servers": True,
-                    "Enter fully qualified server names separated by "
-                    "semicolons": "fakeserver1;fakeserver2",
-                    "Users can only point and print to machines in their "
-                    "forest": True,
-                    "When installing drivers for a new connection": "Show warning and elevation prompt",
-                    "When updating drivers for an existing connection": "Show warning only",
+                    "Enter fully qualified server names separated by semicolons": (
+                        "fakeserver1;fakeserver2"
+                    ),
+                    "Users can only point and print to machines in their forest": True,
+                    "When installing drivers for a new connection": (
+                        "Show warning and elevation prompt"
+                    ),
+                    "When updating drivers for an existing connection": (
+                        "Show warning only"
+                    ),
                 },
             }
             win_lgpo.set_(computer_policy=computer_policy)
@@ -862,12 +872,10 @@ class WinLGPOGetPointAndPrintENTestCase(TestCase, LoaderModuleMockMixin):
                 return_full_policy_names=return_full_policy_names,
                 hierarchical_return=hierarchical_return,
             )
-            if six.PY2:
-                results = salt.states.win_lgpo._convert_to_unicode(results)
             return results
         return "Policy Not Found"
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_point_and_print_enabled(self):
         result = self._get_policy_adm_setting(
             policy_name="Point and Print Restrictions",
@@ -877,7 +885,9 @@ class WinLGPOGetPointAndPrintENTestCase(TestCase, LoaderModuleMockMixin):
         )
         expected = {
             "PointAndPrint_Restrictions_Win7": {
-                "PointAndPrint_NoWarningNoElevationOnInstall_Enum": "Show warning and elevation prompt",
+                "PointAndPrint_NoWarningNoElevationOnInstall_Enum": (
+                    "Show warning and elevation prompt"
+                ),
                 "PointAndPrint_NoWarningNoElevationOnUpdate_Enum": "Show warning only",
                 "PointAndPrint_TrustedForest_Chk": True,
                 "PointAndPrint_TrustedServers_Chk": True,
@@ -898,11 +908,17 @@ class WinLGPOGetPointAndPrintENTestCase(TestCase, LoaderModuleMockMixin):
                 "Administrative Templates": {
                     "Printers": {
                         "PointAndPrint_Restrictions_Win7": {
-                            "PointAndPrint_NoWarningNoElevationOnInstall_Enum": "Show warning and elevation prompt",
-                            "PointAndPrint_NoWarningNoElevationOnUpdate_Enum": "Show warning only",
+                            "PointAndPrint_NoWarningNoElevationOnInstall_Enum": (
+                                "Show warning and elevation prompt"
+                            ),
+                            "PointAndPrint_NoWarningNoElevationOnUpdate_Enum": (
+                                "Show warning only"
+                            ),
                             "PointAndPrint_TrustedForest_Chk": True,
                             "PointAndPrint_TrustedServers_Chk": True,
-                            "PointAndPrint_TrustedServers_Edit": "fakeserver1;fakeserver2",
+                            "PointAndPrint_TrustedServers_Edit": (
+                                "fakeserver1;fakeserver2"
+                            ),
                         }
                     }
                 }
@@ -919,8 +935,12 @@ class WinLGPOGetPointAndPrintENTestCase(TestCase, LoaderModuleMockMixin):
         )
         expected = {
             "Printers\\Point and Print Restrictions": {
-                "Enter fully qualified server names separated by semicolons": "fakeserver1;fakeserver2",
-                "When installing drivers for a new connection": "Show warning and elevation prompt",
+                "Enter fully qualified server names separated by semicolons": (
+                    "fakeserver1;fakeserver2"
+                ),
+                "When installing drivers for a new connection": (
+                    "Show warning and elevation prompt"
+                ),
                 "Users can only point and print to machines in their forest": True,
                 "Users can only point and print to these servers": True,
                 "When updating drivers for an existing connection": "Show warning only",
@@ -928,7 +948,7 @@ class WinLGPOGetPointAndPrintENTestCase(TestCase, LoaderModuleMockMixin):
         }
         self.assertDictEqual(result, expected)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_point_and_print_enabled_full_names_hierarchical(self):
         result = self._get_policy_adm_setting(
             policy_name="Point and Print Restrictions",
@@ -941,13 +961,17 @@ class WinLGPOGetPointAndPrintENTestCase(TestCase, LoaderModuleMockMixin):
                 "Administrative Templates": {
                     "Printers": {
                         "Point and Print Restrictions": {
-                            "Enter fully qualified server names separated by "
-                            "semicolons": "fakeserver1;fakeserver2",
-                            "When installing drivers for a new connection": "Show warning and elevation prompt",
-                            "Users can only point and print to machines in "
-                            "their forest": True,
+                            "Enter fully qualified server names separated by semicolons": (
+                                "fakeserver1;fakeserver2"
+                            ),
+                            "When installing drivers for a new connection": (
+                                "Show warning and elevation prompt"
+                            ),
+                            "Users can only point and print to machines in their forest": True,
                             "Users can only point and print to these servers": True,
-                            "When updating drivers for an existing connection": "Show warning only",
+                            "When updating drivers for an existing connection": (
+                                "Show warning only"
+                            ),
                         }
                     }
                 }
