@@ -1,36 +1,26 @@
-# -*- coding: utf-8 -*-
 """
 Tests for salt.modules.zpool
 
-:codeauthor:    Nitin Madhok <nmadhok@clemson.edu>, Jorge Schrauwen <sjorge@blackdot.be>
+:codeauthor:    Nitin Madhok <nmadhok@g.clemson.edu>, Jorge Schrauwen <sjorge@blackdot.be>
 :maintainer:    Jorge Schrauwen <sjorge@blackdot.be>
 :maturity:      new
 :depends:       salt.utils.zfs
 :platform:      illumos,freebsd,linux
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import Salt Utils
+import pytest
 import salt.loader
 import salt.modules.zpool as zpool
 import salt.utils.decorators
 import salt.utils.decorators.path
-
-# Import Salt Execution module to test
 import salt.utils.zfs
 from salt.utils.odict import OrderedDict
-from tests.support.helpers import slowTest
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.unit import TestCase, skipIf
-
-# Import Salt Testing libs
 from tests.support.zfs import ZFSMockData
 
 
-# Skip this test case if we don't have access to mock!
 class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
     """
     This class contains a set of functions that test salt.modules.zpool module
@@ -48,7 +38,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
 
         return zpool_obj
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_exists_success(self):
         """
         Tests successful return of exists function
@@ -66,7 +56,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
         ):
             self.assertTrue(zpool.exists("myzpool"))
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_exists_failure(self):
         """
         Tests failure return of exists function
@@ -106,7 +96,8 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             [
                 "  pool: mypool",
                 " state: ONLINE",
-                "  scan: scrub repaired 0 in 0h6m with 0 errors on Mon Dec 21 02:06:17 2015",
+                "  scan: scrub repaired 0 in 0h6m with 0 errors on Mon Dec 21 02:06:17"
+                " 2015",
                 "config:",
                 "",
                 "\tNAME        STATE     READ WRITE CKSUM",
@@ -127,7 +118,38 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             ret = zpool.status()
             self.assertEqual("ONLINE", ret["mypool"]["state"])
 
-    @slowTest
+    def test_status_with_colons_in_vdevs(self):
+        """
+        Tests successful return of status function
+        """
+        ret = {}
+        ret["stdout"] = "\n".join(
+            [
+                "  pool: mypool",
+                " state: ONLINE",
+                "  scan: scrub repaired 0 in 0h6m with 0 errors on Mon Dec 21 02:06:17"
+                " 2015",
+                "config:",
+                "",
+                "\tNAME        STATE     READ WRITE CKSUM",
+                "\tmypool      ONLINE       0     0     0",
+                "\t  mirror-0  ONLINE       0     0     0",
+                "\t    usb-WD_My_Book_Duo_25F6_....32-0:0  ONLINE       0     0     0",
+                "\t    usb-WD_My_Book_Duo_25F6_....32-0:1  ONLINE       0     0     0",
+                "",
+                "errors: No known data errors",
+            ]
+        )
+        ret["stderr"] = ""
+        ret["retcode"] = 0
+        mock_cmd = MagicMock(return_value=ret)
+        with patch.dict(zpool.__salt__, {"cmd.run_all": mock_cmd}), patch.dict(
+            zpool.__utils__, self.utils_patch
+        ):
+            ret = zpool.status()
+            self.assertEqual("ONLINE", ret["mypool"]["state"])
+
+    @pytest.mark.slow_test
     def test_iostat(self):
         """
         Tests successful return of iostat function
@@ -217,7 +239,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             )
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_list_parsable(self):
         """
         Tests successful return of list function with parsable output
@@ -266,7 +288,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             res = OrderedDict(OrderedDict([("size", "1.81T")]))
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_get_parsable(self):
         """
         Tests successful return of get function with parsable output
@@ -283,7 +305,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             res = OrderedDict(OrderedDict([("size", 1990116046274)]))
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_get_whitespace(self):
         """
         Tests successful return of get function with a string with whitespaces
@@ -300,7 +322,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             res = OrderedDict(OrderedDict([("comment", "my testing pool")]))
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_scrub_start(self):
         """
         Tests start of scrub
@@ -319,7 +341,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             res = OrderedDict(OrderedDict([("scrubbing", True)]))
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_scrub_pause(self):
         """
         Tests pause of scrub
@@ -338,7 +360,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             res = OrderedDict(OrderedDict([("scrubbing", False)]))
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_scrub_stop(self):
         """
         Tests pauze of scrub
@@ -374,7 +396,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             res = OrderedDict([("split", True)])
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_split_exist_new(self):
         """
         Tests split on exising new pool
@@ -416,7 +438,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             )
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_split_not_mirror(self):
         """
         Tests split on source pool is not a mirror
@@ -438,7 +460,8 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
                     ("split", False),
                     (
                         "error",
-                        "Unable to split datapool: Source pool must be composed only of mirrors",
+                        "Unable to split datapool: Source pool must be composed only of"
+                        " mirrors",
                     ),
                 ]
             )
@@ -531,7 +554,9 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
                     ("labelcleared", False),
                     (
                         "error",
-                        "use 'force=True' to override the following error:\n/dev/rdsk/c0t0d0 is a member of exported pool \"mypool\"",
+                        "use 'force=True' to override the following"
+                        " error:\n/dev/rdsk/c0t0d0 is a member of exported pool"
+                        ' "mypool"',
                     ),
                 ]
             )
@@ -562,9 +587,10 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
         """
         ret = {}
         ret["stdout"] = ""
-        ret[
-            "stderr"
-        ] = "/vdisks/disk0: initialized 10424320 of 67108864 bytes: No space left on device"
+        ret["stderr"] = (
+            "/vdisks/disk0: initialized 10424320 of 67108864 bytes: No space left on"
+            " device"
+        )
         ret["retcode"] = 1
         mock_cmd = MagicMock(return_value=ret)
 
@@ -581,7 +607,8 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
                             [
                                 (
                                     "/vdisks/disk0",
-                                    " initialized 10424320 of 67108864 bytes: No space left on device",
+                                    " initialized 10424320 of 67108864 bytes: No space"
+                                    " left on device",
                                 ),
                             ]
                         ),
@@ -607,7 +634,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             res = OrderedDict([("exported", True)])
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_export_nopool(self):
         """
         Tests export when the pool does not exists
@@ -627,7 +654,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             )
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_import_success(self):
         """
         Tests import
@@ -654,7 +681,8 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
         ret["stderr"] = "\n".join(
             [
                 "cannot import 'mypool': a pool with that name already exists",
-                "use the form 'zpool import <pool | id> <newpool>' to give it a new name",
+                "use the form 'zpool import <pool | id> <newpool>' to give it a new"
+                " name",
             ]
         )
         ret["retcode"] = 1
@@ -669,7 +697,9 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
                     ("imported", False),
                     (
                         "error",
-                        "cannot import 'mypool': a pool with that name already exists\nuse the form 'zpool import <pool | id> <newpool>' to give it a new name",
+                        "cannot import 'mypool': a pool with that name already"
+                        " exists\nuse the form 'zpool import <pool | id> <newpool>' to"
+                        " give it a new name",
                     ),
                 ]
             )
@@ -697,7 +727,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             )
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_online_success(self):
         """
         Tests online
@@ -801,7 +831,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             )
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_reguid_success(self):
         """
         Tests reguid
@@ -819,7 +849,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             res = OrderedDict([("reguided", True)])
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_reguid_nopool(self):
         """
         Tests reguid with missing pool
@@ -839,7 +869,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             )
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_reopen_success(self):
         """
         Tests reopen
@@ -912,7 +942,7 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             )
             self.assertEqual(ret, res)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_history_success(self):
         """
         Tests history
@@ -922,7 +952,8 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
             [
                 "History for 'mypool':",
                 "2018-01-18.16:56:12 zpool create -f mypool /dev/rdsk/c0t0d0",
-                "2018-01-19.16:01:55 zpool attach -f mypool /dev/rdsk/c0t0d0 /dev/rdsk/c0t0d1",
+                "2018-01-19.16:01:55 zpool attach -f mypool /dev/rdsk/c0t0d0"
+                " /dev/rdsk/c0t0d1",
             ]
         )
         ret["stderr"] = ""
@@ -945,7 +976,8 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
                                 ),
                                 (
                                     "2018-01-19.16:01:55",
-                                    "zpool attach -f mypool /dev/rdsk/c0t0d0 /dev/rdsk/c0t0d1",
+                                    "zpool attach -f mypool /dev/rdsk/c0t0d0"
+                                    " /dev/rdsk/c0t0d1",
                                 ),
                             ]
                         ),
@@ -1027,7 +1059,8 @@ class ZpoolTestCase(TestCase, LoaderModuleMockMixin):
                     ("cleared", False),
                     (
                         "error",
-                        "cannot clear errors for /dev/rdsk/c0t0d0: no such device in pool",
+                        "cannot clear errors for /dev/rdsk/c0t0d0: no such device in"
+                        " pool",
                     ),
                 ]
             )
