@@ -1,33 +1,24 @@
-# -*- coding: utf-8 -*-
 """
     :codeauthor: Bo Maryniuk <bo@suse.de>
 """
 
-# Import Python Libs
-from __future__ import absolute_import
 
+import configparser
+import io
 import os
 from xml.dom import minidom
 
 import salt.modules.pkg_resource as pkg_resource
 import salt.modules.zypperpkg as zypper
-
-# Import Salt libs
 import salt.utils.files
 import salt.utils.pkg
 from salt.exceptions import CommandExecutionError
-from salt.ext import six
-
-# Import 3rd-party libs
-from salt.ext.six.moves import configparser
-
-# Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, Mock, call, patch
 from tests.support.unit import TestCase
 
 
-class ZyppCallMock(object):
+class ZyppCallMock:
     def __init__(self, return_value=None):
         self.__return_value = return_value
 
@@ -124,7 +115,7 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
         :return:
         """
 
-        class RunSniffer(object):
+        class RunSniffer:
             def __init__(self, stdout=None, stderr=None, retcode=None):
                 self.calls = list()
                 self._stdout = stdout or ""
@@ -145,7 +136,7 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
             self.assertEqual(zypper.__zypper__.call("foo"), stdout_xml_snippet)
             self.assertEqual(len(sniffer.calls), 1)
 
-            zypper.__zypper__.call("bar")
+            zypper.__zypper__.call("--no-refresh", "bar")
             self.assertEqual(len(sniffer.calls), 2)
             self.assertEqual(
                 sniffer.calls[0]["args"][0],
@@ -198,7 +189,10 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
             )
 
         # Test exceptions
-        stdout_xml_snippet = '<?xml version="1.0"?><stream><message type="error">Booya!</message></stream>'
+        stdout_xml_snippet = (
+            '<?xml version="1.0"?><stream><message'
+            ' type="error">Booya!</message></stream>'
+        )
         sniffer = RunSniffer(stdout=stdout_xml_snippet, retcode=1)
         with patch.dict("salt.modules.zypperpkg.__salt__", {"cmd.run_all": sniffer}):
             with self.assertRaisesRegex(
@@ -237,9 +231,8 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
         ):
             with self.assertRaisesRegex(
                 CommandExecutionError,
-                "^Zypper command failure: Some handled zypper internal error{0}Another zypper internal error$".format(
-                    os.linesep
-                ),
+                "^Zypper command failure: Some handled zypper internal error{}Another"
+                " zypper internal error$".format(os.linesep),
             ):
                 zypper.list_upgrades(refresh=False)
 
@@ -316,7 +309,7 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
                     "--no-refresh",
                     "--disable-repositories",
                     "products",
-                    u"-i",
+                    "-i",
                 ],
                 env={"ZYPP_READONLY_HACK": "1"},
                 output_loglevel="trace",
@@ -338,14 +331,9 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
                     "eol_t",
                     "registerrelease",
                 ]:
-                    if six.PY3:
-                        self.assertCountEqual(
-                            test_data[kwd], [prod.get(kwd) for prod in products]
-                        )
-                    else:
-                        self.assertEqual(
-                            test_data[kwd], sorted([prod.get(kwd) for prod in products])
-                        )
+                    self.assertCountEqual(
+                        test_data[kwd], [prod.get(kwd) for prod in products]
+                    )
                 cmd_run_all.assert_has_calls([mock_call])
 
     def test_refresh_db(self):
@@ -357,7 +345,8 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
             "Repository 'openSUSE-Leap-42.1-Update' is up to date.",
             "Retrieving repository 'openSUSE-Leap-42.1-Update-Non-Oss' metadata",
             "Forcing building of repository cache",
-            "Building repository 'openSUSE-Leap-42.1-Update-Non-Oss' cache ..........[done]",
+            "Building repository 'openSUSE-Leap-42.1-Update-Non-Oss' cache"
+            " ..........[done]",
             "Building repository 'salt-dev' cache",
             "All repositories have been refreshed.",
         ]
@@ -394,7 +383,9 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
             "virgo-dummy": {
                 "build_date": "2015-07-09T10:55:19Z",
                 "vendor": "openSUSE Build Service",
-                "description": "This is the Virgo dummy package used for testing SUSE Manager",
+                "description": (
+                    "This is the Virgo dummy package used for testing SUSE Manager"
+                ),
                 "license": "GPL-2.0",
                 "build_host": "sheep05",
                 "url": "http://www.suse.com",
@@ -405,7 +396,9 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
                 "install_date_time_t": 1456241517,
                 "summary": "Virgo dummy package",
                 "version": "1.0",
-                "signature": "DSA/SHA1, Thu Jul  9 08:55:33 2015, Key ID 27fa41bd8a7c64f9",
+                "signature": (
+                    "DSA/SHA1, Thu Jul  9 08:55:33 2015, Key ID 27fa41bd8a7c64f9"
+                ),
                 "release": "1.1",
                 "group": "Applications/System",
                 "arch": "noarch",
@@ -425,7 +418,9 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
                 "install_date_time_t": 1456241495,
                 "summary": "Secure Sockets and Transport Layer Security",
                 "version": "1.0.1i",
-                "signature": "RSA/SHA256, Wed Nov  4 22:21:34 2015, Key ID 70af9e8139db7c82",
+                "signature": (
+                    "RSA/SHA256, Wed Nov  4 22:21:34 2015, Key ID 70af9e8139db7c82"
+                ),
                 "release": "34.1",
                 "group": "Productivity/Networking/Security",
                 "packager": "https://www.suse.com/",
@@ -476,7 +471,9 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
                 {
                     "build_date": "2015-07-09T10:55:19Z",
                     "vendor": "openSUSE Build Service",
-                    "description": "This is the Virgo dummy package used for testing SUSE Manager",
+                    "description": (
+                        "This is the Virgo dummy package used for testing SUSE Manager"
+                    ),
                     "license": "GPL-2.0",
                     "build_host": "sheep05",
                     "url": "http://www.suse.com",
@@ -487,7 +484,9 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
                     "install_date_time_t": 1456241517,
                     "summary": "Virgo dummy package",
                     "version": "1.0",
-                    "signature": "DSA/SHA1, Thu Jul  9 08:55:33 2015, Key ID 27fa41bd8a7c64f9",
+                    "signature": (
+                        "DSA/SHA1, Thu Jul  9 08:55:33 2015, Key ID 27fa41bd8a7c64f9"
+                    ),
                     "release": "1.1",
                     "group": "Applications/System",
                     "arch": "i686",
@@ -496,7 +495,9 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
                 {
                     "build_date": "2015-07-09T10:15:19Z",
                     "vendor": "openSUSE Build Service",
-                    "description": "This is the Virgo dummy package used for testing SUSE Manager",
+                    "description": (
+                        "This is the Virgo dummy package used for testing SUSE Manager"
+                    ),
                     "license": "GPL-2.0",
                     "build_host": "sheep05",
                     "url": "http://www.suse.com",
@@ -507,7 +508,9 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
                     "install_date_time_t": 14562415127,
                     "summary": "Virgo dummy package",
                     "version": "1.0",
-                    "signature": "DSA/SHA1, Thu Jul  9 08:55:33 2015, Key ID 27fa41bd8a7c64f9",
+                    "signature": (
+                        "DSA/SHA1, Thu Jul  9 08:55:33 2015, Key ID 27fa41bd8a7c64f9"
+                    ),
                     "release": "1.1",
                     "group": "Applications/System",
                     "arch": "x86_64",
@@ -529,7 +532,9 @@ class ZypperTestCase(TestCase, LoaderModuleMockMixin):
                     "install_date_time_t": 1456241495,
                     "summary": "Secure Sockets and Transport Layer Security",
                     "version": "1.0.1i",
-                    "signature": "RSA/SHA256, Wed Nov  4 22:21:34 2015, Key ID 70af9e8139db7c82",
+                    "signature": (
+                        "RSA/SHA256, Wed Nov  4 22:21:34 2015, Key ID 70af9e8139db7c82"
+                    ),
                     "release": "34.1",
                     "group": "Productivity/Networking/Security",
                     "packager": "https://www.suse.com/",
@@ -797,7 +802,7 @@ Use 'zypper repos' to get the list of defined repositories.
 Repository 'DUMMY' not found by its alias, number, or URI.
 """
 
-        class FailingZypperDummy(object):
+        class FailingZypperDummy:
             def __init__(self):
                 self.stdout = zypper_out
                 self.stderr = ""
@@ -892,6 +897,48 @@ Repository 'DUMMY' not found by its alias, number, or URI.
                 self.assertTrue(pkgs.get(pkg_name))
                 self.assertEqual(pkgs[pkg_name], pkg_version)
 
+    def test_list_pkgs_no_context(self):
+        """
+        Test packages listing.
+
+        :return:
+        """
+
+        def _add_data(data, key, value):
+            data.setdefault(key, []).append(value)
+
+        rpm_out = [
+            "protobuf-java_|-(none)_|-2.6.1_|-3.1.develHead_|-noarch_|-(none)_|-1499257756",
+            "yast2-ftp-server_|-(none)_|-3.1.8_|-8.1_|-x86_64_|-(none)_|-1499257798",
+            "jose4j_|-(none)_|-0.4.4_|-2.1.develHead_|-noarch_|-(none)_|-1499257756",
+            "apache-commons-cli_|-(none)_|-1.2_|-1.233_|-noarch_|-(none)_|-1498636510",
+            "jakarta-commons-discovery_|-(none)_|-0.4_|-129.686_|-noarch_|-(none)_|-1498636511",
+            "susemanager-build-keys-web_|-(none)_|-12.0_|-5.1.develHead_|-noarch_|-(none)_|-1498636510",
+            "gpg-pubkey_|-(none)_|-39db7c82_|-5847eb1f_|-(none)_|-(none)_|-1519203802",
+            "gpg-pubkey_|-(none)_|-8a7c64f9_|-5aaa93ca_|-(none)_|-(none)_|-1529925595",
+            "kernel-default_|-(none)_|-4.4.138_|-94.39.1_|-x86_64_|-(none)_|-1529936067",
+            "kernel-default_|-(none)_|-4.4.73_|-5.1_|-x86_64_|-(none)_|-1503572639",
+            "perseus-dummy_|-(none)_|-1.1_|-1.1_|-i586_|-(none)_|-1529936062",
+        ]
+        with patch.dict(zypper.__grains__, {"osarch": "x86_64"}), patch.dict(
+            zypper.__salt__,
+            {"cmd.run": MagicMock(return_value=os.linesep.join(rpm_out))},
+        ), patch.dict(zypper.__salt__, {"pkg_resource.add_pkg": _add_data}), patch.dict(
+            zypper.__salt__,
+            {"pkg_resource.format_pkg_list": pkg_resource.format_pkg_list},
+        ), patch.dict(
+            zypper.__salt__, {"pkg_resource.stringify": MagicMock()}
+        ), patch.object(
+            zypper, "_list_pkgs_from_context"
+        ) as list_pkgs_context_mock:
+            pkgs = zypper.list_pkgs(versions_as_list=True, use_context=False)
+            list_pkgs_context_mock.assert_not_called()
+            list_pkgs_context_mock.reset_mock()
+
+            pkgs = zypper.list_pkgs(versions_as_list=True, use_context=False)
+            list_pkgs_context_mock.assert_not_called()
+            list_pkgs_context_mock.reset_mock()
+
     def test_list_pkgs_with_attr(self):
         """
         Test packages listing with the attr parameter
@@ -1083,10 +1130,7 @@ Repository 'DUMMY' not found by its alias, number, or URI.
                 ],
             }
             for pkgname, pkginfo in pkgs.items():
-                if six.PY3:
-                    self.assertCountEqual(pkginfo, expected_pkg_list[pkgname])
-                else:
-                    self.assertItemsEqual(pkginfo, expected_pkg_list[pkgname])
+                self.assertCountEqual(pkginfo, expected_pkg_list[pkgname])
 
     def test_list_patches(self):
         """
@@ -1446,7 +1490,7 @@ Repository 'DUMMY' not found by its alias, number, or URI.
         :return:
         """
 
-        class ListPackages(object):
+        class ListPackages:
             def __init__(self):
                 self._packages = ["vim", "pico"]
                 self._pkgs = {
@@ -1491,7 +1535,7 @@ Repository 'DUMMY' not found by its alias, number, or URI.
         """
         repos_cfg = configparser.ConfigParser()
         for cfg in ["zypper-repo-1.cfg", "zypper-repo-2.cfg"]:
-            repos_cfg.readfp(six.moves.StringIO(get_test_data(cfg)))
+            repos_cfg.readfp(io.StringIO(get_test_data(cfg)))
 
         for alias in repos_cfg.sections():
             r_info = zypper._get_repo_info(alias, repos_cfg=repos_cfg)
@@ -1884,7 +1928,7 @@ Repository 'DUMMY' not found by its alias, number, or URI.
         """
         _zpr = MagicMock()
         _zpr.nolock.xml.call = MagicMock(return_value=minidom.parseString(xmldoc))
-        assert isinstance(zypper.Wildcard(_zpr)("libzypp", "*.1"), six.string_types)
+        assert isinstance(zypper.Wildcard(_zpr)("libzypp", "*.1"), str)
 
     def test_wildcard_to_query_condition_preservation(self):
         """
@@ -1904,14 +1948,14 @@ Repository 'DUMMY' not found by its alias, number, or URI.
 
         for op in zypper.Wildcard.Z_OP:
             assert zypper.Wildcard(_zpr)(
-                "libzypp", "{0}*.1".format(op)
-            ) == "{0}17.2.6-27.9.1".format(op)
+                "libzypp", "{}*.1".format(op)
+            ) == "{}17.2.6-27.9.1".format(op)
 
         # Auto-fix feature: moves operator from end to front
         for op in zypper.Wildcard.Z_OP:
             assert zypper.Wildcard(_zpr)(
-                "libzypp", "16*{0}".format(op)
-            ) == "{0}16.2.5-25.1".format(op)
+                "libzypp", "16*{}".format(op)
+            ) == "{}16.2.5-25.1".format(op)
 
     def test_wildcard_to_query_unsupported_operators(self):
         """
@@ -1930,7 +1974,7 @@ Repository 'DUMMY' not found by its alias, number, or URI.
         _zpr.nolock.xml.call = MagicMock(return_value=minidom.parseString(xmldoc))
         with self.assertRaises(CommandExecutionError):
             for op in [">>", "==", "<<", "+"]:
-                zypper.Wildcard(_zpr)("libzypp", "{0}*.1".format(op))
+                zypper.Wildcard(_zpr)("libzypp", "{}*.1".format(op))
 
     @patch("salt.modules.zypperpkg._get_visible_patterns")
     def test__get_installed_patterns(self, get_visible_patterns):
@@ -2005,3 +2049,17 @@ pattern() = package-c"""
         with patch.dict(zypper.__context__, context):
             zypper._clean_cache()
             self.assertEqual(zypper.__context__, {"pkg.other_data": None})
+
+    def test_services_need_restart(self):
+        """
+        Test that zypper ps is used correctly to list services that need to
+        be restarted.
+        """
+        expected = ["salt-minion", "firewalld"]
+        zypper_output = "salt-minion\nfirewalld"
+        zypper_mock = Mock()
+        zypper_mock(root=None).nolock.call = Mock(return_value=zypper_output)
+
+        with patch("salt.modules.zypperpkg.__zypper__", zypper_mock):
+            assert zypper.services_need_restart() == expected
+            zypper_mock(root=None).nolock.call.assert_called_with("ps", "-sss")
