@@ -1,12 +1,4 @@
-# -*- coding: utf-8 -*-
-
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import Salt Libs
 import salt.pillar.pepa as pepa
-
-# Import Salt Testing libs
 from tests.support.unit import TestCase
 
 try:
@@ -17,7 +9,6 @@ except ImportError:
 
 class PepaPillarTestCase(TestCase):
     def test_repeated_keys(self):
-        # fmt: off
         expected_result = {
             "foo": {
                 "bar": {
@@ -26,10 +17,11 @@ class PepaPillarTestCase(TestCase):
                 },
             },
         }
-        data = OrderedDict([
-            ('foo..bar..foo', True),
-            ('foo..bar..baz', True),
-        ])
-        # fmt: on
+        data = OrderedDict(
+            [
+                ("foo..bar..foo", True),
+                ("foo..bar..baz", True),
+            ]
+        )
         result = pepa.key_value_to_tree(data)
         self.assertDictEqual(result, expected_result)
