@@ -1,8 +1,3 @@
-# -*- coding: utf-8 -*-
-
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import salt.utils.stringutils
 from salt.pillar.pillar_ldap import _config
 from tests.support.unit import TestCase
