@@ -130,7 +130,7 @@ class InitTestCase(TestCase, LoaderModuleMockMixin):
                 esxdatacenter.init(opts)
         self.assertEqual(
             excinfo.exception.strerror,
-            "Mechanism is set to 'sspi', but no " "'domain' key found in proxy config.",
+            "Mechanism is set to 'sspi', but no 'domain' key found in proxy config.",
         )
 
     def test_no_principal(self):
@@ -143,8 +143,7 @@ class InitTestCase(TestCase, LoaderModuleMockMixin):
                 esxdatacenter.init(opts)
         self.assertEqual(
             excinfo.exception.strerror,
-            "Mechanism is set to 'sspi', but no "
-            "'principal' key found in proxy config.",
+            "Mechanism is set to 'sspi', but no 'principal' key found in proxy config.",
         )
 
     def test_find_credentials(self):
