@@ -23,7 +23,8 @@ class ElasticSearchReturnerTestCase(TestCase, LoaderModuleMockMixin):
         result = elasticsearch_return.__virtual__()
         expected = (
             False,
-            "Elasticsearch module not availble.  Check that the elasticsearch library is installed.",
+            "Elasticsearch module not availble.  Check that the elasticsearch library"
+            " is installed.",
         )
         self.assertEqual(expected, result)
 
