@@ -65,7 +65,13 @@ STATE_APPLY_RET = {
 }
 
 
-def _mocked_func_named(name, names=("Fred", "Swen",)):
+def _mocked_func_named(
+    name,
+    names=(
+        "Fred",
+        "Swen",
+    ),
+):
     """
     Mocked function with named defaults.
 
@@ -128,6 +134,34 @@ class ModuleStateTest(TestCase, LoaderModuleMockMixin):
         if ret["comment"] != "Unavailable function: {}.".format(CMD) or ret["result"]:
             self.fail("module.run did not fail as expected: {}".format(ret))
 
+    def test_run_module_not_available_testmode(self):
+        """
+        Tests the return of module.run state when the module function is not available
+        when run with test=True
+        :return:
+        """
+        with patch.dict(module.__salt__, {}, clear=True), patch.dict(
+            module.__opts__, {"test": True, "use_superseded": ["module.run"]}
+        ):
+            ret = module.run(**{CMD: None})
+        if (
+            ret["comment"] != "Unavailable function: {}.".format(CMD)
+            or ret["result"] is not False
+        ):
+            self.fail("module.run did not fail as expected: {}".format(ret))
+
+    def test_run_module_noop(self):
+        """
+        Tests the return of module.run state when no module function is provided
+        :return:
+        """
+        with patch.dict(module.__salt__, {}, clear=True), patch.dict(
+            module.__opts__, {"test": True, "use_superseded": ["module.run"]}
+        ):
+            ret = module.run()
+        if ret["comment"] != "No function provided." or ret["result"] is not False:
+            self.fail("module.run did not fail as expected: {}".format(ret))
+
     def test_module_run_hidden_varargs(self):
         """
         Tests the return of module.run state when hidden varargs are used with
@@ -150,7 +184,7 @@ class ModuleStateTest(TestCase, LoaderModuleMockMixin):
             ret = module.run(**{CMD: None})
         if (
             ret["comment"] != "Function {} to be executed.".format(CMD)
-            or not ret["result"]
+            or ret["result"] is not None
         ):
             self.fail("module.run failed: {}".format(ret))
 
@@ -223,9 +257,8 @@ class ModuleStateTest(TestCase, LoaderModuleMockMixin):
             module_function = module.__salt__[CMD].__name__
         self.assertEqual(
             ret["comment"],
-            (
-                "'{}' failed: {}() got an unexpected keyword argument "
-                "'foo'".format(CMD, module_function)
+            "'{}' failed: {}() got an unexpected keyword argument 'foo'".format(
+                CMD, module_function
             ),
         )
         self.assertFalse(ret["result"])
@@ -299,7 +332,10 @@ class ModuleStateTest(TestCase, LoaderModuleMockMixin):
             0,
             "a",
             "",
-            (1, 2,),
+            (
+                1,
+                2,
+            ),
             (),
             [1, 2],
             [],
@@ -329,9 +365,9 @@ class ModuleStateTest(TestCase, LoaderModuleMockMixin):
         ), patch.dict(
             module.__salt__,
             {
-                "first": _mocked_none_return,
-                "second": _mocked_none_return,
-                "third": _mocked_none_return,
+                "first.one": _mocked_none_return,
+                "second.one": _mocked_none_return,
+                "third.one": _mocked_none_return,
             },
             clear=True,
         ):
