@@ -1,35 +1,24 @@
-# -*- coding: utf-8 -*-
 """
-    :codeauthor: Pedro Algarvio (pedro@algarvio.me)
-
-
-    tests.unit.states.pip_test
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~
+tests.unit.states.pip_test
+~~~~~~~~~~~~~~~~~~~~~~~~~~
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import os
 import subprocess
 import sys
 
+import pytest
 import salt.states.pip_state as pip_state
 import salt.utils.path
-
-# Import salt libs
 import salt.version
 from salt.modules.virtualenv_mod import KNOWN_BINARY_NAMES
-from tests.support.helpers import VirtualEnv, dedent, requires_network, slowTest
-
-# Import Salt Testing libs
+from tests.support.helpers import VirtualEnv, dedent
 from tests.support.mixins import LoaderModuleMockMixin, SaltReturnAssertsMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import TestCase, skipIf
 
-# Import 3rd-party libs
 try:
     import pip
 
@@ -193,12 +182,14 @@ class PipStateTest(TestCase, SaltReturnAssertsMixin, LoaderModuleMockMixin):
                 return_value={
                     "retcode": 0,
                     "stderr": "",
-                    "stdout": "Downloading/unpacking https://pypi.python.org/packages"
-                    "/source/S/SaltTesting/SaltTesting-0.5.0.tar.gz\n  "
-                    "Downloading SaltTesting-0.5.0.tar.gz\n  Running "
-                    "setup.py egg_info for package from "
-                    "https://pypi.python.org/packages/source/S/SaltTesting/"
-                    "SaltTesting-0.5.0.tar.gz\n    \nCleaning up...",
+                    "stdout": (
+                        "Downloading/unpacking https://pypi.python.org/packages"
+                        "/source/S/SaltTesting/SaltTesting-0.5.0.tar.gz\n  "
+                        "Downloading SaltTesting-0.5.0.tar.gz\n  Running "
+                        "setup.py egg_info for package from "
+                        "https://pypi.python.org/packages/source/S/SaltTesting/"
+                        "SaltTesting-0.5.0.tar.gz\n    \nCleaning up..."
+                    ),
                 }
             )
             with patch.dict(
@@ -252,7 +243,8 @@ class PipStateTest(TestCase, SaltReturnAssertsMixin, LoaderModuleMockMixin):
             ):
                 with patch.dict(pip_state.__opts__, {"test": False}):
                     ret = pip_state.installed(
-                        "arbitrary ID that should be ignored due to requirements specified",
+                        "arbitrary ID that should be ignored due to requirements"
+                        " specified",
                         requirements="/tmp/non-existing-requirements.txt",
                     )
                     self.assertSaltTrueReturn({"test": ret})
@@ -292,18 +284,14 @@ class PipStateTest(TestCase, SaltReturnAssertsMixin, LoaderModuleMockMixin):
 
         site_pkgs = "/tmp/pip-env/lib/python3.7/site-packages"
         check_stdout = [
-            (
-                "Looking in indexes: https://custom-pypi-url.org,"
-                "https://pypi.org/simple/\nRequirement already satisfied: pep8 in {1}"
-                "(from -r /tmp/files/prod/{0} (line 1)) (1.7.1)".format(
-                    req_filename, site_pkgs
-                )
+            "Looking in indexes: https://custom-pypi-url.org,"
+            "https://pypi.org/simple/\nRequirement already satisfied: pep8 in {1}"
+            "(from -r /tmp/files/prod/{0} (line 1)) (1.7.1)".format(
+                req_filename, site_pkgs
             ),
-            (
-                "Requirement already satisfied: pep8 in {1}"
-                "(from -r /tmp/files/prod/{0} (line1)) (1.7.1)".format(
-                    req_filename, site_pkgs
-                )
+            "Requirement already satisfied: pep8 in {1}"
+            "(from -r /tmp/files/prod/{0} (line1)) (1.7.1)".format(
+                req_filename, site_pkgs
             ),
         ]
         pip_version = pip.__version__
@@ -333,17 +321,16 @@ class PipStateTest(TestCase, SaltReturnAssertsMixin, LoaderModuleMockMixin):
 
         site_pkgs = "/tmp/pip-env/lib/python3.7/site-packages"
         check_stdout = [
-            (
-                "Looking in indexes: https://custom-pypi-url.org,"
-                "https://pypi.org/simple/\nCollecting pep8\n  Using cached"
-                "https://custom-pypi-url.org//packages/42/3f/669429cef5acb4/pep8-1.7.1-py2.py3-none-any.whl"
-                " (41 kB)\nInstalling collected packages: pep8\nSuccessfully installed pep8-1.7.1"
-            ),
-            (
-                "Collecting pep8\n  Using cached"
-                "https://custom-pypi-url.org//packages/42/3f/669429cef5acb4/pep8-1.7.1-py2.py3-none-any.whl"
-                " (41 kB)\nInstalling collected packages: pep8\nSuccessfully installed pep8-1.7.1"
-            ),
+            "Looking in indexes:"
+            " https://custom-pypi-url.org,https://pypi.org/simple/\nCollecting pep8\n "
+            " Using"
+            " cachedhttps://custom-pypi-url.org//packages/42/3f/669429cef5acb4/pep8-1.7.1-py2.py3-none-any.whl"
+            " (41 kB)\nInstalling collected packages: pep8\nSuccessfully installed"
+            " pep8-1.7.1",
+            "Collecting pep8\n  Using"
+            " cachedhttps://custom-pypi-url.org//packages/42/3f/669429cef5acb4/pep8-1.7.1-py2.py3-none-any.whl"
+            " (41 kB)\nInstalling collected packages: pep8\nSuccessfully installed"
+            " pep8-1.7.1",
         ]
 
         pip_version = pip.__version__
@@ -356,7 +343,7 @@ class PipStateTest(TestCase, SaltReturnAssertsMixin, LoaderModuleMockMixin):
                     ret = pip_state.installed(name="", requirements=req_filename)
                     self.assertSaltTrueReturn({"test": ret})
                     assert (
-                        "Successfully processed requirements file {0}.".format(
+                        "Successfully processed requirements file {}.".format(
                             req_filename
                         )
                         == ret["comment"]
@@ -419,9 +406,9 @@ class PipStateUtilsTest(TestCase):
 @skipIf(
     salt.utils.path.which_bin(KNOWN_BINARY_NAMES) is None, "virtualenv not installed"
 )
-@requires_network()
+@pytest.mark.requires_network
 class PipStateInstallationErrorTest(TestCase):
-    @slowTest
+    @pytest.mark.slow_test
     def test_importable_installation_error(self):
         extra_requirements = []
         for name, version in salt.version.dependency_information():
@@ -450,11 +437,11 @@ class PipStateInstallationErrorTest(TestCase):
             import salt.states.pip_state
             salt.states.pip_state.InstallationError
         except ImportError as exc:
-            traceback.print_exc(exc, file=sys.stdout)
+            traceback.print_exc(file=sys.stdout)
             sys.stdout.flush()
             sys.exit(1)
         except AttributeError as exc:
-            traceback.print_exc(exc, file=sys.stdout)
+            traceback.print_exc(file=sys.stdout)
             sys.stdout.flush()
             sys.exit(2)
         except Exception as exc:
@@ -492,7 +479,6 @@ class PipStateInstallationErrorTest(TestCase):
             for requirement, exception in failures.items():
                 errors += "pip{}: {}\n\n".format(requirement or "", exception)
             self.fail(
-                "Failed to get InstallationError exception under at least one pip version:\n{}".format(
-                    errors
-                )
+                "Failed to get InstallationError exception under at least one pip"
+                " version:\n{}".format(errors)
             )
