@@ -2,10 +2,10 @@ import os
 import shutil
 import tempfile
 
+import pytest
 import salt.utils.files
+import salt.utils.stringutils
 from salt import crypt
-from salt.ext import six
-from tests.support.helpers import slowTest
 from tests.support.mock import MagicMock, MockCall, mock_open, patch
 from tests.support.unit import TestCase, skipIf
 
@@ -23,7 +23,7 @@ except ImportError:
     HAS_PYCRYPTO_RSA = False
 if not HAS_PYCRYPTO_RSA:
     try:
-        from Crypto.PublicKey import RSA
+        from Crypto.PublicKey import RSA  # nosec
 
         HAS_PYCRYPTO_RSA = True
     except ImportError:
@@ -93,7 +93,7 @@ SIG = (
 @skipIf(not HAS_PYCRYPTO_RSA, "pycrypto >= 2.6 is not available")
 @skipIf(HAS_M2, "m2crypto is used by salt.crypt if installed")
 class CryptTestCase(TestCase):
-    @slowTest
+    @pytest.mark.slow_test
     def test_gen_keys(self):
         open_priv_wb = MockCall("/keydir{}keyname.pem".format(os.sep), "wb+")
         open_pub_wb = MockCall("/keydir{}keyname.pub".format(os.sep), "wb+")
@@ -123,7 +123,7 @@ class CryptTestCase(TestCase):
     @patch("os.chmod", MagicMock())
     @patch("os.chown", MagicMock(), create=True)
     @patch("os.access", MagicMock(return_value=True))
-    @slowTest
+    @pytest.mark.slow_test
     def test_gen_keys_with_passphrase(self):
         key_path = os.path.join(os.sep, "keydir")
         open_priv_wb = MockCall(os.path.join(key_path, "keyname.pem"), "wb+")
@@ -171,7 +171,7 @@ class M2CryptTestCase(TestCase):
     @patch("os.umask", MagicMock())
     @patch("os.chmod", MagicMock())
     @patch("os.access", MagicMock(return_value=True))
-    @slowTest
+    @pytest.mark.slow_test
     def test_gen_keys(self):
         with patch("M2Crypto.RSA.RSA.save_pem", MagicMock()) as save_pem:
             with patch("M2Crypto.RSA.RSA.save_pub_key", MagicMock()) as save_pub:
@@ -199,7 +199,7 @@ class M2CryptTestCase(TestCase):
     @patch("os.chmod", MagicMock())
     @patch("os.chown", MagicMock())
     @patch("os.access", MagicMock(return_value=True))
-    @slowTest
+    @pytest.mark.slow_test
     def test_gen_keys_with_passphrase(self):
         with patch("M2Crypto.RSA.RSA.save_pem", MagicMock()) as save_pem:
             with patch("M2Crypto.RSA.RSA.save_pub_key", MagicMock()) as save_pub:
@@ -232,12 +232,16 @@ class M2CryptTestCase(TestCase):
                     )
 
     def test_sign_message(self):
-        key = M2Crypto.RSA.load_key_string(six.b(PRIVKEY_DATA))
+        key = M2Crypto.RSA.load_key_string(
+            salt.utils.stringutils.to_bytes(PRIVKEY_DATA)
+        )
         with patch("salt.crypt.get_rsa_key", return_value=key):
             self.assertEqual(SIG, salt.crypt.sign_message("/keydir/keyname.pem", MSG))
 
     def test_sign_message_with_passphrase(self):
-        key = M2Crypto.RSA.load_key_string(six.b(PRIVKEY_DATA))
+        key = M2Crypto.RSA.load_key_string(
+            salt.utils.stringutils.to_bytes(PRIVKEY_DATA)
+        )
         with patch("salt.crypt.get_rsa_key", return_value=key):
             self.assertEqual(
                 SIG,
@@ -245,13 +249,18 @@ class M2CryptTestCase(TestCase):
             )
 
     def test_verify_signature(self):
-        with patch("salt.utils.files.fopen", mock_open(read_data=six.b(PUBKEY_DATA))):
+        with patch(
+            "salt.utils.files.fopen",
+            mock_open(read_data=salt.utils.stringutils.to_bytes(PUBKEY_DATA)),
+        ):
             self.assertTrue(crypt.verify_signature("/keydir/keyname.pub", MSG, SIG))
 
     def test_encrypt_decrypt_bin(self):
-        priv_key = M2Crypto.RSA.load_key_string(six.b(PRIVKEY_DATA))
+        priv_key = M2Crypto.RSA.load_key_string(
+            salt.utils.stringutils.to_bytes(PRIVKEY_DATA)
+        )
         pub_key = M2Crypto.RSA.load_pub_key_bio(
-            M2Crypto.BIO.MemoryBuffer(six.b(PUBKEY_DATA))
+            M2Crypto.BIO.MemoryBuffer(salt.utils.stringutils.to_bytes(PUBKEY_DATA))
         )
         encrypted = salt.crypt.private_encrypt(priv_key, b"salt")
         decrypted = salt.crypt.public_decrypt(pub_key, encrypted)
@@ -321,19 +330,27 @@ class TestM2CryptoRegression47124(TestCase):
     @skipIf(not HAS_M2, "Skip when m2crypto is not installed")
     def test_m2crypto_verify_bytes(self):
         message = salt.utils.stringutils.to_unicode("meh")
-        with patch("salt.utils.files.fopen", mock_open(read_data=six.b(PUBKEY_DATA))):
+        with patch(
+            "salt.utils.files.fopen",
+            mock_open(read_data=salt.utils.stringutils.to_bytes(PUBKEY_DATA)),
+        ):
             salt.crypt.verify_signature("/keydir/keyname.pub", message, self.SIGNATURE)
 
     @skipIf(not HAS_M2, "Skip when m2crypto is not installed")
     def test_m2crypto_verify_unicode(self):
         message = salt.utils.stringutils.to_bytes("meh")
-        with patch("salt.utils.files.fopen", mock_open(read_data=six.b(PUBKEY_DATA))):
+        with patch(
+            "salt.utils.files.fopen",
+            mock_open(read_data=salt.utils.stringutils.to_bytes(PUBKEY_DATA)),
+        ):
             salt.crypt.verify_signature("/keydir/keyname.pub", message, self.SIGNATURE)
 
     @skipIf(not HAS_M2, "Skip when m2crypto is not installed")
     def test_m2crypto_sign_bytes(self):
         message = salt.utils.stringutils.to_unicode("meh")
-        key = M2Crypto.RSA.load_key_string(six.b(PRIVKEY_DATA))
+        key = M2Crypto.RSA.load_key_string(
+            salt.utils.stringutils.to_bytes(PRIVKEY_DATA)
+        )
         with patch("salt.crypt.get_rsa_key", return_value=key):
             signature = salt.crypt.sign_message(
                 "/keydir/keyname.pem", message, passphrase="password"
@@ -343,7 +360,9 @@ class TestM2CryptoRegression47124(TestCase):
     @skipIf(not HAS_M2, "Skip when m2crypto is not installed")
     def test_m2crypto_sign_unicode(self):
         message = salt.utils.stringutils.to_bytes("meh")
-        key = M2Crypto.RSA.load_key_string(six.b(PRIVKEY_DATA))
+        key = M2Crypto.RSA.load_key_string(
+            salt.utils.stringutils.to_bytes(PRIVKEY_DATA)
+        )
         with patch("salt.crypt.get_rsa_key", return_value=key):
             signature = salt.crypt.sign_message(
                 "/keydir/keyname.pem", message, passphrase="password"
