@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     :codeauthor: Pedro Algarvio (pedro@algarvio.me)
 
@@ -9,18 +8,12 @@
     Test salt's "hacked" logging
 """
 
-# Import python libs
-from __future__ import absolute_import
 
+import io
 import logging
 
 from salt._logging.handlers import StreamHandler
-
-# Import Salt libs
 from salt._logging.impl import SaltLoggingClass
-from salt.ext.six.moves import StringIO
-
-# Import Salt Testing libs
 from tests.support.case import TestCase
 from tests.support.helpers import TstSuiteLoggingHandler
 
@@ -45,10 +38,10 @@ class TestLog(TestCase):
             # Let's create another log instance to trigger salt's logging class
             # calculations.
             try:
-                SaltLoggingClass("{0}.with_digits".format(__name__))
+                SaltLoggingClass("{}.with_digits".format(__name__))
             except Exception as err:  # pylint: disable=broad-except
                 raise AssertionError(
-                    "No exception should have been raised: {0}".format(err)
+                    "No exception should have been raised: {}".format(err)
                 )
 
         # Remove the testing handler
@@ -64,10 +57,10 @@ class TestLog(TestCase):
             # Let's create another log instance to trigger salt's logging class
             # calculations.
             try:
-                SaltLoggingClass("{0}.without_digits".format(__name__))
+                SaltLoggingClass("{}.without_digits".format(__name__))
             except Exception as err:  # pylint: disable=broad-except
                 raise AssertionError(
-                    "No exception should have been raised: {0}".format(err)
+                    "No exception should have been raised: {}".format(err)
                 )
 
             # Remove the testing handler
@@ -80,8 +73,8 @@ class TestLog(TestCase):
         log = SaltLoggingClass(__name__)
 
         # Only stream2 should contain the traceback
-        stream1 = StringIO()
-        stream2 = StringIO()
+        stream1 = io.StringIO()
+        stream2 = io.StringIO()
         handler1 = StreamHandler(stream1)
         handler2 = StreamHandler(stream2)
 
@@ -115,8 +108,8 @@ class TestLog(TestCase):
             log.removeHandler(handler2)
 
         # Both streams should contain the traceback
-        stream1 = StringIO()
-        stream2 = StringIO()
+        stream1 = io.StringIO()
+        stream2 = io.StringIO()
         handler1 = StreamHandler(stream1)
         handler2 = StreamHandler(stream2)
 
@@ -150,8 +143,8 @@ class TestLog(TestCase):
             log.removeHandler(handler2)
 
         # No streams should contain the traceback
-        stream1 = StringIO()
-        stream2 = StringIO()
+        stream1 = io.StringIO()
+        stream2 = io.StringIO()
         handler1 = StreamHandler(stream1)
         handler2 = StreamHandler(stream2)
 
