@@ -1,20 +1,13 @@
-# coding: utf-8
-
-# Import Python libs
-from __future__ import absolute_import
-
 import os
 import shutil
 import tempfile
 
+import pytest
 import salt.config
 import salt.spm
 import salt.utils.files
-from tests.support.helpers import destructiveTest
 from tests.support.mixins import AdaptedConfigurationTestCaseMixin
 from tests.support.mock import MagicMock, patch
-
-# Import Salt Testing libs
 from tests.support.unit import TestCase
 
 _F1 = {
@@ -45,7 +38,7 @@ _F1["contents"] = (
 )
 
 
-@destructiveTest
+@pytest.mark.destructive_test
 class SPMTestUserInterface(salt.spm.SPMUserInterface):
     """
     Unit test user interface to SPMClient
