@@ -1,25 +1,14 @@
-# -*- coding: utf-8 -*-
-
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import os
 
 import salt.utils.boto3mod as boto3mod
-
-# Import Salt libs
 import salt.utils.botomod as botomod
 from salt.exceptions import SaltInvocationError
-from salt.ext import six
 from salt.utils.versions import LooseVersion
-
-# Import Salt Testing libs
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import TestCase, skipIf
 
-# Import 3rd-party libs
 # pylint: disable=import-error
 try:
     import boto
@@ -125,7 +114,7 @@ def _has_required_boto3():
         else:
             return True
     except AttributeError as exc:
-        if "has no attribute '__version__'" not in six.text_type(exc):
+        if "has no attribute '__version__'" not in str(exc):
             raise
         return False
 
@@ -193,8 +182,9 @@ class BotoUtilsCacheIdTestCase(BotoUtilsTestCaseBase):
 @skipIf(HAS_MOTO is False, "The moto module must be installed.")
 @skipIf(
     _has_required_boto() is False,
-    "The boto module must be greater than"
-    " or equal to version {0}".format(required_boto_version),
+    "The boto module must be greater than or equal to version {}".format(
+        required_boto_version
+    ),
 )
 class BotoUtilsGetConnTestCase(BotoUtilsTestCaseBase):
     @mock_ec2
@@ -210,7 +200,7 @@ class BotoUtilsGetConnTestCase(BotoUtilsTestCaseBase):
     @mock_ec2
     def test_get_conn_with_no_auth_params_raises_invocation_error(self):
         with patch(
-            "boto.{0}.connect_to_region".format(service),
+            "boto.{}.connect_to_region".format(service),
             side_effect=boto.exception.NoAuthHandlerFound(),
         ):
             with self.assertRaises(SaltInvocationError):
@@ -219,7 +209,7 @@ class BotoUtilsGetConnTestCase(BotoUtilsTestCaseBase):
     @mock_ec2
     def test_get_conn_error_raises_command_execution_error(self):
         with patch(
-            "boto.{0}.connect_to_region".format(service),
+            "boto.{}.connect_to_region".format(service),
             side_effect=BotoServerError(400, "Mocked error", body=error_body),
         ):
             with self.assertRaises(BotoServerError):
@@ -235,8 +225,9 @@ class BotoUtilsGetConnTestCase(BotoUtilsTestCaseBase):
 @skipIf(HAS_BOTO is False, "The boto module must be installed.")
 @skipIf(
     _has_required_boto() is False,
-    "The boto module must be greater than"
-    " or equal to version {0}".format(required_boto_version),
+    "The boto module must be greater than or equal to version {}".format(
+        required_boto_version
+    ),
 )
 class BotoUtilsGetErrorTestCase(BotoUtilsTestCaseBase):
     def test_error_message(self):
@@ -275,14 +266,16 @@ class BotoUtilsGetErrorTestCase(BotoUtilsTestCaseBase):
 @skipIf(HAS_BOTO is False, "The boto module must be installed.")
 @skipIf(
     _has_required_boto() is False,
-    "The boto module must be greater than"
-    " or equal to version {0}".format(required_boto_version),
+    "The boto module must be greater than or equal to version {}".format(
+        required_boto_version
+    ),
 )
 @skipIf(HAS_BOTO3 is False, "The boto3 module must be installed.")
 @skipIf(
     _has_required_boto3() is False,
-    "The boto3 module must be greater than"
-    " or equal to version {0}".format(required_boto3_version),
+    "The boto3 module must be greater than or equal to version {}".format(
+        required_boto3_version
+    ),
 )
 class BotoBoto3CacheContextCollisionTest(BotoUtilsTestCaseBase):
     def test_context_conflict_between_boto_and_boto3_utils(self):
