@@ -1,12 +1,4 @@
-# -*- coding: utf-8 -*-
-
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import Salt libs
 import salt.utils.dictdiffer as dictdiffer
-
-# Import Salt Testing libs
 from tests.support.unit import TestCase
 
 NONE = dictdiffer.RecursiveDictDiffer.NONE_VALUE
