@@ -1,14 +1,5 @@
-# -*- coding: utf-8 -*-
-
-# Import python libs
-from __future__ import absolute_import, unicode_literals
-
 from salt.utils import dictdiffer
-
-# Import Salt libs
 from salt.utils.listdiffer import list_diff
-
-# Import Salt Testing libs
 from tests.support.unit import TestCase
 
 NONE = dictdiffer.RecursiveDictDiffer.NONE_VALUE
