@@ -7,7 +7,6 @@ import pytest
 import salt.exceptions
 import salt.utils.network as network
 from salt._compat import ipaddress
-from tests.support.helpers import slowTest
 from tests.support.mock import MagicMock, create_autospec, mock_open, patch
 from tests.support.unit import TestCase
 
@@ -902,7 +901,7 @@ class NetworkTestCase(TestCase):
             b"\xf8\xe7\xd6\xc5\xb4\xa3", network.mac_str_to_bytes("f8e7d6c5b4a3")
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_generate_minion_id_with_long_hostname(self):
         """
         Validate the fix for:
