@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import datetime
 import functools
 import io
@@ -8,16 +5,15 @@ import multiprocessing
 import os
 import signal
 import sys
+import tempfile
 import threading
 import time
 import warnings
 
+import pytest
 import salt.utils.platform
 import salt.utils.process
-from salt.ext import six
-from salt.ext.six.moves import range  # pylint: disable=import-error,redefined-builtin
 from salt.utils.versions import warn_until_date
-from tests.support.helpers import slowTest
 from tests.support.mock import patch
 from tests.support.unit import TestCase, skipIf
 
@@ -41,7 +37,7 @@ def die(func):
         name = func.__name__[5:]
 
         def _die():
-            salt.utils.process.appendproctitle("test_{0}".format(name))
+            salt.utils.process.appendproctitle("test_{}".format(name))
 
         attrname = "die_" + name
         setattr(self, attrname, _die)
@@ -61,7 +57,7 @@ def incr(func):
         name = func.__name__[5:]
 
         def _incr(counter, num):
-            salt.utils.process.appendproctitle("test_{0}".format(name))
+            salt.utils.process.appendproctitle("test_{}".format(name))
             for _ in range(0, num):
                 counter.value += 1
 
@@ -83,7 +79,7 @@ def spin(func):
         name = func.__name__[5:]
 
         def _spin():
-            salt.utils.process.appendproctitle("test_{0}".format(name))
+            salt.utils.process.appendproctitle("test_{}".format(name))
             while True:
                 time.sleep(1)
 
@@ -96,33 +92,25 @@ def spin(func):
 
 class TestProcessManager(TestCase):
     @spin
-    @slowTest
+    @pytest.mark.slow_test
     def test_basic(self):
         """
         Make sure that the process is alive 2s later
         """
         process_manager = salt.utils.process.ProcessManager()
+        self.addCleanup(process_manager.terminate)
         process_manager.add_process(self.spin_basic)
-        initial_pid = next(six.iterkeys(process_manager._process_map))
+        initial_pid = next(iter(process_manager._process_map.keys()))
         time.sleep(2)
         process_manager.check_children()
-        try:
-            assert initial_pid == next(six.iterkeys(process_manager._process_map))
-        finally:
-            process_manager.stop_restarting()
-            process_manager.kill_children()
-            time.sleep(0.5)
-            # Are there child processes still running?
-            if process_manager._process_map.keys():
-                process_manager.send_signal_to_processes(signal.SIGKILL)
-                process_manager.stop_restarting()
-                process_manager.kill_children()
+        assert initial_pid == next(iter(process_manager._process_map.keys()))
 
     @spin
     def test_kill(self):
         process_manager = salt.utils.process.ProcessManager()
+        self.addCleanup(process_manager.terminate)
         process_manager.add_process(self.spin_kill)
-        initial_pid = next(six.iterkeys(process_manager._process_map))
+        initial_pid = next(iter(process_manager._process_map.keys()))
         # kill the child
         if salt.utils.platform.is_windows():
             os.kill(initial_pid, signal.SIGTERM)
@@ -131,17 +119,7 @@ class TestProcessManager(TestCase):
         # give the OS time to give the signal...
         time.sleep(0.1)
         process_manager.check_children()
-        try:
-            assert initial_pid != next(six.iterkeys(process_manager._process_map))
-        finally:
-            process_manager.stop_restarting()
-            process_manager.kill_children()
-            time.sleep(0.5)
-            # Are there child processes still running?
-            if process_manager._process_map.keys():
-                process_manager.send_signal_to_processes(signal.SIGKILL)
-                process_manager.stop_restarting()
-                process_manager.kill_children()
+        assert initial_pid != next(iter(process_manager._process_map.keys()))
 
     @die
     def test_restarting(self):
@@ -149,47 +127,28 @@ class TestProcessManager(TestCase):
         Make sure that the process is alive 2s later
         """
         process_manager = salt.utils.process.ProcessManager()
+        self.addCleanup(process_manager.terminate)
         process_manager.add_process(self.die_restarting)
-        initial_pid = next(six.iterkeys(process_manager._process_map))
+        initial_pid = next(iter(process_manager._process_map.keys()))
         time.sleep(2)
         process_manager.check_children()
-        try:
-            assert initial_pid != next(six.iterkeys(process_manager._process_map))
-        finally:
-            process_manager.stop_restarting()
-            process_manager.kill_children()
-            time.sleep(0.5)
-            # Are there child processes still running?
-            if process_manager._process_map.keys():
-                process_manager.send_signal_to_processes(signal.SIGKILL)
-                process_manager.stop_restarting()
-                process_manager.kill_children()
+        assert initial_pid != next(iter(process_manager._process_map.keys()))
 
-    @skipIf(sys.version_info < (2, 7), "Needs > Py 2.7 due to bug in stdlib")
     @incr
     def test_counter(self):
         counter = multiprocessing.Value("i", 0)
         process_manager = salt.utils.process.ProcessManager()
+        self.addCleanup(process_manager.terminate)
         process_manager.add_process(self.incr_counter, args=(counter, 2))
         time.sleep(1)
         process_manager.check_children()
         time.sleep(1)
         # we should have had 2 processes go at it
-        try:
-            assert counter.value == 4
-        finally:
-            process_manager.stop_restarting()
-            process_manager.kill_children()
-            time.sleep(0.5)
-            # Are there child processes still running?
-            if process_manager._process_map.keys():
-                process_manager.send_signal_to_processes(signal.SIGKILL)
-                process_manager.stop_restarting()
-                process_manager.kill_children()
+        assert counter.value == 4
 
 
 class TestThreadPool(TestCase):
-    @slowTest
+    @pytest.mark.slow_test
     def test_basic(self):
         """
         Make sure the threadpool can do things
@@ -207,7 +166,7 @@ class TestThreadPool(TestCase):
         self.assertEqual(counter.value, 1)
         self.assertEqual(pool._job_queue.qsize(), 0)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_full_queue(self):
         """
         Make sure that a full threadpool acts as we expect
@@ -261,7 +220,7 @@ class TestProcessCallbacks(TestCase):
     def test_callbacks(self):
         "Validate Process call after fork and finalize methods"
         teardown_to_mock = "salt.log.setup.shutdown_multiprocessing_logging"
-        log_to_mock = "salt.utils.process.Process._setup_process_logging"
+        log_to_mock = "salt.log.setup.setup_multiprocessing_logging"
         with patch(teardown_to_mock) as ma, patch(log_to_mock) as mb:
             evt = multiprocessing.Event()
             proc = salt.utils.process.Process(target=self.process_target, args=(evt,))
@@ -275,14 +234,14 @@ class TestProcessCallbacks(TestCase):
 
         class MyProcess(salt.utils.process.Process):
             def __init__(self):
-                super(MyProcess, self).__init__()
+                super().__init__()
                 self.evt = multiprocessing.Event()
 
             def run(self):
                 self.evt.set()
 
         teardown_to_mock = "salt.log.setup.shutdown_multiprocessing_logging"
-        log_to_mock = "salt.utils.process.Process._setup_process_logging"
+        log_to_mock = "salt.log.setup.setup_multiprocessing_logging"
         with patch(teardown_to_mock) as ma, patch(log_to_mock) as mb:
             proc = MyProcess()
             proc.run()
@@ -291,6 +250,7 @@ class TestProcessCallbacks(TestCase):
         mb.assert_called()
 
 
+@skipIf(not HAS_PSUTIL, "Missing psutil")
 class TestSignalHandlingProcess(TestCase):
     @classmethod
     def Process(cls, pid):
@@ -348,7 +308,7 @@ class TestSignalHandlingProcess(TestCase):
             pass
 
     @skipIf(sys.platform.startswith("win"), "No os.fork on Windows")
-    @slowTest
+    @pytest.mark.slow_test
     def test_signal_processing_regression_test(self):
         evt = multiprocessing.Event()
         sh_proc = salt.utils.process.SignalHandlingProcess(
@@ -378,7 +338,7 @@ class TestSignalHandlingProcess(TestCase):
         p.join()
 
     @skipIf(sys.platform.startswith("win"), "Required signals not supported on windows")
-    @slowTest
+    @pytest.mark.slow_test
     def test_signal_processing_handle_signals_called(self):
         "Validate SignalHandlingProcess handles signals"
         # Gloobal event to stop all processes we're creating
@@ -394,7 +354,8 @@ class TestSignalHandlingProcess(TestCase):
 
         # Create a second process that should not respond to SIGINT or SIGTERM
         proc2 = multiprocessing.Process(
-            target=self.run_forever_target, args=(self.run_forever_sub_target, evt),
+            target=self.run_forever_target,
+            args=(self.run_forever_sub_target, evt),
         )
         proc2.start()
 
@@ -435,7 +396,7 @@ class TestSignalHandlingProcessCallbacks(TestCase):
         "Validate SignalHandlingProcess call after fork and finalize methods"
 
         teardown_to_mock = "salt.log.setup.shutdown_multiprocessing_logging"
-        log_to_mock = "salt.utils.process.Process._setup_process_logging"
+        log_to_mock = "salt.log.setup.setup_multiprocessing_logging"
         sig_to_mock = "salt.utils.process.SignalHandlingProcess._setup_signals"
         # Mock _setup_signals so we do not register one for this process.
         evt = multiprocessing.Event()
@@ -454,14 +415,14 @@ class TestSignalHandlingProcessCallbacks(TestCase):
 
         class MyProcess(salt.utils.process.SignalHandlingProcess):
             def __init__(self):
-                super(MyProcess, self).__init__()
+                super().__init__()
                 self.evt = multiprocessing.Event()
 
             def run(self):
                 self.evt.set()
 
         teardown_to_mock = "salt.log.setup.shutdown_multiprocessing_logging"
-        log_to_mock = "salt.utils.process.Process._setup_process_logging"
+        log_to_mock = "salt.log.setup.setup_multiprocessing_logging"
         sig_to_mock = "salt.utils.process.SignalHandlingProcess._setup_signals"
         # Mock _setup_signals so we do not register one for this process.
         with patch(sig_to_mock):
@@ -507,7 +468,7 @@ class TestProcessList(TestCase):
                 raise Exception("Process did not finishe before timeout")
             time.sleep(0.3)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_process_list_process(self):
         plist = salt.utils.process.SubprocessList()
         proc = multiprocessing.Process(target=null_target)
@@ -530,7 +491,7 @@ class TestProcessList(TestCase):
         plist.cleanup()
         assert thread not in plist.processes
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_process_list_cleanup(self):
         plist = salt.utils.process.SubprocessList()
         event = multiprocessing.Event()
@@ -599,7 +560,7 @@ class TestDeprecatedClassNames(TestCase):
                         "and instead use 'salt.utils.process.Process'. "
                         "'salt.utils.process.MultiprocessingProcess' will go away "
                         "after 2022-01-01.",
-                        six.text_type(recorded_warnings[0].message),
+                        str(recorded_warnings[0].message),
                     )
         finally:
             if proc is not None:
@@ -652,11 +613,12 @@ class TestDeprecatedClassNames(TestCase):
                         target=self.process_target
                     )
                     self.assertEqual(
-                        "Please stop using 'salt.utils.process.SignalHandlingMultiprocessingProcess' "
-                        "and instead use 'salt.utils.process.SignalHandlingProcess'. "
-                        "'salt.utils.process.SignalHandlingMultiprocessingProcess' will go away "
-                        "after 2022-01-01.",
-                        six.text_type(recorded_warnings[0].message),
+                        "Please stop using"
+                        " 'salt.utils.process.SignalHandlingMultiprocessingProcess' and"
+                        " instead use 'salt.utils.process.SignalHandlingProcess'."
+                        " 'salt.utils.process.SignalHandlingMultiprocessingProcess'"
+                        " will go away after 2022-01-01.",
+                        str(recorded_warnings[0].message),
                     )
         finally:
             if proc is not None:
@@ -674,9 +636,11 @@ class TestDeprecatedClassNames(TestCase):
             ):
                 with self.assertRaisesRegex(
                     RuntimeError,
-                    r"Please stop using 'salt.utils.process.SignalHandlingMultiprocessingProcess' "
+                    r"Please stop using"
+                    r" 'salt.utils.process.SignalHandlingMultiprocessingProcess' "
                     r"and instead use 'salt.utils.process.SignalHandlingProcess'. "
-                    r"'salt.utils.process.SignalHandlingMultiprocessingProcess' will go away "
+                    r"'salt.utils.process.SignalHandlingMultiprocessingProcess' will go"
+                    r" away "
                     r"after 2022-01-01. "
                     r"This warning\(now exception\) triggered on "
                     r"filename '(.*)test_process.py', line number ([\d]+), is "
@@ -751,6 +715,11 @@ class CMORProcessHelper:
 
 @skipIf(not HAS_PSUTIL, "Missing psutil")
 class TestGetProcessInfo(TestCase):
+    def setUp(self):
+        handle, self.cmor_test_file_path = tempfile.mkstemp()
+        os.close(handle)
+        self.addCleanup(os.unlink, self.cmor_test_file_path)
+
     def test_this_process(self):
         this_process_info = salt.utils.process.get_process_info()
 
@@ -771,109 +740,108 @@ class TestGetProcessInfo(TestCase):
 
     def test_random_processes(self):
         for _ in range(3):
-            with CMORProcessHelper("CMOR_TEST_FILE") as p1:
+            with CMORProcessHelper(self.cmor_test_file_path) as p1:
                 pid = p1.pid
                 self.assertIsInstance(salt.utils.process.get_process_info(pid), dict)
             self.assertIsNone(salt.utils.process.get_process_info(pid))
 
 
+@skipIf(not HAS_PSUTIL, "Missing psutil")
 class TestClaimMantleOfResponsibility(TestCase):
-    @skipIf(HAS_PSUTIL, "Has psutil")
+    def setUp(self):
+        handle, self.cmor_test_file_path = tempfile.mkstemp()
+        os.close(handle)
+        self.addCleanup(os.unlink, self.cmor_test_file_path)
+
     def test_simple_claim_no_psutil(self):
-        salt.utils.process.claim_mantle_of_responsibility("CMOR_TEST_FILE")
+        salt.utils.process.claim_mantle_of_responsibility(self.cmor_test_file_path)
 
-    @skipIf(not HAS_PSUTIL, "Missing psutil")
     def test_simple_claim(self):
-        try:
-            for _ in range(5):
-                self.assertTrue(
-                    salt.utils.process.claim_mantle_of_responsibility("CMOR_TEST_FILE")
-                )
-        finally:
-            os.remove("CMOR_TEST_FILE")
-
-    @skipIf(not HAS_PSUTIL, "Missing psutil")
-    def test_multiple_processes(self):
-        try:
-            with CMORProcessHelper("CMOR_TEST_FILE") as p1:
-                self.assertTrue(p1.claim())
-                self.assertFalse(
-                    salt.utils.process.claim_mantle_of_responsibility("CMOR_TEST_FILE")
-                )
-                with CMORProcessHelper("CMOR_TEST_FILE") as p2:
-                    for _ in range(3):
-                        self.assertFalse(p2.claim())
-                self.assertTrue(p1.claim())
-
-            with CMORProcessHelper("CMOR_TEST_FILE") as p1:
-                self.assertTrue(p1.claim())
-                self.assertFalse(
-                    salt.utils.process.claim_mantle_of_responsibility("CMOR_TEST_FILE")
-                )
-
+        for _ in range(5):
             self.assertTrue(
-                salt.utils.process.claim_mantle_of_responsibility("CMOR_TEST_FILE")
+                salt.utils.process.claim_mantle_of_responsibility(
+                    self.cmor_test_file_path
+                )
             )
-        finally:
-            os.remove("CMOR_TEST_FILE")
 
-
-class TestCheckMantleOfResponsibility(TestCase):
-    @skipIf(HAS_PSUTIL, "Has psutil")
-    def test_simple_claim_no_psutil(self):
-        try:
-            self.assertIsNone(
-                salt.utils.process.check_mantle_of_responsibility("CMOR_TEST_FILE")
-            )
-        finally:
-            os.remove("CMOR_TEST_FILE")
-
-    @skipIf(not HAS_PSUTIL, "Missing psutil")
-    def test_simple_claim(self):
-        try:
-            self.assertIsNone(
-                salt.utils.process.check_mantle_of_responsibility("CMOR_TEST_FILE")
-            )
-            salt.utils.process.claim_mantle_of_responsibility("CMOR_TEST_FILE")
-            pid = salt.utils.process.get_process_info()["pid"]
-            self.assertEqual(
-                pid, salt.utils.process.check_mantle_of_responsibility("CMOR_TEST_FILE")
-            )
-        finally:
-            os.remove("CMOR_TEST_FILE")
-
-    @skipIf(not HAS_PSUTIL, "Missing psutil")
     def test_multiple_processes(self):
-        try:
-            self.assertIsNone(
-                salt.utils.process.check_mantle_of_responsibility("CMOR_TEST_FILE")
+        with CMORProcessHelper(self.cmor_test_file_path) as p1:
+            self.assertTrue(p1.claim())
+            self.assertFalse(
+                salt.utils.process.claim_mantle_of_responsibility(
+                    self.cmor_test_file_path
+                )
+            )
+            with CMORProcessHelper(self.cmor_test_file_path) as p2:
+                for _ in range(3):
+                    self.assertFalse(p2.claim())
+            self.assertTrue(p1.claim())
+
+        with CMORProcessHelper(self.cmor_test_file_path) as p1:
+            self.assertTrue(p1.claim())
+            self.assertFalse(
+                salt.utils.process.claim_mantle_of_responsibility(
+                    self.cmor_test_file_path
+                )
             )
 
-            with CMORProcessHelper("CMOR_TEST_FILE") as p1:
-                self.assertTrue(p1.claim())
-                random_pid = salt.utils.process.check_mantle_of_responsibility(
-                    "CMOR_TEST_FILE"
+        self.assertTrue(
+            salt.utils.process.claim_mantle_of_responsibility(self.cmor_test_file_path)
+        )
+
+
+@skipIf(not HAS_PSUTIL, "Missing psutil")
+class TestCheckMantleOfResponsibility(TestCase):
+    def setUp(self):
+        handle, self.cmor_test_file_path = tempfile.mkstemp()
+        os.close(handle)
+        self.addCleanup(os.unlink, self.cmor_test_file_path)
+
+    def test_simple_claim_no_psutil(self):
+        self.assertIsNone(
+            salt.utils.process.check_mantle_of_responsibility(self.cmor_test_file_path)
+        )
+
+    def test_simple_claim(self):
+        self.assertIsNone(
+            salt.utils.process.check_mantle_of_responsibility(self.cmor_test_file_path)
+        )
+        salt.utils.process.claim_mantle_of_responsibility(self.cmor_test_file_path)
+        pid = salt.utils.process.get_process_info()["pid"]
+        self.assertEqual(
+            pid,
+            salt.utils.process.check_mantle_of_responsibility(self.cmor_test_file_path),
+        )
+
+    def test_multiple_processes(self):
+        self.assertIsNone(
+            salt.utils.process.check_mantle_of_responsibility(self.cmor_test_file_path)
+        )
+
+        with CMORProcessHelper(self.cmor_test_file_path) as p1:
+            self.assertTrue(p1.claim())
+            random_pid = salt.utils.process.check_mantle_of_responsibility(
+                self.cmor_test_file_path
+            )
+
+            self.assertIsInstance(random_pid, int)
+
+            with CMORProcessHelper(self.cmor_test_file_path) as p2:
+                for _ in range(3):
+                    self.assertFalse(p2.claim())
+                self.assertEqual(
+                    random_pid,
+                    salt.utils.process.check_mantle_of_responsibility(
+                        self.cmor_test_file_path
+                    ),
                 )
 
-                self.assertIsInstance(random_pid, int)
-
-                with CMORProcessHelper("CMOR_TEST_FILE") as p2:
-                    for _ in range(3):
-                        self.assertFalse(p2.claim())
-                    self.assertEqual(
-                        random_pid,
-                        salt.utils.process.check_mantle_of_responsibility(
-                            "CMOR_TEST_FILE"
-                        ),
-                    )
-
-            self.assertIsNone(
-                salt.utils.process.check_mantle_of_responsibility("CMOR_TEST_FILE")
-            )
-            salt.utils.process.claim_mantle_of_responsibility("CMOR_TEST_FILE")
-            pid = salt.utils.process.get_process_info()["pid"]
-            self.assertEqual(
-                pid, salt.utils.process.check_mantle_of_responsibility("CMOR_TEST_FILE")
-            )
-        finally:
-            os.remove("CMOR_TEST_FILE")
+        self.assertIsNone(
+            salt.utils.process.check_mantle_of_responsibility(self.cmor_test_file_path)
+        )
+        salt.utils.process.claim_mantle_of_responsibility(self.cmor_test_file_path)
+        pid = salt.utils.process.get_process_info()["pid"]
+        self.assertEqual(
+            pid,
+            salt.utils.process.check_mantle_of_responsibility(self.cmor_test_file_path),
+        )
