@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import random
 
+import pytest
 import salt.modules.cmdmod
 import salt.utils.platform
 import salt.utils.win_lgpo_auditpol as win_lgpo_auditpol
-from tests.support.helpers import slowTest
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.unit import TestCase, skipIf
@@ -35,7 +32,7 @@ class WinLgpoAuditpolTestCase(TestCase, LoaderModuleMockMixin):
             KeyError, win_lgpo_auditpol.get_settings, category="Fake Category"
         )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_get_setting(self):
         names = win_lgpo_auditpol._get_valid_names()
         for name in names:
@@ -58,9 +55,7 @@ class WinLgpoAuditpolTestCase(TestCase, LoaderModuleMockMixin):
                     value = random.choice(settings)
                     win_lgpo_auditpol.set_setting(name=name, value=value)
                     switches = win_lgpo_auditpol.settings[value]
-                    cmd = 'auditpol /set /subcategory:"{0}" {1}' "".format(
-                        name, switches
-                    )
+                    cmd = 'auditpol /set /subcategory:"{}" {}'.format(name, switches)
                     mock_set.assert_called_once_with(cmd=cmd, python_shell=True)
                     mock_set.reset_mock()
 
