@@ -1,12 +1,8 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, print_function, unicode_literals
-
+import pytest
 import salt.utils.stringutils
 import salt.utils.win_reg as win_reg
 from salt.exceptions import CommandExecutionError
-from salt.ext import six
-from tests.support.helpers import destructiveTest, random_string
+from tests.support.helpers import random_string
 from tests.support.mock import MagicMock, patch
 from tests.support.unit import TestCase, skipIf
 
@@ -19,9 +15,9 @@ except ImportError:
 
 UNICODE_KEY = "Unicode Key \N{TRADE MARK SIGN}"
 UNICODE_VALUE = (
-    "Unicode Value " "\N{COPYRIGHT SIGN},\N{TRADE MARK SIGN},\N{REGISTERED SIGN}"
+    "Unicode Value \N{COPYRIGHT SIGN},\N{TRADE MARK SIGN},\N{REGISTERED SIGN}"
 )
-FAKE_KEY = "SOFTWARE\\{0}".format(random_string("SaltTesting-", lowercase=False))
+FAKE_KEY = "SOFTWARE\\{}".format(random_string("SaltTesting-", lowercase=False))
 
 
 @skipIf(not HAS_WIN32, "Tests require win32 libraries")
@@ -193,7 +189,7 @@ class WinFunctionsTestCase(TestCase):
         """
         Test the list_keys function using a non existing registry key
         """
-        expected = (False, "Cannot find key: HKLM\\{0}".format(FAKE_KEY))
+        expected = (False, "Cannot find key: HKLM\\{}".format(FAKE_KEY))
         self.assertEqual(win_reg.list_keys(hive="HKLM", key=FAKE_KEY), expected)
 
     def test_list_keys_invalid_hive(self):
@@ -238,7 +234,7 @@ class WinFunctionsTestCase(TestCase):
         """
         Test the list_values function using a non existing registry key
         """
-        expected = (False, "Cannot find key: HKLM\\{0}".format(FAKE_KEY))
+        expected = (False, "Cannot find key: HKLM\\{}".format(FAKE_KEY))
         self.assertEqual(win_reg.list_values(hive="HKLM", key=FAKE_KEY), expected)
 
     def test_list_values_invalid_hive(self):
@@ -293,8 +289,10 @@ class WinFunctionsTestCase(TestCase):
         Test the read_value function using a non existing value pair
         """
         expected = {
-            "comment": "Cannot find fake_name in HKLM\\SOFTWARE\\Microsoft\\"
-            "Windows\\CurrentVersion",
+            "comment": (
+                "Cannot find fake_name in HKLM\\SOFTWARE\\Microsoft\\"
+                "Windows\\CurrentVersion"
+            ),
             "vdata": None,
             "vname": "fake_name",
             "success": False,
@@ -315,7 +313,7 @@ class WinFunctionsTestCase(TestCase):
         Test the read_value function using a non existing registry key
         """
         expected = {
-            "comment": "Cannot find key: HKLM\\{0}".format(FAKE_KEY),
+            "comment": "Cannot find key: HKLM\\{}".format(FAKE_KEY),
             "vdata": None,
             "vname": "fake_name",
             "success": False,
@@ -370,7 +368,7 @@ class WinFunctionsTestCase(TestCase):
                 vname="ProgramFilesPath",
             )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_read_value_multi_sz_empty_list(self):
         """
         An empty REG_MULTI_SZ value should return an empty list, not None
@@ -394,13 +392,17 @@ class WinFunctionsTestCase(TestCase):
                 "vtype": "REG_MULTI_SZ",
             }
             self.assertEqual(
-                win_reg.read_value(hive="HKLM", key=FAKE_KEY, vname="empty_list",),
+                win_reg.read_value(
+                    hive="HKLM",
+                    key=FAKE_KEY,
+                    vname="empty_list",
+                ),
                 expected,
             )
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_set_value(self):
         """
         Test the set_value function
@@ -426,7 +428,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_set_value_default(self):
         """
         Test the set_value function on the default value
@@ -447,7 +449,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_set_value_unicode_key(self):
         """
         Test the set_value function on a unicode key
@@ -480,7 +482,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_set_value_unicode_value(self):
         """
         Test the set_value function on a unicode value
@@ -506,7 +508,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_set_value_reg_dword(self):
         """
         Test the set_value function on a REG_DWORD value
@@ -536,7 +538,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_set_value_reg_qword(self):
         """
         Test the set_value function on a REG_QWORD value
@@ -639,15 +641,15 @@ class WinFunctionsTestCase(TestCase):
         """
         vdata = salt.utils.stringutils.to_bytes("test data")
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_BINARY")
-        self.assertTrue(isinstance(result, six.binary_type))
+        self.assertTrue(isinstance(result, bytes))
 
         vdata = salt.utils.stringutils.to_str("test data")
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_BINARY")
-        self.assertTrue(isinstance(result, six.binary_type))
+        self.assertTrue(isinstance(result, bytes))
 
         vdata = salt.utils.stringutils.to_unicode("test data")
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_BINARY")
-        self.assertTrue(isinstance(result, six.binary_type))
+        self.assertTrue(isinstance(result, bytes))
 
     def test_cast_vdata_reg_dword(self):
         """
@@ -674,11 +676,11 @@ class WinFunctionsTestCase(TestCase):
         """
         vdata = salt.utils.stringutils.to_str("test data")
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_EXPAND_SZ")
-        self.assertTrue(isinstance(result, six.text_type))
+        self.assertTrue(isinstance(result, str))
 
         vdata = salt.utils.stringutils.to_bytes("test data")
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_EXPAND_SZ")
-        self.assertTrue(isinstance(result, six.text_type))
+        self.assertTrue(isinstance(result, str))
 
     def test_cast_vdata_reg_multi_sz(self):
         """
@@ -692,7 +694,7 @@ class WinFunctionsTestCase(TestCase):
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_MULTI_SZ")
         self.assertTrue(isinstance(result, list))
         for item in result:
-            self.assertTrue(isinstance(item, six.text_type))
+            self.assertTrue(isinstance(item, str))
 
     def test_cast_vdata_reg_qword(self):
         """
@@ -702,21 +704,11 @@ class WinFunctionsTestCase(TestCase):
         """
         vdata = 1
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_QWORD")
-        if six.PY2:
-            # pylint: disable=incompatible-py3-code,undefined-variable
-            self.assertTrue(isinstance(result, long))
-            # pylint: enable=incompatible-py3-code,undefined-variable
-        else:
-            self.assertTrue(isinstance(result, int))
+        self.assertTrue(isinstance(result, int))
 
         vdata = "1"
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_QWORD")
-        if six.PY2:
-            # pylint: disable=incompatible-py3-code,undefined-variable
-            self.assertTrue(isinstance(result, long))
-            # pylint: enable=incompatible-py3-code,undefined-variable
-        else:
-            self.assertTrue(isinstance(result, int))
+        self.assertTrue(isinstance(result, int))
 
     def test_cast_vdata_reg_sz(self):
         """
@@ -725,18 +717,18 @@ class WinFunctionsTestCase(TestCase):
         """
         vdata = salt.utils.stringutils.to_str("test data")
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_SZ")
-        self.assertTrue(isinstance(result, six.text_type))
+        self.assertTrue(isinstance(result, str))
 
         vdata = salt.utils.stringutils.to_bytes("test data")
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_SZ")
-        self.assertTrue(isinstance(result, six.text_type))
+        self.assertTrue(isinstance(result, str))
 
         vdata = None
         result = win_reg.cast_vdata(vdata=vdata, vtype="REG_SZ")
-        self.assertTrue(isinstance(result, six.text_type))
+        self.assertTrue(isinstance(result, str))
         self.assertEqual(result, "")
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_delete_value(self):
         """
         Test the delete_value function
@@ -793,7 +785,7 @@ class WinFunctionsTestCase(TestCase):
                 vname="fake_name",
             )
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_delete_value_unicode(self):
         """
         Test the delete_value function on a unicode value
@@ -810,7 +802,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_delete_value_unicode_vname(self):
         """
         Test the delete_value function on a unicode vname
@@ -827,7 +819,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_delete_value_unicode_key(self):
         """
         Test the delete_value function on a unicode key
@@ -879,7 +871,7 @@ class WinFunctionsTestCase(TestCase):
         with patch("salt.utils.win_reg.key_exists", mock_true):
             self.assertFalse(win_reg.delete_key_recursive(hive="HKLM", key="FAKE_KEY"))
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_delete_key_recursive(self):
         """
         Test the delete_key_recursive function
@@ -897,7 +889,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_delete_key_recursive_failed_to_open_key(self):
         """
         Test the delete_key_recursive function on failure to open the key
@@ -928,7 +920,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_delete_key_recursive_failed_to_delete(self):
         """
         Test the delete_key_recursive function on failure to delete a key
@@ -953,7 +945,7 @@ class WinFunctionsTestCase(TestCase):
         finally:
             win_reg.delete_key_recursive(hive="HKLM", key=FAKE_KEY)
 
-    @destructiveTest
+    @pytest.mark.destructive_test
     def test_delete_key_recursive_unicode(self):
         """
         Test the delete_key_recursive function on value within a unicode key
@@ -985,14 +977,4 @@ class WinFunctionsTestCase(TestCase):
         Test the ``_to_unicode`` function when it receives an integer value.
         Should return a unicode value, which is unicode in PY2 and str in PY3.
         """
-        if six.PY3:
-            self.assertTrue(isinstance(win_reg._to_unicode(1), str))
-        else:
-            # fmt: off
-            self.assertTrue(
-                isinstance(
-                    win_reg._to_unicode(1),
-                    unicode,  # pylint: disable=incompatible-py3-code,undefined-variable
-                )
-            )
-            # fmt: on
+        self.assertTrue(isinstance(win_reg._to_unicode(1), str))
