@@ -1,12 +1,4 @@
-# -*- coding: utf-8 -*-
-
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import Salt Libs
 from salt.utils.validate import net
-
-# Import Salt Testing Libs
 from tests.support.unit import TestCase
 
 
